@@ -84,17 +84,6 @@ public class ClusterControlWorkbenchWindowAdvisor extends WorkbenchWindowAdvisor
 		// 起動時にログインダイアログを表示する。
 		// パースペクティブが何もない時に必ずこのルートを通る。
 		LoginManager.login();
-
-		// Clear stored perspective layouts if login failed or cancelled
-		if( !LoginManager.isLogin() ){
-			IWorkbenchWindow window = getWindowConfigurer().getWindow();
-			IWorkbenchPage page = window.getActivePage();
-			IPerspectiveRegistry pr = window.getWorkbench().getPerspectiveRegistry();
-
-			page.closeAllPerspectives( false, false );
-			page.setPerspective( pr.findPerspectiveWithId( StartUpPerspective.ID ) );
-			page.resetPerspective();
-		}
 	}
 
 	@Override
