@@ -19,7 +19,7 @@ import java.io.Serializable;
 
 /**
  * CommonTableViewerクラス用のテーブルカラム情報クラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 1.0.0
  */
@@ -71,9 +71,6 @@ public class TableColumnInfo implements Serializable {
 	/** ファシリティ名(データタイプの種別) */
 	public static final int FACILITY_NAME = 13;
 
-	/** 一括制御状態(データタイプの種別) */
-	public static final int CRUN_STATUS = 14;
-
 	/** チェックボックス(データタイプの種別) */
 	public static final int CHECKBOX = 15;
 
@@ -104,6 +101,11 @@ public class TableColumnInfo implements Serializable {
 	/** 収集状態 */
 	public static final int COLLECT_STATUS = 24;
 
+	/** マネージャ名 */
+	public static final int MANAGER_NAME = 25;
+
+	/** マネージャ名 */
+	public static final int DUMMY = 26;
 
 	/** カラム名 */
 	private String m_name = null;
@@ -122,7 +124,7 @@ public class TableColumnInfo implements Serializable {
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param name
 	 * @param type
 	 * @since 1.0.0
@@ -213,4 +215,4 @@ public class TableColumnInfo implements Serializable {
 	public void setOrder(int order) {
 		m_order = order;
 	}
-}
\ No newline at end of file
+}
