@@ -17,7 +17,7 @@ package com.clustercontrol.preference;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.eclipse.jface.dialogs.MessageDialog;
+import org.eclipse.jface.preference.BooleanFieldEditor;
 import org.eclipse.jface.preference.FieldEditorPreferencePage;
 import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.preference.IntegerFieldEditor;
@@ -30,37 +30,37 @@ import org.eclipse.ui.IWorkbench;
 import org.eclipse.ui.IWorkbenchPreferencePage;
 
 import com.clustercontrol.ClusterControlPlugin;
+import com.clustercontrol.accesscontrol.util.ClientSession;
 import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.util.EndpointManager;
 import com.clustercontrol.util.LoginManager;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.PasswordFieldEditor;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * アクセス機能の設定ページクラス<BR>
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
-public class ClusterControlCorePreferencePage extends FieldEditorPreferencePage
-implements IWorkbenchPreferencePage {
-
+public class ClusterControlCorePreferencePage extends FieldEditorPreferencePage implements IWorkbenchPreferencePage {
 	// ログ
 	private static Log m_log = LogFactory.getLog( ClusterControlCorePreferencePage.class );
 
-	/** EJB接続先URL */
-	public static final String EJB_URL = LoginManager.KEY_EJB_URL;
+	/** 接続先URL */
+	public static final String URL = LoginManager.KEY_URL;
 
-	/** EJB接続の死活監視間隔 */
+	/** 接続の死活監視間隔 */
 	public static final String KEY_INTERVAL = LoginManager.KEY_INTERVAL;
-	public static final String KEY_HTTP_CONNECT_TIMEOUT = LoginManager.KEY_HTTP_CONNECT_TIMEOUT;
 	public static final String KEY_HTTP_REQUEST_TIMEOUT = LoginManager.KEY_HTTP_REQUEST_TIMEOUT;
 	public static final int VALUE_INTERVAL_MAX = 60;
 	public static final int VALUE_INTERVAL_MIN = 1;
-	public static final int VALUE_HTTP_TIMEOUT_MAX = 600;
-	public static final int VALUE_HTTP_TIMEOUT_MIN = 1;
+	public static final int VALUE_HTTP_TIMEOUT_MAX = 600000; // ms = 600 s
+	public static final int VALUE_HTTP_TIMEOUT_MIN = 1; // ms = 1 s
 
 	/** Proxy */
+	public static final String KEY_PROXY_ENABLE = LoginManager.KEY_PROXY_ENABLE;
 	public static final String KEY_PROXY_HOST = LoginManager.KEY_PROXY_HOST;
 	public static final String KEY_PROXY_PORT = LoginManager.KEY_PROXY_PORT;
 	public static final String KEY_PROXY_USER = LoginManager.KEY_PROXY_USER;
@@ -68,25 +68,15 @@ implements IWorkbenchPreferencePage {
 	public static final int VALUE_PROXY_PORT_MAX = 65535;
 	public static final int VALUE_PROXY_PORT_MIN = 0;
 
-	/** HTTPS */
-	public static final String KEY_HTTPS_KEYSTORE_PATH = LoginManager.KEY_HTTPS_KEYSTORE_PATH;
-	public static final String KEY_HTTPS_KEYSTORE_PASSWORD = LoginManager.KEY_HTTPS_KEYSTORE_PASSWORD;
-
-	/** 接続先URL */
-	StringFieldEditor url = null;
-
 	/** 接続先チェック間隔 */
 	IntegerFieldEditor managerPollingInterval = null;
 
-	/** HTTPコネクトタイムアウト */
-	IntegerFieldEditor httpConnectTimeout = null;
-
-	/** HTTPコネクトタイムアウト */
+	/** HTTPリクエストタイムアウト */
 	IntegerFieldEditor httpRequestTimeout = null;
 
-	/** EJB接続先URL */
-	public static final String EJB_UID = LoginManager.KEY_EJB_UID;
-
+	/** Proxyを利用するか否か */
+	BooleanFieldEditor proxyEnable = null;
+	
 	/** Proxyホスト */
 	StringFieldEditor proxyHost = null;
 
@@ -106,13 +96,18 @@ implements IWorkbenchPreferencePage {
 	PasswordFieldEditor keyStorePassword = null;
 
 	/**
-	 * 初期値が設定されたインスタンスを返します。
+	 * Set style
 	 */
 	public ClusterControlCorePreferencePage() {
 		super(GRID);
-		this.setPreferenceStore(ClusterControlPlugin.getDefault()
-				.getPreferenceStore());
+	}
 
+	/**
+	 * 初期値が設定されたインスタンスを返します。
+	 */
+	@Override
+	public void init(IWorkbench workbench) {
+		setPreferenceStore(ClusterControlPlugin.getDefault().getPreferenceStore());
 	}
 
 	/**
@@ -124,6 +119,7 @@ implements IWorkbenchPreferencePage {
 		GridData gridData = null;
 		// 接続関連
 		Group group = new Group(parent, SWT.SHADOW_NONE);
+		WidgetTestUtil.setTestId(this, "group", group);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -133,11 +129,6 @@ implements IWorkbenchPreferencePage {
 
 		group.setText(Messages.getString("connection.setting"));
 
-		// 接続先URL
-		url = new StringFieldEditor(EJB_URL, Messages.getString("connection.url"), group);
-		url.setTextLimit(DataRangeConstant.VARCHAR_256);
-		this.addField(url);
-
 		// 接続死活間隔
 		managerPollingInterval = new IntegerFieldEditor(KEY_INTERVAL, Messages.getString("manager.polling.interval"), group);
 		managerPollingInterval.setValidRange(VALUE_INTERVAL_MIN, VALUE_INTERVAL_MAX);
@@ -148,13 +139,9 @@ implements IWorkbenchPreferencePage {
 		this.addField(managerPollingInterval);
 
 		// HTTPタイムアウト
-		httpConnectTimeout = new IntegerFieldEditor(KEY_HTTP_CONNECT_TIMEOUT, Messages.getString("connection.connect.timeout"), group);
-		httpConnectTimeout.setValidRange(VALUE_HTTP_TIMEOUT_MIN, VALUE_HTTP_TIMEOUT_MAX);
 		String[] args2 = {
 				Integer.toString(VALUE_HTTP_TIMEOUT_MIN),
 				Integer.toString(VALUE_HTTP_TIMEOUT_MAX) };
-		httpConnectTimeout.setErrorMessage(Messages.getString("message.hinemos.8", args2 ));
-		this.addField(httpConnectTimeout);
 		httpRequestTimeout = new IntegerFieldEditor(KEY_HTTP_REQUEST_TIMEOUT, Messages.getString("connection.request.timeout"), group);
 		httpRequestTimeout.setValidRange(VALUE_HTTP_TIMEOUT_MIN, VALUE_HTTP_TIMEOUT_MAX);
 		httpRequestTimeout.setErrorMessage(Messages.getString("message.hinemos.8", args2 ));
@@ -162,6 +149,7 @@ implements IWorkbenchPreferencePage {
 
 		// Proxy接続関連
 		Group proxyGroup = new Group(parent, SWT.SHADOW_NONE);
+		WidgetTestUtil.setTestId(this, "proxygroup", proxyGroup);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -171,6 +159,10 @@ implements IWorkbenchPreferencePage {
 
 		proxyGroup.setText(Messages.getString("proxy.connection.setting"));
 
+		// Proxy有効/無効
+		proxyEnable = new BooleanFieldEditor(KEY_PROXY_ENABLE, Messages.getString("proxy.connection.enable"), proxyGroup);
+		this.addField(proxyEnable);
+
 		// Proxyホスト
 		proxyHost = new StringFieldEditor(KEY_PROXY_HOST, Messages.getString("proxy.connection.host"), proxyGroup);
 		proxyHost.setTextLimit(DataRangeConstant.VARCHAR_256);
@@ -195,73 +187,31 @@ implements IWorkbenchPreferencePage {
 		proxyPassword.setTextLimit(DataRangeConstant.VARCHAR_256);
 		this.addField(proxyPassword);
 
-		// HTTPS接続関連
-		Group httpsGroup = new Group(parent, SWT.SHADOW_NONE);
-		gridData = new GridData();
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		gridData.horizontalSpan = 10;
-		gridData.verticalSpan = 10;
-		httpsGroup.setLayoutData(gridData);
-
-		httpsGroup.setText(Messages.getString("https.connection.setting"));
-
-		// HTTPSキーストアパス
-		keyStorePath = new StringFieldEditor(KEY_HTTPS_KEYSTORE_PATH, Messages.getString("https.connection.keystore.path"), httpsGroup);
-		keyStorePath.setTextLimit(DataRangeConstant.VARCHAR_256);
-		this.addField(keyStorePath);
-
-		// HTTPSキーストアパスワード
-		keyStorePassword = new PasswordFieldEditor(KEY_HTTPS_KEYSTORE_PASSWORD, Messages.getString("https.connection.keystore.password"), httpsGroup);
-		keyStorePassword.setTextLimit(DataRangeConstant.VARCHAR_256);
-		this.addField(keyStorePassword);
 	}
 
 	/*
 	 * (non-Javadoc)
-	 * 
+	 *
 	 * @see org.eclipse.jface.preference.IPreferencePage#performOk()
 	 */
 	@Override
 	public boolean performOk() {
-		//m_log.debug("ClusterControlCorePreferencePage.performOk() start");
-
-		String urlStr = url.getStringValue();
-		// 接続先URLの書式確認
-		if (urlStr.length() == 0 ||
-				!(urlStr.startsWith("http://") || urlStr.startsWith("https://"))){
-			//エラーメッセージ
-			MessageDialog.openWarning(
-					null,
-					Messages.getString("message.hinemos.1"),
-					Messages.getString("message.hinemos.9"));
-			return false;
-		}
+		m_log.trace("ClusterControlCorePreferencePage.performOk() start");
 
 		// 接続死活間隔の更新
-		LoginManager.restartChecktask(managerPollingInterval.getIntValue());
+		ClientSession.restartChecktask(managerPollingInterval.getIntValue());
 
 		// JAX-WSタイムアウト値の更新
-		EndpointManager.m_httpConnectTimeout = httpConnectTimeout.getIntValue();
-		EndpointManager.m_httpRequestTimeout = httpRequestTimeout.getIntValue();
-		m_log.info("connect.timeout=" + EndpointManager.m_httpConnectTimeout + ", request.timeout=" + EndpointManager.m_httpRequestTimeout);
+		EndpointManager.setHttpRequestTimeout( httpRequestTimeout.getIntValue() );
+		m_log.info("request.timeout=" + EndpointManager.getHttpRequestTimeout());
 
 		boolean result = super.performOk();
 
 		//セッションに接続先URLを格納
 		IPreferenceStore store = this.getPreferenceStore();
-		store.getString(EJB_URL);
+		store.getString(URL);
 
+		LoginManager.setup();
 		return result;
 	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.eclipse.ui.IWorkbenchPreferencePage#init(org.eclipse.ui.IWorkbench)
-	 */
-	@Override
-	public void init(IWorkbench workbench) {
-
-	}
-}
\ No newline at end of file
+}
