@@ -4,16 +4,21 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import org.eclipse.rap.rwt.SingletonUtil;
 
 import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.ws.repository.FacilityInfo;
 import com.clustercontrol.ws.repository.FacilityTreeItem;
 
 public class FacilityTreeItemUtil {
-	private static Log m_log = LogFactory.getLog( FacilityTreeItemUtil.class );
 
+	/**
+	 * Session Singleton
+	 */
+	private static FacilityTreeItemUtil getInstance(){
+		return SingletonUtil.getSessionInstance( FacilityTreeItemUtil.class );
+	}
+	
 	/**
 	 * ツリーのディープコピーを生成して返します
 	 * 
@@ -21,57 +26,59 @@ public class FacilityTreeItemUtil {
 	 * @throws IOException
 	 * @throws ClassNotFoundException
 	 */
-	public static synchronized FacilityTreeItem deepCopy(FacilityTreeItem item, FacilityTreeItem parentItem) {
+	public static FacilityTreeItem deepCopy(FacilityTreeItem item, FacilityTreeItem parentItem) {
+		synchronized(getInstance()) {
 		FacilityTreeItem resultItem = new FacilityTreeItem();
-		if (item.getData() != null) {
-			FacilityInfo resultData = new FacilityInfo();
-			if (item.getData().isBuiltInFlg() != null) {
-				resultData.setBuiltInFlg(new Boolean(item.getData().isBuiltInFlg()));
-			}
-			if (item.getData().getCreateDatetime() != null) {
-				resultData.setCreateDatetime(new Long(item.getData().getCreateDatetime()));
-			}
-			resultData.setCreateUserId(item.getData().getCreateUserId());
-			resultData.setDescription(item.getData().getDescription());
-			if (item.getData().getDisplaySortOrder() != null) {
-				resultData.setDisplaySortOrder(new Integer(item.getData().getDisplaySortOrder()));
-			}
-			resultData.setFacilityId(item.getData().getFacilityId());
-			resultData.setFacilityName(item.getData().getFacilityName());
-			if (item.getData().getFacilityType() != null) {
-				resultData.setFacilityType(new Integer(item.getData().getFacilityType()));
-			}
-			if (item.getData().getModifyDatetime() != null) {
-				resultData.setModifyDatetime(new Long(item.getData().getModifyDatetime()));
-			}
-			resultData.setModifyUserId(item.getData().getModifyUserId());
-			if (item.getData().isValid() != null) {
-				resultData.setValid(new Boolean(item.getData().isValid()));
-			}
-			resultData.setOwnerRoleId(item.getData().getOwnerRoleId());
-			if (item.getData().isNotReferFlg() != null) {
-				resultData.setNotReferFlg(new Boolean(item.getData().isNotReferFlg()));
-			}
-			resultItem.setData(resultData);
-		}
-
-		if (item.getChildren() != null) {
-			List<FacilityTreeItem> resultChildren = new ArrayList<FacilityTreeItem>();
-			for(FacilityTreeItem child : item.getChildren()) {
-				if (child != null) {
-					FacilityTreeItem resultChild = deepCopy(child, resultItem);
-					resultChildren.add(resultChild);
-				} else {
-					resultChildren.add(null);
+			if (item.getData() != null) {
+				FacilityInfo resultData = new FacilityInfo();
+				if (item.getData().isBuiltInFlg() != null) {
+					resultData.setBuiltInFlg(new Boolean(item.getData().isBuiltInFlg()));
 				}
+				if (item.getData().getCreateDatetime() != null) {
+					resultData.setCreateDatetime(new Long(item.getData().getCreateDatetime()));
+				}
+				resultData.setCreateUserId(item.getData().getCreateUserId());
+				resultData.setDescription(item.getData().getDescription());
+				if (item.getData().getDisplaySortOrder() != null) {
+					resultData.setDisplaySortOrder(new Integer(item.getData().getDisplaySortOrder()));
+				}
+				resultData.setFacilityId(item.getData().getFacilityId());
+				resultData.setFacilityName(item.getData().getFacilityName());
+				if (item.getData().getFacilityType() != null) {
+					resultData.setFacilityType(new Integer(item.getData().getFacilityType()));
+				}
+				if (item.getData().getModifyDatetime() != null) {
+					resultData.setModifyDatetime(new Long(item.getData().getModifyDatetime()));
+				}
+				resultData.setModifyUserId(item.getData().getModifyUserId());
+				if (item.getData().isValid() != null) {
+					resultData.setValid(new Boolean(item.getData().isValid()));
+				}
+				resultData.setOwnerRoleId(item.getData().getOwnerRoleId());
+				if (item.getData().isNotReferFlg() != null) {
+					resultData.setNotReferFlg(new Boolean(item.getData().isNotReferFlg()));
+				}
+				resultItem.setData(resultData);
 			}
-			resultItem.getChildren().clear();
-			resultItem.getChildren().addAll(resultChildren);
-		} else {
-			resultItem.getChildren().clear();
+	
+			if (item.getChildren() != null) {
+				List<FacilityTreeItem> resultChildren = new ArrayList<FacilityTreeItem>();
+				for(FacilityTreeItem child : item.getChildren()) {
+					if (child != null) {
+						FacilityTreeItem resultChild = deepCopy(child, resultItem);
+						resultChildren.add(resultChild);
+					} else {
+						resultChildren.add(null);
+					}
+				}
+				resultItem.getChildren().clear();
+				resultItem.getChildren().addAll(resultChildren);
+			} else {
+				resultItem.getChildren().clear();
+			}
+			resultItem.setParent(parentItem);
+			return resultItem;
 		}
-		resultItem.setParent(parentItem);
-		return resultItem;
 	}
 
 	/**
