@@ -35,7 +35,7 @@ public class CommonTableContentProvider implements IStructuredContentProvider {
 	 */
 	@Override
 	public Object[] getElements(Object inputElement) {
-		return ((List) inputElement).toArray();
+		return ((List<?>) inputElement).toArray();
 	}
 
 	/*
@@ -57,4 +57,4 @@ public class CommonTableContentProvider implements IStructuredContentProvider {
 	@Override
 	public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
 	}
-}
\ No newline at end of file
+}
