@@ -16,7 +16,6 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.accesscontrol.dialog;
 
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashMap;
@@ -37,14 +36,11 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.List;
 import org.eclipse.swt.widgets.Shell;
 
-import com.clustercontrol.accesscontrol.action.CheckPermission;
-import com.clustercontrol.accesscontrol.bean.FunctionConstant;
-import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.SystemPrivilegeMode;
 import com.clustercontrol.accesscontrol.util.AccessEndpointWrapper;
-import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.ws.access.InvalidRole_Exception;
 import com.clustercontrol.ws.access.RoleInfo;
 import com.clustercontrol.ws.access.UnEditableRole_Exception;
@@ -53,7 +49,7 @@ import com.clustercontrol.ws.access.UserInfo;
 
 /**
  * アカウント[ユーザの選択]ダイアログクラスです。
- * 
+ *
  * @version 4.1.0
  * @since 4.1.0
  */
@@ -65,8 +61,8 @@ public class RoleSettingDialog extends CommonDialog {
 	/** ロールID */
 	private String roleId = "";
 
-	/** モード */
-	private int mode = 0;
+	/** マネージャ名 */
+	private String managerName = "";
 
 	/** 全ユーザ一覧　リストボックス */
 	private List listNotRoleUser = null;
@@ -94,33 +90,28 @@ public class RoleSettingDialog extends CommonDialog {
 
 	/** 全ユーザ一覧の表示名をキーとし、ユーザIDを格納しているハッシュマップ */
 	private HashMap<String, String> mapNotRoleUser = null;
-	
+
 	/** 所属ユーザ一覧の表示名をキーとし、ユーザIDを格納しているハッシュマップ */
 	private HashMap<String, String> mapRoleUser = null;
-	
-	private boolean permission = false;		// 現在のユーザが変更権限をもつか否か
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param parent 親シェル
+	 * @paramn managerName マネージャ名
 	 * @param uid ユーザID
 	 */
-	public RoleSettingDialog(Shell parent, String roleId) {
+	public RoleSettingDialog(Shell parent, String managerName, String roleId) {
 		super(parent);
-
+		this.managerName = managerName;
 		this.roleId = roleId;
-
-		// 現在のユーザがアカウント機能の設定権限をもつか否かを取得する
-		permission = new CheckPermission().check(FunctionConstant.ACCESSCONTROL, SystemPrivilegeMode.WRITE);
-
 	}
 
 	/**
 	 * ダイアログの初期サイズを返します。
-	 * 
+	 *
 	 * @return 初期サイズ
-	 * 
+	 *
 	 * @see org.eclipse.jface.window.Window#getInitialSize()
 	 */
 	@Override
@@ -130,9 +121,9 @@ public class RoleSettingDialog extends CommonDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親コンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#customizeDialog(org.eclipse.swt.widgets.Composite)
 	 */
 	@Override
@@ -143,17 +134,11 @@ public class RoleSettingDialog extends CommonDialog {
 		shell.setText(Messages
 				.getString("dialog.accesscontrol.role.setting"));
 
-		// プロパティの取得及び設定
-		if (permission) {
-			this.mode = PropertyDefineConstant.MODE_MODIFY;
-		} else {
-			this.mode = PropertyDefineConstant.MODE_SHOW;
-		}
-
 		// ロール情報の取得
 		RoleInfo info = null;
 		try {
-			info = AccessEndpointWrapper.getRoleInfo(this.roleId);
+			AccessEndpointWrapper wrapper = AccessEndpointWrapper.getWrapper(this.managerName);
+			info = wrapper.getRoleInfo(this.roleId);
 		} catch (InvalidRole_Exception e) {
 			MessageDialog.openInformation(null, Messages.getString("message"),
 					Messages.getString("message.accesscontrol.16"));
@@ -177,6 +162,7 @@ public class RoleSettingDialog extends CommonDialog {
 		 */
 		// ラベル
 		Label label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "role", label);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -188,6 +174,8 @@ public class RoleSettingDialog extends CommonDialog {
 		 * 全ユーザ用一覧用コンポジット
 		 */
 		Composite compositeNotRole = new Composite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "all", compositeNotRole);
+
 		layout = new GridLayout(1, true);
 		layout.numColumns = 1;
 		compositeNotRole.setLayout(layout);
@@ -202,6 +190,7 @@ public class RoleSettingDialog extends CommonDialog {
 
 		// 全ユーザ一覧 ラベル
 		label = new Label(compositeNotRole, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "alluserlist", label);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -210,12 +199,13 @@ public class RoleSettingDialog extends CommonDialog {
 
 		// 全ユーザ一覧 リスト
 		this.listNotRoleUser = new List(compositeNotRole, SWT.MULTI | SWT.BORDER | SWT.V_SCROLL);
+		WidgetTestUtil.setTestId(this, "all", compositeNotRole);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		gridData.heightHint = this.listNotRoleUser.getItemHeight() * 12;
 		this.listNotRoleUser.setLayoutData(gridData);
-		
+
 		// 全ユーザ一覧 ハッシュマップ
 		this.mapNotRoleUser = new HashMap<String, String>();
 
@@ -223,6 +213,7 @@ public class RoleSettingDialog extends CommonDialog {
 		 * 操作ボタン用コンポジット
 		 */
 		Composite compositeButton = new Composite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "composite", compositeButton);
 		layout = new GridLayout(1, true);
 		layout.numColumns = 1;
 		compositeButton.setLayout(layout);
@@ -236,6 +227,7 @@ public class RoleSettingDialog extends CommonDialog {
 
 		// 空
 		label = new Label(compositeButton, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "blank1", label);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -244,7 +236,9 @@ public class RoleSettingDialog extends CommonDialog {
 		// 所属ボタン
 		@SuppressWarnings("unused")
 		Label dummy = new Label(compositeButton, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "dummy", dummy);
 		this.buttonRoleUser = this.createButton(compositeButton, Messages.getString("RoleSettingDialog.role_user_button"));
+		WidgetTestUtil.setTestId(this, "assign", buttonRoleUser);
 		this.buttonRoleUser.addSelectionListener(new SelectionAdapter()
 		{
 			@Override
@@ -253,7 +247,7 @@ public class RoleSettingDialog extends CommonDialog {
 				for (String item : items) {
 					listNotRoleUser.remove(item);
 					listRoleUser.add(item);
-					
+
 					// 表示名をキーとしたユーザIDのHashMapを内容の遷移に合わせて移動
 					mapRoleUser.put(item, mapNotRoleUser.get(item));
 					mapNotRoleUser.remove(item);
@@ -263,7 +257,9 @@ public class RoleSettingDialog extends CommonDialog {
 
 		// 所属解除ボタン
 		dummy = new Label(compositeButton, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "unassign", dummy);
 		this.buttonNotRoleUser = this.createButton(compositeButton, Messages.getString("RoleSettingDialog.not_role_user_button"));
+		WidgetTestUtil.setTestId(this, "unassign", buttonNotRoleUser);
 		this.buttonNotRoleUser.addSelectionListener(new SelectionAdapter()
 		{
 			@Override
@@ -272,7 +268,7 @@ public class RoleSettingDialog extends CommonDialog {
 				for (String item : items) {
 					listRoleUser.remove(item);
 					listNotRoleUser.add(item);
-					
+
 					// 表示名をキーとしたユーザIDのHashMapを内容の遷移に合わせて移動
 					mapNotRoleUser.put(item, mapRoleUser.get(item));
 					mapRoleUser.remove(item);
@@ -282,6 +278,7 @@ public class RoleSettingDialog extends CommonDialog {
 
 		// 空
 		label = new Label(compositeButton, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "blank", label);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -291,6 +288,7 @@ public class RoleSettingDialog extends CommonDialog {
 		 * 所属ユーザ用一覧用コンポジット
 		 */
 		Composite compositeRole = new Composite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "role", compositeRole);
 		layout = new GridLayout(1, true);
 		layout.numColumns = 1;
 		compositeRole.setLayout(layout);
@@ -305,6 +303,7 @@ public class RoleSettingDialog extends CommonDialog {
 
 		// 所属ユーザ一覧 ラベル
 		label = new Label(compositeRole, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "userlist", label);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -313,12 +312,13 @@ public class RoleSettingDialog extends CommonDialog {
 
 		// 所属ユーザ一覧 リスト
 		this.listRoleUser = new List(compositeRole, SWT.MULTI | SWT.BORDER | SWT.V_SCROLL);
+		WidgetTestUtil.setTestId(this, "roleuserlist", listRoleUser);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		gridData.heightHint = this.listRoleUser.getItemHeight() * 12;
 		this.listRoleUser.setLayoutData(gridData);
-		
+
 		// 所属ユーザ一覧 ハッシュマップ
 		this.mapRoleUser = new HashMap<String, String>();
 
@@ -332,14 +332,14 @@ public class RoleSettingDialog extends CommonDialog {
 		shell.setLocation((display.getBounds().width - shell.getSize().x) / 2,
 				(display.getBounds().height - shell.getSize().y) / 2);
 
-		this.setInputData(info);
+		this.setInputData(this.managerName, info);
 	}
 
 	/**
 	 * 入力値チェックをします。
-	 * 
+	 *
 	 * @return 検証結果
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#validate()
 	 */
 	@Override
@@ -356,9 +356,9 @@ public class RoleSettingDialog extends CommonDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -371,14 +371,16 @@ public class RoleSettingDialog extends CommonDialog {
 		}
 
 		try {
-			AccessEndpointWrapper.assignUserRole(roleInfo.getId(), roleInfo.getUserList());
+			AccessEndpointWrapper wrapper = AccessEndpointWrapper.getWrapper(managerName);
+			wrapper.assignUserRole(roleInfo.getId(), roleInfo.getUserList());
 			result = true;
 
+			Object[] arg = {managerName};
 			// 完了メッセージ
 			MessageDialog.openInformation(
 					null,
 					Messages.getString("successful"),
-					Messages.getString("message.accesscontrol.34"));
+					Messages.getString("message.accesscontrol.34", arg));
 
 		} catch (UserDuplicate_Exception e) {
 			//ロールID取得
@@ -415,10 +417,10 @@ public class RoleSettingDialog extends CommonDialog {
 
 	/**
 	 * ロール用プロパティを設定します。
-	 * 
+	 *
 	 * @param roleInfo 設定値として用いるロール情報
 	 */
-	protected void setInputData(RoleInfo roleInfo) {
+	protected void setInputData(String managerName, RoleInfo roleInfo) {
 
 		this.inputData = roleInfo;
 
@@ -427,7 +429,8 @@ public class RoleSettingDialog extends CommonDialog {
 		java.util.List<UserInfo> allUserList = null;
 		// 全ユーザを取得
 		try {
-			allUserList = AccessEndpointWrapper.getUserInfoList();
+			AccessEndpointWrapper wrapper = AccessEndpointWrapper.getWrapper(managerName);
+			allUserList = wrapper.getUserInfoList();
 			//昇順ソート
 			Collections.sort(allUserList, new Comparator<UserInfo>(){
 				@Override
@@ -452,10 +455,10 @@ public class RoleSettingDialog extends CommonDialog {
 		// リストを振り分ける
 		String listName = null;
 		for (UserInfo userInfo : allUserList) {
-			
+
 			//リストの表示名を生成する
 			listName = userInfo.getName() + "(" + userInfo.getId() + ")";
-			
+
 			if (roleInfo.getUserList().contains(userInfo.getId())) {
 				this.listRoleUser.add(listName);
 				this.mapRoleUser.put(listName, userInfo.getId());
@@ -469,7 +472,7 @@ public class RoleSettingDialog extends CommonDialog {
 	/**
 	 * 入力値を設定したロール情報を返します。<BR>
 	 * 入力値チェックを行い、不正な場合は<code>null</code>を返します。
-	 * 
+	 *
 	 * @return ロール情報
 	 */
 	private RoleInfo createInputData() {
@@ -492,7 +495,7 @@ public class RoleSettingDialog extends CommonDialog {
 
 	/**
 	 * ＯＫボタンのテキストを返します。
-	 * 
+	 *
 	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
@@ -502,7 +505,7 @@ public class RoleSettingDialog extends CommonDialog {
 
 	/**
 	 * キャンセルボタンのテキストを返します。
-	 * 
+	 *
 	 * @return キャンセルボタンのテキスト
 	 */
 	@Override
@@ -512,7 +515,7 @@ public class RoleSettingDialog extends CommonDialog {
 
 	/**
 	 * 共通のボタンを生成します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のコンポジット
 	 * @param label
@@ -521,6 +524,7 @@ public class RoleSettingDialog extends CommonDialog {
 	 */
 	private Button createButton(Composite parent, String label) {
 		Button button = new Button(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, button);
 
 		GridData gridData = new GridData(GridData.FILL_HORIZONTAL);
 		gridData.horizontalAlignment = GridData.FILL;
@@ -534,7 +538,7 @@ public class RoleSettingDialog extends CommonDialog {
 
 	/**
 	 * 表示名をキーとしたハッシュマップからユーザIDのリストを返す
-	 * 
+	 *
 	 * @param userMap HashMap
 	 * @return ユーザIDのリスト
 	 */
@@ -545,5 +549,5 @@ public class RoleSettingDialog extends CommonDialog {
 		}
 		return resultList;
 	}
-	
-}
\ No newline at end of file
+
+}
