@@ -17,7 +17,10 @@ package com.clustercontrol.accesscontrol.dialog;
 
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
+import java.util.HashMap;
 import java.util.Locale;
+import java.util.Map;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
@@ -37,15 +40,13 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.List;
 import org.eclipse.swt.widgets.Shell;
 
-import com.clustercontrol.accesscontrol.action.CheckPermission;
-import com.clustercontrol.accesscontrol.bean.FunctionConstant;
 import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.SystemPrivilegeMode;
 import com.clustercontrol.accesscontrol.util.AccessEndpointWrapper;
 import com.clustercontrol.accesscontrol.util.SystemPrivilegePropertyUtil;
-import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.ws.access.InvalidRole_Exception;
 import com.clustercontrol.ws.access.InvalidSetting_Exception;
 import com.clustercontrol.ws.access.RoleInfo;
@@ -55,7 +56,7 @@ import com.clustercontrol.ws.access.UserDuplicate_Exception;
 
 /**
  * アカウント[システム権限設定]ダイアログクラスです。
- * 
+ *
  * @version 4.0.0
  * @since 2.0.0
  */
@@ -64,12 +65,12 @@ public class SystemPrivilegeDialog extends CommonDialog {
 	// ログ
 	private static Log m_log = LogFactory.getLog( SystemPrivilegeDialog.class );
 
+	/**　マネージャ名 */
+	private String managerName = "";
+
 	/** ロールID */
 	private String roleId = "";
 
-	/** モード */
-	private int mode = 0;
-
 	/** 全システム権限一覧　リストボックス */
 	private List listNotRoleSystemPrivilege = null;
 
@@ -82,6 +83,12 @@ public class SystemPrivilegeDialog extends CommonDialog {
 	/** 権限解除　ボタン */
 	private Button buttonNotRoleSystemPrivilege = null;
 
+	/** ソート（権限）　ボタン */
+	private Button buttonSortRole = null;
+
+	/** ソート（機能）　ボタン */
+	private Button buttonSortFunction = null;
+
 	/** カラム数 */
 	public static final int WIDTH	 = 15;
 
@@ -94,29 +101,25 @@ public class SystemPrivilegeDialog extends CommonDialog {
 	/** 入力値を保持するオブジェクト。 */
 	private RoleInfo inputData = null;
 
-	private boolean permission = false;		// 現在のユーザが変更権限をもつか否か
-
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param parent 親シェル
+	 * @param managerName マネージャ名
 	 * @param uid ユーザID
 	 */
-	public SystemPrivilegeDialog(Shell parent, String roleId) {
+	public SystemPrivilegeDialog(Shell parent, String managerName, String roleId) {
 		super(parent);
 
+		this.managerName = managerName;
 		this.roleId = roleId;
-
-		// 現在のユーザがアカウント機能の設定権限をもつか否かを取得する
-		permission = new CheckPermission().check(FunctionConstant.ACCESSCONTROL, SystemPrivilegeMode.WRITE);
-
 	}
 
 	/**
 	 * ダイアログの初期サイズを返します。
-	 * 
+	 *
 	 * @return 初期サイズ
-	 * 
+	 *
 	 * @see org.eclipse.jface.window.Window#getInitialSize()
 	 */
 	@Override
@@ -124,11 +127,43 @@ public class SystemPrivilegeDialog extends CommonDialog {
 		return new Point(600, 600);
 	}
 
+	/**
+	 * 権限又は機能で、ソートする。
+	 */
+	public List sortFunctionPrivilege(List sortItem, Boolean sortOrder) {
+		String[] items = sortItem.getItems();
+		String keyValue = null;
+		Map<String, String> keys_Map = new HashMap<String, String>();
+		ArrayList<String> item_keys = new ArrayList<String>();
+		//itemから、KEYを生成して、テーブルにソート優先順位の指定別に格納
+		for (String value : items) {
+			//画面表示の文言別に、KEY用のKEY項目を作成する。
+			keyValue = SystemPrivilegePropertyUtil.getFunctionPrivilege(value);
+			String func = SystemPrivilegePropertyUtil.getSystemPrivilegeInfo(keyValue).getSystemFunction();
+			String priv = SystemPrivilegePropertyUtil.getSystemPrivilegeInfo(keyValue).getSystemPrivilege();
+			String key = "";
+			if (sortOrder) {
+				key = func + priv;
+			} else {
+				key = priv + func;
+			}
+			item_keys.add(key);
+			keys_Map.put(key, value);
+		}
+		Collections.sort(item_keys);
+		sortItem.removeAll();
+		//sort済のKEY情報順に、mapから情報をitemに設定する。
+		for (String sortKey : item_keys) {
+			sortItem.add(keys_Map.get(sortKey));
+		}
+		return sortItem;
+	}
+
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親コンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#customizeDialog(org.eclipse.swt.widgets.Composite)
 	 */
 	@Override
@@ -139,17 +174,11 @@ public class SystemPrivilegeDialog extends CommonDialog {
 		shell.setText(Messages
 				.getString("dialog.accesscontrol.system.privilege.setting"));
 
-		// プロパティの取得及び設定
-		if (permission) {
-			this.mode = PropertyDefineConstant.MODE_MODIFY;
-		} else {
-			this.mode = PropertyDefineConstant.MODE_SHOW;
-		}
-
 		// ロール情報の取得
 		RoleInfo info = null;
 		try {
-			info = AccessEndpointWrapper.getRoleInfo(this.roleId);
+			AccessEndpointWrapper wrapper = AccessEndpointWrapper.getWrapper(this.managerName);
+			info = wrapper.getRoleInfo(this.roleId);
 		} catch (InvalidRole_Exception e) {
 			MessageDialog.openInformation(null, Messages.getString("message"),
 					Messages.getString("message.accesscontrol.16"));
@@ -173,6 +202,7 @@ public class SystemPrivilegeDialog extends CommonDialog {
 		 */
 		// ラベル
 		Label label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, label);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -184,6 +214,7 @@ public class SystemPrivilegeDialog extends CommonDialog {
 		 * 全システム権限一覧用コンポジット
 		 */
 		Composite compositeNotRole = new Composite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "all", compositeNotRole);
 		layout = new GridLayout(1, true);
 		layout.numColumns = 1;
 		compositeNotRole.setLayout(layout);
@@ -198,6 +229,7 @@ public class SystemPrivilegeDialog extends CommonDialog {
 
 		// 全システム権限一覧 ラベル
 		label = new Label(compositeNotRole, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "systemprivilegelist", label);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -206,6 +238,7 @@ public class SystemPrivilegeDialog extends CommonDialog {
 
 		// 全システム権限一覧 リスト
 		this.listNotRoleSystemPrivilege = new List(compositeNotRole, SWT.MULTI | SWT.BORDER | SWT.V_SCROLL);
+		WidgetTestUtil.setTestId(this, "all", listNotRoleSystemPrivilege);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -216,6 +249,7 @@ public class SystemPrivilegeDialog extends CommonDialog {
 		 * 操作ボタン用コンポジット
 		 */
 		Composite compositeButton = new Composite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "button", compositeButton);
 		layout = new GridLayout(1, true);
 		layout.numColumns = 1;
 		compositeButton.setLayout(layout);
@@ -229,6 +263,7 @@ public class SystemPrivilegeDialog extends CommonDialog {
 
 		// 空
 		label = new Label(compositeButton, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "blank", label);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -237,7 +272,9 @@ public class SystemPrivilegeDialog extends CommonDialog {
 		// 権限付与ボタン
 		@SuppressWarnings("unused")
 		Label dummy = new Label(compositeButton, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "dummy", dummy);
 		this.buttonRoleSystemPrivilege = this.createButton(compositeButton, Messages.getString("SystemPrivilegeDialog.role_system_privilege_button"));
+		WidgetTestUtil.setTestId(this, "assign", buttonRoleSystemPrivilege);
 		this.buttonRoleSystemPrivilege.addSelectionListener(new SelectionAdapter()
 		{
 			@Override
@@ -252,7 +289,9 @@ public class SystemPrivilegeDialog extends CommonDialog {
 
 		// 権限解除ボタン
 		dummy = new Label(compositeButton, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "notrolesystemprivilege", dummy);
 		this.buttonNotRoleSystemPrivilege = this.createButton(compositeButton, Messages.getString("SystemPrivilegeDialog.not_role_system_privilege_button"));
+		WidgetTestUtil.setTestId(this, "unassign", buttonNotRoleSystemPrivilege);
 		this.buttonNotRoleSystemPrivilege.addSelectionListener(new SelectionAdapter()
 		{
 			@Override
@@ -265,8 +304,37 @@ public class SystemPrivilegeDialog extends CommonDialog {
 			}
 		});
 
+		// ソート（機能）ボタン
+		dummy = new Label(compositeButton, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "buttonsortfunction", dummy);
+		this.buttonSortFunction = this.createButton(compositeButton, Messages.getString("SystemPrivilegeDialog.sort_function_button"));
+		WidgetTestUtil.setTestId(this, "sortfunction", buttonSortFunction);
+		this.buttonSortFunction.addSelectionListener(new SelectionAdapter()
+		{
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				listRoleSystemPrivilege = sortFunctionPrivilege(listRoleSystemPrivilege, true);
+				listNotRoleSystemPrivilege = sortFunctionPrivilege(listNotRoleSystemPrivilege, true);
+			}
+		});
+
+		// ソート（権限）ボタン
+		dummy = new Label(compositeButton, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "buttonsortrole", dummy);
+		this.buttonSortRole = this.createButton(compositeButton, Messages.getString("SystemPrivilegeDialog.sort_privilege_button"));
+		WidgetTestUtil.setTestId(this, "sortrole", buttonSortRole);
+		this.buttonSortRole.addSelectionListener(new SelectionAdapter()
+		{
+			@Override
+			public void widgetSelected(SelectionEvent e) {
+				listRoleSystemPrivilege = sortFunctionPrivilege(listRoleSystemPrivilege, false);
+				listNotRoleSystemPrivilege = sortFunctionPrivilege(listNotRoleSystemPrivilege, false);
+			}
+		});
+
 		// 空
 		label = new Label(compositeButton, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, label);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -276,6 +344,7 @@ public class SystemPrivilegeDialog extends CommonDialog {
 		 * 付与システム権限一覧用コンポジット
 		 */
 		Composite compositeRole = new Composite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, compositeRole);
 		layout = new GridLayout(1, true);
 		layout.numColumns = 1;
 		compositeRole.setLayout(layout);
@@ -290,6 +359,7 @@ public class SystemPrivilegeDialog extends CommonDialog {
 
 		// 付与システム権限一覧 ラベル
 		label = new Label(compositeRole, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "systemprivilege", label);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -298,6 +368,7 @@ public class SystemPrivilegeDialog extends CommonDialog {
 
 		// 付与システム権限一覧 リスト
 		this.listRoleSystemPrivilege = new List(compositeRole, SWT.MULTI | SWT.BORDER | SWT.V_SCROLL);
+		WidgetTestUtil.setTestId(this, null, listRoleSystemPrivilege);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
@@ -314,14 +385,14 @@ public class SystemPrivilegeDialog extends CommonDialog {
 		shell.setLocation((display.getBounds().width - shell.getSize().x) / 2,
 				(display.getBounds().height - shell.getSize().y) / 2);
 
-		this.setInputData(info);
+		this.setInputData(this.managerName, info);
 	}
 
 	/**
 	 * 入力値チェックをします。
-	 * 
+	 *
 	 * @return 検証結果
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#validate()
 	 */
 	@Override
@@ -338,9 +409,9 @@ public class SystemPrivilegeDialog extends CommonDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -353,14 +424,16 @@ public class SystemPrivilegeDialog extends CommonDialog {
 		}
 
 		try {
-			AccessEndpointWrapper.replaceSystemPrivilegeRole(this.roleId, roleInfo.getSystemPrivilegeList());
+			AccessEndpointWrapper wrapper = AccessEndpointWrapper.getWrapper(this.managerName);
+			wrapper.replaceSystemPrivilegeRole(this.roleId, roleInfo.getSystemPrivilegeList());
 			result = true;
 
+			Object[] arg = {this.managerName};
 			// 完了メッセージ
 			MessageDialog.openInformation(
 					null,
 					Messages.getString("successful"),
-					Messages.getString("message.accesscontrol.47"));
+					Messages.getString("message.accesscontrol.47", arg));
 
 		} catch (UserDuplicate_Exception e) {
 			//ロールID取得
@@ -374,16 +447,16 @@ public class SystemPrivilegeDialog extends CommonDialog {
 
 		} catch (InvalidSetting_Exception e) {
 			// 「リポジトリ - 参照」が登録するシステム権限に含まれていない
-			String args[] = { 
+			String args[] = {
 					Messages.getString("repository.read", Locale.getDefault())
 			};
-			
+
 			MessageDialog.openInformation(
-					null, 
+					null,
 					Messages.getString("message"),
 					Messages.getString("message.accesscontrol.51", args));
-			
-			
+
+
 		} catch (Exception e) {
 			String errMessage = "";
 			if (e instanceof InvalidRole_Exception) {
@@ -403,17 +476,17 @@ public class SystemPrivilegeDialog extends CommonDialog {
 					Messages.getString("message.accesscontrol.48") + errMessage);
 
 		}
-	
+
 
 		return result;
 	}
 
 	/**
 	 * ロール用プロパティを設定します。
-	 * 
+	 *
 	 * @param roleInfo 設定値として用いるロール情報
 	 */
-	protected void setInputData(RoleInfo roleInfo) {
+	protected void setInputData(String managerName, RoleInfo roleInfo) {
 
 		this.inputData = roleInfo;
 
@@ -422,12 +495,13 @@ public class SystemPrivilegeDialog extends CommonDialog {
 		java.util.List<String> allSystemPrivilegeList = null;
 		java.util.List<SystemPrivilegeInfo> roleSystemPrivilegeKeyList = null;
 		// 全システム権限を取得
-		allSystemPrivilegeList = SystemPrivilegePropertyUtil.getValueList();
+		allSystemPrivilegeList = SystemPrivilegePropertyUtil.getSystemPrivilegeNameList();
 		//TODO 保留！！！この修正では最初の時点でのソートしかできない。以降はSWTのオブジェクトを直接いじっているように見える
 		java.util.Collections.sort(allSystemPrivilegeList);
 		// 付与システム権限を取得
 		try {
-			roleSystemPrivilegeKeyList = AccessEndpointWrapper.getSystemPrivilegeInfoListByRoleId(roleId);
+			AccessEndpointWrapper wrapper = AccessEndpointWrapper.getWrapper(managerName);
+			roleSystemPrivilegeKeyList = wrapper.getSystemPrivilegeInfoListByRoleId(roleId);
 		} catch (InvalidRole_Exception e) {
 			// 権限なし
 			MessageDialog.openInformation(null, Messages.getString("message"),
@@ -456,7 +530,7 @@ public class SystemPrivilegeDialog extends CommonDialog {
 	/**
 	 * 入力値を設定したロール情報を返します。<BR>
 	 * 入力値チェックを行い、不正な場合は<code>null</code>を返します。
-	 * 
+	 *
 	 * @return ロール情報
 	 */
 	private RoleInfo createInputData() {
@@ -479,7 +553,7 @@ public class SystemPrivilegeDialog extends CommonDialog {
 
 	/**
 	 * ＯＫボタンのテキストを返します。
-	 * 
+	 *
 	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
@@ -489,7 +563,7 @@ public class SystemPrivilegeDialog extends CommonDialog {
 
 	/**
 	 * キャンセルボタンのテキストを返します。
-	 * 
+	 *
 	 * @return キャンセルボタンのテキスト
 	 */
 	@Override
@@ -499,7 +573,7 @@ public class SystemPrivilegeDialog extends CommonDialog {
 
 	/**
 	 * 共通のボタンを生成します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のコンポジット
 	 * @param label
@@ -508,6 +582,7 @@ public class SystemPrivilegeDialog extends CommonDialog {
 	 */
 	private Button createButton(Composite parent, String label) {
 		Button button = new Button(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, button);
 
 		GridData gridData = new GridData(GridData.FILL_HORIZONTAL);
 		gridData.horizontalAlignment = GridData.FILL;
@@ -521,14 +596,14 @@ public class SystemPrivilegeDialog extends CommonDialog {
 
 	/**
 	 * 表示名称リストからシステム権限リストを返す
-	 * 
+	 *
 	 * @param beforeList 表示名称リスト
 	 * @return システム権限リスト
 	 */
 	private java.util.List<SystemPrivilegeInfo> getSystemPrivilegeKeyList(java.util.List<String> beforeList) {
 		java.util.List<SystemPrivilegeInfo> afterList = new ArrayList<SystemPrivilegeInfo>();
 		for (String beforeStr : beforeList) {
-			String key = SystemPrivilegePropertyUtil.getKey(beforeStr);
+			String key = SystemPrivilegePropertyUtil.getFunctionPrivilege(beforeStr);
 			// 画面変更前の仮対応
 			SystemPrivilegeInfo info = new SystemPrivilegeInfo();
 			String regexp = "(.+?)(" + SystemPrivilegeMode.READ.name() + ")";
@@ -540,12 +615,12 @@ public class SystemPrivilegeDialog extends CommonDialog {
 				afterList.add(info);
 				continue;
 			}
-			regexp = "(.+?)(" + SystemPrivilegeMode.WRITE.name() + ")";
+			regexp = "(.+?)(" + SystemPrivilegeMode.MODIFY.name() + ")";
 			pattern = Pattern.compile(regexp);
 			matcher = pattern.matcher(key);
 			if (matcher.find()) {
 				info.setSystemFunction(matcher.group(1));
-				info.setSystemPrivilege(SystemPrivilegeMode.WRITE.name());
+				info.setSystemPrivilege(SystemPrivilegeMode.MODIFY.name());
 				afterList.add(info);
 				continue;
 			}
@@ -573,15 +648,15 @@ public class SystemPrivilegeDialog extends CommonDialog {
 
 	/**
 	 * システム権限リストから表示名称リストを返す
-	 * 
+	 *
 	 * @param beforeList システム権限リスト
 	 * @return 表示名称リスト
 	 */
 	private java.util.List<String> getSystemPrivilegeValueList(java.util.List<SystemPrivilegeInfo> beforeList) {
 		java.util.List<String> afterList = new ArrayList<String>();
 		for (SystemPrivilegeInfo systemPrivilegeInfo : beforeList) {
-			afterList.add(SystemPrivilegePropertyUtil.getValue(systemPrivilegeInfo.getSystemFunction(), systemPrivilegeInfo.getSystemPrivilege()));
+			afterList.add(SystemPrivilegePropertyUtil.getSystemPrivilegeName(systemPrivilegeInfo.getSystemFunction(), systemPrivilegeInfo.getSystemPrivilege()));
 		}
 		return afterList;
 	}
-}
\ No newline at end of file
+}
