@@ -33,15 +33,14 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
-import com.clustercontrol.accesscontrol.action.CheckPermission;
-import com.clustercontrol.accesscontrol.bean.FunctionConstant;
-import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.SystemPrivilegeMode;
 import com.clustercontrol.accesscontrol.util.AccessEndpointWrapper;
 import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
+import com.clustercontrol.composite.ManagerListComposite;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.ws.access.InvalidRole_Exception;
 import com.clustercontrol.ws.access.UnEditableUser_Exception;
 import com.clustercontrol.ws.access.UserDuplicate_Exception;
@@ -49,7 +48,7 @@ import com.clustercontrol.ws.access.UserInfo;
 
 /**
  * アカウント[ユーザの作成・変更]ダイアログクラスです。
- * 
+ *
  * @version 4.0.0
  * @since 2.0.0
  */
@@ -58,9 +57,6 @@ public class UserDialog extends CommonDialog {
 	// ログ
 	private static Log m_log = LogFactory.getLog( UserDialog.class );
 
-	/** ユーザID */
-	private String userId = "";
-
 	/** モード */
 	private int mode = 0;
 
@@ -86,33 +82,37 @@ public class UserDialog extends CommonDialog {
 	public static final int WIDTH_TEXT = 10;
 
 	/** 入力値を保持するオブジェクト。 */
-	private UserInfo inputData = null;
+	private UserInfo inputData;
 
 	private boolean permission = false;		// 現在のユーザが変更権限をもつか否か
 
+	/** マネージャ名コンボボックス用コンポジット */
+	private ManagerListComposite m_managerComposite = null;
+
+	private String managerName = null;
+
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param parent 親シェル
+	 * @param managerName マネージャ名
 	 * @param uid ユーザID
 	 * @param isModifyDialog 変更用ダイアログとして利用する場合は、true
 	 */
-	public UserDialog(Shell parent, String userId, boolean isModifyDialog) {
+	public UserDialog(Shell parent, String managerName, UserInfo userInfo, boolean isModifyDialog) {
 		super(parent);
 
-		this.userId = userId;
+		this.managerName = managerName;
+		this.inputData = userInfo;
 		this.isModifyDialog = isModifyDialog;
 
-		// 現在のユーザがアカウント機能の設定権限をもつか否かを取得する
-		permission = new CheckPermission().check(FunctionConstant.ACCESSCONTROL, SystemPrivilegeMode.WRITE);
-
 	}
 
 	/**
 	 * ダイアログの初期サイズを返します。
-	 * 
+	 *
 	 * @return 初期サイズ
-	 * 
+	 *
 	 * @see org.eclipse.jface.window.Window#getInitialSize()
 	 */
 	@Override
@@ -122,9 +122,9 @@ public class UserDialog extends CommonDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親コンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#customizeDialog(org.eclipse.swt.widgets.Composite)
 	 */
 	@Override
@@ -142,12 +142,40 @@ public class UserDialog extends CommonDialog {
 		layout.numColumns = 15;
 		parent.setLayout(layout);
 
+		/*
+		 * マネージャ
+		 */
+		Label labelManager = new Label(parent, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "manager", labelManager);
+		GridData gridData = new GridData();
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		gridData.horizontalSpan = WIDTH_LABEL;
+		labelManager.setLayoutData(gridData);
+		labelManager.setText(Messages.getString("facility.manager") + " : ");
+		if(this.isModifyDialog){
+			this.m_managerComposite = new ManagerListComposite(parent, SWT.NONE, false);
+		} else {
+			this.m_managerComposite = new ManagerListComposite(parent, SWT.NONE, true);
+		}
+		WidgetTestUtil.setTestId(this, "managerComposite", this.m_managerComposite);
+		gridData = new GridData();
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.horizontalSpan = WIDTH_TEXT;
+		gridData.grabExcessHorizontalSpace = true;
+		this.m_managerComposite.setLayoutData(gridData);
+
+		if(this.managerName != null) {
+			this.m_managerComposite.setText(this.managerName);
+		}
+
 		/*
 		 * ユーザID
 		 */
 		// ラベル
 		Label label = new Label(parent, SWT.NONE);
-		GridData gridData = new GridData();
+		WidgetTestUtil.setTestId(this, "userid", label);
+		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		gridData.horizontalSpan = WIDTH_LABEL;
@@ -155,6 +183,7 @@ public class UserDialog extends CommonDialog {
 		label.setText(Messages.getString("user.id") + " : ");
 		// テキスト
 		this.textUserId = new Text(parent, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "id", textUserId);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -177,12 +206,13 @@ public class UserDialog extends CommonDialog {
 		} else {
 			this.mode = PropertyDefineConstant.MODE_ADD;
 		}
-		
+
 		/*
 		 * ユーザ名
 		 */
 		// ラベル
 		label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "username", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_LABEL;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -191,6 +221,7 @@ public class UserDialog extends CommonDialog {
 		label.setText(Messages.getString("user.name") + " : ");
 		// テキスト
 		this.textUserName = new Text(parent, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "name", textUserName);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -208,6 +239,7 @@ public class UserDialog extends CommonDialog {
 		 */
 		// ラベル
 		label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "description", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_LABEL;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -216,6 +248,7 @@ public class UserDialog extends CommonDialog {
 		label.setText(Messages.getString("description") + " : ");
 		// テキスト
 		this.textDescription = new Text(parent, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "description", textDescription);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -238,32 +271,14 @@ public class UserDialog extends CommonDialog {
 		shell.setLocation((display.getBounds().width - shell.getSize().x) / 2,
 				(display.getBounds().height - shell.getSize().y) / 2);
 
-		// ユーザIDが指定されている場合、その情報を初期化する。
-		UserInfo info = null;
-		if (this.userId != null) {
-			try {
-				info = AccessEndpointWrapper.getUserInfo(this.userId);
-			} catch (InvalidRole_Exception e) {
-				MessageDialog.openInformation(null, Messages.getString("message"),
-						Messages.getString("message.accesscontrol.16"));
-			} catch (Exception e) {
-				m_log.warn("customizeDialog(), " + e.getMessage(), e);
-				MessageDialog.openError(
-						null,
-						Messages.getString("failed"),
-						Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
-			}
-		} else {
-			info = new UserInfo();
-		}
-		this.setInputData(info);
+		this.setInputData();
 	}
 
 	/**
 	 * 入力値チェックをします。
-	 * 
+	 *
 	 * @return 検証結果
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#validate()
 	 */
 	@Override
@@ -280,9 +295,9 @@ public class UserDialog extends CommonDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -294,17 +309,19 @@ public class UserDialog extends CommonDialog {
 			return result;
 		}
 
+		AccessEndpointWrapper wrapper = AccessEndpointWrapper.getWrapper(m_managerComposite.getText());
 		if(!this.isModifyDialog){
 			// 作成の場合
 			try {
-				AccessEndpointWrapper.addUserInfo(userInfo);
+				wrapper.addUserInfo(userInfo);
 				result = true;
 
+				Object[] arg = {this.m_managerComposite.getText()};
 				// 完了メッセージ
 				MessageDialog.openInformation(
 						null,
 						Messages.getString("successful"),
-						Messages.getString("message.accesscontrol.7"));
+						Messages.getString("message.accesscontrol.7", arg));
 
 			} catch (UserDuplicate_Exception e) {
 				//ユーザID取得
@@ -334,14 +351,15 @@ public class UserDialog extends CommonDialog {
 		} else{
 			// 変更の場合
 			try {
-				AccessEndpointWrapper.modifyUserInfo(userInfo);
+				wrapper.modifyUserInfo(userInfo);
 				result = true;
 
+				Object[] arg = {this.m_managerComposite.getText()};
 				// 完了メッセージ
 				MessageDialog.openInformation(
 						null,
 						Messages.getString("successful"),
-						Messages.getString("message.accesscontrol.9"));
+						Messages.getString("message.accesscontrol.9", arg));
 
 			} catch (Exception e) {
 				String errMessage = "";
@@ -369,7 +387,7 @@ public class UserDialog extends CommonDialog {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	public void update(){
 		// 必須項目を明示
@@ -390,28 +408,25 @@ public class UserDialog extends CommonDialog {
 
 	/**
 	 * 指定されたユーザ情報を元に、ダイアログのテキストボックスにユーザID、ユーザ名、説明をセットする
-	 * 
+	 *
 	 * @param userInfo 設定値として用いるユーザ情報
 	 */
-	protected void setInputData(UserInfo userInfo) {
-
-		this.inputData = userInfo;
-
+	protected void setInputData() {
 		// 各項目に反映
 		// ユーザID
-		if (userInfo.getId() != null) {
-			this.textUserId.setText(userInfo.getId());
+		if (inputData.getId() != null) {
+			this.textUserId.setText(inputData.getId());
 		}
 		// ユーザ名
-		if (userInfo.getName() != null) {
-			this.textUserName.setText(userInfo.getName());
+		if (inputData.getName() != null) {
+			this.textUserName.setText(inputData.getName());
 		}
 		// 説明
-		if (userInfo.getDescription() != null) {
-			this.textDescription.setText(userInfo.getDescription());
+		if (inputData.getDescription() != null) {
+			this.textDescription.setText(inputData.getDescription());
 		}
 
-		// 入力制御 
+		// 入力制御
 		if(this.mode == PropertyDefineConstant.MODE_SHOW
 				|| this.mode == PropertyDefineConstant.MODE_MODIFY){
 			this.textUserId.setEnabled(false);
@@ -425,10 +440,10 @@ public class UserDialog extends CommonDialog {
 		roleList.add("AccessControlWrite");
 		roleList.add("CalendarRead");
 		roleList.add("CalendarWrite");
-		roleList.add("CollectiveRunExecute");
-		roleList.add("CollectiveRunRead");
-		roleList.add("CollectiveRunWrite");
 		roleList.add("HinemosUser");
+		roleList.add("InfraExecute");
+		roleList.add("InfraRead");
+		roleList.add("InfraWrite");
 		roleList.add("JobManagementExecute");
 		roleList.add("JobManagementRead");
 		roleList.add("JobManagementWrite");
@@ -459,7 +474,7 @@ public class UserDialog extends CommonDialog {
 	/**
 	 * ダイアログ中で入力されたユーザID・ユーザ名・説明を読みだし、ユーザ情報として返却する。<BR>
 	 * 入力値チェックは行わないため、null文字などが入っている場合もありうる。
-	 * 
+	 *
 	 * @return ユーザ情報
 	 */
 	private UserInfo createInputData() {
@@ -472,7 +487,7 @@ public class UserDialog extends CommonDialog {
 
 	/**
 	 * ＯＫボタンのテキストを返します。
-	 * 
+	 *
 	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
@@ -486,11 +501,11 @@ public class UserDialog extends CommonDialog {
 
 	/**
 	 * キャンセルボタンのテキストを返します。
-	 * 
+	 *
 	 * @return キャンセルボタンのテキスト
 	 */
 	@Override
 	protected String getCancelButtonText() {
 		return Messages.getString("cancel"); //$NON-NLS-1$
 	}
-}
\ No newline at end of file
+}
