@@ -15,24 +15,23 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.accesscontrol.etc.action;
 
-import org.eclipse.jface.action.IAction;
-import org.eclipse.jface.viewers.ISelection;
+import org.eclipse.core.commands.AbstractHandler;
+import org.eclipse.core.commands.ExecutionEvent;
+import org.eclipse.core.commands.ExecutionException;
 import org.eclipse.ui.IViewPart;
 import org.eclipse.ui.IWorkbenchPage;
-import org.eclipse.ui.IWorkbenchWindow;
-import org.eclipse.ui.IWorkbenchWindowActionDelegate;
 import org.eclipse.ui.PartInitException;
-import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.handlers.HandlerUtil;
 
 import com.clustercontrol.accesscontrol.view.UserListView;
 
 /**
  * アクセス[ユーザ]ビューを表示するアクションクラスです。
  * 
- * @version 2.0.0
+ * @version 5.0.0
  * @since 2.0.0
  */
-public class UserListAction implements IWorkbenchWindowActionDelegate {
+public class UserListAction extends AbstractHandler {
 
 	/**
 	 * 終了する際に呼ばれます。
@@ -44,27 +43,10 @@ public class UserListAction implements IWorkbenchWindowActionDelegate {
 
 	}
 
-	/**
-	 * ワークベンチにロードされた際に呼ばれます。
-	 * 
-	 * @see org.eclipse.ui.IWorkbenchWindowActionDelegate#init(org.eclipse.ui.IWorkbenchWindow)
-	 */
 	@Override
-	public void init(IWorkbenchWindow window) {
-
-	}
-
-	/**
-	 * アクセス[ユーザ]ビューを表示します。
-	 * 
-	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
-	 * @see com.clustercontrol.accesscontrol.view.UserListView
-	 */
-	@Override
-	public void run(IAction action) {
+	public Object execute(ExecutionEvent event) throws ExecutionException {
 		//アクティブページを手に入れる
-		IWorkbenchPage page = PlatformUI.getWorkbench()
-				.getActiveWorkbenchWindow().getActivePage();
+		IWorkbenchPage page = HandlerUtil.getActiveWorkbenchWindow( event ).getActivePage();
 
 		//ビューを表示する
 		try {
@@ -75,16 +57,7 @@ public class UserListAction implements IWorkbenchWindowActionDelegate {
 			view.setFocus();
 		} catch (PartInitException e) {
 		}
-	}
-
-	/**
-	 * 選択を変更した際に呼ばれます。
-	 * 
-	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction, org.eclipse.jface.viewers.ISelection)
-	 */
-	@Override
-	public void selectionChanged(IAction action, ISelection selection) {
-
+		return null;
 	}
 
 }
