@@ -789,7 +789,7 @@ public class AccessControllerBean {
 			RepositoryValidator.validateScopeInfo(null, scopeInfo, false);
 
 			// ロールスコープ更新
-			FacilityModifier.modifyScope(scopeInfo, (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID), false);
+			FacilityModifier.modifyOwnerRoleScope(scopeInfo, (String)HinemosSessionContext.instance().getProperty(HinemosSessionContext.LOGIN_USER_ID), false);
 			
 			jtm.addCallback(new FacilityIdCacheInitCallback());
 			jtm.addCallback(new FacilityTreeCacheRefreshCallback());
