@@ -199,6 +199,17 @@ public class Agent {
 		DatagramSocket sock = null;
 		boolean flag = true;
 		int port = 24005;
+		
+		int awakeDelay = 1000;
+		
+		try {
+			String awakeDelayStr = AgentProperties.getProperty("awake.delay", Integer.toString(1000));
+			awakeDelay = Integer.parseInt(awakeDelayStr);
+			m_log.info("awake.delay = " + awakeDelay + " msec");
+		} catch (NumberFormatException e) {
+			m_log.error("awake.delay", e);
+		}
+
 		while (true) {
 			/*
 			 * UDPパケットを受信したらflagがtrueになる。
@@ -215,7 +226,7 @@ public class Agent {
 				if (sock == null || !sock.isBound()) {
 					port = awakePort;
 					sock = new DatagramSocket(port);
-					sock.setSoTimeout(1000);
+					sock.setSoTimeout(awakeDelay);
 				}
 				DatagramPacket recvPacket = new DatagramPacket(buf, BUFSIZE);
 				sock.receive(recvPacket);
