@@ -82,6 +82,14 @@ public class ReceiveTopic extends Thread {
 	private long disconnectCounter = 1;
 	private static boolean m_clearFlg = false;
 	private static boolean m_reloadFlg = false;
+	
+	// topic受信とエージェント終了時の通信コンフリクトを防ぐためのロック
+	public static final Object lockTopicReceiveTiming = new Object();
+	// エージェン終了フラグ
+	private static boolean isTerminated = false;
+	public static void terminate() {
+		isTerminated = true;
+	}
 
 	// 最後に受信した設定情報更新日時
 	private static SettingUpdateInfo settingLastUpdateInfo = null;
@@ -181,7 +189,14 @@ public class ReceiveTopic extends Thread {
 				List<TopicInfo> topicInfoList = null;
 				SettingUpdateInfo updateInfo = null;
 				try {
-					hinemosTopicInfo = AgentEndPointWrapper.getHinemosTopic();
+					// エージェントの終了処理が行われているにもかかわらずtopicをとりにいってしまう競合を防ぐためsynchronizedする
+					synchronized (lockTopicReceiveTiming) {
+						if (isTerminated == true) {
+							// エージェントの終了処理が行われている場合、このスレッドを即時終了させる
+							return;
+						}
+						hinemosTopicInfo = AgentEndPointWrapper.getHinemosTopic();
+					}
 				} catch (Exception e) {
 					/*
 					 * マネージャが停止している、もしくはマネージャと通信ができないと、
