@@ -21,6 +21,7 @@ import java.io.FileNotFoundException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.PrintWriter;
+import java.io.UnsupportedEncodingException;
 import java.nio.charset.Charset;
 import java.text.DateFormat;
 import java.text.ParseException;
@@ -138,6 +139,9 @@ public class WinEventCollector implements CollectorTask, Runnable {
 	private Calendar lastrun = null;
 	private static String targetProperty;
 	
+	// PowerShellの文字コード
+	private static String POWERSHELL_CHARSET_KEY = "collector.winevent.charset";
+	private final String charset;
 	
 	public WinEventCollector(final MonitorInfo monitorInfo, SendQueue sendQueue) {
 		this.monitorInfo = monitorInfo;
@@ -220,6 +224,14 @@ public class WinEventCollector implements CollectorTask, Runnable {
 			tmpLtCode = TMP_GT_CODE;
 			m_log.info("collector.winevent.lt.char.replace uses " + tmpLtCode + ". ");
 		}
+		
+		// PowerShellの書き出し・実行文字コードを決定する
+		String tmpCharset = AgentProperties.getProperty(POWERSHELL_CHARSET_KEY);
+		if (tmpCharset == null || tmpCharset.length() == 0) {
+			tmpCharset = "MS932";
+			m_log.info(POWERSHELL_CHARSET_KEY + " uses " + tmpCharset);
+		}
+		charset = tmpCharset;
 	}
 	
 	@Override
@@ -324,7 +336,7 @@ public class WinEventCollector implements CollectorTask, Runnable {
 			synchronized(WinEventCollector.class){
 				try {
 					CommandExecutor cmdExecutor = new CommandExecutor(command,
-							Charset.forName("MS932"), timeout, bufferLength);
+							Charset.forName(charset), timeout, bufferLength);
 	
 					// 実行結果を取得する
 					cmdExecutor.execute();
@@ -425,7 +437,7 @@ public class WinEventCollector implements CollectorTask, Runnable {
 			command = CommandCreator.createCommand(System.getProperty("user.name"), commandCheckEnabled, platform);
 
 			CommandExecutor cmdExecutor = new CommandExecutor(command,
-					Charset.forName("MS932"), timeout, bufferLength);
+					Charset.forName(charset), timeout, bufferLength);
 			cmdExecutor.execute();
 			CommandResult ret = cmdExecutor.getResult();
 			
@@ -465,7 +477,7 @@ public class WinEventCollector implements CollectorTask, Runnable {
 			command = CommandCreator.createCommand(System.getProperty("user.name"), commandCheckPolicy, platform);
 
 			CommandExecutor cmdExecutor = new CommandExecutor(command,
-					Charset.forName("MS932"), timeout, bufferLength);
+					Charset.forName(charset), timeout, bufferLength);
 			cmdExecutor.execute();
 			CommandResult ret = cmdExecutor.getResult();
 			
@@ -524,7 +536,7 @@ public class WinEventCollector implements CollectorTask, Runnable {
 		// PowerShellスクリプトを生成する
 		PrintWriter pw = null;
 		try {
-			pw = new PrintWriter(psFileName);
+			pw = new PrintWriter(psFileName, charset);
 			pw.println("$Error.Clear()");
 
 			for(String logName : checkInfo.getLogName()){
@@ -640,6 +652,8 @@ public class WinEventCollector implements CollectorTask, Runnable {
 
 		} catch (FileNotFoundException e) {
 			m_log.debug("createGetEventLogPs() cannot create powershell script", e);
+		} catch (UnsupportedEncodingException e) {
+			m_log.warn("createGetEventLogPs() : can't create powershell script. invalid charset. charset = " + charset, e);
 		} finally {
 			pw.close();
 		}
@@ -665,7 +679,7 @@ public class WinEventCollector implements CollectorTask, Runnable {
 		// PowerShellスクリプトを生成する
 		PrintWriter pw = null;
 		try {
-			pw = new PrintWriter(psFileName);
+			pw = new PrintWriter(psFileName, charset);
 			pw.println("$eventlogs = @()");
 			pw.println("$Error.Clear()");
 
@@ -793,6 +807,8 @@ public class WinEventCollector implements CollectorTask, Runnable {
 
 		} catch (FileNotFoundException e) {
 			m_log.debug("createGetWinEventPs() cannot create powershell script", e);
+		} catch (UnsupportedEncodingException e) {
+			m_log.warn("createGetWinEventPs() : can't create powershell script. invalid charset. charset = " + charset, e);
 		} finally {
 			pw.close();
 		}
@@ -819,7 +835,7 @@ public class WinEventCollector implements CollectorTask, Runnable {
 		// PowerShellスクリプトを生成する
 		PrintWriter pw = null;
 		try {
-			pw = new PrintWriter(psFileName);
+			pw = new PrintWriter(psFileName, charset);
 			pw.println("$Error.Clear()");
 
 			for(String logName : checkInfo.getLogName()){
@@ -940,6 +956,8 @@ public class WinEventCollector implements CollectorTask, Runnable {
 
 		} catch (FileNotFoundException e) {
 			m_log.debug("createWevtutilPs() cannot create powershell script", e);
+		} catch (UnsupportedEncodingException e) {
+			m_log.warn("createWevtutilPs() : can't create powershell script. invalid charset. charset = " + charset, e);
 		} finally {
 			pw.close();
 		}
