@@ -18,10 +18,11 @@ package com.clustercontrol.calendar.composite;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;
+import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.viewers.TableViewer;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.layout.GridData;
@@ -35,14 +36,17 @@ import com.clustercontrol.calendar.composite.action.CalendarDoubleClickListener;
 import com.clustercontrol.calendar.composite.action.CalendarSelectionChangedListener;
 import com.clustercontrol.calendar.composite.action.VerticalBarSelectionListener;
 import com.clustercontrol.calendar.util.CalendarEndpointWrapper;
+import com.clustercontrol.util.EndpointManager;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.UIManager;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.viewer.CommonTableViewer;
 import com.clustercontrol.ws.calendar.CalendarInfo;
 import com.clustercontrol.ws.calendar.InvalidRole_Exception;
 
 /**
  * カレンダ一覧コンポジットクラス<BR>
- * 
+ *
  * @version 2.0.0
  * @since 2.0.0
  */
@@ -53,7 +57,7 @@ public class CalendarListComposite extends Composite {
 	/** テーブルビューア */
 	private CommonTableViewer m_viewer = null;
 	/** テーブル */
-	private Table m_table = null;
+	private Table calListTable = null;
 	/** ラベル */
 	private Label m_labelCount = null;
 	/** カレンダID */
@@ -61,7 +65,7 @@ public class CalendarListComposite extends Composite {
 
 	/**
 	 * このコンポジットが利用するテーブルビューアを取得します。<BR>
-	 * 
+	 *
 	 * @return テーブルビューア
 	 */
 	public TableViewer getTableViewer() {
@@ -69,7 +73,7 @@ public class CalendarListComposite extends Composite {
 	}
 	/**
 	 * このコンポジットが利用するテーブルを取得します。<BR>
-	 * 
+	 *
 	 * @return テーブル
 	 */
 	public Table getTable() {
@@ -92,7 +96,7 @@ public class CalendarListComposite extends Composite {
 	}
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param parent
 	 * @param style
 	 * @since 2.0.0
@@ -104,7 +108,7 @@ public class CalendarListComposite extends Composite {
 
 	/**
 	 * 初期化処理<BR>
-	 * 
+	 *
 	 * @since 2.0.0
 	 */
 	private void initialize() {
@@ -114,10 +118,11 @@ public class CalendarListComposite extends Composite {
 		layout.marginWidth = 0;
 
 		//カレンダ一覧テーブル作成
-		m_table = new Table(this, SWT.H_SCROLL | SWT.V_SCROLL
+		calListTable = new Table(this, SWT.H_SCROLL | SWT.V_SCROLL
 				| SWT.FULL_SELECTION | SWT.MULTI | SWT.BORDER);
-		m_table.setHeaderVisible(true);
-		m_table.setLinesVisible(true);
+		WidgetTestUtil.setTestId(this, null, calListTable);
+		calListTable.setHeaderVisible(true);
+		calListTable.setLinesVisible(true);
 
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
@@ -125,19 +130,24 @@ public class CalendarListComposite extends Composite {
 		gridData.grabExcessHorizontalSpace = true;
 		gridData.grabExcessVerticalSpace = true;
 		gridData.horizontalSpan = 1;
-		m_table.setLayoutData(gridData);
+		calListTable.setLayoutData(gridData);
 
 		m_labelCount = new Label(this, SWT.RIGHT);
+		WidgetTestUtil.setTestId(this, "count", m_labelCount);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
 		m_labelCount.setLayoutData(gridData);
 
-		m_viewer = new CommonTableViewer(m_table);
+		m_viewer = new CommonTableViewer(calListTable);
 		m_viewer.createTableColumn(GetCalendarListTableDefine.get(),
-				GetCalendarListTableDefine.SORT_COLUMN_INDEX,
+				GetCalendarListTableDefine.SORT_COLUMN_INDEX1,
+				GetCalendarListTableDefine.SORT_COLUMN_INDEX2,
 				GetCalendarListTableDefine.SORT_ORDER);
 
+		for (int i = 0; i < calListTable.getColumnCount(); i++){
+			calListTable.getColumn(i).setMoveable(true);
+		}
 		m_viewer.addSelectionChangedListener(new CalendarSelectionChangedListener(this));
 		// ダブルクリックリスナの追加
 		m_viewer.addDoubleClickListener(new CalendarDoubleClickListener(this));
@@ -147,7 +157,7 @@ public class CalendarListComposite extends Composite {
 
 	/**
 	 * 更新処理<BR>
-	 * 
+	 *
 	 * @since 2.0.0
 	 */
 	@Override
@@ -155,41 +165,54 @@ public class CalendarListComposite extends Composite {
 		List<CalendarInfo> list = null;
 
 		//カレンダ一覧情報取得
-		try {
-			list = CalendarEndpointWrapper.getAllCalendarList();
-		} catch (InvalidRole_Exception e) {
-			// 権限なし
-			MessageDialog.openInformation(null, Messages.getString("message"),
-					Messages.getString("message.accesscontrol.16"));
-		} catch (Exception e) {
-			// 上記以外の例外
-			m_log.warn("update(), " + e.getMessage(), e);
-			MessageDialog.openError(
-					null,
-					Messages.getString("failed"),
-					Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+		Map<String, List<CalendarInfo>> dispDataMap= new ConcurrentHashMap<String, List<CalendarInfo>>();
+		Map<String, String> errorMsgs = new ConcurrentHashMap<>();
+		for(String managerName : EndpointManager.getActiveManagerSet()) {
+			CalendarEndpointWrapper wrapper = CalendarEndpointWrapper.getWrapper(managerName);
+			try {
+				list = wrapper.getAllCalendarList();
+			} catch (InvalidRole_Exception e) {
+				// 権限なし
+				errorMsgs.put( managerName, Messages.getString("message.accesscontrol.16") );
+			} catch (Exception e) {
+				// 上記以外の例外
+				m_log.warn("update(), " + e.getMessage(), e);
+				errorMsgs.put( managerName, Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+			}
+			if(list == null){
+				list = new ArrayList<CalendarInfo>();
+			}
+
+			dispDataMap.put(managerName, list);
 		}
-		if(list == null){
-			list = new ArrayList<CalendarInfo>();
+
+		//メッセージ表示
+		if( 0 < errorMsgs.size() ){
+			UIManager.showMessageBox(errorMsgs, true);
 		}
+
 		ArrayList<Object> listInput = new ArrayList<Object>();
-		for (CalendarInfo info : list) {
-			ArrayList<Object> obj = new ArrayList<Object>();
-			obj.add(info.getId());
-			obj.add(info.getName());
-			obj.add(new Date(info.getValidTimeFrom()));
-			obj.add(new Date(info.getValidTimeTo()));
-			obj.add(info.getDescription());
-			obj.add(info.getOwnerRoleId());
-			obj.add(info.getRegUser());
-			obj.add(new Date(info.getRegDate()));
-			obj.add(info.getUpdateUser());
-			obj.add(new Date(info.getUpdateDate()));
-			listInput.add(obj);
+		for(Map.Entry<String, List<CalendarInfo>> map: dispDataMap.entrySet()) {
+			for (CalendarInfo info : map.getValue()) {
+				ArrayList<Object> obj = new ArrayList<Object>();
+				obj.add(map.getKey());
+				obj.add(info.getId());
+				obj.add(info.getName());
+				obj.add(new Date(info.getValidTimeFrom()));
+				obj.add(new Date(info.getValidTimeTo()));
+				obj.add(info.getDescription());
+				obj.add(info.getOwnerRoleId());
+				obj.add(info.getRegUser());
+				obj.add(new Date(info.getRegDate()));
+				obj.add(info.getUpdateUser());
+				obj.add(new Date(info.getUpdateDate()));
+				obj.add(null);
+				listInput.add(obj);
+			}
 		}
 		m_viewer.setInput(listInput);
 
-		Object[] args = { new Integer(list.size()) };
+		Object[] args = { new Integer(listInput.size()) };
 		m_labelCount.setText(Messages.getString("records", args));
 	}
-}
\ No newline at end of file
+}
