@@ -8,22 +8,24 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.util.EndpointManager;
-import com.clustercontrol.util.EndpointManager.EndpointSetting;
+import com.clustercontrol.util.EndpointUnit;
+import com.clustercontrol.util.EndpointUnit.EndpointSetting;
 import com.clustercontrol.ws.calendar.CalendarDetailInfo;
+import com.clustercontrol.ws.calendar.CalendarDuplicate_Exception;
+import com.clustercontrol.ws.calendar.CalendarEndpoint;
+import com.clustercontrol.ws.calendar.CalendarEndpointService;
 import com.clustercontrol.ws.calendar.CalendarInfo;
+import com.clustercontrol.ws.calendar.CalendarNotFound_Exception;
 import com.clustercontrol.ws.calendar.CalendarPatternInfo;
 import com.clustercontrol.ws.calendar.HinemosUnknown_Exception;
 import com.clustercontrol.ws.calendar.InvalidRole_Exception;
 import com.clustercontrol.ws.calendar.InvalidSetting_Exception;
 import com.clustercontrol.ws.calendar.InvalidUserPass_Exception;
-import com.clustercontrol.ws.calendar.CalendarDuplicate_Exception;
-import com.clustercontrol.ws.calendar.CalendarEndpoint;
-import com.clustercontrol.ws.calendar.CalendarNotFound_Exception;
 
 /**
  * Hinemosマネージャとの通信をするクラス。
  * HAのような複数マネージャ対応のため、このクラスを実装する。
- * 
+ *
  * Hinemosマネージャと通信できない場合は、WebServiceExceptionがthrowされる。
  * WebServiceExeptionが出力された場合は、もう一台のマネージャと通信する。
  */
@@ -31,6 +33,21 @@ public class CalendarEndpointWrapper {
 
 	// ログ
 	private static Log m_log = LogFactory.getLog( CalendarEndpointWrapper.class );
+
+	private EndpointUnit endpointUnit;
+
+	public CalendarEndpointWrapper(EndpointUnit endpointUnit) {
+		this.endpointUnit = endpointUnit;
+	}
+
+	public static CalendarEndpointWrapper getWrapper(String managerName) {
+		return new CalendarEndpointWrapper(EndpointManager.get(managerName));
+	}
+
+	private static List<EndpointSetting<CalendarEndpoint>> getCalendarEndpoint(EndpointUnit endpointUnit) {
+		return endpointUnit.getEndpoint(CalendarEndpointService.class, CalendarEndpoint.class);
+	}
+
 	/**
 	 * カレンダ情報を返す。
 	 * @param id
@@ -40,16 +57,16 @@ public class CalendarEndpointWrapper {
 	 * @throws InvalidRole_Exception
 	 * @throws InvalidUserPass_Exception
 	 */
-	public static CalendarInfo getCalendar(String id) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+	public CalendarInfo getCalendar(String id) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getCalendarEndpoint()) {
+		for (EndpointSetting<CalendarEndpoint> endpointSetting : getCalendarEndpoint(endpointUnit)) {
 			try {
-				CalendarEndpoint endpoint = (CalendarEndpoint) endpointSetting.getEndpoint();
+				CalendarEndpoint endpoint = endpointSetting.getEndpoint();
 				return endpoint.getCalendar(id);
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getCalendar(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getCalendar(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
@@ -64,17 +81,17 @@ public class CalendarEndpointWrapper {
 	 * @throws InvalidUserPass_Exception
 	 * @throws InvalidSetting_Exception
 	 */
-	public static void addCalendar(CalendarInfo calendarInfo) throws CalendarDuplicate_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception,InvalidSetting_Exception {
+	public void addCalendar(CalendarInfo calendarInfo) throws CalendarDuplicate_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception,InvalidSetting_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getCalendarEndpoint()) {
+		for (EndpointSetting<CalendarEndpoint> endpointSetting : getCalendarEndpoint(endpointUnit)) {
 			try {
-				CalendarEndpoint endpoint = (CalendarEndpoint) endpointSetting.getEndpoint();
+				CalendarEndpoint endpoint = endpointSetting.getEndpoint();
 				endpoint.addCalendar(calendarInfo);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("addCalendar(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("addCalendar(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
@@ -89,17 +106,17 @@ public class CalendarEndpointWrapper {
 	 * @throws InvalidUserPass_Exception
 	 * @throws InvalidSetting_Exception
 	 */
-	public static void modifyCalendar(CalendarInfo calendarInfo) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
+	public void modifyCalendar(CalendarInfo calendarInfo) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getCalendarEndpoint()) {
+		for (EndpointSetting<CalendarEndpoint> endpointSetting : getCalendarEndpoint(endpointUnit)) {
 			try {
-				CalendarEndpoint endpoint = (CalendarEndpoint) endpointSetting.getEndpoint();
+				CalendarEndpoint endpoint = endpointSetting.getEndpoint();
 				endpoint.modifyCalendar(calendarInfo);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("modifyCalendar(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("modifyCalendar(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
@@ -108,23 +125,23 @@ public class CalendarEndpointWrapper {
 
 	/**
 	 * カレンダ情報を削除する。
-	 * @param uid
+	 * @param uidList
 	 * @throws CalendarNotFound_Exception
 	 * @throws HinemosUnknown_Exception
 	 * @throws InvalidRole_Exception
 	 * @throws InvalidUserPass_Exception
 	 */
-	public static void deleteCalendar(String uid) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+	public void deleteCalendar(List<String> uidList) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getCalendarEndpoint()) {
+		for (EndpointSetting<CalendarEndpoint> endpointSetting : getCalendarEndpoint(endpointUnit)) {
 			try {
-				CalendarEndpoint endpoint = (CalendarEndpoint) endpointSetting.getEndpoint();
-				endpoint.deleteCalendar(uid);
+				CalendarEndpoint endpoint = endpointSetting.getEndpoint();
+				endpoint.deleteCalendar(uidList);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("deleteCalendar(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("deleteCalendar(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
@@ -138,16 +155,16 @@ public class CalendarEndpointWrapper {
 	 * @throws InvalidRole_Exception
 	 * @throws InvalidUserPass_Exception
 	 */
-	public static List<CalendarInfo> getAllCalendarList() throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+	public List<CalendarInfo> getAllCalendarList() throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getCalendarEndpoint()) {
+		for (EndpointSetting<CalendarEndpoint> endpointSetting : getCalendarEndpoint(endpointUnit)) {
 			try {
-				CalendarEndpoint endpoint = (CalendarEndpoint) endpointSetting.getEndpoint();
+				CalendarEndpoint endpoint = endpointSetting.getEndpoint();
 				return endpoint.getAllCalendarList();
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getAllCalendarList(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getAllCalendarList(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
@@ -162,16 +179,16 @@ public class CalendarEndpointWrapper {
 	 * @throws InvalidRole_Exception
 	 * @throws InvalidUserPass_Exception
 	 */
-	public static List<CalendarInfo> getCalendarList(String ownerRoleId) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+	public List<CalendarInfo> getCalendarList(String ownerRoleId) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getCalendarEndpoint()) {
+		for (EndpointSetting<CalendarEndpoint> endpointSetting : getCalendarEndpoint(endpointUnit)) {
 			try {
-				CalendarEndpoint endpoint = (CalendarEndpoint) endpointSetting.getEndpoint();
+				CalendarEndpoint endpoint = endpointSetting.getEndpoint();
 				return endpoint.getCalendarList(ownerRoleId);
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getCalendarListByOwnerRole(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getCalendarListByOwnerRole(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
@@ -187,16 +204,16 @@ public class CalendarEndpointWrapper {
 	 * @throws InvalidRole_Exception
 	 * @throws InvalidUserPass_Exception
 	 */
-	public static List<Integer> getCalendarMonth(String id, Integer year,Integer month) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+	public List<Integer> getCalendarMonth(String id, Integer year,Integer month) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getCalendarEndpoint()) {
+		for (EndpointSetting<CalendarEndpoint> endpointSetting : getCalendarEndpoint(endpointUnit)) {
 			try {
 				CalendarEndpoint endpoint = (CalendarEndpoint) endpointSetting.getEndpoint();
 				return endpoint.getCalendarMonth(id, year, month);
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getCalendarMonth(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getCalendarMonth(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
@@ -212,18 +229,18 @@ public class CalendarEndpointWrapper {
 	 * @throws InvalidRole_Exception
 	 * @throws InvalidUserPass_Exception
 	 */
-	public static List<CalendarDetailInfo> getCalendarWeek(String id, Integer year, Integer month, Integer day)
+	public List<CalendarDetailInfo> getCalendarWeek(String id, Integer year, Integer month, Integer day)
 			throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getCalendarEndpoint()) {
+		for (EndpointSetting<CalendarEndpoint> endpointSetting : getCalendarEndpoint(endpointUnit)) {
 			try {
 				CalendarEndpoint endpoint = (CalendarEndpoint) endpointSetting.getEndpoint();
 				List<CalendarDetailInfo> list = endpoint.getCalendarWeek(id, year, month, day);
 				return list;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getCalendarWeek(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getCalendarWeek(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
@@ -238,17 +255,17 @@ public class CalendarEndpointWrapper {
 	 * @throws InvalidRole_Exception
 	 * @throws InvalidUserPass_Exception
 	 */
-	public static List<CalendarPatternInfo> getCalendarPatternList(String ownerRoleId) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+	public List<CalendarPatternInfo> getCalendarPatternList(String ownerRoleId) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getCalendarEndpoint()) {
+		for (EndpointSetting<CalendarEndpoint> endpointSetting : getCalendarEndpoint(endpointUnit)) {
 			try {
-				CalendarEndpoint endpoint = (CalendarEndpoint) endpointSetting.getEndpoint();
+				CalendarEndpoint endpoint = endpointSetting.getEndpoint();
 				return endpoint.getCalendarPatternList(ownerRoleId);
 
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getCalendarPatternList(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getCalendarPatternList(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
@@ -262,16 +279,16 @@ public class CalendarEndpointWrapper {
 	 * @throws InvalidRole_Exception
 	 * @throws InvalidUserPass_Exception
 	 */
-	public static CalendarPatternInfo getCalendarPattern(String id) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+	public CalendarPatternInfo getCalendarPattern(String id) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getCalendarEndpoint()) {
+		for (EndpointSetting<CalendarEndpoint> endpointSetting : getCalendarEndpoint(endpointUnit)) {
 			try {
-				CalendarEndpoint endpoint = (CalendarEndpoint) endpointSetting.getEndpoint();
+				CalendarEndpoint endpoint = endpointSetting.getEndpoint();
 				return endpoint.getCalendarPattern(id);
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("getCalendarPattern(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("getCalendarPattern(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
@@ -286,18 +303,18 @@ public class CalendarEndpointWrapper {
 	 * @throws InvalidSetting_Exception
 	 * @throws CalendarNotFound_Exception
 	 */
-	public static void addCalendarPattern(CalendarPatternInfo info)
+	public void addCalendarPattern(CalendarPatternInfo info)
 			throws CalendarDuplicate_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception,InvalidSetting_Exception, CalendarNotFound_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getCalendarEndpoint()) {
+		for (EndpointSetting<CalendarEndpoint> endpointSetting : getCalendarEndpoint(endpointUnit)) {
 			try {
-				CalendarEndpoint endpoint = (CalendarEndpoint) endpointSetting.getEndpoint();
+				CalendarEndpoint endpoint = endpointSetting.getEndpoint();
 				endpoint.addCalendarPattern(info);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("addCalendarPattern(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("addCalendarPattern(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
@@ -312,40 +329,40 @@ public class CalendarEndpointWrapper {
 	 * @throws InvalidUserPass_Exception
 	 * @throws InvalidSetting_Exception
 	 */
-	public static void modifyCalendarPattern(CalendarPatternInfo info) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
+	public void modifyCalendarPattern(CalendarPatternInfo info) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception, InvalidSetting_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getCalendarEndpoint()) {
+		for (EndpointSetting<CalendarEndpoint> endpointSetting : getCalendarEndpoint(endpointUnit)) {
 			try {
-				CalendarEndpoint endpoint = (CalendarEndpoint) endpointSetting.getEndpoint();
+				CalendarEndpoint endpoint = endpointSetting.getEndpoint();
 				endpoint.modifyCalendarPattern(info);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("modifyCalendarPattern(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("modifyCalendarPattern(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
 	}
 	/**
 	 * IDと一致するカレンダ[カレンダパターン]情報を削除する<BR>
-	 * @param id
+	 * @param idList
 	 * @throws CalendarNotFound_Exception
 	 * @throws HinemosUnknown_Exception
 	 * @throws InvalidRole_Exception
 	 * @throws InvalidUserPass_Exception
 	 */
-	public static void deleteCalendarPattern(String id) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
+	public void deleteCalendarPattern(List<String> idList) throws CalendarNotFound_Exception, HinemosUnknown_Exception, InvalidRole_Exception, InvalidUserPass_Exception {
 		WebServiceException wse = null;
-		for (EndpointSetting endpointSetting : EndpointManager.getCalendarEndpoint()) {
+		for (EndpointSetting<CalendarEndpoint> endpointSetting : getCalendarEndpoint(endpointUnit)) {
 			try {
 				CalendarEndpoint endpoint = (CalendarEndpoint) endpointSetting.getEndpoint();
-				endpoint.deleteCalendarPattern(id);
+				endpoint.deleteCalendarPattern(idList);
 				return;
 			} catch (WebServiceException e) {
 				wse = e;
-				m_log.warn("deleteCalendarPattern(), " + e.getMessage(), e);
-				EndpointManager.changeEndpoint();
+				m_log.warn("deleteCalendarPattern(), " + e.getMessage());
+				endpointUnit.changeEndpoint();
 			}
 		}
 		throw wse;
