@@ -32,6 +32,7 @@ import com.clustercontrol.jobmanagement.model.JobMstEntity;
 import com.clustercontrol.jobmanagement.model.JobScheduleEntity;
 import com.clustercontrol.maintenance.model.MaintenanceInfoEntity;
 import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
+import com.clustercontrol.notify.model.NotifyInfoEntity;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.calendar.bean.CalendarDetailInfo;
 import com.clustercontrol.calendar.bean.CalendarInfo;
@@ -66,6 +67,9 @@ public class CalendarValidator {
 		// ownerRoleId
 		CommonValidator.validateOwnerRoleId(calendarInfo.getOwnerRoleId(), true, calendarInfo.getId(), HinemosModuleConstant.PLATFORM_CALENDAR);
 		
+		// description
+		CommonValidator.validateString(Messages.getString("description"), calendarInfo.getDescription(), false, 0, 256);
+
 		if (calendarInfo.getValidTimeFrom() == null || calendarInfo.getValidTimeFrom() == 0) {
 			m_log.warn("validateCalendarInfo() " + Messages.getString("start"));
 			String[] args = { "(" + Messages.getString("start") + ")" };
@@ -95,10 +99,13 @@ public class CalendarValidator {
 	 * @throws InvalidRole
 	 */
 	private static void validdateCalendarDetailInfo(CalendarDetailInfo detailInfo, String ownerRoleId) throws InvalidSetting, InvalidRole {
+		//説明
+		CommonValidator.validateString(Messages.getString("description"), detailInfo.getDescription(), false, 0, 256);
+		
 		//年は必須項目のためチェック
 		if (detailInfo.getYear() == null || detailInfo.getYear() < 0) {
 			String[] args = { "(" + Messages.getString("year") + ")" };
-			m_log.warn("ValidYear:" + args.toString());
+			m_log.warn("ValidYear:" + args[0]);
 			throw new InvalidSetting(Messages.getString("message.calendar.15", args));
 		}
 		//月は必須項目のためチェック（コンボボックス入力だが、一応）
@@ -157,7 +164,7 @@ public class CalendarValidator {
 		}
 		if (detailInfo.getAfterday() != null) {
 			if (-32768 > detailInfo.getAfterday() || detailInfo.getAfterday() > 32767) {
-				String[] args = {Messages.getString("calendar.detail.before.after"), 
+				String[] args = {Messages.getString("calendar.detail.before.after"),
 						"-32768", "32767"};
 				m_log.warn("ValidAfterDay:" + args.toString());
 				throw new InvalidSetting(Messages.getString("message.calendar.52", args));
@@ -196,9 +203,9 @@ public class CalendarValidator {
 		CommonValidator.validateString(Messages.getString("calendar.pattern.name"), info.getName(), true, 1, 128);
 
 		// ownerRoleId
-		CommonValidator.validateOwnerRoleId(info.getOwnerRoleId(), true, 
+		CommonValidator.validateOwnerRoleId(info.getOwnerRoleId(), true,
 				info.getId(), HinemosModuleConstant.PLATFORM_CALENDAR_PATTERN);
-		
+
 		//カレンダパターン詳細チェック
 		for(YMD ymd : info.getYmd()){
 			validateYMD(ymd);
@@ -314,6 +321,19 @@ public class CalendarValidator {
 					}
 				}
 			}
+			//通知
+			List<NotifyInfoEntity> notifyInfoList =
+					com.clustercontrol.notify.util.QueryUtil.getNotifyInfoFindByCalendarId_NONE(calendarId);
+			if (notifyInfoList != null) {
+				for(NotifyInfoEntity notifyInfo : notifyInfoList){
+					m_log.debug("valideDeleteCalendar() target MaintenanceInfo " + notifyInfo.getNotifyId() + ", calendarId = " + calendarId);
+					if(notifyInfo.getCalendarId() != null){
+						String[] args = {notifyInfo.getNotifyId(), calendarId};
+						throw new InvalidSetting(Messages.getString("message.calendar.73", args));
+					}
+				}
+			}
+			
 		} catch (InvalidSetting e) {
 			throw e;
 		} catch (Exception e) {
