@@ -583,10 +583,6 @@ public class HinemosEntityManager implements EntityManager {
 				return;
 			}
 			String ownerRoleId = ((ObjectPrivilegeTargetEntity)before_entity).getOwnerRoleId();
-			// ALL_USERSロールの場合はオブジェクト権限有り
-			if (RoleIdConstant.ALL_USERS.equals(ownerRoleId)) {
-				return;		// オブジェクト権限有り
-			}
 			// 所属ロールの場合はオブジェクト権限有り
 			if (roleIdList.contains(ownerRoleId)) {
 				return;		// オブジェクト権限有り
@@ -595,20 +591,12 @@ public class HinemosEntityManager implements EntityManager {
 
 		String objectType = hinemosObjectPrivilege.objectType();
 		// オブジェクト権限テーブルにデータが存在するかの確認
-		// ALL_USERSロールが設定されている場合はオブジェクト権限有り
-		ObjectPrivilegeEntityPK objectPrivilegeEntityPK
-		= new ObjectPrivilegeEntityPK(objectType, ((ObjectPrivilegeTargetEntity)before_entity).getObjectId(), RoleIdConstant.ALL_USERS, mode.name());
-		ObjectPrivilegeEntity objectPrivilegeEntity = em.find(ObjectPrivilegeEntity.class, objectPrivilegeEntityPK);
-		if (objectPrivilegeEntity != null) {
-			return;	// オブジェクト権限有り
-		}
-
 		// 所属ロールが設定されている場合はオブジェクト権限有り
 		boolean existsflg = false;
 		for (String roleId : roleIdList) {
-			objectPrivilegeEntityPK
+			ObjectPrivilegeEntityPK objectPrivilegeEntityPK
 			= new ObjectPrivilegeEntityPK(objectType, ((ObjectPrivilegeTargetEntity)before_entity).getObjectId(), roleId, mode.name());
-			objectPrivilegeEntity = em.find(ObjectPrivilegeEntity.class, objectPrivilegeEntityPK);
+			ObjectPrivilegeEntity objectPrivilegeEntity = em.find(ObjectPrivilegeEntity.class, objectPrivilegeEntityPK);
 			if (objectPrivilegeEntity != null) {
 				existsflg = true;	// オブジェクト権限有り
 				break;
