@@ -1,12 +1,11 @@
 package com.clustercontrol.hinemosagent.bean;
 
+import java.io.Serializable;
+
 import com.clustercontrol.jobmanagement.bean.RunInstructionInfo;
 import com.clustercontrol.agent.bean.TopicFlagConstant;
 
-public class TopicInfo {
-	// facilityID
-	private String facilityId = "";
-
+public class TopicInfo implements Serializable {
 	// job
 	private RunInstructionInfo runInstructionInfo = null;
 
@@ -31,13 +30,6 @@ public class TopicInfo {
 				generateDate + topicValidPeriod * 1000);
 	}
 
-	public String getFacilityId() {
-		return facilityId;
-	}
-	public void setFacilityId(String facilityId) {
-		this.facilityId = facilityId;
-	}
-
 	public long getFlag() {
 		return flag;
 	}
@@ -142,26 +134,28 @@ public class TopicInfo {
 		if (otherTopic.getFlag() != this.getFlag()) {
 			return false;
 		}
-		if (otherTopic.facilityId == null && this.facilityId != null) {
-			return false;
-		}
-		if (otherTopic.facilityId != null && this.facilityId == null) {
-			return false;
-		}
 		if (otherTopic.runInstructionInfo == null && this.runInstructionInfo != null) {
 			return false;
 		}
 		if (otherTopic.runInstructionInfo != null && this.runInstructionInfo == null) {
 			return false;
 		}
-		if ((otherTopic.facilityId == null && this.facilityId == null) ||
-				(otherTopic.facilityId.equals(otherTopic.facilityId))) {
-			if (otherTopic.runInstructionInfo == null && this.runInstructionInfo == null) {
-				return true;
-			}
-			return otherTopic.runInstructionInfo.equals(this.runInstructionInfo);
+		if (otherTopic.runInstructionInfo == null && this.runInstructionInfo == null) {
+			return true;
 		}
-		return false;
+		return otherTopic.runInstructionInfo.equals(this.runInstructionInfo);
+	}
+	
+	@Override
+	public String toString() {
+		String ret = flag + "," + agentCommand;
+		if (runInstructionInfo != null) {
+			ret += "," + runInstructionInfo.getSessionId() + 
+					"," + runInstructionInfo.getJobunitId() + 
+					"," + runInstructionInfo.getJobId() +
+					"," + isValid();
+		}
+		return ret;
 	}
 
 	public static void main (String args[]) {
