@@ -15,14 +15,12 @@
 
 package com.clustercontrol.http.factory;
 
-import javax.ejb.CreateException;
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
-import com.clustercontrol.commons.scheduler.TriggerScheduler;
+import com.clustercontrol.fault.InvalidRole;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.http.util.ControlHttpInfo;
 import com.clustercontrol.monitor.run.factory.AddMonitor;
 import com.clustercontrol.monitor.run.factory.ModifyMonitorNumericValueType;
+import com.clustercontrol.plugin.impl.SchedulerPlugin.TriggerType;
 
 /**
  * HTTP監視 数値監視をマネージャで変更するクラス<BR>
@@ -36,7 +34,7 @@ public class ModifyMonitorHttp extends ModifyMonitorNumericValueType{
 	 * @see com.clustercontrol.monitor.run.factory.ModifyMonitor#modifyCheckInfo()
 	 */
 	@Override
-	protected boolean modifyCheckInfo() throws CreateException, FinderException, NamingException {
+	protected boolean modifyCheckInfo() throws MonitorNotFound, InvalidRole {
 
 		// HTTP監視情報を変更
 		ControlHttpInfo http = new ControlHttpInfo(m_monitorInfo.getMonitorId(), m_monitorInfo.getMonitorTypeId());
@@ -55,7 +53,7 @@ public class ModifyMonitorHttp extends ModifyMonitorNumericValueType{
 	 * スケジュール実行種別を返します。
 	 */
 	@Override
-	protected String getTriggerType() {
-		return TriggerScheduler.TRIGGER_TYPE_SIMPLE;
+	protected TriggerType getTriggerType() {
+		return TriggerType.SIMPLE;
 	}
 }
