@@ -582,6 +582,8 @@ public class RunMonitorHttpScenario extends RunMonitor {
 									variable.getId().getName(),
 									variable.getValue()));
 						}
+					} else {
+						value = variable.getValue();
 					}
 
 					if (value != null) {
