@@ -15,9 +15,7 @@
 
 package com.clustercontrol.http.factory;
 
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.http.bean.HttpCheckInfo;
 import com.clustercontrol.http.util.ControlHttpInfo;
 import com.clustercontrol.monitor.run.factory.SelectMonitor;
@@ -34,7 +32,7 @@ public class SelectMonitorHttp extends SelectMonitor{
 	 * @see com.clustercontrol.monitor.run.factory.SelectMonitor#getCheckInfo()
 	 */
 	@Override
-	protected HttpCheckInfo getHttpCheckInfo() throws FinderException, NamingException{
+	protected HttpCheckInfo getHttpCheckInfo() throws MonitorNotFound {
 
 		// HTTP監視情報を取得
 		ControlHttpInfo http = new ControlHttpInfo(m_monitorId, m_monitorTypeId);
