@@ -51,6 +51,8 @@ public class GetForwardFileTableDefine {
 	public static final int START_RERUN_TIME = 7;
 	/** 終了・中断日時 */
 	public static final int END_SUSPEND_TIME = 8;
+	/** 実行時間 */
+	public static final int SESSION_TIME = 9;
 
 	/** 初期表示時ソートカラム */
 	public static final int SORT_COLUMN_INDEX = STATUS;
@@ -87,6 +89,8 @@ public class GetForwardFileTableDefine {
 				new TableColumnInfo(Messages.getString("start.rerun.time", locale), TableColumnInfo.NONE, 140, SWT.LEFT));
 		tableDefine.add(END_SUSPEND_TIME,
 				new TableColumnInfo(Messages.getString("end.suspend.time", locale), TableColumnInfo.NONE, 140, SWT.LEFT));
+		tableDefine.add(SESSION_TIME,
+				new TableColumnInfo(Messages.getString("session.time", locale), TableColumnInfo.NONE, 70, SWT.LEFT));
 
 		return tableDefine;
 	}
