@@ -36,6 +36,8 @@ public class GetWaitRuleTableDefine {
 	public static final int JOB_ID = 1;
 	/** 値 */
 	public static final int START_VALUE = 2;
+	/**  セッション開始時の時間（分） */
+	public static final int START_MINUTE = 3;
 
 	/** 初期表示時ソートカラム */
 	public static final int SORT_COLUMN_INDEX = JUDGMENT_OBJECT;
@@ -52,7 +54,7 @@ public class GetWaitRuleTableDefine {
 		ArrayList<TableColumnInfo> tableDefine = new ArrayList<TableColumnInfo>();
 
 		tableDefine.add(JUDGMENT_OBJECT,
-				new TableColumnInfo(Messages.getString("name"), TableColumnInfo.JUDGMENT_OBJECT, 150, SWT.LEFT));
+				new TableColumnInfo(Messages.getString("name"), TableColumnInfo.JUDGMENT_OBJECT, 200, SWT.LEFT));
 		tableDefine.add(JOB_ID,
 				new TableColumnInfo(Messages.getString("job.id"), TableColumnInfo.NONE, 150, SWT.LEFT));
 		tableDefine.add(START_VALUE,
