@@ -39,10 +39,11 @@ import com.clustercontrol.composite.action.NumberVerifyListener;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * 制御タブ用のコンポジットクラスです。
- * 
+ *
  * @version 2.1.0
  * @since 2.1.0
  */
@@ -52,7 +53,7 @@ public class ControlComposite extends Composite {
 	/** スキップ用チェックボタン */
 	private Button m_skipCondition = null;
 	/** スキップ用グループ */
-	private Group m_skipEndConditionGroup = null;
+	private Group CtrlskipEndConditionGroup = null;
 	/** スキップ終了状態用テキスト */
 	private Combo m_skipEndStatus = null;
 	/** スキップ終了値用テキスト */
@@ -72,10 +73,10 @@ public class ControlComposite extends Composite {
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param parent 親コンポジット
 	 * @param style スタイル
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
 	 * @see #initialize()
@@ -97,16 +98,17 @@ public class ControlComposite extends Composite {
 		layout.fill = true;
 		this.setLayout(layout);
 
-		Composite composite = null;
 		RowLayout rowLayout = null;
 
 		//カレンダ
-		composite = new Composite(this, SWT.NONE);
+		Composite ctrlCalComposite = new Composite(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "cal", ctrlCalComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
-		composite.setLayout(rowLayout);
+		ctrlCalComposite.setLayout(rowLayout);
 
-		m_calendarCondition = new Button(composite, SWT.CHECK);
+		m_calendarCondition = new Button(ctrlCalComposite, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "calconditioncheck", m_calendarCondition);
 		m_calendarCondition.setText(Messages.getString("calendar"));
 		m_calendarCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -114,6 +116,7 @@ public class ControlComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_calendarConditionGroup.setEnabled(true);
 					m_calendarId.setEnabled(true);
@@ -135,6 +138,7 @@ public class ControlComposite extends Composite {
 		});
 
 		m_calendarConditionGroup = new Group(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "calcondition", m_calendarConditionGroup);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		rowLayout.marginWidth = 5;
@@ -142,30 +146,36 @@ public class ControlComposite extends Composite {
 		rowLayout.spacing = 1;
 		m_calendarConditionGroup.setLayout(rowLayout);
 
-		composite = new Composite(m_calendarConditionGroup, SWT.NONE);
+		Composite ctrlCalConditionComposite= new Composite(m_calendarConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "calcondition", ctrlCalConditionComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
 		rowLayout.marginHeight = 2;
-		composite.setLayout(rowLayout);
-		Label calendarIdTitle = new Label(composite, SWT.LEFT);
+		ctrlCalConditionComposite.setLayout(rowLayout);
+		Label calendarIdTitle = new Label(ctrlCalConditionComposite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "calendarid", calendarIdTitle);
 		calendarIdTitle.setText(Messages.getString("calendar.id") + " : ");
 		calendarIdTitle.setLayoutData(new RowData(80,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_calendarId = new CalendarIdListComposite(composite, SWT.NONE, false);
+		m_calendarId = new CalendarIdListComposite(ctrlCalConditionComposite, SWT.NONE, false);
+		WidgetTestUtil.setTestId(this, "idlist", m_calendarId);
 		m_calendarId.setEnabled(false);
 
 		// カレンダ終了状態
-		composite = new Composite(m_calendarConditionGroup, SWT.NONE);
+		Composite ctrlCalEndComposite= new Composite(m_calendarConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "calend", ctrlCalEndComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		Label calendarEndStatusTitle = new Label(composite, SWT.LEFT);
+		ctrlCalEndComposite.setLayout(rowLayout);
+		Label calendarEndStatusTitle = new Label(ctrlCalEndComposite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "endstatus", calendarEndStatusTitle);
 		calendarEndStatusTitle.setText(Messages.getString("end.status") + " : ");
 		calendarEndStatusTitle.setLayoutData(new RowData(80,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_calendarEndStatus = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
+		m_calendarEndStatus = new Combo(ctrlCalEndComposite, SWT.CENTER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "calendstatus", m_calendarEndStatus);
 		m_calendarEndStatus.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_COMBO_HEIGHT));
 		m_calendarEndStatus.add(EndStatusConstant.STRING_NORMAL);
@@ -173,16 +183,19 @@ public class ControlComposite extends Composite {
 		m_calendarEndStatus.add(EndStatusConstant.STRING_ABNORMAL);
 
 		// カレンダ終了値
-		composite = new Composite(m_calendarConditionGroup, SWT.NONE);
+		Composite ctrlCalEndValueComposite = new Composite(m_calendarConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "calendvalue", ctrlCalEndValueComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		Label calendarEndValueTitle = new Label(composite, SWT.LEFT);
+		ctrlCalEndValueComposite.setLayout(rowLayout);
+		Label calendarEndValueTitle = new Label(ctrlCalEndValueComposite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "endvalue", calendarEndValueTitle);
 		calendarEndValueTitle.setText(Messages.getString("end.value") + " : ");
 		calendarEndValueTitle.setLayoutData(new RowData(80,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_calendarEndValue = new Text(composite, SWT.BORDER);
+		m_calendarEndValue = new Text(ctrlCalEndValueComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "calendvalue", m_calendarEndValue);
 		m_calendarEndValue.setLayoutData(new RowData(100, SizeConstant.SIZE_TEXT_HEIGHT));
 		m_calendarEndValue.addVerifyListener(
 				new NumberVerifyListener(DataRangeConstant.SMALLINT_LOW, DataRangeConstant.SMALLINT_HIGH));
@@ -196,14 +209,17 @@ public class ControlComposite extends Composite {
 				);
 
 		//保留
-		composite = new Composite(this, SWT.NONE);
+		Composite ctrlReserveComposite = new Composite(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "reserve", ctrlReserveComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
-		composite.setLayout(rowLayout);
+		ctrlReserveComposite.setLayout(rowLayout);
 
-		Label dummy4 = new Label(composite, SWT.NONE);
+		Label dummy4 = new Label(ctrlReserveComposite, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "dymmy4", dummy4);
 		dummy4.setLayoutData(new RowData(190, SizeConstant.SIZE_LABEL_HEIGHT));
-		m_waitCondition = new Button(composite, SWT.CHECK);
+		m_waitCondition = new Button(ctrlReserveComposite, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "waitcondition", m_waitCondition);
 		m_waitCondition.setText(Messages.getString("reserve"));
 		m_waitCondition.setLayoutData(new RowData(200,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -211,9 +227,10 @@ public class ControlComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_skipCondition.setSelection(false);
-					m_skipEndConditionGroup.setEnabled(false);
+					CtrlskipEndConditionGroup.setEnabled(false);
 					m_skipEndStatus.setEnabled(false);
 					m_skipEndValue.setEnabled(false);
 				}
@@ -227,12 +244,14 @@ public class ControlComposite extends Composite {
 		});
 
 		//スキップ
-		composite = new Composite(this, SWT.NONE);
+		Composite ctrlSkipComposite = new Composite(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "skip", ctrlSkipComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
-		composite.setLayout(rowLayout);
+		ctrlSkipComposite.setLayout(rowLayout);
 
-		m_skipCondition = new Button(composite, SWT.CHECK);
+		m_skipCondition = new Button(ctrlSkipComposite, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "skipconditioncheck", m_skipCondition);
 		m_skipCondition.setText(Messages.getString("skip"));
 		m_skipCondition.setLayoutData(new RowData(200,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -240,13 +259,14 @@ public class ControlComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
-					m_skipEndConditionGroup.setEnabled(true);
+					CtrlskipEndConditionGroup.setEnabled(true);
 					m_skipEndStatus.setEnabled(true);
 					m_skipEndValue.setEnabled(true);
 					m_waitCondition.setSelection(false);
 				} else {
-					m_skipEndConditionGroup.setEnabled(false);
+					CtrlskipEndConditionGroup.setEnabled(false);
 					m_skipEndStatus.setEnabled(false);
 					m_skipEndValue.setEnabled(false);
 				}
@@ -259,25 +279,29 @@ public class ControlComposite extends Composite {
 			}
 		});
 
-		m_skipEndConditionGroup = new Group(this, SWT.NONE);
+		CtrlskipEndConditionGroup = new Group(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "skipend", CtrlskipEndConditionGroup);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		rowLayout.marginWidth = 5;
 		rowLayout.marginHeight = 5;
 		rowLayout.spacing = 1;
-		m_skipEndConditionGroup.setLayout(rowLayout);
+		CtrlskipEndConditionGroup.setLayout(rowLayout);
 
 		// スキップ終了状態
-		composite = new Composite(m_skipEndConditionGroup, SWT.NONE);
+		Composite ctrlSkipEndStatusComposite = new Composite(CtrlskipEndConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "skipend", ctrlSkipEndStatusComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		Label skipEndStatusTitle = new Label(composite, SWT.LEFT);
+		ctrlSkipEndStatusComposite.setLayout(rowLayout);
+		Label skipEndStatusTitle = new Label(ctrlSkipEndStatusComposite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "endstatus", skipEndStatusTitle);
 		skipEndStatusTitle.setText(Messages.getString("end.status") + " : ");
 		skipEndStatusTitle.setLayoutData(new RowData(80,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_skipEndStatus = new Combo(composite, SWT.CENTER | SWT.READ_ONLY);
+		m_skipEndStatus = new Combo(ctrlSkipEndStatusComposite, SWT.CENTER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "skipendstatus", m_skipEndStatus);
 		m_skipEndStatus.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_COMBO_HEIGHT));
 		m_skipEndStatus.add(EndStatusConstant.STRING_NORMAL);
@@ -285,16 +309,19 @@ public class ControlComposite extends Composite {
 		m_skipEndStatus.add(EndStatusConstant.STRING_ABNORMAL);
 
 		// スキップ終了値
-		composite = new Composite(m_skipEndConditionGroup, SWT.NONE);
+		Composite ctrlSkipEndValueComposite = new Composite(CtrlskipEndConditionGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "skipendvalue", ctrlSkipEndValueComposite);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
-		Label skipEndValueTitle = new Label(composite, SWT.LEFT);
+		ctrlSkipEndValueComposite.setLayout(rowLayout);
+		Label skipEndValueTitle = new Label(ctrlSkipEndValueComposite, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "endvalue", skipEndValueTitle);
 		skipEndValueTitle.setText(Messages.getString("end.value") + " : ");
 		skipEndValueTitle.setLayoutData(new RowData(80,
 				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_skipEndValue = new Text(composite, SWT.BORDER);
+		m_skipEndValue = new Text(ctrlSkipEndValueComposite, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "skipendvalue", m_skipEndValue);
 		m_skipEndValue.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		m_skipEndValue.addVerifyListener(
@@ -307,12 +334,11 @@ public class ControlComposite extends Composite {
 					}
 				}
 				);
-
 	}
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -331,7 +357,7 @@ public class ControlComposite extends Composite {
 
 	/**
 	 * ジョブ待ち条件情報をコンポジットに反映します。
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo
 	 */
 	public void reflectWaitRuleInfo() {
@@ -343,11 +369,7 @@ public class ControlComposite extends Composite {
 			//カレンダID
 			if (m_waitRule.getCalendarId() != null &&
 					m_waitRule.getCalendarId().length() > 0) {
-				if (!m_calendarId.getEnabled()) {
-					// カレンダー参照権限が無い場合
-					m_calendarId.addText(m_waitRule.getCalendarId());
-				}
-				this.m_calendarId.setText(m_waitRule.getCalendarId());
+				m_calendarId.setText(m_waitRule.getCalendarId());
 			}
 
 			//カレンダの終了状態
@@ -382,12 +404,12 @@ public class ControlComposite extends Composite {
 
 		//スキップ
 		if (m_skipCondition.getSelection()) {
-			m_skipEndConditionGroup.setEnabled(true);
+			CtrlskipEndConditionGroup.setEnabled(true);
 			m_skipEndStatus.setEnabled(true);
 			m_skipEndValue.setEnabled(true);
 			m_waitCondition.setSelection(false);
 		} else {
-			m_skipEndConditionGroup.setEnabled(false);
+			CtrlskipEndConditionGroup.setEnabled(false);
 			m_skipEndStatus.setEnabled(false);
 			m_skipEndValue.setEnabled(false);
 		}
@@ -398,7 +420,7 @@ public class ControlComposite extends Composite {
 
 	/**
 	 * ジョブ待ち条件情報を設定します。
-	 * 
+	 *
 	 * @param start ジョブ待ち条件情報
 	 */
 	public void setWaitRuleInfo(JobWaitRuleInfo start) {
@@ -407,7 +429,7 @@ public class ControlComposite extends Composite {
 
 	/**
 	 * ジョブ待ち条件情報を返します。
-	 * 
+	 *
 	 * @return ジョブ待ち条件情報
 	 */
 	public JobWaitRuleInfo getWaitRuleInfo() {
@@ -416,9 +438,9 @@ public class ControlComposite extends Composite {
 
 	/**
 	 * コンポジットの情報から、ジョブ待ち条件情報を作成する。
-	 * 
+	 *
 	 * @return 入力値の検証結果
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.JobWaitRuleInfo
 	 */
 	public ValidateResult createWaitRuleInfo() {
@@ -487,7 +509,7 @@ public class ControlComposite extends Composite {
 
 	/**
 	 *終了状態用コンボボックスにて選択している項目を取得します。
-	 * 
+	 *
 	 */
 	private int getSelectEndStatus(Combo combo) {
 		String select = combo.getText();
@@ -496,7 +518,7 @@ public class ControlComposite extends Composite {
 
 	/**
 	 * 指定した重要度に該当する終了状態用コンボボックスの項目を選択します。
-	 * 
+	 *
 	 */
 	private void setSelectEndStatus(Combo combo, int status) {
 		String select = "";
@@ -519,7 +541,7 @@ public class ControlComposite extends Composite {
 	public void setCalendarId(CalendarIdListComposite calendarId) {
 		this.m_calendarId = calendarId;
 	}
-	
+
 	/**
 	 * 読み込み専用時にグレーアウトします。
 	 */
@@ -537,4 +559,4 @@ public class ControlComposite extends Composite {
 	}
 
 
-}
\ No newline at end of file
+}
