@@ -31,7 +31,6 @@ import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Text;
 
-import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.EndStatusConstant;
 import com.clustercontrol.bean.PriorityConstant;
@@ -40,8 +39,10 @@ import com.clustercontrol.bean.SizeConstant;
 import com.clustercontrol.bean.StatusConstant;
 import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.composite.action.NumberVerifyListener;
+import com.clustercontrol.composite.action.PositiveNumberVerifyListener;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.ws.jobmanagement.JobCommandInfo;
 import com.clustercontrol.ws.jobmanagement.JobFileInfo;
 import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
@@ -318,7 +319,7 @@ public class ControlNodeComposite extends Composite {
 		WidgetTestUtil.setTestId(this, "messageretry", m_messageRetry);
 		m_messageRetry.setLayoutData(new RowData(100, SizeConstant.SIZE_TEXT_HEIGHT));
 		m_messageRetry.addVerifyListener(
-				new NumberVerifyListener(DataRangeConstant.SMALLINT_LOW, DataRangeConstant.SMALLINT_HIGH));
+				new PositiveNumberVerifyListener(1, DataRangeConstant.SMALLINT_HIGH));
 		m_messageRetry.addModifyListener(
 				new ModifyListener(){
 					@Override
@@ -411,7 +412,7 @@ public class ControlNodeComposite extends Composite {
 		//m_errorMessageRetry.setData(ClusterControlPlugin.CUSTOM_WIDGET_ID, "commandCompositeMessageRetryText");
 		m_commandRetry.setLayoutData(new RowData(100, SizeConstant.SIZE_TEXT_HEIGHT));
 		m_commandRetry.addVerifyListener(
-				new NumberVerifyListener(DataRangeConstant.SMALLINT_LOW, DataRangeConstant.SMALLINT_HIGH));
+				new PositiveNumberVerifyListener(1, DataRangeConstant.SMALLINT_HIGH));
 		m_commandRetry.addModifyListener(
 				new ModifyListener(){
 					@Override
