@@ -115,6 +115,10 @@ public class DetailComposite extends Composite {
 		m_viewer.createTableColumn(GetJobDetailTableDefine.get(),
 				GetJobDetailTableDefine.SORT_COLUMN_INDEX,
 				GetJobDetailTableDefine.SORT_ORDER);
+		// 列移動が可能に設定
+		for (int i = 0; i < tree.getColumnCount(); i++){
+			tree.getColumn(i).setMoveable(true);
+		}
 
 
 		m_viewer.addSelectionChangedListener(
