@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2006 NTT DATA Corporation
+//Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
@@ -36,7 +36,6 @@ import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.bean.SizeConstant;
 import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.composite.action.NumberVerifyListener;
 import com.clustercontrol.composite.action.StringVerifyListener;
 import com.clustercontrol.dialog.ScopeTreeDialog;
 import com.clustercontrol.dialog.ValidateResult;
@@ -46,10 +45,11 @@ import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.jobmanagement.JobFileInfo;
 import com.clustercontrol.ws.repository.FacilityInfo;
 import com.clustercontrol.ws.repository.FacilityTreeItem;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * ファイル転送タブ用のコンポジットクラスです。
- * 
+ *
  * @version 4.0.0
  * @since 2.0.0
  */
@@ -90,23 +90,21 @@ public class FileComposite extends Composite {
 	private String m_destFacilityId = null;
 	/** 受信ファシリティパス */
 	private String m_destFacilityPath = null;
-	/** リトライ回数用グループ */
-	private Group m_messageRetryGroup;
-	/** リトライ回数用テキスト */
-	private Text m_messageRetry;
 	/** ジョブファイル転送情報 */
 	private JobFileInfo m_jobFileInfo = null;
 	/** シェル */
 	private Shell m_shell = null;
 	/** オーナーロールID */
 	private String m_ownerRoleId = null;
+	/** マネージャ名 */
+	private String m_managerName = null;
 
 	/**
 	 * コンストラクタ
-	 * 
+	 *
 	 * @param parent 親コンポジット
 	 * @param style スタイル
-	 * 
+	 *
 	 * @see org.eclipse.swt.SWT
 	 * @see org.eclipse.swt.widgets.Composite#Composite(Composite parent, int style)
 	 * @see #initialize()
@@ -129,31 +127,34 @@ public class FileComposite extends Composite {
 		layout.fill = true;
 		this.setLayout(layout);
 
-		Composite composite = null;
 		RowLayout rowLayout = null;
 
 		//転送元用グループ
-		Group group = new Group(this, SWT.NONE);
-		group.setText(Messages.getString("forward.source"));
+		Group fileTransferFromgroup = new Group(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "transferfrom", fileTransferFromgroup);
+		fileTransferFromgroup.setText(Messages.getString("forward.source"));
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		rowLayout.marginWidth = 10;
 		rowLayout.marginHeight = 10;
-		group.setLayout(rowLayout);
+		fileTransferFromgroup.setLayout(rowLayout);
 
 		//転送元スコープ用コンポジット
-		composite = new Composite(group, SWT.NONE);
+		Composite fileComposite1 = new Composite(fileTransferFromgroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "srcscope", fileComposite1);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
+		fileComposite1.setLayout(rowLayout);
 
-		Label srcScopeTitle = new Label(composite, SWT.NONE);
+		Label srcScopeTitle = new Label(fileComposite1, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "scopetitle", srcScopeTitle);
 		srcScopeTitle.setText(Messages.getString("scope") + " : ");
 		srcScopeTitle.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 
-		this.m_srcScope = new Text(composite, SWT.BORDER | SWT.READ_ONLY);
+		this.m_srcScope = new Text(fileComposite1, SWT.BORDER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "srcscope", m_srcScope);
 		this.m_srcScope.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
 		this.m_srcScope.setText("");
 		this.m_srcScope.addModifyListener(new ModifyListener(){
@@ -163,14 +164,15 @@ public class FileComposite extends Composite {
 			}
 		});
 
-		m_srcScopeSelect = new Button(composite, SWT.NONE);
+		m_srcScopeSelect = new Button(fileComposite1, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "srcscopeselect", m_srcScopeSelect);
 		m_srcScopeSelect.setText(Messages.getString("refer"));
 		m_srcScopeSelect.setLayoutData(new RowData(80,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_srcScopeSelect.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell, m_ownerRoleId);
+				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell, m_managerName, m_ownerRoleId);
 				// ノードのみ選択可能とする。
 				dialog.setSelectNodeOnly(true);
 				if (dialog.open() == IDialogConstants.OK_ID) {
@@ -187,18 +189,21 @@ public class FileComposite extends Composite {
 		});
 
 		//転送ファイル用コンポジット
-		composite = new Composite(group, SWT.NONE);
+		Composite fileComposite2 = new Composite(fileTransferFromgroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "file", fileComposite2);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
+		fileComposite2.setLayout(rowLayout);
 
-		Label fileTitle = new Label(composite, SWT.NONE);
+		Label fileTitle = new Label(fileComposite2, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "filetitle", fileTitle);
 		fileTitle.setText(Messages.getString("file") + " : ");
 		fileTitle.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 
-		this.m_srcFile = new Text(composite, SWT.BORDER);
+		this.m_srcFile = new Text(fileComposite2, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "srcfile", m_srcFile);
 		this.m_srcFile.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
 		this.m_srcFile.addVerifyListener(
 				new StringVerifyListener(DataRangeConstant.VARCHAR_4096));
@@ -211,27 +216,31 @@ public class FileComposite extends Composite {
 		});
 
 		//転送先用グループ
-		group = new Group(this, SWT.NONE);
-		group.setText(Messages.getString("forward.destination"));
+		Group fileTransferTogroup = new Group(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "filetransferto", fileTransferTogroup);
+		fileTransferTogroup.setText(Messages.getString("forward.destination"));
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		rowLayout.marginWidth = 10;
 		rowLayout.marginHeight = 10;
-		group.setLayout(rowLayout);
+		fileTransferTogroup.setLayout(rowLayout);
 
 		//転送先スコープ用コンポジット
-		composite = new Composite(group, SWT.NONE);
+		Composite fileComposite3 = new Composite(fileTransferTogroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "destscope", fileComposite3);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
+		fileComposite3.setLayout(rowLayout);
 
-		Label destScopeTitle = new Label(composite, SWT.NONE);
+		Label destScopeTitle = new Label(fileComposite3, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "destscopetitle", destScopeTitle);
 		destScopeTitle.setText(Messages.getString("scope") + " : ");
 		destScopeTitle.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 
-		this.m_destScope = new Text(composite, SWT.BORDER | SWT.READ_ONLY);
+		this.m_destScope = new Text(fileComposite3, SWT.BORDER | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "destscope", m_destScope);
 		this.m_destScope.setLayoutData(new RowData(200, SizeConstant.SIZE_TEXT_HEIGHT));
 		this.m_destScope.setText("");
 		this.m_destScope.addModifyListener(new ModifyListener(){
@@ -241,14 +250,15 @@ public class FileComposite extends Composite {
 			}
 		});
 
-		m_destScopeSelect = new Button(composite, SWT.NONE);
+		m_destScopeSelect = new Button(fileComposite3, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "destscopeselect", m_destScopeSelect);
 		m_destScopeSelect.setText(Messages.getString("refer"));
 		m_destScopeSelect.setLayoutData(new RowData(80,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_destScopeSelect.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell, m_ownerRoleId);
+				ScopeTreeDialog dialog = new ScopeTreeDialog(m_shell, m_managerName, m_ownerRoleId);
 				if (dialog.open() == IDialogConstants.OK_ID) {
 					FacilityTreeItem selectItem = dialog.getSelectItem();
 					FacilityInfo info = selectItem.getData();
@@ -263,7 +273,8 @@ public class FileComposite extends Composite {
 		});
 
 		//処理方式グループ
-		Group methodGroup = new Group(group, SWT.NONE);
+		Group methodGroup = new Group(fileTransferTogroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "method", methodGroup);
 		methodGroup.setText(Messages.getString("process.method"));
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
@@ -272,27 +283,32 @@ public class FileComposite extends Composite {
 		methodGroup.setLayout(rowLayout);
 
 		m_allNode = new Button(methodGroup, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "allnode", m_allNode);
 		m_allNode.setText(Messages.getString("forward.all.nodes"));
 		m_allNode.setLayoutData(
 				new RowData(220, SizeConstant.SIZE_BUTTON_HEIGHT));
 		m_oneNode = new Button(methodGroup, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "onenode", m_oneNode);
 		m_oneNode.setText(Messages.getString("forward.one.node"));
 		m_oneNode.setLayoutData(
 				new RowData(250, SizeConstant.SIZE_BUTTON_HEIGHT));
 
 		//転送先ディレクトリ用コンポジット
-		composite = new Composite(group, SWT.NONE);
+		Composite fileComposite4 = new Composite(fileTransferTogroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "directory", fileComposite4);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
+		fileComposite4.setLayout(rowLayout);
 
-		Label forwardDirTitle = new Label(composite, SWT.NONE);
+		Label forwardDirTitle = new Label(fileComposite4, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "forwarddirtitle", forwardDirTitle);
 		forwardDirTitle.setText(Messages.getString("directory") + " : ");
 		forwardDirTitle.setLayoutData(new RowData(100,
 				SizeConstant.SIZE_LABEL_HEIGHT));
 
-		this.m_destDirectory = new Text(composite, SWT.BORDER);
+		this.m_destDirectory = new Text(fileComposite4, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "destdirectory", m_destDirectory);
 		this.m_destDirectory.setLayoutData(new RowData(200,
 				SizeConstant.SIZE_TEXT_HEIGHT));
 		this.m_destDirectory.addVerifyListener(
@@ -305,36 +321,42 @@ public class FileComposite extends Composite {
 		});
 
 		//ファイル圧縮用コンポジット
-		composite = new Composite(this, SWT.NONE);
+		Composite fileComposite5 = new Composite(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "compression", fileComposite5);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
-		composite.setLayout(rowLayout);
+		fileComposite5.setLayout(rowLayout);
 
-		m_compressionCondition = new Button(composite, SWT.CHECK);
+		m_compressionCondition = new Button(fileComposite5, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "compressioncondition", m_compressionCondition);
 		m_compressionCondition.setText(Messages.getString("forward.compression.file"));
 		m_compressionCondition.setLayoutData(new RowData(220,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 
-		m_checkFileCondition = new Button(composite, SWT.CHECK);
+		m_checkFileCondition = new Button(fileComposite5, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "checkfile", m_checkFileCondition);
 		m_checkFileCondition.setText(Messages.getString("forward.file.check"));
 		m_checkFileCondition.setLayoutData(new RowData(250,
 				SizeConstant.SIZE_BUTTON_HEIGHT));
 
-		group = new Group(this, SWT.NONE);
-		group.setText(Messages.getString("effective.user"));
+		Group fileEffectiveUserGroup = new Group(this, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "effectiveuser", fileEffectiveUserGroup);
+		fileEffectiveUserGroup.setText(Messages.getString("effective.user"));
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.VERTICAL;
 		rowLayout.marginWidth = 10;
 		rowLayout.marginHeight = 10;
-		group.setLayout(rowLayout);
+		fileEffectiveUserGroup.setLayout(rowLayout);
 
-		composite = new Composite(group, SWT.NONE);
+		Composite fileComposite6 = new Composite(fileEffectiveUserGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "agentuser", fileComposite6);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
+		fileComposite6.setLayout(rowLayout);
 
-		m_agentUser = new Button(composite, SWT.RADIO);
+		m_agentUser = new Button(fileComposite6, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "agentuser", m_agentUser);
 		m_agentUser.setText(Messages.getString("agent.user"));
 		m_agentUser.setLayoutData(
 				new RowData(350, SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -342,6 +364,7 @@ public class FileComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_specifyUser.setSelection(false);
 					m_user.setEnabled(false);
@@ -355,13 +378,15 @@ public class FileComposite extends Composite {
 			}
 		});
 
-		composite = new Composite(group, SWT.NONE);
+		Composite fileComposite7 = new Composite(fileEffectiveUserGroup, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "specifyuser", fileComposite7);
 		rowLayout = new RowLayout();
 		rowLayout.type = SWT.HORIZONTAL;
 		rowLayout.spacing = 10;
-		composite.setLayout(rowLayout);
+		fileComposite7.setLayout(rowLayout);
 
-		m_specifyUser = new Button(composite, SWT.RADIO);
+		m_specifyUser = new Button(fileComposite7, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "specifyuser", m_specifyUser);
 		m_specifyUser.setText(Messages.getString("specified.user"));
 		m_specifyUser.setLayoutData(
 				new RowData(120, SizeConstant.SIZE_BUTTON_HEIGHT));
@@ -369,6 +394,7 @@ public class FileComposite extends Composite {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				Button check = (Button) e.getSource();
+				WidgetTestUtil.setTestId(this, null, check);
 				if (check.getSelection()) {
 					m_agentUser.setSelection(false);
 					m_user.setEnabled(true);
@@ -382,7 +408,8 @@ public class FileComposite extends Composite {
 			}
 		});
 
-		this.m_user = new Text(composite, SWT.BORDER);
+		this.m_user = new Text(fileComposite7, SWT.BORDER);
+		WidgetTestUtil.setTestId(this, "user", m_user);
 		this.m_user.setLayoutData(new RowData(300, SizeConstant.SIZE_TEXT_HEIGHT));
 		this.m_user.addVerifyListener(
 				new StringVerifyListener(DataRangeConstant.VARCHAR_64));
@@ -393,41 +420,11 @@ public class FileComposite extends Composite {
 			}
 		});
 
-		// リトライ回数
-		m_messageRetryGroup = new Group(this, SWT.NONE);
-		m_messageRetryGroup.setText(Messages.getString("job.timeout"));
-		rowLayout = new RowLayout();
-		rowLayout.type = SWT.VERTICAL;
-		rowLayout.marginWidth = 5;
-		rowLayout.marginHeight = 5;
-		rowLayout.spacing = 1;
-		m_messageRetryGroup.setLayout(rowLayout);
-
-		composite = new Composite(m_messageRetryGroup, SWT.NONE);
-		rowLayout = new RowLayout();
-		rowLayout.type = SWT.HORIZONTAL;
-		composite.setLayout(rowLayout);
-		Label messageRetryTitle = new Label(composite, SWT.LEFT);
-		messageRetryTitle.setText(Messages.getString("job.retries") + " : ");
-		messageRetryTitle.setLayoutData(new RowData(100,
-				SizeConstant.SIZE_LABEL_HEIGHT));
-		m_messageRetry= new Text(composite, SWT.BORDER);
-		m_messageRetry.setLayoutData(new RowData(300, SizeConstant.SIZE_TEXT_HEIGHT));
-		m_messageRetry.addVerifyListener(
-				new NumberVerifyListener(DataRangeConstant.SMALLINT_LOW, DataRangeConstant.SMALLINT_HIGH));
-		m_messageRetry.addModifyListener(
-				new ModifyListener(){
-					@Override
-					public void modifyText(ModifyEvent arg0) {
-						update();
-					}
-				}
-				);
 	}
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -457,17 +454,11 @@ public class FileComposite extends Composite {
 		}else{
 			this.m_destDirectory.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
 		}
-		if("".equals(this.m_messageRetry.getText())){
-			this.m_messageRetry.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-		}else{
-			this.m_messageRetry.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-		}
-
 	}
 
 	/**
 	 * ジョブファイル転送情報をコンポジットに反映します。
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.JobFileInfo
 	 */
 	public void reflectFileInfo() {
@@ -484,7 +475,6 @@ public class FileComposite extends Composite {
 		m_specifyUser.setSelection(false);
 		m_user.setText("");
 		m_user.setEnabled(false);
-		m_messageRetry.setText("10");
 
 		if (m_jobFileInfo != null) {
 			//転送元スコープ設定
@@ -536,14 +526,12 @@ public class FileComposite extends Composite {
 			if (m_jobFileInfo.getUser() != null && m_jobFileInfo.getUser().length() > 0) {
 				m_user.setText(m_jobFileInfo.getUser());
 			}
-			//リトライ回数
-			m_messageRetry.setText(String.valueOf(m_jobFileInfo.getMessageRetry()));
 		}
 	}
 
 	/**
 	 * ジョブファイル転送情報を設定します。
-	 * 
+	 *
 	 * @param jobFileInfo ジョブファイル転送情報
 	 */
 	public void setFileInfo(JobFileInfo jobFileInfo) {
@@ -552,7 +540,7 @@ public class FileComposite extends Composite {
 
 	/**
 	 * ジョブファイル転送情報を返します。
-	 * 
+	 *
 	 * @return ジョブファイル転送情報
 	 */
 	public JobFileInfo getFileInfo() {
@@ -561,9 +549,9 @@ public class FileComposite extends Composite {
 
 	/**
 	 * コンポジットの情報から、ジョブファイル転送情報を作成する。
-	 * 
+	 *
 	 * @return 入力値の検証結果
-	 * 
+	 *
 	 * @see com.clustercontrol.jobmanagement.bean.JobFileInfo
 	 */
 	public ValidateResult createFileInfo() {
@@ -665,26 +653,6 @@ public class FileComposite extends Composite {
 			}
 		}
 
-		//リトライ回数
-		try {
-			if (m_messageRetry.getText().length() > 0) {
-				m_jobFileInfo.setMessageRetry(Integer.parseInt(m_messageRetry.getText()));
-			} else {
-				result = new ValidateResult();
-				result.setValid(false);
-				result.setID(Messages.getString("message.hinemos.1"));
-				//FIXME
-				result.setMessage(Messages.getString("message.job.87"));
-				return result;
-			}
-		} catch(NumberFormatException e) {
-			result = new ValidateResult();
-			result.setValid(false);
-			result.setID(Messages.getString("message.hinemos.1"));
-			result.setMessage(Messages.getString("message.job.87"));
-			return result;
-		}
-
 		return null;
 	}
 
@@ -695,7 +663,11 @@ public class FileComposite extends Composite {
 		this.m_srcScope.setText("");
 		this.m_srcFacilityId = null;
 	}
-	
+
+	public void setManagerName(String managerName) {
+		this.m_managerName = managerName;
+	}
+
 	/**
 	 * 読み込み専用時にグレーアウトします。
 	 */
@@ -715,6 +687,5 @@ public class FileComposite extends Composite {
 		m_oneNode.setEnabled(enabled);
 		m_compressionCondition.setEnabled(enabled);
 		m_checkFileCondition.setEnabled(enabled);
-		m_messageRetry.setEnabled(enabled);
 	}
-}
\ No newline at end of file
+}
