@@ -112,6 +112,10 @@ public class ForwardFileComposite extends Composite {
 		m_viewer.createTableColumn(GetForwardFileTableDefine.get(),
 				GetForwardFileTableDefine.SORT_COLUMN_INDEX,
 				GetForwardFileTableDefine.SORT_ORDER);
+		// 列移動が可能に設定
+		for (int i = 0; i < table.getColumnCount(); i++){
+			table.getColumn(i).setMoveable(true);
+		}
 	}
 
 	/**
