@@ -106,6 +106,10 @@ public class JobKickListComposite extends Composite {
 				GetJobKickTableDefine.SORT_COLUMN_INDEX1,
 				GetJobKickTableDefine.SORT_COLUMN_INDEX2,
 				GetJobKickTableDefine.SORT_ORDER);
+		// 列移動が可能に設定
+		for (int i = 0; i < table.getColumnCount(); i++){
+			table.getColumn(i).setMoveable(true);
+		}
 
 		m_viewer
 		.addSelectionChangedListener(new JobKickSelectionChangedListener(
