@@ -120,7 +120,10 @@ public class JobPlanComposite extends Composite {
 				GetPlanTableDefine.SORT_COLUMN_INDEX1,
 				GetPlanTableDefine.SORT_COLUMN_INDEX2,
 				GetPlanTableDefine.SORT_ORDER);
-
+		// 列移動が可能に設定
+		for (int i = 0; i < table.getColumnCount(); i++){
+			table.getColumn(i).setMoveable(true);
+		}
 		m_viewer.addDoubleClickListener(
 				new SessionJobDoubleClickListener(this));
 	}
