@@ -117,6 +117,10 @@ public class NodeDetailComposite extends Composite {
 		m_viewer.createTableColumn(GetNodeDetailTableDefine.get(),
 				GetNodeDetailTableDefine.SORT_COLUMN_INDEX,
 				GetNodeDetailTableDefine.SORT_ORDER);
+		// 列移動が可能に設定
+		for (int i = 0; i < table.getColumnCount(); i++){
+			table.getColumn(i).setMoveable(true);
+		}
 
 		m_viewer
 		.addSelectionChangedListener(new NodeDetailSelectionChangedListener(
