@@ -15,38 +15,37 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.jobmanagement.factory;
 
-import java.sql.Timestamp;
 import java.util.ArrayList;
 import java.util.List;
 
 import javax.persistence.EntityExistsException;
-import javax.persistence.EntityManager;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
+import com.clustercontrol.bean.StatusConstant;
+import com.clustercontrol.bean.YesNoConstant;
+import com.clustercontrol.commons.util.HinemosEntityManager;
+import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.commons.util.NotifyGroupIdGenerator;
 import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.JobInfoNotFound;
 import com.clustercontrol.fault.JobMasterNotFound;
 import com.clustercontrol.fault.JobSessionDuplicate;
-import com.clustercontrol.bean.StatusConstant;
-import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.commons.util.HinemosProperties;
-import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.jobmanagement.bean.DelayNotifyConstant;
 import com.clustercontrol.jobmanagement.bean.EndStatusCheckConstant;
 import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.bean.JobParamTypeConstant;
+import com.clustercontrol.jobmanagement.bean.JobSessionRequestMessage;
 import com.clustercontrol.jobmanagement.bean.JobTriggerInfo;
 import com.clustercontrol.jobmanagement.bean.SystemParameterConstant;
 import com.clustercontrol.jobmanagement.model.JobEndInfoEntity;
 import com.clustercontrol.jobmanagement.model.JobEndMstEntity;
 import com.clustercontrol.jobmanagement.model.JobInfoEntity;
 import com.clustercontrol.jobmanagement.model.JobMstEntity;
-import com.clustercontrol.jobmanagement.model.JobNoticeInfoEntity;
-import com.clustercontrol.jobmanagement.model.JobNoticeMstEntity;
 import com.clustercontrol.jobmanagement.model.JobParamInfoEntity;
 import com.clustercontrol.jobmanagement.model.JobParamMstEntity;
 import com.clustercontrol.jobmanagement.model.JobSessionEntity;
@@ -60,7 +59,7 @@ import com.clustercontrol.jobmanagement.util.QueryUtil;
 import com.clustercontrol.notify.bean.NotifyRelationInfo;
 import com.clustercontrol.notify.bean.OutputBasicInfo;
 import com.clustercontrol.notify.session.NotifyControllerBean;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
+import com.clustercontrol.plugin.impl.AsyncWorkerPlugin;
 import com.clustercontrol.repository.bean.NodeInfo;
 import com.clustercontrol.repository.session.RepositoryControllerBean;
 
@@ -80,7 +79,7 @@ public class CreateJobSession {
 
 	/**
 	 * ジョブの実行用情報を階層に従い作成します。<BR>
-	 * 
+	 *
 	 * @param jobunitId 所属ジョブユニットのジョブID
 	 * @param jobId ジョブID
 	 * @param info ログ出力情報
@@ -92,68 +91,20 @@ public class CreateJobSession {
 	 * @throws HinemosUnknown
 	 * @throws JobSessionDuplicate
 	 * @throws InvalidRole
-	 * 
+	 *
 	 */
-	public static JobSessionJobEntityPK makeSession(String jobunitId, String jobId, OutputBasicInfo info, JobTriggerInfo triggerInfo)
-			throws FacilityNotFound, JobMasterNotFound, JobInfoNotFound, HinemosUnknown, JobSessionDuplicate, InvalidRole {
+	public static String makeSession(String jobunitId, String jobId, OutputBasicInfo info, JobTriggerInfo triggerInfo)
+			throws HinemosUnknown {
+		String sessionId = CreateSessionId.create();
+		m_log.debug("makeSession() sessionId=" + sessionId);
+		
+		JobSessionRequestMessage message = new JobSessionRequestMessage(sessionId, jobunitId, jobId, info, triggerInfo);
+		AsyncWorkerPlugin.addTask(CreateJobSessionTaskFactory.class.getSimpleName(), message, true);
 
-		JpaTransactionManager jtm = new JpaTransactionManager();
-		JobSessionJobEntityPK jobSessionJobEntityPk = null;
-
-		try {
-			JobMstEntity job = QueryUtil.getJobMstPK(jobunitId, jobId);
-
-			String sessionId = CreateSessionId.create();
-			m_log.debug("makeSession() sessionId=" + sessionId);
-
-			//JobSessionを作成
-			JobSessionEntity jobSessionEntity = new JobSessionEntity(sessionId);
-			// 重複チェック
-			jtm.checkEntityExists(JobSessionEntity.class, jobSessionEntity.getSessionId());
-			jobSessionEntity.setJobunitId(jobunitId);
-			jobSessionEntity.setJobId(job.getId().getJobId());
-			jobSessionEntity.setScheduleDate(new Timestamp(System.currentTimeMillis()));
-			jobSessionEntity.setOperationFlg(0);
-			jobSessionEntity.setTriggerType(triggerInfo.getTrigger_type());
-			jobSessionEntity.setTriggerInfo(triggerInfo.getTrigger_info());
-			jobSessionEntity.setFilename(triggerInfo.getFilename());
-
-			m_log.trace("jobSessionEntity SessionId : " + jobSessionEntity.getSessionId());
-			m_log.trace("jobSessionEntity JobUnitId : " + jobSessionEntity.getJobunitId());
-			m_log.trace("jobSessionEntity JobId : " + jobSessionEntity.getJobId());
-
-			// 最上位のジョブセッション作成
-			// インスタンス生成
-			JobSessionJobEntity jobSessionJobEntity
-			= new JobSessionJobEntity(jobSessionEntity, TOP_JOBUNIT_ID, TOP_JOB_ID);
-			// 重複チェック
-			jtm.checkEntityExists(JobSessionJobEntity.class, jobSessionJobEntity.getId());
-			jobSessionJobEntity.setStatus(StatusConstant.TYPE_WAIT);
-			// ジョブセッション作成(このジョブは待ち条件は無視する。)
-			jobSessionJobEntityPk = createJobSessionJob(job, sessionId, info, true);
-
-		} catch (JobMasterNotFound e) {
-			throw e;
-		} catch (JobInfoNotFound e) {
-			throw e;
-		} catch (FacilityNotFound e) {
-			throw e;
-		} catch (HinemosUnknown e) {
-			throw e;
-		} catch (InvalidRole e) {
-			throw e;
-		} catch (EntityExistsException e) {
-			m_log.warn("makeSession() : "
-					+ e.getClass().getSimpleName() + ", " + e.getMessage());
-			throw new JobSessionDuplicate(e.getMessage(), e);
-		} catch (Exception e) {
-			m_log.warn("makeSession() : "
-					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-			throw new HinemosUnknown(e.getMessage(), e);
-		}
-		//return sessionId;
-		return jobSessionJobEntityPk;
+		return sessionId;
 	}
+	
+
 
 	/**
 	 * ジョブの実行用情報を作成します。
@@ -165,7 +116,7 @@ public class CreateJobSession {
 	 * <li>ジョブ待ち条件情報を作成します。</li>
 	 * <li>ジョブコマンド情報を作成します。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @param job ファイル転送ジョブのジョブマスタ
 	 * @param sessionId セッションID
 	 * @return
@@ -176,18 +127,18 @@ public class CreateJobSession {
 	 * @throws JobMasterNotFound
 	 * @throws InvalidRole
 	 */
-	private static JobSessionJobEntityPK createJobSessionJob(JobMstEntity job, String sessionId, OutputBasicInfo info, boolean first)
+	public static JobSessionJobEntityPK createJobSessionJob(JobMstEntity job, String sessionId, OutputBasicInfo info, boolean first, JobTriggerInfo triggerInfo)
 			throws JobInfoNotFound, FacilityNotFound, EntityExistsException, HinemosUnknown, JobMasterNotFound, InvalidRole {
 
 		JpaTransactionManager jtm = new JpaTransactionManager();
-		EntityManager em = jtm.getEntityManager();
+		HinemosEntityManager em = jtm.getEntityManager();
 
 		String jobunitId = job.getId().getJobunitId();
 		String jobId = job.getId().getJobId();
 		JobMstEntity referJob = null;
 
 		//JobSessionEntityを設定
-		JobSessionEntity jobSessionEntity = em.find(JobSessionEntity.class, sessionId);
+		JobSessionEntity jobSessionEntity = em.find(JobSessionEntity.class, sessionId, ObjectPrivilegeMode.READ);
 		//親ジョブを設定
 		JobSessionJobEntity parentJobSessionJobEntity = null;
 		try {
@@ -304,16 +255,22 @@ public class CreateJobSession {
 		if(job.getJobType() == JobConstant.TYPE_JOB){
 			jobInfoEntity.setFacilityId(job.getFacilityId());
 			jobInfoEntity.setProcessMode(job.getProcessMode());
-			jobInfoEntity.setStartCommand(job.getStartCommand());
+			if (triggerInfo.getJobCommand()) {
+				jobInfoEntity.setStartCommand(triggerInfo.getJobCommandText());
+			} else {
+				jobInfoEntity.setStartCommand(job.getStartCommand());
+			}
 			jobInfoEntity.setStopType(job.getStopType());
 			jobInfoEntity.setStopCommand(job.getStopCommand());
 			jobInfoEntity.setSpecifyUser(job.getSpecifyUser());
 			jobInfoEntity.setEffectiveUser(job.getEffectiveUser());
-			jobInfoEntity.setErrorEndFlg(job.getErrorEndFlg());
-			jobInfoEntity.setErrorEndValue(job.getErrorEndValue());
+			jobInfoEntity.setMessageRetryEndFlg(job.getMessageRetryEndFlg());
+			jobInfoEntity.setMessageRetryEndValue(job.getMessageRetryEndValue());
 			jobInfoEntity.setArgumentJobId(job.getArgumentJobId());
 			jobInfoEntity.setArgument(job.getArgument());
 			jobInfoEntity.setMessageRetry(job.getMessageRetry());
+			jobInfoEntity.setCommandRetryFlg(job.getCommandRetryFlg());
+			jobInfoEntity.setCommandRetry(job.getCommandRetry());
 		}
 
 		//ファイル転送情報を設定
@@ -330,13 +287,10 @@ public class CreateJobSession {
 			jobInfoEntity.setSpecifyUser(job.getSpecifyUser());
 			jobInfoEntity.setEffectiveUser(job.getEffectiveUser());
 			jobInfoEntity.setMessageRetry(job.getMessageRetry());
-
-			//ファイル転送を行うジョブネットの実行用情報を作成
-			if (CreateHulftJob.hulftMode) {
-				new CreateHulftJob().createHulftDetailJob(jobInfoEntity);
-			} else {
-				new CreateFileJob().createGetFileListJob(jobInfoEntity);
-			}
+			jobInfoEntity.setMessageRetryEndFlg(job.getMessageRetryEndFlg());
+			jobInfoEntity.setMessageRetryEndValue(job.getMessageRetryEndValue());
+			jobInfoEntity.setCommandRetryFlg(job.getCommandRetryFlg());
+			jobInfoEntity.setCommandRetry(job.getCommandRetry());
 		}
 
 		// 待ち条件を設定
@@ -354,7 +308,20 @@ public class CreateJobSession {
 			} else {
 				tmp = job;
 			}
-			jobInfoEntity.setStartTime(tmp.getStartTime());
+			//待ち条件－時刻
+			if (triggerInfo.getJobWaitTime()) {
+				jobInfoEntity.setStartTime(null);
+			} else {
+				jobInfoEntity.setStartTime(tmp.getStartTime());
+			}
+
+			//待ち条件－セッション開始時の時間（分）
+			if (triggerInfo.getJobWaitMinute()) {
+				jobInfoEntity.setStartMinute(null);
+			} else {
+				jobInfoEntity.setStartMinute(tmp.getStartMinute());
+			}
+
 			//JobStartJobInfoEntityを作成
 			List<JobStartJobMstEntity> jobStartJobMstEntityList = tmp.getJobStartJobMstEntities();
 			if (jobStartJobMstEntityList != null) {
@@ -397,18 +364,26 @@ public class CreateJobSession {
 					jobParamInfoEntity.setDescription(jobParamMstEntity.getDescription());
 					//パラメータ値を取得
 					String value = null;
-					if(jobParamMstEntity.getParamType() == JobParamTypeConstant.TYPE_SYSTEM){
-						//システム変数
+					if(jobParamMstEntity.getParamType() == JobParamTypeConstant.TYPE_SYSTEM_JOB){
+						//システム変数（ジョブ）
 						// システム変数に格納する情報が、どの機能のものかチェック
 						int functionType = ParameterUtil.checkFunctionType(jobParamMstEntity.getId().getParamId());
-						if (functionType == ParameterUtil.TYPE_JOB){
-							// ジョブ管理の情報を取得する場合
+						String paramId = jobParamMstEntity.getId().getParamId();
+						if (functionType == ParameterUtil.TYPE_JOB
+								&& SystemParameterConstant.FILENAME.equals(paramId)) {
+							// ジョブ管理(FILENAME)の情報を取得する場合
+							value = triggerInfo.getFilename();
+						} else if (functionType == ParameterUtil.TYPE_JOB
+								&& SystemParameterConstant.DIRECTORY.equals(paramId)) {
+								// ジョブ管理(DIRECTORY)の情報を取得する場合
+								value = triggerInfo.getDirectory();
+						} else if (functionType == ParameterUtil.TYPE_JOB) {
 							value = ParameterUtil.getJobParameterValue(sessionId, jobParamMstEntity.getId().getParamId());
 						} else if (functionType == ParameterUtil.TYPE_MONITOR){
 							// 監視管理の情報を取得する場合
 							value = ParameterUtil.getParameterValue(jobParamMstEntity.getId().getParamId(), info);
 						}
-					}else{
+					} else if(jobParamMstEntity.getParamType() == JobParamTypeConstant.TYPE_USER) {
 						//ユーザ変数
 						value = jobParamMstEntity.getValue();
 					}
@@ -465,44 +440,32 @@ public class CreateJobSession {
 			}
 		}
 
-		//JobNoticeEntityを作成
-		List<JobNoticeMstEntity> jobNoticeMstEntityList = job.getJobNoticeMstEntities();
-		if (jobNoticeMstEntityList != null) {
-			for(JobNoticeMstEntity jobNoticeMstEntity : jobNoticeMstEntityList) {
-				// インスタンス生成
-				JobNoticeInfoEntity jobNoticeInfoEntity
-				= new JobNoticeInfoEntity(jobInfoEntity, jobNoticeMstEntity.getId().getNoticeType());
-				// 重複チェック
-				jtm.checkEntityExists(JobNoticeInfoEntity.class, jobNoticeInfoEntity.getId());
-				//JobNoticeInfo用の通知グループID
-				String infoNotifyGroupId = NotifyGroupIdGenerator.createNotifyGroupIdJobInfo(
-						sessionId, jobunitId, jobId, 0);
-				jobNoticeInfoEntity.setPriority(jobNoticeMstEntity.getPriority());
-				jobNoticeInfoEntity.setNotifyGroupId(infoNotifyGroupId);
-			}
+		jobInfoEntity.setBeginPriority(job.getBeginPriority());
+		jobInfoEntity.setNormalPriority(job.getNormalPriority());
+		jobInfoEntity.setWarnPriority(job.getWarnPriority());
+		jobInfoEntity.setAbnormalPriority(job.getAbnormalPriority());
+		String infoNotifyGroupId = NotifyGroupIdGenerator.generate(jobInfoEntity);
+		jobInfoEntity.setNotifyGroupId(infoNotifyGroupId);
+
+		// 取得したマスタ情報の通知グループIDで、通知関連情報を取得する
+		List<NotifyRelationInfo> ct = new NotifyControllerBean().getNotifyRelation(job.getNotifyGroupId());
+		// JobNoticeInfo用の通知グループIDで、通知関連テーブルのコピーを作成する
+		for (NotifyRelationInfo relation : ct) {
+			relation.setNotifyGroupId(infoNotifyGroupId);
 		}
+		// JobからNotifyRelationInfoは１件のみ登録すればよい。
+		new NotifyControllerBean().addNotifyRelation(ct);
 
-		//通知関連情報の作成
-		if (jobNoticeMstEntityList != null) {
-			boolean checkflg = true;
-			for(JobNoticeMstEntity jobNoticeMstEntity : jobNoticeMstEntityList) {
-				// JobNoticeInfo用に通知グループIDを置き換えたもので、通知関連テーブルにコピーを作成する
-				//JobNoticeInfo用の通知グループID
-				String infoNotifyGroupId = NotifyGroupIdGenerator.createNotifyGroupIdJobInfo(
-						sessionId, jobunitId, jobId, 0);
-				// 取得したマスタ情報の通知グループIDで、通知関連情報を取得する
-				List<NotifyRelationInfo> ct = new NotifyControllerBean().getNotifyRelation(jobNoticeMstEntity.getNotifyGroupId());
-				// JobNoticeInfo用の通知グループIDで、通知関連テーブルのコピーを作成する
-				for (NotifyRelationInfo relation : ct) {
-					relation.setNotifyGroupId(infoNotifyGroupId);
-				}
-				// JobからNotifyRelationInfoは１件のみ登録すればよい。
-				if (checkflg) {
-					new NotifyControllerBean().addNotifyRelation(ct);
-					checkflg = false;
-				}
+
+		//ファイル転送を行うジョブネットの実行用情報を作成
+		// 通知の設定が済んでいる必要があるため、この位置で設定を行う
+		if(job.getJobType() == JobConstant.TYPE_FILEJOB){
+			if (CreateHulftJob.isHulftMode()) {
+				new CreateHulftJob().createHulftDetailJob(jobInfoEntity);
+			} else {
+				// 参照ジョブの場合も通知マスタ取得のために、参照先のファイル転送ジョブのIDを引数で渡す
+				new CreateFileJob().createGetFileListJob(jobInfoEntity, job.getId().getJobId());
 			}
-
 		}
 
 		//JobEndInfoEntityの作成
@@ -528,7 +491,7 @@ public class CreateJobSession {
 		.getResultList();
 		if (childJobMstEntities != null) {
 			for(JobMstEntity childJob : childJobMstEntities) {
-				createJobSessionJob(childJob, sessionId, info, false);
+				createJobSessionJob(childJob, sessionId, info, false, triggerInfo);
 			}
 		}
 		return jobSessionJobEntity.getId();
