@@ -478,12 +478,24 @@ public class SelectJob {
 		//セッションジョブを取得
 		JobSessionJobEntity sessionJob = QueryUtil.getJobSessionJobPK(session.getSessionId(), session.getJobunitId(), session.getJobId());
 		m_log.debug("sessionJob = " + sessionJob);
+		
+		HashMap<String, List<JobSessionJobEntity>> map = new HashMap<>();
+		List<JobSessionJobEntity> jobList = QueryUtil.getJobSessionJobBySessionId(session.getSessionId());
+		for (JobSessionJobEntity e : jobList) {
+			String parentId = e.getParentJobId();
+			List<JobSessionJobEntity> list = map.get(parentId);
+			if (map.get(parentId) == null) {
+				list = new ArrayList<JobSessionJobEntity>();
+				map.put(parentId, list);
+			}
+			list.add(e);
+		}
 
 		//CommonTableTreeItemの最上位インスタンスを作成
 		tree = new JobTreeItem();
 		//ジョブ詳細ツリーを作成
 		m_log.debug("createDetailTree start");
-		createDetailTree(sessionJob, tree);
+		createDetailTree(sessionJob, tree, map);
 		m_log.debug("createDetailTree end");
 
 		return tree;
@@ -514,7 +526,8 @@ public class SelectJob {
 	 */
 	private void createDetailTree(
 			JobSessionJobEntity sessionJob,
-			JobTreeItem parent) throws JobInfoNotFound {
+			JobTreeItem parent,
+			HashMap<String, List<JobSessionJobEntity>> map) throws JobInfoNotFound {
 
 		//セッションジョブからジョブ詳細一覧の１行を作成
 		JobInfo info = createJobInfo(sessionJob);
@@ -532,36 +545,21 @@ public class SelectJob {
 		if(m_openForwardFileJob || job.getJobType() != JobConstant.TYPE_FILEJOB){
 
 			//ジョブリレーションを親ジョブIDで検索
-			List<JobSessionJobEntity> collection
-			= QueryUtil.getChildJobSessionJob(
-							sessionJob.getId().getSessionId(),
-							sessionJob.getId().getJobunitId(),
-							sessionJob.getId().getJobId());
-			if (collection == null) {
-				JobInfoNotFound je = new JobInfoNotFound("JobSessionJobEntity.findByParentJobId"
-						+ ", [sessionId, parentJobId] = "
-						+ "[" + sessionJob.getId().getSessionId() + ", " + sessionJob.getId().getJobId() + "]");
-				m_log.info("createDetailTree() : "
-						+ je.getClass().getSimpleName() + ", " + je.getMessage());
-				je.setSessionId(sessionJob.getId().getSessionId());
-				je.setParentJobId(sessionJob.getId().getJobId());
-				throw je;
-			}
+			List<JobSessionJobEntity> collection = map.get(sessionJob.getId().getJobId());
 
-			Collections.sort(collection, new Comparator<JobSessionJobEntity>() {
-				@Override
-				public int compare(JobSessionJobEntity o1, JobSessionJobEntity o2) {
-					return o1.getId().getJobId().compareTo(o2.getId().getJobId());
-				}
-
-			});
 			if(collection != null && collection.size() > 0){
+				Collections.sort(collection, new Comparator<JobSessionJobEntity>() {
+					@Override
+					public int compare(JobSessionJobEntity o1, JobSessionJobEntity o2) {
+						return o1.getId().getJobId().compareTo(o2.getId().getJobId());
+					}
+				});
 				Iterator<JobSessionJobEntity> itr = collection.iterator();
 				while(itr.hasNext()){
 					//セッションジョブを取得
 					JobSessionJobEntity childJob = itr.next();
 					//ジョブ詳細ツリーを作成
-					createDetailTree(childJob, item);
+					createDetailTree(childJob, item, map);
 				}
 			}
 		}
