@@ -1,22 +1,33 @@
 package com.clustercontrol.jobmanagement.model;
 
 import java.io.Serializable;
-import javax.persistence.*;
-
-import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.commons.util.JpaTransactionManager;
-
 import java.sql.Timestamp;
 import java.util.Date;
 import java.util.List;
 
+import javax.persistence.CascadeType;
+import javax.persistence.Column;
+import javax.persistence.EmbeddedId;
+import javax.persistence.Entity;
+import javax.persistence.FetchType;
+import javax.persistence.OneToMany;
+import javax.persistence.OneToOne;
+import javax.persistence.PrimaryKeyJoinColumn;
+import javax.persistence.PrimaryKeyJoinColumns;
+import javax.persistence.Table;
+
+import com.clustercontrol.bean.YesNoConstant;
+import com.clustercontrol.commons.util.HinemosEntityManager;
+import com.clustercontrol.commons.util.JpaTransactionManager;
+
+
 
 /**
  * The persistent class for the cc_job_info database table.
- * 
+ *
  */
 @Entity
-@Table(name="cc_job_info")
+@Table(name="cc_job_info", schema="log")
 public class JobInfoEntity implements Serializable {
 	private static final long serialVersionUID = 1L;
 	private JobInfoEntityPK id;
@@ -35,11 +46,13 @@ public class JobInfoEntity implements Serializable {
 	private String stopCommand					=	"";
 	private Integer specifyUser					= YesNoConstant.TYPE_NO;
 	private String effectiveUser				=	null;
-	private Integer errorEndFlg					=	null;
-	private Integer errorEndValue				=	null;
+	private Integer messageRetryEndFlg			=	null;
+	private Integer messageRetryEndValue		=	null;
+	private Integer commandRetryFlg				= 1;
 	private String argumentJobId				=	null;
 	private String argument						=	null;
-	private Integer messageRetry 			= null;
+	private Integer messageRetry 				= null;
+	private Integer commandRetry 				= 10;
 	// cc_job_start_info
 	private Integer conditionType				=	null;
 	private Integer suspend						=	YesNoConstant.TYPE_NO;
@@ -97,10 +110,18 @@ public class JobInfoEntity implements Serializable {
 	private String destFacilityId;
 	// cc_job_start_time_info
 	private Timestamp startTime;
+	private Integer startMinute;
+
+	//ジョブ通知関連
+	private String notifyGroupId = "";
+	private Integer beginPriority = 0;
+	private Integer normalPriority = 0;
+	private Integer warnPriority = 0;
+	private Integer abnormalPriority = 0;
+
 
 	private JobSessionJobEntity jobSessionJobEntity;
 	private List<JobEndInfoEntity> jobEndInfoEntities;
-	private List<JobNoticeInfoEntity> jobNoticeInfoEntities;
 	private List<JobParamInfoEntity> jobParamInfoEntities;
 	private List<JobStartJobInfoEntity> jobStartJobInfoEntities;
 
@@ -111,7 +132,7 @@ public class JobInfoEntity implements Serializable {
 	public JobInfoEntity(JobInfoEntityPK pk,
 			JobSessionJobEntity jobSessionJobEntity) {
 		this.setId(pk);
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		em.persist(this);
 		this.relateToJobSessionJobEntity(jobSessionJobEntity);
 	}
@@ -244,23 +265,33 @@ public class JobInfoEntity implements Serializable {
 	}
 
 
-	@Column(name="error_end_flg")
-	public Integer getErrorEndFlg() {
-		return this.errorEndFlg;
+	@Column(name="message_retry_end_flg")
+	public Integer getMessageRetryEndFlg() {
+		return this.messageRetryEndFlg;
 	}
 
-	public void setErrorEndFlg(Integer errorEndFlg) {
-		this.errorEndFlg = errorEndFlg;
+	public void setMessageRetryEndFlg(Integer messageRetryEndFlg) {
+		this.messageRetryEndFlg = messageRetryEndFlg;
 	}
 
 
-	@Column(name="error_end_value")
-	public Integer getErrorEndValue() {
-		return this.errorEndValue;
+	@Column(name="message_retry_end_value")
+	public Integer getMessageRetryEndValue() {
+		return this.messageRetryEndValue;
 	}
 
-	public void setErrorEndValue(Integer errorEndValue) {
-		this.errorEndValue = errorEndValue;
+	public void setMessageRetryEndValue(Integer messageRetryEndValue) {
+		this.messageRetryEndValue = messageRetryEndValue;
+	}
+
+
+	@Column(name="command_retry_flg")
+	public Integer getCommandRetryFlg() {
+		return this.commandRetryFlg;
+	}
+
+	public void setCommandRetryFlg(Integer commandRetryFlg) {
+		this.commandRetryFlg = commandRetryFlg;
 	}
 
 
@@ -320,6 +351,15 @@ public class JobInfoEntity implements Serializable {
 		this.messageRetry = messageRetry;
 	}
 
+	@Column(name="command_retry")
+	public Integer getCommandRetry() {
+		return commandRetry;
+	}
+
+	public void setCommandRetry(Integer commandRetry) {
+		this.commandRetry = commandRetry;
+	}
+
 	// cc_job_start_info
 	public Integer getCalendar() {
 		return this.calendar;
@@ -829,9 +869,62 @@ public class JobInfoEntity implements Serializable {
 		this.startTime = startTime;
 	}
 
+	@Column(name="start_minute")
+	public Integer getStartMinute() {
+		return this.startMinute;
+	}
+
+	public void setStartMinute(Integer startMinute) {
+		this.startMinute = startMinute;
+	}
+
+	@Column(name="notify_group_id")
+	public String getNotifyGroupId() {
+		return notifyGroupId;
+	}
+
+	public void setNotifyGroupId(String notifyGroupId) {
+		this.notifyGroupId = notifyGroupId;
+	}
+
+	@Column(name="begin_priority")
+	public Integer getBeginPriority() {
+		return beginPriority;
+	}
+
+	public void setBeginPriority(Integer beginPriority) {
+		this.beginPriority = beginPriority;
+	}
+
+	@Column(name="normal_priority")
+	public Integer getNormalPriority() {
+		return normalPriority;
+	}
+
+	public void setNormalPriority(Integer normalPriority) {
+		this.normalPriority = normalPriority;
+	}
+
+	@Column(name="warn_priority")
+	public Integer getWarnPriority() {
+		return warnPriority;
+	}
+
+	public void setWarnPriority(Integer warnPriority) {
+		this.warnPriority = warnPriority;
+	}
+
+	@Column(name="abnormal_priority")
+	public Integer getAbnormalPriority() {
+		return abnormalPriority;
+	}
+
+	public void setAbnormalPriority(Integer abnormalPriority) {
+		this.abnormalPriority = abnormalPriority;
+	}
 
 	//bi-directional many-to-one association to JobEndInfoEntity
-	@OneToMany(mappedBy="jobInfoEntity", cascade=CascadeType.ALL, orphanRemoval=true, fetch=FetchType.LAZY)
+	@OneToMany(mappedBy="jobInfoEntity", cascade=CascadeType.ALL, fetch=FetchType.LAZY)
 	public List<JobEndInfoEntity> getJobEndInfoEntities() {
 		return this.jobEndInfoEntities;
 	}
@@ -859,14 +952,14 @@ public class JobInfoEntity implements Serializable {
 
 	/**
 	 * JobSessionJobEntityオブジェクト参照設定<BR>
-	 * 
+	 *
 	 * JobSessionJobEntity設定時はSetterに代わりこちらを使用すること。
-	 * 
+	 *
 	 * JPAの仕様(JSR 220)では、データ更新に伴うrelationshipの管理はユーザに委ねられており、
 	 * INSERTやDELETE時に、そのオブジェクトに対する参照をメンテナンスする処理を実装する。
-	 * 
+	 *
 	 * JSR 220 3.2.3 Synchronization to the Database
-	 * 
+	 *
 	 * Bidirectional relationships between managed entities will be persisted
 	 * based on references held by the owning side of the relationship.
 	 * It is the developer’s responsibility to keep the in-memory references
@@ -881,19 +974,8 @@ public class JobInfoEntity implements Serializable {
 	}
 
 
-	//bi-directional many-to-one association to JobNoticeInfoEntity
-	@OneToMany(mappedBy="jobInfoEntity", cascade=CascadeType.ALL, orphanRemoval=true, fetch=FetchType.LAZY)
-	public List<JobNoticeInfoEntity> getJobNoticeInfoEntities() {
-		return this.jobNoticeInfoEntities;
-	}
-
-	public void setJobNoticeInfoEntities(List<JobNoticeInfoEntity> jobNoticeInfoEntities) {
-		this.jobNoticeInfoEntities = jobNoticeInfoEntities;
-	}
-
-
 	//bi-directional many-to-one association to JobParamInfoEntity
-	@OneToMany(mappedBy="jobInfoEntity", cascade=CascadeType.ALL, orphanRemoval=true, fetch=FetchType.LAZY)
+	@OneToMany(mappedBy="jobInfoEntity", cascade=CascadeType.ALL, fetch=FetchType.LAZY)
 	public List<JobParamInfoEntity> getJobParamInfoEntities() {
 		return this.jobParamInfoEntities;
 	}
@@ -904,7 +986,7 @@ public class JobInfoEntity implements Serializable {
 
 
 	//bi-directional many-to-one association to JobStartJobInfoEntity
-	@OneToMany(mappedBy="jobInfoEntity", cascade=CascadeType.ALL, orphanRemoval=true, fetch=FetchType.LAZY)
+	@OneToMany(mappedBy="jobInfoEntity", cascade=CascadeType.ALL, fetch=FetchType.LAZY)
 	public List<JobStartJobInfoEntity> getJobStartJobInfoEntities() {
 		return this.jobStartJobInfoEntities;
 	}
@@ -915,12 +997,12 @@ public class JobInfoEntity implements Serializable {
 
 	/**
 	 * 削除前処理<BR>
-	 * 
+	 *
 	 * JPAの仕様(JSR 220)では、データ更新に伴うrelationshipの管理はユーザに委ねられており、
 	 * INSERTやDELETE時に、そのオブジェクトに対する参照をメンテナンスする処理を実装する。
-	 * 
+	 *
 	 * JSR 220 3.2.3 Synchronization to the Database
-	 * 
+	 *
 	 * Bidirectional relationships between managed entities will be persisted
 	 * based on references held by the owning side of the relationship.
 	 * It is the developer’s responsibility to keep the in-memory references
