@@ -13,7 +13,7 @@ public class JobManagementPreferenceInitializer extends AbstractPreferenceInitia
 
 		store.setDefault(JobManagementPreferencePage.P_HISTORY_UPDATE_FLG, true);
 		store.setDefault(JobManagementPreferencePage.P_HISTORY_UPDATE_CYCLE, 10);
-		store.setDefault(JobManagementPreferencePage.P_HISTORY_MESSAGE_FLG, true);
+		store.setDefault(JobManagementPreferencePage.P_HISTORY_MESSAGE_FLG, false);
 		store.setDefault(JobManagementPreferencePage.P_HISTORY_MAX_HISTORIES, 500);
 		store.setDefault(JobManagementPreferencePage.P_PLAN_MAX_SCHEDULE, 100);
 	}
