@@ -20,6 +20,7 @@ import java.sql.Timestamp;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Date;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Locale;
 import java.util.Random;
@@ -2273,22 +2274,20 @@ public class JobControllerBean implements CheckFacility {
 			jtm = new JpaTransactionManager();
 			jtm.begin();
 			HinemosEntityManager em = jtm.getEntityManager();
+			ct = em.createNamedQuery("JobMstEntity.findByJobType", JobMstEntity.class)
+					.setParameter("jobType", JobConstant.TYPE_JOBUNIT)
+					.getResultList();
+			HashMap<String, JobMstEntity> map = new HashMap<String, JobMstEntity> ();
+			for (JobMstEntity entity : ct) {
+				map.put(entity.getId().getJobunitId(), entity);
+			}
 			for (String jobunitId : jobunitIdList) {
-				ct = em.createNamedQuery("JobMstEntity.findByJobunitId", JobMstEntity.class)
-						.setParameter("jobunitId", jobunitId)
-						.getResultList();
-				if (ct != null) {
-					if (ct.size() == 0) {
-						m_log.info("getUpdateDateFromJobMstList " + jobunitId + " is not found");
-					}
-					// ジョブユニットが存在する
-					for (JobMstEntity entity : ct) {
-						if (entity.getJobType() == JobConstant.TYPE_JOBUNIT) {
-							updateDateList.add(entity.getUpdateDate().getTime());
-							break;
-						}
-					}
+				Long time = null;
+				if (map.get(jobunitId) != null &&
+					map.get(jobunitId).getUpdateDate() != null) {
+					time = map.get(jobunitId).getUpdateDate().getTime();
 				}
+				updateDateList.add(time);
 			}
 			jtm.commit();
 		} catch (ObjectPrivilege_InvalidRole e) {
