@@ -15,6 +15,7 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.jobmanagement.session;
 
+import java.sql.Timestamp;
 import java.util.HashMap;
 import java.util.List;
 import java.util.concurrent.Semaphore;
@@ -25,14 +26,20 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.StatusConstant;
+import com.clustercontrol.commons.util.ILock;
+import com.clustercontrol.commons.util.ILockManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.commons.util.LockManagerFactory;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.JobInfoNotFound;
 import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.bean.JobOperationInfo;
+import com.clustercontrol.jobmanagement.bean.JobSessionRequestMessage;
+import com.clustercontrol.jobmanagement.bean.JobTriggerInfo;
 import com.clustercontrol.jobmanagement.bean.OperationConstant;
 import com.clustercontrol.jobmanagement.bean.RunResultInfo;
+import com.clustercontrol.jobmanagement.factory.CreateJobSession;
 import com.clustercontrol.jobmanagement.factory.JobOperationJudgment;
 import com.clustercontrol.jobmanagement.factory.OperateForceStopOfJob;
 import com.clustercontrol.jobmanagement.factory.OperateMaintenanceOfJob;
@@ -44,10 +51,13 @@ import com.clustercontrol.jobmanagement.factory.OperateStartOfJob;
 import com.clustercontrol.jobmanagement.factory.OperateStopOfJob;
 import com.clustercontrol.jobmanagement.factory.OperateSuspendOfJob;
 import com.clustercontrol.jobmanagement.factory.OperateWaitOfJob;
+import com.clustercontrol.jobmanagement.model.JobMstEntity;
+import com.clustercontrol.jobmanagement.model.JobSessionEntity;
 import com.clustercontrol.jobmanagement.model.JobSessionJobEntity;
 import com.clustercontrol.jobmanagement.model.JobSessionNodeEntity;
 import com.clustercontrol.jobmanagement.model.JobSessionNodeEntityPK;
 import com.clustercontrol.jobmanagement.util.QueryUtil;
+import com.clustercontrol.notify.bean.OutputBasicInfo;
 import com.clustercontrol.util.apllog.AplLogger;
 
 
@@ -64,7 +74,7 @@ public class JobRunManagementBean {
 
 	// 二重起動を防ぐためのセマフォ
 	private static final Semaphore duplicateExec = new Semaphore(1);
-	
+
 	/**
 	 * Quartzからのコールバックメソッド<BR>
 	 * <P>
@@ -93,6 +103,11 @@ public class JobRunManagementBean {
 		}
 	}
 	
+	public static ILock getLock (String sessionId) {
+		ILockManager lm = LockManagerFactory.instance().create();
+		return lm.create(JobSessionImpl.class.getName() + "-" + sessionId);
+	}
+
 	private void runSub() throws HinemosUnknown, JobInfoNotFound, InvalidRole {
 		m_log.trace("run() start");
 		JpaTransactionManager jtm = null;
@@ -129,8 +144,11 @@ public class JobRunManagementBean {
 					continue;
 				}
 			}
-			Object o = JobSessionImpl.getLockObject(sessionId);
-			synchronized(o) {
+
+			ILock lock = getLock(sessionId);
+			try {
+				lock.writeLock();
+				
 				try{
 					jtm = new JpaTransactionManager();
 					jtm.begin();
@@ -153,6 +171,8 @@ public class JobRunManagementBean {
 				} finally {
 					jtm.close();
 				}
+			} finally {
+				lock.writeUnlock();
 			}
 		}
 		long to = System.currentTimeMillis();
@@ -162,8 +182,11 @@ public class JobRunManagementBean {
 		from = System.currentTimeMillis();
 		int nodeCount = 0;
 		for (String sessionId : sessionNodeMap.keySet()) {
-			Object o = JobSessionImpl.getLockObject(sessionId);
-			synchronized(o) {
+
+			ILock lock = getLock(sessionId);
+			try {
+				lock.writeLock();
+				
 				try{
 					jtm = new JpaTransactionManager();
 					jtm.begin();
@@ -183,6 +206,8 @@ public class JobRunManagementBean {
 				} finally {
 					jtm.close();
 				}
+			} finally {
+				lock.writeUnlock();
 			}
 		}
 		to = System.currentTimeMillis();
@@ -202,42 +227,83 @@ public class JobRunManagementBean {
 
 	/**
 	 * ジョブを実行します。<BR>
-	 * JobControllerBeanから呼ばれます。
+	/**
+	 * CreateJobSessionTaskFactoryから呼ばれる
 	 * 
-	 * @param sessionId セッションID
-	 * @param jobunitId 所属ジョブユニットのジョブID
-	 * @param jobId ジョブID
-	 * @throws HinemosUnknown
-	 * @throws JobInfoNotFound
-	 * @throws InvalidRole
-	 * @see com.clustercontrol.jobmanagement.factory.OperationJob#kickJob(String, String, String)
 	 */
-	public void runJob(String sessionId, String jobunitId, String jobId) throws HinemosUnknown, JobInfoNotFound, InvalidRole {
-		m_log.debug("runJob() : sessionId=" + sessionId);
+	public static void makeSession(JobSessionRequestMessage message) {
+		String sessionId = message.getSessionId();
+		String jobunitId = message.getJobunitId();
+		String jobId = message.getJobId();
+		OutputBasicInfo info = message.getOutputBasicInfo();
+		JobTriggerInfo triggerInfo = message.getTriggerInfo();
+		
 		JpaTransactionManager jtm = null;
 
+		ILock lock = getLock(sessionId);
 		try {
-			jtm = new JpaTransactionManager();
-			jtm.begin();
-			//実行
-			new JobSessionJobImpl().startJob(sessionId, jobunitId, jobId);
-			jtm.commit();
-		} catch (JobInfoNotFound e) {
-			jtm.rollback();
-			throw e;
-		} catch (InvalidRole e) {
-			jtm.rollback();
-			throw e;
-		} catch (HinemosUnknown e) {
-			jtm.rollback();
-			throw e;
-		} catch (Exception e) {
-			m_log.warn("runJob() : "
-					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-			jtm.rollback();
-			throw new HinemosUnknown(e.getMessage(), e);
+			lock.writeLock();
+			try {
+				jtm = new JpaTransactionManager();
+				jtm.begin();
+	
+				JobMstEntity job = QueryUtil.getJobMstPK(jobunitId, jobId);
+				//JobSessionを作成
+				JobSessionEntity jobSessionEntity = new JobSessionEntity(sessionId);
+				// 重複チェック
+				jtm.checkEntityExists(JobSessionEntity.class, jobSessionEntity.getSessionId());
+				jobSessionEntity.setJobunitId(jobunitId);
+				jobSessionEntity.setJobId(job.getId().getJobId());
+				jobSessionEntity.setScheduleDate(new Timestamp(System.currentTimeMillis()));
+				jobSessionEntity.setOperationFlg(0);
+				jobSessionEntity.setTriggerType(triggerInfo.getTrigger_type());
+				jobSessionEntity.setTriggerInfo(triggerInfo.getTrigger_info());
+	
+				m_log.trace("jobSessionEntity SessionId : " + jobSessionEntity.getSessionId());
+				m_log.trace("jobSessionEntity JobUnitId : " + jobSessionEntity.getJobunitId());
+				m_log.trace("jobSessionEntity JobId : " + jobSessionEntity.getJobId());
+	
+				// 最上位のジョブセッション作成
+				// インスタンス生成
+				JobSessionJobEntity jobSessionJobEntity
+				= new JobSessionJobEntity(jobSessionEntity, CreateJobSession.TOP_JOBUNIT_ID, CreateJobSession.TOP_JOB_ID);
+				// 重複チェック
+				jtm.checkEntityExists(JobSessionJobEntity.class, jobSessionJobEntity.getId());
+				jobSessionJobEntity.setStatus(StatusConstant.TYPE_WAIT);
+				// ジョブセッション作成(このジョブは待ち条件は無視する。)
+				CreateJobSession.createJobSessionJob(job, sessionId, info, true, triggerInfo);
+	
+				jtm.commit();
+			} catch (Exception e) {
+				m_log.warn("makeSession() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+				AplLogger apllog = new AplLogger("JOB", "job");
+				String[] args = {jobId};
+				apllog.put("SYS", "003", args);
+				return;
+			} finally {
+				jtm.close();
+			}
+			
+			try {
+				jtm = new JpaTransactionManager();
+				jtm.begin();
+				//実行
+				new JobSessionJobImpl().startJob(sessionId, jobunitId, jobId);
+				jtm.commit();
+			} catch (Exception e) {
+				m_log.warn("makeSession() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+				AplLogger apllog = new AplLogger("JOB", "job");
+				String[] args = {jobId};
+				apllog.put("SYS", "003", args);
+				jtm.rollback();
+				return;
+			} finally {
+				jtm.close();
+			}
 		} finally {
-			jtm.close();
+			lock.writeUnlock();
 		}
 	}
 
@@ -732,39 +798,41 @@ public class JobRunManagementBean {
 	public boolean endNode(RunResultInfo info) throws HinemosUnknown, JobInfoNotFound, InvalidRole {
 		m_log.trace("endNode() : sessionId=" + info.getSessionId() + ", jobId=" + info.getJobId() + ", facilityId=" + info.getFacilityId());
 		JpaTransactionManager jtm = null;
-		
+
 		boolean result = false;
 
+		ILock lock = getLock(info.getSessionId());
 		try {
-			jtm = new JpaTransactionManager();
-
-			JobSessionNodeImpl nodeImpl = new JobSessionNodeImpl();
-			Object o = JobSessionImpl.getLockObject(info.getSessionId());
-			synchronized(o) {
+			lock.writeLock();
+			try {
+				jtm = new JpaTransactionManager();
+				JobSessionNodeImpl nodeImpl = new JobSessionNodeImpl();
 				jtm.begin();
 				result = nodeImpl.endNode(info);
 				jtm.commit();
+			} catch (JobInfoNotFound e) {
+				jtm.rollback();
+				throw e;
+			} catch (HinemosUnknown e) {
+				jtm.rollback();
+				throw e;
+			} catch (InvalidRole e) {
+				jtm.rollback();
+				throw e;
+			} catch (EntityExistsException e) {
+				jtm.rollback();
+				m_log.warn("endNode() : " + e.getMessage(), e);
+				throw new HinemosUnknown(e.getMessage(), e);
+			} catch (Exception e) {
+				m_log.warn("endNode() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+				jtm.rollback();
+				throw new HinemosUnknown(e.getMessage(), e);
+			} finally {
+				jtm.close();
 			}
-		} catch (JobInfoNotFound e) {
-			jtm.rollback();
-			throw e;
-		} catch (HinemosUnknown e) {
-			jtm.rollback();
-			throw e;
-		} catch (InvalidRole e) {
-			jtm.rollback();
-			throw e;
-		} catch (EntityExistsException e) {
-			jtm.rollback();
-			m_log.warn("endNode() : " + e.getMessage(), e);
-			throw new HinemosUnknown(e.getMessage(), e);
-		} catch (Exception e) {
-			m_log.warn("endNode() : "
-					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
-			jtm.rollback();
-			throw new HinemosUnknown(e.getMessage(), e);
 		} finally {
-			jtm.close();
+			lock.writeUnlock();
 		}
 		return result;
 	}
