@@ -30,26 +30,23 @@ import org.eclipse.jface.dialogs.MessageDialog;
 import com.clustercontrol.fault.JobInvalid;
 import com.clustercontrol.jobmanagement.bean.JobConstant;
 import com.clustercontrol.jobmanagement.bean.JudgmentObjectConstant;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.jobmanagement.InvalidRole_Exception;
 import com.clustercontrol.ws.jobmanagement.JobInfo;
 import com.clustercontrol.ws.jobmanagement.JobInvalid_Exception;
-import com.clustercontrol.ws.jobmanagement.JobNotificationsInfo;
 import com.clustercontrol.ws.jobmanagement.JobObjectInfo;
 import com.clustercontrol.ws.jobmanagement.JobTreeItem;
 import com.clustercontrol.ws.jobmanagement.JobWaitRuleInfo;
 import com.clustercontrol.ws.jobmanagement.OtherUserGetLock_Exception;
 import com.clustercontrol.ws.jobmanagement.UpdateTimeNotLatest_Exception;
-import com.clustercontrol.ws.notify.NotifyRelationInfo;
 
 /**
  * ジョブユーティリティクラス
- * 
+ *
  * 以下を提供します。<BR>
  * <li>ジョブツリーアイテムに関するユーティリティ
  * <li>ログインユーザが参照可能なジョブユニットかどうかをチェックするユーティリティ
- * 
+ *
  * @version 2.0.0
  * @since 2.0.0
  */
@@ -62,7 +59,7 @@ public class JobUtil {
 
 	/**
 	 * 引数で指定されたジョブツリーアイテムのコピーを作成する
-	 * 
+	 *
 	 * @param original コピー元ジョブツリーアイテム
 	 * @return コピーとして作成されたジョブツリーアイテム
 	 */
@@ -89,12 +86,18 @@ public class JobUtil {
 
 		//オーナーロールIDをコピー先のものに変更
 		clone = changeOwnerRoleId(clone, ownerRoleId);
-		
+
 		//ジョブIDの変更
 		HashMap<String, String> jobIdMap = changeJobId(clone, top, clone);
 
 		//待ち条件を変更する
 		modifyWaitRule(clone, jobIdMap);
+		
+		//ジョブユニットのコピー　または　ジョブユニットの異なる参照ジョブのコピーの場合は参照を消す
+		if (original.getData().getType() == JobConstant.TYPE_JOBUNIT ||
+				!jobunitId.equals(original.getData().getJobunitId())) {
+			modifyReferJob(clone);
+		}
 
 		//FIXME ジョブユニットIDを変更する
 
@@ -123,7 +126,7 @@ public class JobUtil {
 		// マッチしなかったら、そのまま返す。
 		return jobId;
 	}
-	
+
 	/**
 	 * オーナーロールIDを一括変更する<BR>
 	 * ジョブツリーアイテムのツリー階層の全てに対して一括変更する。<BR>
@@ -146,7 +149,7 @@ public class JobUtil {
 	 * ジョブツリーアイテムのツリー階層の全てに対して一括変更する。<BR>
 	 * topとcloneに指定されたジョブツリーアイテムを、ジョブIDの重複チェック対象とする。<BR>
 	 * ジョブIDが重複した場合、コピーしたジョブIDの接頭語とカウンタを付加してジョブIDを決定する。
-	 * 
+	 *
 	 * @param item ジョブID変更対象のジョブツリーアイテム
 	 * @param top ジョブIDの重複チェック対象のジョブツリーアイテム
 	 * @param clone ジョブIDの重複チェック対象のジョブツリーアイテム
@@ -191,67 +194,18 @@ public class JobUtil {
 			// ジョブユニットの場合のみジョブユニットIDを上書き
 			if (info.getType() == JobConstant.TYPE_JOBUNIT) {
 				info.setJobunitId(jobId.toString());
-				//m_log.debug("changeJobId() setJobunitId = " + jobId.toString());
+				m_log.trace("changeJobId() setJobunitId = " + jobId.toString());
 			}
 			//else {
 			//	info.setJobunitId(item.getParent().getData().getJobunitId());
-			//	m_log.debug("changeJobId() setJobunitId = " + item.getParent().getData().getJobunitId() + " from jobid = " + item.getParent().getData().getJobunitId());
 			//}
-
-			// 通知グループIDの変更
-			List<JobNotificationsInfo> jobNotifyList = info.getNotifications();
-			Iterator<JobNotificationsInfo> itrJob = jobNotifyList.iterator();
-
-			Iterator<NotifyRelationInfo> itrNotify = null;
-			List<NotifyRelationInfo> ctNotify = null;
-			List<NotifyRelationInfo> modCtNotify = null;
-
-			NotifyRelationInfo notify = null;
-			NotifyRelationInfo modNotify = null;	//変更後格納用
-
-			// 新しい通知グループIDを作成
-			String newNotifyGroupId = NotifyGroupIdGenerator.createNotifyGroupIdJob(info.getJobunitId(), info.getId(), 0);
-			//m_log.debug("changeJobId() newNotifyGroupId = " + newNotifyGroupId);
-			// ジョブの通知の種類（開始・通知・警告・危険）分調べる
-			while(itrJob.hasNext()){
-				JobNotificationsInfo jobNotify = itrJob.next();
-				jobNotify.setNotifyGroupId(newNotifyGroupId);
-
-				// 通知関連情報を調査
-				ctNotify = jobNotify.getNotifyId();
-
-				if(ctNotify != null) {
-					itrNotify = ctNotify.iterator();
-					modCtNotify = new ArrayList<NotifyRelationInfo>();
-
-					// 通知関連情報内の通知グループIDの変更
-					while(itrNotify.hasNext()){
-						notify = itrNotify.next();
-
-						// ディープコピー（通知グループIDは新規）を作成
-						modNotify = new NotifyRelationInfo();
-						modNotify.setNotifyGroupId(newNotifyGroupId);
-						modNotify.setNotifyId(notify.getNotifyId());
-						modNotify.setNotifyType(notify.getNotifyType());
-						modNotify.setNotifyFlg(notify.getNotifyFlg());
-
-						modCtNotify.add(modNotify);
-
-					}
-
-					if(modCtNotify.size() != 0){
-						jobNotify.getNotifyId().clear();
-						jobNotify.getNotifyId().addAll(modCtNotify);
-					}
-				}
-			}
 		}
 
 		//子JobTreeItemを取得
 		List<JobTreeItem> childrens = item.getChildren();
 		for(int i = 0; i < childrens.size(); i++){
 			childrens.get(i).getData().setJobunitId(info.getJobunitId());
-			//m_log.debug("changeJobId() set childrens[i] " + info.getJobunitId());
+			m_log.trace("changeJobId() set childrens[i] " + info.getJobunitId());
 			jobIdMap.putAll(changeJobId(childrens.get(i), top, clone));
 		}
 
@@ -262,7 +216,7 @@ public class JobUtil {
 	/**
 	 * ジョブツリーアイテムのジョブ待ち条件情報を修正する<BR>
 	 * ジョブツリーアイテムのツリー階層の全てが修正対象
-	 * 
+	 *
 	 * @param item ジョブ待ち条件情報を修正するジョブツリーアイテム
 	 */
 	private static void modifyWaitRule(JobTreeItem item, HashMap<String, String>jobIdMap) {
@@ -282,7 +236,8 @@ public class JobUtil {
 					if (jobId != null) {
 						jobObjectInfo.setJobId(jobId);
 						list.add(jobObjectInfo);
-					} else if (jobObjectInfo.getTime() != null) {
+					} else if (jobObjectInfo.getType() == JudgmentObjectConstant.TYPE_TIME ||
+							jobObjectInfo.getType() == JudgmentObjectConstant.TYPE_START_MINUTE) {
 						list.add(jobObjectInfo);
 					}
 				}
@@ -298,10 +253,30 @@ public class JobUtil {
 		}
 	}
 
+	/**
+	 * ジョブツリーアイテムの参照ジョブの参照先を修正する<BR>
+	 * ジョブツリーアイテムのツリー階層の全ての参照ジョブが修正対象
+	 *
+	 * @param item ジョブ待ち条件情報を修正するジョブツリーアイテム
+	 */
+	private static void modifyReferJob(JobTreeItem item) {
+		JobInfo cloneInfo = item.getData();
+		if (cloneInfo.getType() == JobConstant.TYPE_REFERJOB) {
+			cloneInfo.setReferJobId("");
+			cloneInfo.setReferJobUnitId("");
+		}
+		
+		//子JobTreeItemを取得
+		List<JobTreeItem> childrens = item.getChildren();
+		for (int i = 0; i < childrens.size(); i++) {
+			modifyReferJob(childrens.get(i));
+		}
+	}
+	
 	/**
 	 * ジョブツリーアイテムからジョブIDが一致するインスタンスの有無を返す<BR>
 	 * ジョブツリーアイテムのツリー階層の全てが検索対象
-	 * 
+	 *
 	 * @param jobId ジョブID
 	 * @param item ジョブツリーアイテム
 	 * @return ジョブIDが一致するジョブツリーアイテムがあればtrue、なければfalse。
@@ -332,7 +307,7 @@ public class JobUtil {
 
 	/**
 	 * ジョブツリーアイテム内のジョブIDが一致するインスタンスの有無を返す<BR>
-	 * 
+	 *
 	 * @param item ジョブツリーアイテム
 	 * @param isTop ツリーのトップか否か
 	 * @return ジョブIDが一致するジョブ/ネット/ユニットが存在すればtrue、なければfalse。
@@ -378,7 +353,7 @@ public class JobUtil {
 
 	/**
 	 * ジョブツリーアイテム内のジョブユニットIDが一致するインスタンスの有無を返す<BR>
-	 * 
+	 *
 	 * @param item ジョブツリーアイテム
 	 * @return ジョブユニットIDが一致するユニットが存在すればtrue、なければfalse。
 	 * @throws JobInvalid
@@ -410,7 +385,7 @@ public class JobUtil {
 
 	/**
 	 * ジョブツリーアイテムの最上位のインスタンスを取得する
-	 * 
+	 *
 	 * @param item ジョブツリーアイテム
 	 * @return 最上位のジョブツリーアイテム
 	 */
@@ -433,7 +408,7 @@ public class JobUtil {
 
 	/**
 	 * ジョブツリーアイテムの付属するジョブユニットのインスタンスを取得する
-	 * 
+	 *
 	 * @param item ジョブツリーアイテム
 	 * @return 付属するジョブユニットのジョブツリーアイテム
 	 */
@@ -442,7 +417,7 @@ public class JobUtil {
 			return null;
 
 		while (item.getParent() != null) {
-			//m_log.debug("getTopJobUnitTreeItem() " + item.getParent().getData().getJobunitId() + "." + item.getParent().getData().getId());
+			m_log.trace("getTopJobUnitTreeItem() " + item.getParent().getData().getJobunitId() + "." + item.getParent().getData().getId());
 			if(item.getParent().getData().getType() == JobConstant.TYPE_JOBUNIT){
 				item = item.getParent();
 				break;
@@ -460,7 +435,7 @@ public class JobUtil {
 
 	/**
 	 * ジョブツリーアイテムのジョブ待ち条件情報をチェックする
-	 * 
+	 *
 	 * @param item ジョブ待ち条件情報をチェックするジョブツリーアイテム
 	 */
 	public static boolean checkWaitRule(JobTreeItem item) throws JobInvalid{
@@ -521,15 +496,17 @@ public class JobUtil {
 
 	/**
 	 * 編集ロックを取得します。
+	 * @param managerName
 	 * @param jobunitId
 	 * @param updateTime
 	 * @param forceFlag
 	 * @return
 	 * @throws OtherUserGetLock_Exception
 	 */
-	public static Integer getEditLock(String jobunitId, Long updateTime, boolean forceFlag) throws OtherUserGetLock_Exception {
+	public static Integer getEditLock(String managerName, String jobunitId, Long updateTime, boolean forceFlag) throws OtherUserGetLock_Exception {
 		try {
-			return JobEndpointWrapper.getEditLock(jobunitId, updateTime, forceFlag);
+			JobEndpointWrapper wrapper = JobEndpointWrapper.getWrapper(managerName);
+			return wrapper.getEditLock(jobunitId, updateTime, forceFlag);
 		} catch (OtherUserGetLock_Exception e) {
 			throw e;
 		} catch (InvalidRole_Exception e) {
@@ -554,55 +531,30 @@ public class JobUtil {
 
 	/**
 	 * ジョブユニットIDをすべて更新する。<BR>
-	 * 
+	 *
 	 * @param item ジョブツリーアイテム
 	 * @param jobunitID ジョブユニットID
 	 */
 	public static void setJobunitIdAll(JobTreeItem item, String jobunitId) {
-		if (item == null || item.getData() == null) {
+		JobInfo jobInfo = item.getData();
+		if (item == null || jobInfo == null) {
 			return;
 		}
 
-		if (item.getData().getType() == JobConstant.TYPE_JOBUNIT) {
-			jobunitId = item.getData().getJobunitId();
+		if (jobInfo.getType() == JobConstant.TYPE_JOBUNIT) {
+			jobunitId = jobInfo.getJobunitId();
 		}
 
-		m_log.trace("setJobunitIdAll() : jobId = " + item.getData().getId() +
-				", old jobunitId = " + item.getData().getJobunitId() +
+		m_log.trace("setJobunitIdAll() : jobId = " + jobInfo.getId() +
+				", old jobunitId = " + jobInfo.getJobunitId() +
 				", new jobunitId = " + jobunitId);
 
 		// ジョブユニットIDを変更する
-		item.getData().setJobunitId(jobunitId);
+		jobInfo.setJobunitId(jobunitId);
 
 		// 参照ジョブの場合は参照先のジョブユニットIDを変更する
-		if (item.getData().getType() == JobConstant.TYPE_REFERJOB) {
-			item.getData().setReferJobUnitId(jobunitId);
-		}
-		
-		// 通知グループIDを新しいジョブユニットIDのものに変更する
-		List<JobNotificationsInfo> jobNotifyList = item.getData().getNotifications();
-		Iterator<JobNotificationsInfo> itrJob = jobNotifyList.iterator();
-
-		// 新しい通知グループIDを作成
-		String newNotifyGroupId = NotifyGroupIdGenerator.createNotifyGroupIdJob(jobunitId, item.getData().getId(), 0);
-		m_log.debug("changeJobId() newNotifyGroupId = " + newNotifyGroupId);
-		// ジョブの通知の種類（開始・通知・警告・危険）分調べる
-		while(itrJob.hasNext()){
-			JobNotificationsInfo jobNotify = itrJob.next();
-			jobNotify.setNotifyGroupId(newNotifyGroupId);
-
-			// 通知関連情報を調査
-			List<NotifyRelationInfo> ctNotify = jobNotify.getNotifyId();
-
-			if(ctNotify != null) {
-				Iterator<NotifyRelationInfo> itrNotify = ctNotify.iterator();
-
-				// 通知関連情報内の通知グループIDの変更
-				while(itrNotify.hasNext()){
-					NotifyRelationInfo notify = itrNotify.next();
-					notify.setNotifyGroupId(newNotifyGroupId);
-				}
-			}
+		if (jobInfo.getType() == JobConstant.TYPE_REFERJOB) {
+			jobInfo.setReferJobUnitId(jobunitId);
 		}
 
 		// 子のジョブツリーアイテムを再帰的に呼び出す
@@ -610,4 +562,4 @@ public class JobUtil {
 			setJobunitIdAll(child, jobunitId);
 		}
 	}
-}
\ No newline at end of file
+}
