@@ -24,6 +24,7 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
+import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.ScheduleConstant;
 import com.clustercontrol.bean.YesNoConstant;
@@ -63,6 +64,8 @@ import com.clustercontrol.util.Messages;
  */
 public class JobValidator {
 	private static Log m_log = LogFactory.getLog( JobValidator.class );
+	// ジョブの試行回数が未設定時のデフォルト値
+	private static final Integer DEFAULT_JOB_RETRY_CNT = 10;
 
 	/**
 	 * ジョブスケジュールのvalidate
@@ -496,7 +499,31 @@ public class JobValidator {
 
 					}
 				}
+				try {
+					// 試行回数の未設定時はデフォルト値を設定
+					if (command.getMessageRetry() == null) {
+						command.setMessageRetry(DEFAULT_JOB_RETRY_CNT);
+					}
+					if (command.getCommandRetry() == null) {
+						command.setCommandRetry(DEFAULT_JOB_RETRY_CNT);
+					}
 
+					// 試行回数のチェック
+					CommonValidator.validateInt(
+							Messages.getString("job.retries"),
+							command.getMessageRetry(), 1,
+							DataRangeConstant.SMALLINT_HIGH);
+
+					if (command.getCommandRetryFlg() == YesNoConstant.TYPE_YES) {
+						CommonValidator.validateInt(
+								Messages.getString("job.retries"),
+								command.getCommandRetry(), 1,
+								DataRangeConstant.SMALLINT_HIGH);
+					}
+				} catch (Exception e) {
+					m_log.info("validateJobUnit() add job retry error. FacilityId = " + command.getFacilityID() + ", jobunitId = " + jobunitId + ", jobId = " + jobId + " : " + e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+					throw e;
+				}
 			}
 		} else if (jobInfo.getType() == JobConstant.TYPE_FILEJOB) {
 			JobFileInfo file = jobInfo.getFile();
@@ -556,6 +583,32 @@ public class JobValidator {
 						+ e.getClass().getSimpleName() + ", " + e.getMessage());
 				throw e;
 			}
+			try {
+				// 試行回数の未設定時はデフォルト値を設定
+				if (file.getMessageRetry() == null) {
+					file.setMessageRetry(DEFAULT_JOB_RETRY_CNT);
+				}
+				if (file.getCommandRetry() == null) {
+					file.setCommandRetry(DEFAULT_JOB_RETRY_CNT);
+				}
+
+				// 試行回数のチェック
+				CommonValidator.validateInt(Messages.getString("job.retries"),
+						file.getMessageRetry(), 1,
+						DataRangeConstant.SMALLINT_HIGH);
+
+				if (file.getCommandRetryFlg() == YesNoConstant.TYPE_YES) {
+					CommonValidator.validateInt(
+							Messages.getString("job.retries"),
+							file.getCommandRetry(), 1,
+							DataRangeConstant.SMALLINT_HIGH);
+				}
+			} catch (Exception e) {
+				m_log.info("validateJobUnit() add file transfer job retry error. Dest FacilityId = " + file.getDestFacilityID() + ", jobunitId = " + jobunitId + ", jobId = " + jobId + " "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+				throw e;
+			}
+
 		}else if (jobInfo.getType() == JobConstant.TYPE_REFERJOB) {
 			if ( jobInfo.getReferJobId() == null || jobInfo.getReferJobId().equals("")) {
 				InvalidSetting e = new InvalidSetting(Messages.getString("message.job.100"));
@@ -613,7 +666,6 @@ public class JobValidator {
 				CommonValidator.validateCalenderId(jobInfo.getWaitRule().getCalendarId(), true, jobInfo.getOwnerRoleId());
 			}
 		}
-
 		//子JobTreeItemを取得
 		for(JobTreeItem child : item.getChildren()){
 			validateJobInfo(child);
