@@ -116,13 +116,12 @@ public class JobDetailView extends CommonViewPart {
 	 *
 	 * @see com.clustercontrol.jobmanagement.composite.DetailComposite#update(String, String)
 	 */
-	public void update(String managerNamne, String sessionId, String jobunitId) {
-		m_detail.update(managerNamne, sessionId, jobunitId);
-
-		if(managerNamne == null || managerNamne.equals("")) {
+	public void update(String managerName, String sessionId, String jobunitId) {
+		if(managerName == null || managerName.equals("")) {
 			return;
 		}
-		String viewName = orgViewName + "(" + managerNamne + ")";
+		m_detail.update(managerName, sessionId, jobunitId);
+		String viewName = orgViewName + "(" + managerName + ")";
 		setPartName(viewName);
 	}
 
