@@ -15,38 +15,39 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.jobmanagement.view.action;
 
-import org.eclipse.jface.action.IAction;
-import org.eclipse.jface.viewers.ISelection;
-import org.eclipse.ui.IViewActionDelegate;
-import org.eclipse.ui.IViewPart;
-import org.eclipse.ui.PlatformUI;
+import org.eclipse.core.commands.AbstractHandler;
+import org.eclipse.core.commands.ExecutionEvent;
+import org.eclipse.core.commands.ExecutionException;
+import org.eclipse.ui.IWorkbenchPart;
+import org.eclipse.ui.IWorkbenchWindow;
+import org.eclipse.ui.handlers.HandlerUtil;
 
+import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.jobmanagement.composite.JobKickListComposite;
 import com.clustercontrol.jobmanagement.dialog.ScheduleDialog;
 import com.clustercontrol.jobmanagement.view.JobKickListView;
+import com.clustercontrol.util.EndpointManager;
 
 /**
  * ジョブ[実行契機]ビューの「スケジュール作成」のクライアント側アクションクラス<BR>
- * 
- * @version 4.1.0
+ *
+ * @version 5.0.0
  * @since 1.0.0
  */
-public class CreateScheduleAction implements IViewActionDelegate {
+public class CreateScheduleAction extends AbstractHandler {
 	/** アクションID */
-	public static final String ID = "com.clustercontrol.jobmanagement.view.action.CreateScheduleAction";
+	public static final String ID = CreateScheduleAction.class.getName();
+	private IWorkbenchWindow window;
 	/** ビュー */
-	private IViewPart m_view;
+	private IWorkbenchPart viewPart;
 
 	/**
-	 * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
-	 * 
-	 * @param view ビューのインスタンス
-	 * 
-	 * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
+	 * Dispose
 	 */
 	@Override
-	public void init(IViewPart view) {
-		m_view = view;
+	public void dispose() {
+		this.viewPart = null;
+		this.window = null;
 	}
 
 	/**
@@ -56,32 +57,36 @@ public class CreateScheduleAction implements IViewActionDelegate {
 	 * <li>ジョブ[スケジュールの作成・変更]ダイアログを表示します。</li>
 	 * <li>ジョブ[実行契機]ビューを更新します。</li>
 	 * </ol>
-	 * 
+	 *
 	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
 	 * @see com.clustercontrol.jobmanagement.dialog.ScheduleDialog
 	 * @see com.clustercontrol.jobmanagement.view.JobKickListView
 	 * @see com.clustercontrol.jobmanagement.composite.JobKickListComposite
 	 */
 	@Override
-	public void run(IAction action) {
-		if (m_view instanceof JobKickListView) {
-			JobKickListView view = (JobKickListView) m_view
+	public Object execute(ExecutionEvent event) throws ExecutionException {
+		this.window = HandlerUtil.getActiveWorkbenchWindow(event);
+		// In case this action has been disposed
+		if( null == this.window || !isEnabled() ){
+			return null;
+		}
+
+		// 選択アイテムの取得
+		this.viewPart = HandlerUtil.getActivePart(event);
+
+		if (viewPart instanceof JobKickListView) {
+			JobKickListView view = (JobKickListView) viewPart
 					.getAdapter(JobKickListView.class);
 			JobKickListComposite composite = view.getComposite();
 
+			String managerName = EndpointManager.getActiveManagerNameList().get(0);
+
 			//ダイアログ表示
-			ScheduleDialog dialog = new ScheduleDialog(PlatformUI
-					.getWorkbench().getActiveWorkbenchWindow().getShell());
+			ScheduleDialog dialog = new ScheduleDialog(HandlerUtil.getActiveWorkbenchWindow( event ).getShell(),
+					managerName, null, PropertyDefineConstant.MODE_ADD);
 			dialog.open();
 			composite.update();
 		}
+		return null;
 	}
-
-	/* (non-Javadoc)
-	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction, org.eclipse.jface.viewers.ISelection)
-	 */
-	@Override
-	public void selectionChanged(IAction action, ISelection selection) {
-
-	}
-}
\ No newline at end of file
+}
