@@ -15,6 +15,7 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.jobmanagement.view.action;
 
+import java.util.List;
 import java.util.Map;
 
 import org.apache.commons.logging.Log;
@@ -74,7 +75,7 @@ public class RunJobAction extends AbstractHandler implements IElementUpdater {
 	}
 
 	/**
-	 * ジョブ[一覧]ビューの「登録」が押された場合に、ジョブを登録します。
+	 * ジョブ[一覧]ビューの「実行」が押された場合に、ジョブを実行します。
 	 * <p>
 	 * <ol>
 	 * <li>ジョブ[一覧]ビューから選択されたジョブツリーアイテムを取得します。</li>
@@ -88,7 +89,6 @@ public class RunJobAction extends AbstractHandler implements IElementUpdater {
 	 */
 	@Override
 	public Object execute(ExecutionEvent event) throws ExecutionException {
-		JobTreeItem item = null;
 
 		this.window = HandlerUtil.getActiveWorkbenchWindow(event);
 		// In case this action has been disposed
@@ -101,57 +101,81 @@ public class RunJobAction extends AbstractHandler implements IElementUpdater {
 
 		if (viewPart instanceof JobListView) {
 			JobListView view = (JobListView) viewPart.getAdapter(JobListView.class);
-			item = view.getSelectJobTreeItemList().get(0);
+			List<JobTreeItem> itemList = null;
+			itemList = view.getSelectJobTreeItemList();
+			
+			// ジョブ実行確認ダイアログメッセージの生成
+			StringBuffer jobListMessage = new StringBuffer();
+			jobListMessage.append(Messages.getString("message.job.125"));
+			jobListMessage.append("\n");
 
-			if (item instanceof JobTreeItem) {
-				JobTreeItem manager = JobTreeItemUtil.getManager(item);
-				String managerName = manager.getData().getName();
-				JobEditState jobEditState = JobEditStateUtil.getJobEditState( managerName );
-				if(jobEditState.isEditing()){
-					// 確認ダイアログを生成
-					MessageDialog.openWarning(
-							null,
-							Messages.getString("confirmed"),
-							Messages.getString("message.job.43") + "\n" +
-									Messages.getString("message.job.44"));
-					return null;
+			for (JobTreeItem item : itemList) {
+				String managerName = "";
+
+				// ジョブ実行前の状態確認
+				if (item instanceof JobTreeItem) {
+					JobTreeItem manager = JobTreeItemUtil.getManager(item);
+					managerName = manager.getData().getName();
+					JobEditState jobEditState = JobEditStateUtil.getJobEditState( managerName );
+					if(jobEditState.isEditing()){
+						// 確認ダイアログを生成
+						MessageDialog.openWarning(
+								null,
+								Messages.getString("confirmed"),
+								Messages.getString("message.job.43") + "\n" +
+										Messages.getString("message.job.44"));
+						return null;
+					}
 				}
 
-				// 確認ダイアログを生成
-				Object[] args1 = { item.getData().getName(), item.getData().getId(), item.getData().getJobunitId() };
-				//ダイアログ表示
-				JobRunConfirm dialog = new JobRunConfirm(null);
-				dialog.setMessageText(Messages.getString(Messages.getString("message.job.32"), args1));
-				if (dialog.open() == IDialogConstants.OK_ID) {
-					m_trigger = dialog.getInputData();
-					//ジョブ実行
-					try {
-						// 実行契機情報を登録
-						JobTriggerInfo triggerInfo = new JobTriggerInfo();
-						triggerInfo.setTriggerType(JobTriggerTypeConstant.TYPE_MANUAL);
-						triggerInfo.setJobWaitTime(m_trigger.isJobWaitTime());
-						triggerInfo.setJobWaitMinute(m_trigger.isJobWaitMinute());
-						triggerInfo.setJobCommand(m_trigger.isJobCommand());
-						triggerInfo.setJobCommandText(m_trigger.getJobCommandText());
+				// 実行対象のジョブリストを作成(ダイアログ表示用)
+				Object[] args1 = { item.getData().getName(), managerName, item.getData().getId(), item.getData().getJobunitId() };
+				jobListMessage.append(Messages.getString(Messages.getString("message.job.32"), args1));
+				jobListMessage.append("\n");
+			}
 
-						JobEndpointWrapper wrapper = JobEndpointWrapper.getWrapper(managerName);
-						wrapper.runJob(
-								item.getData().getJobunitId(),
-								item.getData().getId(),
-								null,
-								triggerInfo);
-					} catch (InvalidRole_Exception e) {
-						MessageDialog.openInformation(null, Messages.getString("message"),
-								Messages.getString("message.accesscontrol.16"));
-					} catch (Exception e) {
-						m_log.warn("run(), " + e.getMessage(), e);
-						MessageDialog.openError(
-								null,
-								Messages.getString("failed"),
-								Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+			// ジョブ実行確認ダイアログを生成
+			JobRunConfirm dialog = new JobRunConfirm(null);
+			dialog.setMessageText(jobListMessage.toString());
+
+			// ジョブ実行確認ダイアログ表示
+			if (dialog.open() == IDialogConstants.OK_ID) {
+				m_trigger = dialog.getInputData();
+				// 選択されているジョブの実行
+				for (JobTreeItem item : itemList) {
+					if (item instanceof JobTreeItem) {
+						JobTreeItem manager = JobTreeItemUtil.getManager(item);
+						String managerName = manager.getData().getName();
+						// ジョブ実行
+						try {
+							// 実行契機情報を登録
+							JobTriggerInfo triggerInfo = new JobTriggerInfo();
+							triggerInfo.setTriggerType(JobTriggerTypeConstant.TYPE_MANUAL);
+							triggerInfo.setJobWaitTime(m_trigger.isJobWaitTime());
+							triggerInfo.setJobWaitMinute(m_trigger.isJobWaitMinute());
+							triggerInfo.setJobCommand(m_trigger.isJobCommand());
+							triggerInfo.setJobCommandText(m_trigger.getJobCommandText());
+
+							JobEndpointWrapper wrapper = JobEndpointWrapper.getWrapper(managerName);
+							wrapper.runJob(
+									item.getData().getJobunitId(),
+									item.getData().getId(),
+									null,
+									triggerInfo);
+						} catch (InvalidRole_Exception e) {
+							MessageDialog.openInformation(null, Messages.getString("message"),
+									Messages.getString("message.accesscontrol.16"));
+						} catch (Exception e) {
+							m_log.warn("run(), " + e.getMessage(), e);
+							MessageDialog.openError(
+									null,
+									Messages.getString("failed"),
+									Messages.getString("message.hinemos.failure.unexpected") + ", " + e.getMessage());
+						}
 					}
 				}
 			}
+
 		}
 		return null;
 	}
@@ -167,16 +191,20 @@ public class RunJobAction extends AbstractHandler implements IElementUpdater {
 
 				boolean editEnable = false;
 				if(part instanceof JobListView){
-					// Enable button when 1 item is selected
 					JobListView view = (JobListView)part;
-					int size = view.getJobTreeComposite().getSelectItemList().size();
-					if(size == 1) {
-						if(view.getDataType() == JobConstant.TYPE_JOBUNIT ||
-								view.getDataType() == JobConstant.TYPE_JOBNET ||
-								view.getDataType() == JobConstant.TYPE_JOB ||
-								view.getDataType() == JobConstant.TYPE_FILEJOB ||
-								view.getDataType() == JobConstant.TYPE_REFERJOB){
+					// ジョブ設定パースペクティブのジョブリストのUIにあるツリービューとリストビューのうち、選択されているほうのJobTreeItemListを取得
+					List<JobTreeItem> itemList = view.getSelectJobTreeItemList();
+					for (JobTreeItem item : itemList) {
+						// 選択されている項目をチェックし、ジョブ実行可能なものである場合にツールバーとコンテキストメニューの「実行」を活性化する
+						if (item.getData().getType() == JobConstant.TYPE_JOBUNIT ||
+								item.getData().getType() == JobConstant.TYPE_JOBNET ||
+								item.getData().getType() == JobConstant.TYPE_JOB ||
+								item.getData().getType() == JobConstant.TYPE_FILEJOB ||
+								item.getData().getType() == JobConstant.TYPE_REFERJOB){
 							editEnable = true;
+						} else {
+							editEnable = false;
+							break;
 						}
 					}
 				}
