@@ -10,6 +10,7 @@ import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
+import org.eclipse.swt.widgets.Combo;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
@@ -20,8 +21,8 @@ import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorStringDialog;
 import com.clustercontrol.monitor.util.MonitorSettingEndpointWrapper;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.ws.monitor.InvalidRole_Exception;
 import com.clustercontrol.ws.monitor.LogfileCheckInfo;
 import com.clustercontrol.ws.monitor.MonitorDuplicate_Exception;
@@ -49,44 +50,55 @@ public class LogfileStringCreateDialog extends CommonMonitorStringDialog {
 	/** ファイル名 */
 	private Text m_fileName = null;
 
+	/** エンコード */
+	private Text m_fileEncoding = null;
 
+	/** 改行コード */
+	private Combo m_fileReturnCode = null;
+
+	/** マネージャ名 */
+	private String managerName = null;
 	// ----- コンストラクタ ----- //
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
 	 */
 	public LogfileStringCreateDialog(Shell parent) {
-		super(parent);
+		super(parent, null);
 		logLineFlag = true;
 	}
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
+	 * @param managerName マネージャ名
 	 * @param monitorType 監視判定タイプ
 	 */
-	public LogfileStringCreateDialog(Shell parent, int monitorType) {
-		super(parent);
+	public LogfileStringCreateDialog(Shell parent, String managerName, int monitorType) {
+		super(parent, managerName);
 
 		logLineFlag = true;
+		this.managerName = managerName;
 		this.m_monitorType = monitorType;
 	}
 
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
+	 * @param managerName マネージャ名
 	 * @param monitorId 変更する監視項目ID
 	 * @param updateFlg 更新するか否か（true:変更、false:新規登録）
 	 */
-	public LogfileStringCreateDialog(Shell parent, String monitorId, boolean updateFlg) {
-		super(parent);
+	public LogfileStringCreateDialog(Shell parent, String managerName, String monitorId, boolean updateFlg) {
+		super(parent, managerName);
 
 		logLineFlag = true;
+		this.managerName = managerName;
 		this.monitorId = monitorId;
 		this.updateFlg = updateFlg;
 	}
@@ -95,7 +107,7 @@ public class LogfileStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のインスタンス
 	 */
 	@Override
@@ -116,13 +128,14 @@ public class LogfileStringCreateDialog extends CommonMonitorStringDialog {
 		 * チェック設定グループ（条件グループの子グループ）
 		 */
 		Group groupCheckRule = new Group(groupRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, groupCheckRule);
 		GridLayout layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
-		layout.numColumns = 15;
+		layout.numColumns = BASIC_UNIT;
 		groupCheckRule.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupCheckRule.setLayoutData(gridData);
@@ -131,16 +144,18 @@ public class LogfileStringCreateDialog extends CommonMonitorStringDialog {
 		//ディレクトリ
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "directory", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("directory") + " : ");
 		// テキスト
 		this.m_directory = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "directory", m_directory);
 		gridData = new GridData();
-		gridData.horizontalSpan = 10;
+		gridData.horizontalSpan = LONG_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_directory.setLayoutData(gridData);
@@ -153,16 +168,18 @@ public class LogfileStringCreateDialog extends CommonMonitorStringDialog {
 		//ファイル名
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "filename", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("file.name") + "(" + Messages.getString("regex") + ") : ");
 		// テキスト
 		this.m_fileName = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "filename", m_fileName);
 		gridData = new GridData();
-		gridData.horizontalSpan = 10;
+		gridData.horizontalSpan = LONG_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.m_fileName.setLayoutData(gridData);
@@ -174,6 +191,55 @@ public class LogfileStringCreateDialog extends CommonMonitorStringDialog {
 		});
 		this.m_fileName.setToolTipText(Messages.getString("dialog.logfile.pattern"));
 
+		//ファイルエンコーディング
+		// ラベル
+		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "fileencoding", label);
+		gridData = new GridData();
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		label.setLayoutData(gridData);
+		label.setText(Messages.getString("file.encoding") + " : ");
+		// テキスト
+		this.m_fileEncoding = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "fileencoding", m_fileEncoding);
+		gridData = new GridData();
+		gridData.horizontalSpan = LONG_UNIT;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		this.m_fileEncoding.setLayoutData(gridData);
+		this.m_fileEncoding.addModifyListener(new ModifyListener(){
+			@Override
+			public void modifyText(ModifyEvent arg0) {
+				update();
+			}
+		});
+		
+		//ファイル改行コード
+		// ラベル
+		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "filereturncode", label);
+		gridData = new GridData();
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		label.setLayoutData(gridData);
+		label.setText(Messages.getString("file.returncode") + " : ");
+		// コンボボックス
+		this.m_fileReturnCode = new Combo(groupCheckRule, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "filereturncode", m_fileReturnCode);
+		gridData = new GridData();
+		gridData.horizontalSpan = LONG_UNIT;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		this.m_fileReturnCode.setLayoutData(gridData);
+
+		m_fileReturnCode.add("LF");
+		m_fileReturnCode.add("CR");
+		m_fileReturnCode.add("CRLF");
+		m_fileReturnCode.setText("LF");//デフォルト
+		
 		// 監視間隔の設定を利用不可とする
 		this.m_monitorRule.setRunIntervalEnabled(false);
 
@@ -189,7 +255,8 @@ public class LogfileStringCreateDialog extends CommonMonitorStringDialog {
 		} else {
 			// 変更の場合、情報取得
 			try {
-				info = MonitorSettingEndpointWrapper.getMonitor(monitorId, HinemosModuleConstant.MONITOR_LOGFILE);
+				MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
+				info = wrapper.getMonitor(monitorId, HinemosModuleConstant.MONITOR_LOGFILE);
 			} catch (InvalidRole_Exception e) {
 				// アクセス権なしの場合、エラーダイアログを表示する
 				MessageDialog.openInformation(
@@ -212,28 +279,26 @@ public class LogfileStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
 		super.update();
 
 		// 必須項目を明示
-		if("".equals(this.m_directory.getText())){
-			this.m_directory.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-		}else{
-			this.m_directory.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
-		}
-		if("".equals(this.m_fileName.getText())){
-			this.m_fileName.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
-		}else{
-			this.m_fileName.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+		Text[] texts = {m_directory, m_fileName, m_fileEncoding};
+		for (Text text : texts) {
+			if("".equals(text.getText())){
+				text.setBackground(RequiredFieldColorConstant.COLOR_REQUIRED);
+			}else{
+				text.setBackground(RequiredFieldColorConstant.COLOR_UNREQUIRED);
+			}
 		}
 	}
 
 	/**
 	 * 各項目に入力値を設定します。
-	 * 
+	 *
 	 * @param monitor 設定値として用いる監視情報
 	 */
 	@Override
@@ -261,6 +326,14 @@ public class LogfileStringCreateDialog extends CommonMonitorStringDialog {
 			if (logfileInfo.getFileName() != null){
 				this.m_fileName.setText(logfileInfo.getFileName());
 			}
+			if (logfileInfo.getFileEncoding() != null){
+				this.m_fileEncoding.setText(logfileInfo.getFileEncoding());
+			} else {
+				this.m_fileEncoding.setText("UTF-8");
+			}
+			if (logfileInfo.getFileReturnCode() != null){
+				this.m_fileReturnCode.setText(logfileInfo.getFileReturnCode());
+			}
 		}
 
 		// ログファイル名が必須項目であることを明示
@@ -271,7 +344,7 @@ public class LogfileStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 入力値を用いて通知情報を生成します。
-	 * 
+	 *
 	 * @return 入力値を保持した通知情報
 	 */
 	@Override
@@ -298,7 +371,15 @@ public class LogfileStringCreateDialog extends CommonMonitorStringDialog {
 				&& !"".equals(this.m_fileName.getText())) {
 			logfileInfo.setFileName(this.m_fileName.getText());
 		}
-
+		if (this.m_fileEncoding.getText() != null
+				&& !"".equals(this.m_fileEncoding.getText())) {
+			logfileInfo.setFileEncoding(this.m_fileEncoding.getText());
+		}
+		if (this.m_fileReturnCode.getText() != null
+				&& !"".equals(this.m_fileReturnCode.getText())) {
+			logfileInfo.setFileReturnCode(this.m_fileReturnCode.getText());
+		}
+		
 		monitorInfo.setLogfileCheckInfo(logfileInfo);
 
 		// 結果判定の定義
@@ -308,8 +389,6 @@ public class LogfileStringCreateDialog extends CommonMonitorStringDialog {
 		}
 
 		// 通知関連情報とアプリケーションの設定
-		// 通知グループIDの設定
-		monitorInfo.setNotifyGroupId(NotifyGroupIdGenerator.createNotifyGroupId(HinemosModuleConstant.MONITOR_LOGFILE, monitorInfo.getMonitorId()));
 		validateResult = m_notifyInfo.createInputData(monitorInfo);
 		if (validateResult != null) {
 			if(validateResult.getID() == null){	// 通知ID警告用出力
@@ -328,9 +407,9 @@ public class LogfileStringCreateDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -338,12 +417,14 @@ public class LogfileStringCreateDialog extends CommonMonitorStringDialog {
 		boolean result = false;
 
 		MonitorInfo info = this.inputData;
+		String managerName = this.getManagerName();
 		if(info != null){
-			String[] args = { info.getMonitorId() };
+			String[] args = { info.getMonitorId(), managerName };
+			MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
 			if(!this.updateFlg){
 				// 作成の場合
 				try {
-					result = MonitorSettingEndpointWrapper.addMonitor(info);
+					result = wrapper.addMonitor(info);
 
 					if(result){
 						MessageDialog.openInformation(
@@ -384,7 +465,7 @@ public class LogfileStringCreateDialog extends CommonMonitorStringDialog {
 				// 変更の場合
 				String errMessage = "";
 				try {
-					result = MonitorSettingEndpointWrapper.modifyMonitor(info);
+					result = wrapper.modifyMonitor(info);
 				} catch (InvalidRole_Exception e) {
 					// アクセス権なしの場合、エラーダイアログを表示する
 					MessageDialog.openInformation(
