@@ -23,21 +23,22 @@ import com.clustercontrol.ws.maintenance.InvalidRole_Exception;
 import com.clustercontrol.ws.maintenance.MaintenanceInfo;
 
 /**
- * 
+ *
  * メンテナンス情報を修正するクライアント側アクションクラス<BR>
- * 
+ *
  * @version 3.0.0
  * @since 2.2.0
  *
  */
 public class ModifyMaintenance {
 
-	public boolean modify(MaintenanceInfo info) {
+	public boolean modify(String managerName, MaintenanceInfo info) {
 		boolean ret = false;
 
-		String[] args = { info.getMaintenanceId() };
+		String[] args = { info.getMaintenanceId(), managerName };
 		try {
-			MaintenanceEndpointWrapper.modifyMaintenance(info);
+			MaintenanceEndpointWrapper wrapper = MaintenanceEndpointWrapper.getWrapper(managerName);
+			wrapper.modifyMaintenance(info);
 
 			MessageDialog.openInformation(
 					null,
