@@ -19,6 +19,7 @@ import org.eclipse.ui.IFolderLayout;
 import org.eclipse.ui.IPageLayout;
 
 import com.clustercontrol.ClusterControlPerspectiveBase;
+import com.clustercontrol.maintenance.view.HinemosPropertyView;
 import com.clustercontrol.maintenance.view.MaintenanceListView;
 
 
@@ -44,7 +45,10 @@ public class MaintenancePerspective extends ClusterControlPerspectiveBase {
 		String editorArea = layout.getEditorArea();
 		//エディタ領域の上部percent%を占めるフォルダを作成
 		IFolderLayout top = layout.createFolder("top", IPageLayout.TOP, percent, editorArea);
+		// エディタ領域の下部(1-percent)%を占めるフォルダを作成
+		IFolderLayout bottom = layout.createFolder( "bottom", IPageLayout.BOTTOM, (IPageLayout.RATIO_MAX - percent), editorArea );
 
 		top.addView(MaintenanceListView.ID);
+		bottom.addView(HinemosPropertyView.ID);
 	}
-}
\ No newline at end of file
+}
