@@ -17,9 +17,6 @@ package com.clustercontrol.monitor.run.factory;
 
 import java.util.ArrayList;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.bean.MonitorTruthValueInfo;
@@ -37,8 +34,6 @@ import com.clustercontrol.monitor.run.util.QueryUtil;
  */
 abstract public class AddMonitorTruthValueType extends AddMonitor{
 
-	private static Log m_log = LogFactory.getLog(AddMonitorTruthValueType.class);
-
 	/**
 	 * 真偽値監視の判定情報を作成し、監視情報に設定します。
 	 * 
