@@ -23,25 +23,24 @@ import java.util.List;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.bean.ValidConstant;
+import com.clustercontrol.custom.bean.CustomCheckInfo;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.MonitorNotFound;
-import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.bean.YesNoConstant;
-import com.clustercontrol.custom.bean.CustomCheckInfo;
 import com.clustercontrol.http.bean.HttpCheckInfo;
+import com.clustercontrol.http.bean.HttpScenarioCheckInfo;
+import com.clustercontrol.jmx.bean.JmxCheckInfo;
 import com.clustercontrol.logfile.bean.LogfileCheckInfo;
 import com.clustercontrol.monitor.bean.MonitorFilterInfo;
 import com.clustercontrol.monitor.plugin.bean.PluginCheckInfo;
 import com.clustercontrol.monitor.run.bean.MonitorInfo;
 import com.clustercontrol.monitor.run.bean.MonitorNumericValueInfo;
 import com.clustercontrol.monitor.run.bean.MonitorStringValueInfo;
-import com.clustercontrol.monitor.run.bean.MonitorTrapValueInfo;
 import com.clustercontrol.monitor.run.bean.MonitorTruthValueInfo;
 import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
 import com.clustercontrol.monitor.run.model.MonitorNumericValueInfoEntity;
 import com.clustercontrol.monitor.run.model.MonitorStringValueInfoEntity;
-import com.clustercontrol.monitor.run.model.MonitorTrapValueInfoEntity;
 import com.clustercontrol.monitor.run.model.MonitorTruthValueInfoEntity;
 import com.clustercontrol.monitor.run.util.QueryUtil;
 import com.clustercontrol.notify.bean.NotifyRelationInfo;
@@ -163,13 +162,16 @@ public class SelectMonitor {
 	protected ArrayList<MonitorStringValueInfo> getStringValueInfo() {
 
 		// 文字列監視判定情報を取得
-		Collection<MonitorStringValueInfoEntity> ct = m_monitor.getMonitorStringValueInfoEntities();
+		List<MonitorStringValueInfoEntity> ct = m_monitor.getMonitorStringValueInfoEntities();
+		
+		// Entityを直接ソートすると、データが変更されたと判定されてしまうため別のリストにつめなおす
+		List<MonitorStringValueInfoEntity> entityList = new ArrayList<>(ct);
+		Collections.sort(entityList, new MonitorStringValueInfoComparator());
 		ArrayList<MonitorStringValueInfo> valueList = new ArrayList<MonitorStringValueInfo>();
 
-		for (MonitorStringValueInfoEntity entity : ct) {
+		for (MonitorStringValueInfoEntity entity : entityList) {
 			MonitorStringValueInfo value = new MonitorStringValueInfo(
 					entity.getId().getMonitorId(),
-					entity.getId().getOrderNo().intValue(),
 					entity.getDescription(),
 					entity.getProcessType().intValue(),
 					entity.getPattern(),
@@ -181,8 +183,6 @@ public class SelectMonitor {
 			valueList.add(value);
 		}
 
-		// orderNoでソート
-		Collections.sort(valueList, new MonitorStringValueInfoComparator());
 		return valueList;
 	}
 
@@ -210,37 +210,15 @@ public class SelectMonitor {
 	}
 
 	/**
-	 * 判定情報を返します。
+	 * チェック条件情報を返します。
 	 * <p>
-	 * @return 判定情報（{@link com.clustercontrol.monitor.run.bean.MonitorJudgementInfo}のリスト）
+	 * 各監視管理のサブクラスで実装します。
+	 * 
+	 * @return チェック条件情報
+	 * @throws MonitorNotFound
 	 */
-	protected ArrayList<MonitorTrapValueInfo> getTrapValueInfo() {
-		m_log.debug("getTrapValueInfo() : start");
-
-		// 真偽値監視判定情報を取得
-		Collection<MonitorTrapValueInfoEntity> ct = m_monitor.getMonitorTrapValueInfoEntities();
-
-		ArrayList<MonitorTrapValueInfo> valueList = new ArrayList<MonitorTrapValueInfo>();
-
-		for (MonitorTrapValueInfoEntity entity : ct) {
-			m_log.debug("getTrapValueInfo() : add Uei = " + entity.getId().getUei());
-
-			MonitorTrapValueInfo value = new MonitorTrapValueInfo(
-					entity.getId().getMonitorId(),
-					entity.getId().getMib(),
-					entity.getId().getTrapOid(),
-					entity.getId().getGenericId(),
-					entity.getId().getSpecificId(),
-					entity.getId().getUei(),
-					YesNoConstant.typeToBoolean(entity.getValidFlg()),
-					entity.getPriority(),
-					entity.getLogmsg(),
-					entity.getDescr());
-			valueList.add(value);
-		}
-
-		m_log.debug("getTrapValueInfo() : end");
-		return valueList;
+	protected HttpCheckInfo getHttpCheckInfo() throws MonitorNotFound {
+		return null;
 	}
 
 	/**
@@ -251,7 +229,19 @@ public class SelectMonitor {
 	 * @return チェック条件情報
 	 * @throws MonitorNotFound
 	 */
-	protected HttpCheckInfo getHttpCheckInfo() throws MonitorNotFound {
+	protected HttpScenarioCheckInfo getHttpScenarioCheckInfo() throws MonitorNotFound {
+		return null;
+	}
+
+	/**
+	 * チェック条件情報を返します。
+	 * <p>
+	 * 各監視管理のサブクラスで実装します。
+	 * 
+	 * @return チェック条件情報
+	 * @throws MonitorNotFound
+	 */
+	protected JmxCheckInfo getJmxCheckInfo() throws MonitorNotFound {
 		return null;
 	}
 
@@ -670,7 +660,6 @@ public class SelectMonitor {
 				m_monitor.getRegDate()==null?null:m_monitor.getRegDate().getTime(),
 				m_monitor.getRegUser(),
 				m_monitor.getRunInterval(),
-				m_monitor.getNotifyGroupId(),
 				notifyId,
 				m_monitor.getUpdateDate()==null?null:m_monitor.getUpdateDate().getTime(),
 				m_monitor.getUpdateUser(),
@@ -682,8 +671,8 @@ public class SelectMonitor {
 				getNumericValueInfo(),
 				getStringValueInfo(),
 				getTruthValueInfo(),
-				getTrapValueInfo(),
 				getHttpCheckInfo(),
+				getHttpScenarioCheckInfo(),
 				getPerfCheckInfo(),
 				getPingCheckInfo(),
 				getPluginCheckInfo(),
@@ -695,7 +684,8 @@ public class SelectMonitor {
 				getCommandCheckInfo(),
 				getLogfileCheckInfo(),
 				getWinServiceCheckInfo(),
-				getWinEventCheckInfo());
+				getWinEventCheckInfo(),
+				getJmxCheckInfo());
 
 		return info;
 	}
@@ -710,20 +700,19 @@ public class SelectMonitor {
 		String[] args = {m_monitorTypeId, m_monitorId };
 		apllog.put("SYS", index, args);
 	}
-}
 
-/**
- * 文字列監視用のフィルタ条件のリストのOrderNo順のソート処理用
- * 
- * @author hinemos
- *
- */
-class MonitorStringValueInfoComparator implements java.util.Comparator<MonitorStringValueInfo>{
 	/**
-	 * orderNoの昇順でソート
+	 * 文字列監視用のフィルタ条件のリストのOrderNo順のソート処理用
+	 * 
+	 *
 	 */
-	@Override
-	public int compare(MonitorStringValueInfo o1, MonitorStringValueInfo o2) {
-		return (o1.getOrderNo() - o2.getOrderNo());
+	class MonitorStringValueInfoComparator implements java.util.Comparator<MonitorStringValueInfoEntity>{
+		/**
+		 * orderNoの昇順でソート
+		 */
+		@Override
+		public int compare(MonitorStringValueInfoEntity o1, MonitorStringValueInfoEntity o2) {
+			return (o1.getId().getOrderNo() - o2.getId().getOrderNo());
+		}
 	}
 }
\ No newline at end of file
