@@ -1,14 +1,29 @@
 package com.clustercontrol.monitor.run.model;
 
-import javax.persistence.*;
+import java.sql.Timestamp;
+import java.util.Iterator;
+import java.util.List;
 
+import javax.persistence.AttributeOverride;
+import javax.persistence.Cacheable;
+import javax.persistence.CascadeType;
+import javax.persistence.Column;
+import javax.persistence.Entity;
+import javax.persistence.FetchType;
+import javax.persistence.Id;
+import javax.persistence.OneToMany;
+import javax.persistence.OneToOne;
+import javax.persistence.Table;
 
 import com.clustercontrol.accesscontrol.annotation.HinemosObjectPrivilege;
 import com.clustercontrol.accesscontrol.model.ObjectPrivilegeTargetEntity;
 import com.clustercontrol.bean.HinemosModuleConstant;
+import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.custom.model.MonitorCustomInfoEntity;
 import com.clustercontrol.http.model.MonitorHttpInfoEntity;
+import com.clustercontrol.http.model.MonitorHttpScenarioInfoEntity;
+import com.clustercontrol.jmx.model.MonitorJmxInfoEntity;
 import com.clustercontrol.logfile.model.MonitorLogfileInfoEntity;
 import com.clustercontrol.monitor.plugin.model.MonitorPluginInfoEntity;
 import com.clustercontrol.performance.monitor.model.MonitorPerfInfoEntity;
@@ -21,17 +36,13 @@ import com.clustercontrol.sql.model.MonitorSqlInfoEntity;
 import com.clustercontrol.winevent.model.MonitorWinEventInfoEntity;
 import com.clustercontrol.winservice.model.MonitorWinserviceInfoEntity;
 
-import java.sql.Timestamp;
-import java.util.Iterator;
-import java.util.List;
-
 
 /**
  * The persistent class for the cc_monitor_info database table.
  * 
  */
 @Entity
-@Table(name="cc_monitor_info")
+@Table(name="cc_monitor_info", schema="setting")
 @Cacheable(true)
 @HinemosObjectPrivilege(
 		objectType=HinemosModuleConstant.MONITOR,
@@ -74,8 +85,9 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 	private MonitorWinEventInfoEntity monitorWinEventInfoEntity;
 	private MonitorLogfileInfoEntity monitorLogfileInfoEntity;
 	private MonitorPluginInfoEntity monitorPluginInfoEntity;
+	private MonitorHttpScenarioInfoEntity monitorHttpScenarioInfoEntity;
+	private MonitorJmxInfoEntity monitorJmxInfoEntity;
 	private List<MonitorStringValueInfoEntity> monitorStringValueInfoEntities;
-	private List<MonitorTrapValueInfoEntity> monitorTrapValueInfoEntities;
 	private List<MonitorTruthValueInfoEntity> monitorTruthValueInfoEntities;
 
 	@Deprecated
@@ -85,7 +97,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 
 	public MonitorInfoEntity(String monitorId) {
 		super();
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		this.setMonitorId(monitorId);
 		em.persist(this);
 		this.setObjectId(this.getMonitorId());
@@ -431,6 +443,29 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 	}
 
 
+	//bi-directional one-to-one association to MonitorLogfileInfoEntity
+	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL)
+	public MonitorHttpScenarioInfoEntity getMonitorHttpScenarioInfoEntity() {
+		return monitorHttpScenarioInfoEntity;
+	}
+
+	public void setMonitorHttpScenarioInfoEntity(
+			MonitorHttpScenarioInfoEntity monitorHttpScenarioInfoEntity) {
+		this.monitorHttpScenarioInfoEntity = monitorHttpScenarioInfoEntity;
+	}
+
+	//bi-directional one-to-one association to MonitorLogfileInfoEntity
+	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL)
+	public MonitorJmxInfoEntity getMonitorJmxInfoEntity() {
+		return monitorJmxInfoEntity;
+	}
+
+	public void setMonitorJmxInfoEntity(
+			MonitorJmxInfoEntity monitorJmxInfoEntity) {
+		this.monitorJmxInfoEntity = monitorJmxInfoEntity;
+	}
+
+
 	//bi-directional one-to-one association to MonitorLogfileInfoEntity
 	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL)
 	public MonitorPluginInfoEntity getMonitorPluginInfoEntity() {
@@ -441,6 +476,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 		this.monitorPluginInfoEntity = monitorPluginInfoEntity;
 	}
 
+
 	//bi-directional many-to-one association to MonitorStringValueInfoEntity
 	@OneToMany(mappedBy="monitorInfoEntity", cascade=CascadeType.ALL, fetch=FetchType.LAZY)
 	public List<MonitorStringValueInfoEntity> getMonitorStringValueInfoEntities() {
@@ -452,17 +488,6 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 	}
 
 
-	//bi-directional many-to-one association to MonitorTrapValueInfoEntity
-	@OneToMany(mappedBy="monitorInfoEntity", cascade=CascadeType.ALL, fetch=FetchType.LAZY)
-	public List<MonitorTrapValueInfoEntity> getMonitorTrapValueInfoEntities() {
-		return this.monitorTrapValueInfoEntities;
-	}
-
-	public void setMonitorTrapValueInfoEntities(List<MonitorTrapValueInfoEntity> monitorTrapValueInfoEntities) {
-		this.monitorTrapValueInfoEntities = monitorTrapValueInfoEntities;
-	}
-
-
 	//bi-directional many-to-one association to MonitorTruthValueInfoEntity
 	@OneToMany(mappedBy="monitorInfoEntity", cascade=CascadeType.ALL, fetch=FetchType.LAZY)
 	public List<MonitorTruthValueInfoEntity> getMonitorTruthValueInfoEntities() {
@@ -473,7 +498,6 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 		this.monitorTruthValueInfoEntities = monitorTruthValueInfoEntities;
 	}
 
-
 	/**
 	 * MonitorNumericValueInfoEntity削除<BR>
 	 * 
@@ -481,7 +505,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 	 * 
 	 */
 	public void deleteMonitorNumericValueInfoEntities(List<MonitorNumericValueInfoEntityPK> notDelPkList) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<MonitorNumericValueInfoEntity> list = this.getMonitorNumericValueInfoEntities();
 		Iterator<MonitorNumericValueInfoEntity> iter = list.iterator();
 		while(iter.hasNext()) {
@@ -500,7 +524,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 	 * 
 	 */
 	public void deleteMonitorStringValueInfoEntities(List<MonitorStringValueInfoEntityPK> notDelPkList) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<MonitorStringValueInfoEntity> list = this.getMonitorStringValueInfoEntities();
 		Iterator<MonitorStringValueInfoEntity> iter = list.iterator();
 		while(iter.hasNext()) {
@@ -512,25 +536,6 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 		}
 	}
 
-	/**
-	 * MonitorTrapValueInfoEntity削除<BR>
-	 * 
-	 * 指定されたPK以外の子Entityを削除する。
-	 * 
-	 */
-	public void deleteMonitorTrapValueInfoEntities(List<MonitorTrapValueInfoEntityPK> notDelPkList) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		List<MonitorTrapValueInfoEntity> list = this.getMonitorTrapValueInfoEntities();
-		Iterator<MonitorTrapValueInfoEntity> iter = list.iterator();
-		while(iter.hasNext()) {
-			MonitorTrapValueInfoEntity entity = iter.next();
-			if (!notDelPkList.contains(entity.getId())) {
-				iter.remove();
-				em.remove(entity);
-			}
-		}
-	}
-
 	/**
 	 * MonitorTruthValueInfoEntity削除<BR>
 	 * 
@@ -538,7 +543,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 	 * 
 	 */
 	public void deleteMonitorTruthValueInfoEntities(List<MonitorTruthValueInfoEntityPK> notDelPkList) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<MonitorTruthValueInfoEntity> list = this.getMonitorTruthValueInfoEntities();
 		Iterator<MonitorTruthValueInfoEntity> iter = list.iterator();
 		while(iter.hasNext()) {
@@ -549,5 +554,4 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 			}
 		}
 	}
-
 }
\ No newline at end of file
