@@ -18,14 +18,13 @@ package com.clustercontrol.monitor.run.util;
 import java.sql.Timestamp;
 import java.util.List;
 
-import javax.persistence.EntityManager;
 import javax.persistence.TypedQuery;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
+import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
@@ -36,8 +35,6 @@ import com.clustercontrol.monitor.run.model.MonitorNumericValueInfoEntity;
 import com.clustercontrol.monitor.run.model.MonitorNumericValueInfoEntityPK;
 import com.clustercontrol.monitor.run.model.MonitorStringValueInfoEntity;
 import com.clustercontrol.monitor.run.model.MonitorStringValueInfoEntityPK;
-import com.clustercontrol.monitor.run.model.MonitorTrapValueInfoEntity;
-import com.clustercontrol.monitor.run.model.MonitorTrapValueInfoEntityPK;
 import com.clustercontrol.monitor.run.model.MonitorTruthValueInfoEntity;
 import com.clustercontrol.monitor.run.model.MonitorTruthValueInfoEntityPK;
 
@@ -50,10 +47,10 @@ public class QueryUtil {
 	}
 
 	public static MonitorInfoEntity getMonitorInfoPK(String monitorId, ObjectPrivilegeMode mode) throws MonitorNotFound, InvalidRole {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		MonitorInfoEntity entity = null;
 		try {
-			entity = ((HinemosEntityManager)em).find(MonitorInfoEntity.class, monitorId, mode);
+			entity = em.find(MonitorInfoEntity.class, monitorId, mode);
 			if (entity == null) {
 				MonitorNotFound e = new MonitorNotFound("MonitorInfoEntity.findByPrimaryKey"
 						+ ", monitorId = " + monitorId);
@@ -70,9 +67,9 @@ public class QueryUtil {
 	}
 
 	public static MonitorInfoEntity getMonitorInfoPK_NONE(String monitorId) throws MonitorNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		MonitorInfoEntity entity
-		= ((HinemosEntityManager)em).find(MonitorInfoEntity.class, monitorId, ObjectPrivilegeMode.NONE);
+		= em.find(MonitorInfoEntity.class, monitorId, ObjectPrivilegeMode.NONE);
 		if (entity == null) {
 			MonitorNotFound e = new MonitorNotFound("MonitorInfoEntity.findByPrimaryKey"
 					+ ", monitorId = " + monitorId);
@@ -84,7 +81,7 @@ public class QueryUtil {
 	}
 
 	public static List<MonitorInfoEntity> getAllMonitorInfo() throws HinemosUnknown {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<MonitorInfoEntity> list
 		= em.createNamedQuery("MonitorInfoEntity.findAll", MonitorInfoEntity.class)
 		.getResultList();
@@ -92,25 +89,25 @@ public class QueryUtil {
 	}
 
 	public static List<MonitorInfoEntity> getMonitorInfoByOwnerRoleId_NONE(String roleId) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<MonitorInfoEntity> list
-		= ((HinemosEntityManager)em).createNamedQuery("MonitorInfoEntity.findByOwnerRoleId", MonitorInfoEntity.class, ObjectPrivilegeMode.NONE)
+		= em.createNamedQuery("MonitorInfoEntity.findByOwnerRoleId", MonitorInfoEntity.class, ObjectPrivilegeMode.NONE)
 		.setParameter("ownerRoleId", roleId)
 		.getResultList();
 		return list;
 	}
-	
+
 	public static List<MonitorInfoEntity> getMonitorInfoByFacilityId_NONE(String facilityId) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<MonitorInfoEntity> list
-		= ((HinemosEntityManager)em).createNamedQuery("MonitorInfoEntity.findByFacilityId", MonitorInfoEntity.class, ObjectPrivilegeMode.NONE)
+		= em.createNamedQuery("MonitorInfoEntity.findByFacilityId", MonitorInfoEntity.class, ObjectPrivilegeMode.NONE)
 		.setParameter("facilityId", facilityId)
 		.getResultList();
 		return list;
 	}
 
 	public static List<MonitorInfoEntity> getMonitorInfoByMonitorTypeId(String monitorTypeId) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<MonitorInfoEntity> list
 		= em.createNamedQuery("MonitorInfoEntity.findByMonitorTypeId", MonitorInfoEntity.class)
 		.setParameter("monitorTypeId", monitorTypeId)
@@ -119,8 +116,8 @@ public class QueryUtil {
 	}
 
 	public static MonitorNumericValueInfoEntity getMonitorNumericValueInfoPK(MonitorNumericValueInfoEntityPK pk) throws MonitorNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		MonitorNumericValueInfoEntity entity = em.find(MonitorNumericValueInfoEntity.class, pk);
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
+		MonitorNumericValueInfoEntity entity = em.find(MonitorNumericValueInfoEntity.class, pk, ObjectPrivilegeMode.READ);
 		if (entity == null) {
 			MonitorNotFound e = new MonitorNotFound("MonitorNumericValueInfoEntity.findByPrimaryKey"
 					+ pk.toString());
@@ -136,8 +133,8 @@ public class QueryUtil {
 	}
 
 	public static MonitorStringValueInfoEntity getMonitorStringValueInfoPK(MonitorStringValueInfoEntityPK pk) throws MonitorNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		MonitorStringValueInfoEntity entity = em.find(MonitorStringValueInfoEntity.class, pk);
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
+		MonitorStringValueInfoEntity entity = em.find(MonitorStringValueInfoEntity.class, pk, ObjectPrivilegeMode.READ);
 		if (entity == null) {
 			MonitorNotFound e = new MonitorNotFound("MonitorStringValueInfoEntity.findByPrimaryKey"
 					+ pk.toString());
@@ -152,40 +149,9 @@ public class QueryUtil {
 		return getMonitorStringValueInfoPK(new MonitorStringValueInfoEntityPK(monitorId, orderNo));
 	}
 
-	public static MonitorTrapValueInfoEntity getMonitorTrapValueInfoPK(MonitorTrapValueInfoEntityPK pk) throws MonitorNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		MonitorTrapValueInfoEntity entity = em.find(MonitorTrapValueInfoEntity.class, pk);
-		if (entity == null) {
-			MonitorNotFound e = new MonitorNotFound("MonitorTrapValueInfoEntity.findByPrimaryKey"
-					+ pk.toString());
-			m_log.info("getMonitorTrapValueInfoPK() : "
-					+ e.getClass().getSimpleName() + ", " + e.getMessage());
-			throw e;
-		}
-		return entity;
-	}
-
-	public static MonitorTrapValueInfoEntity getMonitorTrapValueInfoPK(String monitorId,
-			String mib,
-			String trapOid,
-			Integer genericId,
-			Integer specificId,
-			String uei) throws MonitorNotFound {
-		return getMonitorTrapValueInfoPK(new MonitorTrapValueInfoEntityPK(monitorId, mib, trapOid, genericId, specificId, uei));
-	}
-	
-	public static List<MonitorTrapValueInfoEntity> getAllMonitorTrapValueInfo() throws HinemosUnknown {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		List<MonitorTrapValueInfoEntity> list
-		= em.createNamedQuery("MonitorTrapValueInfoEntity.findAll", MonitorTrapValueInfoEntity.class)
-		.getResultList();
-		return list;
-		
-	}
-
 	public static MonitorTruthValueInfoEntity getMonitorTruthValueInfoPK(MonitorTruthValueInfoEntityPK pk) throws MonitorNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		MonitorTruthValueInfoEntity entity = em.find(MonitorTruthValueInfoEntity.class, pk);
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
+		MonitorTruthValueInfoEntity entity = em.find(MonitorTruthValueInfoEntity.class, pk, ObjectPrivilegeMode.READ);
 		if (entity == null) {
 			MonitorNotFound e = new MonitorNotFound("MonitorTruthValueInfoEntity.findByPrimaryKey"
 					+ pk.toString());
@@ -196,9 +162,9 @@ public class QueryUtil {
 		return entity;
 	}
 	public static List<MonitorInfoEntity> getMonitorInfoEntityFindByCalendarId_NONE(String calendarId){
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<MonitorInfoEntity> monitorInfoEntityList
-		= ((HinemosEntityManager)em).createNamedQuery("MonitorInfoEntity.findByCalendarId", MonitorInfoEntity.class, ObjectPrivilegeMode.NONE)
+		= em.createNamedQuery("MonitorInfoEntity.findByCalendarId", MonitorInfoEntity.class, ObjectPrivilegeMode.NONE)
 		.setParameter("calendarId", calendarId).getResultList();
 		return monitorInfoEntityList;
 	}
@@ -207,7 +173,7 @@ public class QueryUtil {
 		return getMonitorTruthValueInfoPK(new MonitorTruthValueInfoEntityPK(monitorId, priority, truthValue));
 	}
 	public static int deleteCalculatedDataByCollectorid(String collectorid) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		return em.createNamedQuery("CalculatedDataEntity.deleteByCollectorid")
 				.setParameter("collectorid", collectorid)
 				.executeUpdate();
@@ -228,7 +194,7 @@ public class QueryUtil {
 			Integer collectorFlg,
 			String ownerRoleId) {
 
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 
 		StringBuffer sbJpql = new StringBuffer();
 		sbJpql.append("SELECT a FROM MonitorInfoEntity a WHERE true = true");
@@ -288,23 +254,23 @@ public class QueryUtil {
 
 		// monitorId
 		if(monitorId != null && !"".equals(monitorId)) {
-			typedQuery = typedQuery.setParameter("monitorId", "%" + monitorId + "%");
+			typedQuery = typedQuery.setParameter("monitorId", monitorId);
 		}
 		// monitorTypeId
 		if(monitorTypeId != null && !"".equals(monitorTypeId)) {
-			typedQuery = typedQuery.setParameter("monitorTypeId", "%" + monitorTypeId + "%");
+			typedQuery = typedQuery.setParameter("monitorTypeId", monitorTypeId);
 		}
 		// description
 		if(description != null && !"".equals(description)) {
-			typedQuery = typedQuery.setParameter("description", "%" + description + "%");
+			typedQuery = typedQuery.setParameter("description", description);
 		}
 		// calendarId
 		if(calendarId != null && !"".equals(calendarId)) {
-			typedQuery = typedQuery.setParameter("calendarId", "%" + calendarId + "%");
+			typedQuery = typedQuery.setParameter("calendarId", calendarId);
 		}
 		// regUser
 		if(regUser != null && !"".equals(regUser)) {
-			typedQuery = typedQuery.setParameter("regUser", "%" + regUser + "%");
+			typedQuery = typedQuery.setParameter("regUser", regUser);
 		}
 		// regFromDate
 		if (regFromDate > 0) {
@@ -316,7 +282,7 @@ public class QueryUtil {
 		}
 		// updateUser
 		if(updateUser != null && !"".equals(updateUser)) {
-			typedQuery = typedQuery.setParameter("updateUser", "%" + updateUser + "%");
+			typedQuery = typedQuery.setParameter("updateUser", updateUser);
 		}
 		// updateFromDate
 		if(updateFromDate > 0) {
