@@ -16,20 +16,14 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.monitor.session;
 
 import java.util.ArrayList;
+import java.util.List;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.fault.HinemosUnknown;
-import com.clustercontrol.fault.InvalidRole;
-import com.clustercontrol.fault.InvalidSetting;
-import com.clustercontrol.fault.MonitorDuplicate;
-import com.clustercontrol.fault.MonitorNotFound;
-import com.clustercontrol.fault.ObjectPrivilege_InvalidRole;
 import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.commons.bean.SettingUpdateInfo;
 import com.clustercontrol.commons.scheduler.TriggerSchedulerException;
 import com.clustercontrol.commons.util.HinemosSessionContext;
 import com.clustercontrol.commons.util.JpaTransactionManager;
@@ -37,23 +31,34 @@ import com.clustercontrol.custom.factory.AddCustom;
 import com.clustercontrol.custom.factory.DeleteCustom;
 import com.clustercontrol.custom.factory.ModifyCustom;
 import com.clustercontrol.custom.factory.SelectCustom;
-import com.clustercontrol.custom.util.CustomManagerUtil;
+import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.InvalidRole;
+import com.clustercontrol.fault.InvalidSetting;
+import com.clustercontrol.fault.MonitorDuplicate;
+import com.clustercontrol.fault.MonitorNotFound;
+import com.clustercontrol.fault.ObjectPrivilege_InvalidRole;
 import com.clustercontrol.hinemosagent.factory.AddMonitorAgent;
 import com.clustercontrol.hinemosagent.factory.DeleteMonitorAgent;
 import com.clustercontrol.hinemosagent.factory.ModifyMonitorAgent;
 import com.clustercontrol.hinemosagent.factory.SelectMonitorAgent;
 import com.clustercontrol.http.factory.AddMonitorHttp;
+import com.clustercontrol.http.factory.AddMonitorHttpScenario;
 import com.clustercontrol.http.factory.AddMonitorHttpString;
 import com.clustercontrol.http.factory.DeleteMonitorHttp;
+import com.clustercontrol.http.factory.DeleteMonitorHttpScenario;
 import com.clustercontrol.http.factory.ModifyMonitorHttp;
+import com.clustercontrol.http.factory.ModifyMonitorHttpScenario;
 import com.clustercontrol.http.factory.ModifyMonitorHttpString;
 import com.clustercontrol.http.factory.SelectMonitorHttp;
+import com.clustercontrol.http.factory.SelectMonitorHttpScenario;
+import com.clustercontrol.jmx.factory.AddMonitorJmx;
+import com.clustercontrol.jmx.factory.DeleteMonitorJmx;
+import com.clustercontrol.jmx.factory.ModifyMonitorJmx;
+import com.clustercontrol.jmx.factory.SelectMonitorJmx;
 import com.clustercontrol.logfile.factory.AddMonitorLogfileString;
 import com.clustercontrol.logfile.factory.DeleteMonitorLogfile;
 import com.clustercontrol.logfile.factory.ModifyMonitorLogfileString;
 import com.clustercontrol.logfile.factory.SelectMonitorLogfile;
-import com.clustercontrol.logfile.session.MonitorLogfileControllerBean;
-import com.clustercontrol.logfile.util.LogfileManagerUtil;
 import com.clustercontrol.monitor.bean.MonitorFilterInfo;
 import com.clustercontrol.monitor.plugin.factory.AddMonitorPluginNumeric;
 import com.clustercontrol.monitor.plugin.factory.AddMonitorPluginString;
@@ -69,6 +74,7 @@ import com.clustercontrol.monitor.run.factory.AddMonitor;
 import com.clustercontrol.monitor.run.factory.DeleteMonitor;
 import com.clustercontrol.monitor.run.factory.ModifyMonitor;
 import com.clustercontrol.monitor.run.factory.SelectMonitor;
+import com.clustercontrol.monitor.run.util.MonitorChangedNotificationCallback;
 import com.clustercontrol.monitor.run.util.MonitorValidator;
 import com.clustercontrol.monitor.run.util.QueryUtil;
 import com.clustercontrol.notify.util.NotifyRelationCache;
@@ -113,8 +119,6 @@ import com.clustercontrol.winevent.factory.AddMonitorWinEvent;
 import com.clustercontrol.winevent.factory.DeleteMonitorWinEvent;
 import com.clustercontrol.winevent.factory.ModifyMonitorWinEvent;
 import com.clustercontrol.winevent.factory.SelectMonitorWinEvent;
-import com.clustercontrol.winevent.session.MonitorWinEventControllerBean;
-import com.clustercontrol.winevent.util.WinEventManagerUtil;
 import com.clustercontrol.winservice.factory.AddMonitorWinService;
 import com.clustercontrol.winservice.factory.DeleteMonitorWinService;
 import com.clustercontrol.winservice.factory.ModifyMonitorWinService;
@@ -122,35 +126,16 @@ import com.clustercontrol.winservice.factory.SelectMonitorWinService;
 
 /**
  * 監視設定を制御するSesison Bean<BR>
- * 
+ *
  */
 public class MonitorSettingControllerBean {
 
 	// Logger
 	private static Log m_log = LogFactory.getLog( MonitorSettingControllerBean.class );
 
-	// トランザクション処理(JTAアクセス)を含むメソッド
-	private void broadcastConfigure(String monitorTypeId) {
-		m_log.info("broadcastConfigure " + monitorTypeId);
-		if (HinemosModuleConstant.MONITOR_SYSTEMLOG.equals(monitorTypeId)) {
-			SettingUpdateInfo.getInstance().setSystemLogMonitorUpdateTime(System.currentTimeMillis());
-		} else if (HinemosModuleConstant.MONITOR_SNMPTRAP.equals(monitorTypeId)) {
-			SettingUpdateInfo.getInstance().setSnmptrapMonitorUpdateTime(System.currentTimeMillis());
-		} else if (HinemosModuleConstant.MONITOR_LOGFILE.equals(monitorTypeId)) {
-			MonitorLogfileControllerBean.clearLogfileCache();
-			LogfileManagerUtil.broadcastConfigured();
-		} else if (HinemosModuleConstant.MONITOR_CUSTOM.equals(monitorTypeId)) {
-			SelectCustom.clearCustomCache();
-			CustomManagerUtil.broadcastConfigured();
-		} else if (HinemosModuleConstant.MONITOR_WINEVENT.equals(monitorTypeId)) {
-			MonitorWinEventControllerBean.clearWinEventCache();
-			WinEventManagerUtil.broadcastConfigured();
-		}
-	}
-
 	/**
 	 * 監視設定情報をマネージャに登録します。<BR>
-	 * 
+	 *
 	 * @param info
 	 * @return
 	 * @throws MonitorDuplicate
@@ -191,7 +176,9 @@ public class MonitorSettingControllerBean {
 				addMonitor = new AddMonitorAgent();
 			}
 			// HTTP 監視
-			else if(HinemosModuleConstant.MONITOR_HTTP.equals(monitorTypeId)){
+			else if (HinemosModuleConstant.MONITOR_HTTP_N.equals(monitorTypeId)
+					|| HinemosModuleConstant.MONITOR_HTTP_S.equals(monitorTypeId)
+					|| HinemosModuleConstant.MONITOR_HTTP_SCENARIO.equals(monitorTypeId)) {
 				// 数値監視
 				if(MonitorTypeConstant.TYPE_NUMERIC == monitorType){
 					addMonitor = new AddMonitorHttp();
@@ -200,6 +187,10 @@ public class MonitorSettingControllerBean {
 				else if(MonitorTypeConstant.TYPE_STRING == monitorType){
 					addMonitor = new AddMonitorHttpString();
 				}
+				// シナリオ
+				else if(MonitorTypeConstant.TYPE_SCENARIO == monitorType){
+					addMonitor = new AddMonitorHttpScenario();
+				}
 				// それ以外
 				else{
 					HinemosUnknown e = new HinemosUnknown("This monitorTypeId = " + monitorTypeId + ", but unknown monitorType = " + monitorType);
@@ -233,7 +224,8 @@ public class MonitorSettingControllerBean {
 				addMonitor = new AddMonitorTrap();
 			}
 			// SNMP監視
-			else if(HinemosModuleConstant.MONITOR_SNMP.equals(monitorTypeId)){
+			else if (HinemosModuleConstant.MONITOR_SNMP_N.equals(monitorTypeId)
+					|| HinemosModuleConstant.MONITOR_SNMP_S.equals(monitorTypeId)) {
 				// 数値監視
 				if(MonitorTypeConstant.TYPE_NUMERIC == monitorType){
 					addMonitor = new AddMonitorSnmp();
@@ -255,7 +247,8 @@ public class MonitorSettingControllerBean {
 				addMonitor = new AddMonitorSystemlogString();
 			}
 			// SQL監視
-			else if(HinemosModuleConstant.MONITOR_SQL.equals(monitorTypeId)){
+			else if (HinemosModuleConstant.MONITOR_SQL_N.equals(monitorTypeId)
+					|| HinemosModuleConstant.MONITOR_SQL_S.equals(monitorTypeId)) {
 				// 数値監視
 				if(MonitorTypeConstant.TYPE_NUMERIC == monitorType){
 					addMonitor = new AddMonitorSql();
@@ -284,9 +277,13 @@ public class MonitorSettingControllerBean {
 			else if(HinemosModuleConstant.MONITOR_WINEVENT.equals(monitorTypeId)){
 				addMonitor = new AddMonitorWinEvent();
 			}
+			// JMX 監視
+			else if(HinemosModuleConstant.MONITOR_JMX.equals(monitorTypeId)){
+				addMonitor = new AddMonitorJmx();
+			}
 			// Other(Pluginで追加する汎用的な監視)
 			else{
-				
+
 				// 数値
 				if(MonitorTypeConstant.TYPE_NUMERIC == monitorType){
 					addMonitor = new AddMonitorPluginNumeric();
@@ -299,7 +296,7 @@ public class MonitorSettingControllerBean {
 				else if(MonitorTypeConstant.TYPE_TRUTH == monitorType){
 					addMonitor = new AddMonitorPluginTruth();
 				}
-				
+
 				if(addMonitor == null){
 					HinemosUnknown e = new HinemosUnknown("Unknown monitorTypeId = " + monitorTypeId + ", monitorType = " + monitorType);
 					m_log.info("addMonitor() : "
@@ -309,24 +306,21 @@ public class MonitorSettingControllerBean {
 			}
 
 			try {
-				// トランザクションがすでに開始されている場合は処理終了
-				jtm.begin(true);
+				jtm.begin();
 
 				flag = addMonitor.add(info, loginUser);
 
+				jtm.addCallback(new MonitorChangedNotificationCallback(monitorTypeId));
 				jtm.commit();
-				if (flag) {
-					jtm.begin(true);
-					broadcastConfigure(monitorTypeId);
-					jtm.commit();
-				}
 			} catch (MonitorDuplicate e) {
 				jtm.rollback();
 				throw e;
 			} catch (MonitorNotFound e) {
+				m_log.info("addMonitor " + e.getClass().getName() + ", " + e.getMessage());
 				jtm.rollback();
 				throw new HinemosUnknown(e.getMessage(), e);
 			} catch (TriggerSchedulerException e) {
+				m_log.info("addMonitor " + e.getClass().getName() + ", " + e.getMessage());
 				jtm.rollback();
 				throw new HinemosUnknown(e.getMessage(), e);
 			} catch (HinemosUnknown e) {
@@ -350,7 +344,7 @@ public class MonitorSettingControllerBean {
 						NotifyRelationCache.refresh();
 
 						if (HinemosModuleConstant.MONITOR_SYSTEMLOG.equals(monitorTypeId)) {
-							SystemlogCache.clear();
+							SystemlogCache.refresh();
 						}
 					} catch (Exception e) {
 						m_log.warn("addMonitor() transaction failure. : "
@@ -368,7 +362,7 @@ public class MonitorSettingControllerBean {
 
 	/**
 	 * 監視設定情報を更新します。<BR>
-	 * 
+	 *
 	 * @param info
 	 * @return
 	 * @throws MonitorNotFound
@@ -410,7 +404,9 @@ public class MonitorSettingControllerBean {
 				modMonitor = new ModifyMonitorAgent();
 			}
 			// HTTP 監視
-			else if(HinemosModuleConstant.MONITOR_HTTP.equals(monitorTypeId)){
+			else if (HinemosModuleConstant.MONITOR_HTTP_N.equals(monitorTypeId)
+					|| HinemosModuleConstant.MONITOR_HTTP_S.equals(monitorTypeId)
+					|| HinemosModuleConstant.MONITOR_HTTP_SCENARIO.equals(monitorTypeId)) {
 				// 数値監視
 				if(MonitorTypeConstant.TYPE_NUMERIC == monitorType){
 					modMonitor = new ModifyMonitorHttp();
@@ -419,6 +415,10 @@ public class MonitorSettingControllerBean {
 				else if(MonitorTypeConstant.TYPE_STRING == monitorType){
 					modMonitor = new ModifyMonitorHttpString();
 				}
+				// シナリオ
+				else if(MonitorTypeConstant.TYPE_SCENARIO == monitorType){
+					modMonitor = new ModifyMonitorHttpScenario();
+				}
 				// それ以外
 				else{
 					HinemosUnknown e = new HinemosUnknown("This monitorTypeId = " + monitorTypeId + ", but unknown monitorType = " + monitorType);
@@ -452,7 +452,8 @@ public class MonitorSettingControllerBean {
 				modMonitor = new ModifyMonitorTrap();
 			}
 			// SNMP監視
-			else if(HinemosModuleConstant.MONITOR_SNMP.equals(monitorTypeId)){
+			else if (HinemosModuleConstant.MONITOR_SNMP_N.equals(monitorTypeId)
+					|| HinemosModuleConstant.MONITOR_SNMP_S.equals(monitorTypeId)) {
 				// 数値監視
 				if(MonitorTypeConstant.TYPE_NUMERIC == monitorType){
 					modMonitor = new ModifyMonitorSnmp();
@@ -474,7 +475,8 @@ public class MonitorSettingControllerBean {
 				modMonitor = new ModifyMonitorSystemlogString();
 			}
 			// SQL監視
-			else if(HinemosModuleConstant.MONITOR_SQL.equals(monitorTypeId)){
+			else if (HinemosModuleConstant.MONITOR_SQL_N.equals(monitorTypeId)
+					|| HinemosModuleConstant.MONITOR_SQL_S.equals(monitorTypeId)) {
 				// 数値監視
 				if(MonitorTypeConstant.TYPE_NUMERIC == monitorType){
 					modMonitor = new ModifyMonitorSql();
@@ -503,6 +505,10 @@ public class MonitorSettingControllerBean {
 			else if(HinemosModuleConstant.MONITOR_WINEVENT.equals(monitorTypeId)){
 				modMonitor = new ModifyMonitorWinEvent();
 			}
+			// JMX 監視
+			else if(HinemosModuleConstant.MONITOR_JMX.equals(monitorTypeId)){
+				modMonitor = new ModifyMonitorJmx();
+			}
 			// Other
 			else{
 
@@ -518,7 +524,7 @@ public class MonitorSettingControllerBean {
 				else if(MonitorTypeConstant.TYPE_TRUTH == monitorType){
 					modMonitor = new ModifyMonitorPluginTruth();
 				}
-				
+
 				if(modMonitor == null){
 					HinemosUnknown e = new HinemosUnknown("Unknown monitorTypeId = " + monitorTypeId + ", monitorType = " + monitorType);
 					m_log.info("modifyMonitor() : "
@@ -529,21 +535,17 @@ public class MonitorSettingControllerBean {
 
 			// 監視設定情報を更新
 			try {
-				// トランザクションがすでに開始されている場合は処理終了
-				jtm.begin(true);
+				jtm.begin();
 
 				flag = modMonitor.modify(info, loginUser);
 
+				jtm.addCallback(new MonitorChangedNotificationCallback(monitorTypeId));
 				jtm.commit();
-				if (flag) {
-					jtm.begin(true);
-					broadcastConfigure(monitorTypeId);
-					jtm.commit();
-				}
 			} catch (MonitorNotFound e) {
 				jtm.rollback();
 				throw e;
 			} catch (TriggerSchedulerException e) {
+				m_log.info("modifyMonitor " + e.getClass().getName() + ", " + e.getMessage());
 				jtm.rollback();
 				throw new HinemosUnknown(e.getMessage(), e);
 			} catch (HinemosUnknown e) {
@@ -567,7 +569,7 @@ public class MonitorSettingControllerBean {
 						NotifyRelationCache.refresh();
 
 						if (HinemosModuleConstant.MONITOR_SYSTEMLOG.equals(monitorTypeId)) {
-							SystemlogCache.clear();
+							SystemlogCache.refresh();
 						}
 					} catch (Exception e) {
 						m_log.warn("modifyMonitor() transaction failure. : "
@@ -584,23 +586,23 @@ public class MonitorSettingControllerBean {
 
 
 	/**
-	 * 
+	 *
 	 * 監視設定情報をマネージャから削除します。<BR>
-	 * 
-	 * @param monitorId
+	 *
+	 * @param monitorIdList
 	 * @param monitorTypeId
 	 * @return
 	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
 	 */
-	public boolean deleteMonitor(String monitorId, String monitorTypeId) throws MonitorNotFound, HinemosUnknown, InvalidRole {
-		m_log.debug("deleteMonitor() monitorId = " + monitorId + ", monitorTypeId = " + monitorTypeId);
+	public boolean deleteMonitor(List<String> monitorIdList, String monitorTypeId) throws MonitorNotFound, HinemosUnknown, InvalidRole {
+		m_log.debug("deleteMonitor() monitorId = " + monitorIdList + ", monitorTypeId = " + monitorTypeId);
 
 		JpaTransactionManager jtm = null;
 
 		// null チェック
-		if(monitorId == null || "".equals(monitorId)){
-			HinemosUnknown e = new HinemosUnknown("monitorId is null or empty.");
+		if(monitorIdList == null || monitorIdList.isEmpty()){
+			HinemosUnknown e = new HinemosUnknown("monitorIdList is null or empty.");
 			m_log.info("deleteMonitor() : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			throw e;
@@ -618,9 +620,14 @@ public class MonitorSettingControllerBean {
 			deleteMonitor = new DeleteMonitorAgent();
 		}
 		// HTTP 監視
-		else if(HinemosModuleConstant.MONITOR_HTTP.equals(monitorTypeId)){
+		else if (HinemosModuleConstant.MONITOR_HTTP_N.equals(monitorTypeId)
+				|| HinemosModuleConstant.MONITOR_HTTP_S.equals(monitorTypeId)) {
 			deleteMonitor = new DeleteMonitorHttp();
 		}
+		// HTTP シナリオ監視
+		else if (HinemosModuleConstant.MONITOR_HTTP_SCENARIO.equals(monitorTypeId)) {
+			deleteMonitor = new DeleteMonitorHttpScenario();
+		}
 		// ログファイル 監視
 		else if(HinemosModuleConstant.MONITOR_LOGFILE.equals(monitorTypeId)){
 			deleteMonitor =  new DeleteMonitorLogfile();
@@ -646,7 +653,8 @@ public class MonitorSettingControllerBean {
 			deleteMonitor = new DeleteMonitorTrap();
 		}
 		// SNMP監視
-		else if(HinemosModuleConstant.MONITOR_SNMP.equals(monitorTypeId)){
+		else if (HinemosModuleConstant.MONITOR_SNMP_N.equals(monitorTypeId)
+				|| HinemosModuleConstant.MONITOR_SNMP_S.equals(monitorTypeId)) {
 			deleteMonitor = new DeleteMonitorSnmp();
 		}
 		// システムログ監視
@@ -654,7 +662,8 @@ public class MonitorSettingControllerBean {
 			deleteMonitor = new DeleteMonitorSystemlog();
 		}
 		// SQL監視
-		else if(HinemosModuleConstant.MONITOR_SQL.equals(monitorTypeId)){
+		else if (HinemosModuleConstant.MONITOR_SQL_N.equals(monitorTypeId)
+				|| HinemosModuleConstant.MONITOR_SQL_S.equals(monitorTypeId)) {
 			deleteMonitor = new DeleteMonitorSql();
 		}
 		// コマンド監視
@@ -669,6 +678,10 @@ public class MonitorSettingControllerBean {
 		else if(HinemosModuleConstant.MONITOR_WINEVENT.equals(monitorTypeId)){
 			deleteMonitor = new DeleteMonitorWinEvent();
 		}
+		// JMX 監視
+		else if(HinemosModuleConstant.MONITOR_JMX.equals(monitorTypeId)){
+			deleteMonitor = new DeleteMonitorJmx();
+		}
 		// Other
 		else{
 			deleteMonitor = new DeleteMonitorPlugin();
@@ -677,18 +690,15 @@ public class MonitorSettingControllerBean {
 		// 監視設定情報を削除
 		boolean flag = false;
 		try {
-			// トランザクションがすでに開始されている場合は処理終了
 			jtm = new JpaTransactionManager();
-			jtm.begin(true);
+			jtm.begin();
 
-			flag = deleteMonitor.delete(monitorTypeId, monitorId);
-			jtm.commit();
-			
-			if (flag) {
-				jtm.begin(true);
-				broadcastConfigure(monitorTypeId);
-				jtm.commit();
+			for (String monitorId : monitorIdList) {
+				flag = deleteMonitor.delete(monitorTypeId, monitorId);
 			}
+
+			jtm.addCallback(new MonitorChangedNotificationCallback(monitorTypeId));
+			jtm.commit();
 		} catch (MonitorNotFound e) {
 			jtm.rollback();
 			throw e;
@@ -696,6 +706,7 @@ public class MonitorSettingControllerBean {
 			jtm.rollback();
 			throw e;
 		} catch (TriggerSchedulerException e) {
+			m_log.info("deleteMonitor " + e.getClass().getName() + ", " + e.getMessage());
 			jtm.rollback();
 			throw new HinemosUnknown(e.getMessage(), e);
 		} catch (InvalidRole e) {
@@ -716,7 +727,7 @@ public class MonitorSettingControllerBean {
 					NotifyRelationCache.refresh();
 
 					if (HinemosModuleConstant.MONITOR_SYSTEMLOG.equals(monitorTypeId)) {
-						SystemlogCache.clear();
+						SystemlogCache.refresh();
 					}
 				} catch (Exception e) {
 					m_log.warn("deleteMonitor() transaction failure. : "
@@ -734,7 +745,7 @@ public class MonitorSettingControllerBean {
 
 	/**
 	 * 監視情報を取得します。<BR>
-	 * 
+	 *
 	 * @param monitorId
 	 * @param monitorTypeId
 	 * @return
@@ -766,9 +777,14 @@ public class MonitorSettingControllerBean {
 			selectMonitor = new SelectMonitorAgent();
 		}
 		// HTTP 監視
-		else if(HinemosModuleConstant.MONITOR_HTTP.equals(monitorTypeId)){
+		else if (HinemosModuleConstant.MONITOR_HTTP_N.equals(monitorTypeId)
+				|| HinemosModuleConstant.MONITOR_HTTP_S.equals(monitorTypeId)) {
 			selectMonitor = new SelectMonitorHttp();
 		}
+		// HTTP 監視
+		else if (HinemosModuleConstant.MONITOR_HTTP_SCENARIO.equals(monitorTypeId)) {
+			selectMonitor = new SelectMonitorHttpScenario();
+		}
 		// ログファイル 監視
 		else if(HinemosModuleConstant.MONITOR_LOGFILE.equals(monitorTypeId)){
 			selectMonitor =  new SelectMonitorLogfile();
@@ -794,7 +810,8 @@ public class MonitorSettingControllerBean {
 			selectMonitor = new SelectMonitorTrap();
 		}
 		// SNMP監視
-		else if(HinemosModuleConstant.MONITOR_SNMP.equals(monitorTypeId)){
+		else if (HinemosModuleConstant.MONITOR_SNMP_N.equals(monitorTypeId)
+				|| HinemosModuleConstant.MONITOR_SNMP_S.equals(monitorTypeId)) {
 			selectMonitor = new SelectMonitorSnmp();
 		}
 		// システムログ監視
@@ -802,7 +819,8 @@ public class MonitorSettingControllerBean {
 			selectMonitor = new SelectMonitorSystemlog();
 		}
 		// SQL監視
-		else if(HinemosModuleConstant.MONITOR_SQL.equals(monitorTypeId)){
+		else if (HinemosModuleConstant.MONITOR_SQL_N.equals(monitorTypeId)
+				|| HinemosModuleConstant.MONITOR_SQL_S.equals(monitorTypeId)) {
 			selectMonitor = new SelectMonitorSql();
 		}
 		// コマンド監視
@@ -817,6 +835,10 @@ public class MonitorSettingControllerBean {
 		else if(HinemosModuleConstant.MONITOR_WINEVENT.equals(monitorTypeId)){
 			selectMonitor = new SelectMonitorWinEvent();
 		}
+		// JMXイベント監視
+		else if(HinemosModuleConstant.MONITOR_JMX.equals(monitorTypeId)){
+			selectMonitor = new SelectMonitorJmx();
+		}
 		// Other
 		else{
 			selectMonitor = new SelectMonitorPlugin();
@@ -851,7 +873,7 @@ public class MonitorSettingControllerBean {
 
 	/**
 	 * 監視設定一覧を取得する
-	 * 
+	 *
 	 * @return
 	 * @throws HinemosUnknown
 	 */
@@ -889,7 +911,7 @@ public class MonitorSettingControllerBean {
 
 	/**
 	 * Hinemos Agent監視一覧リストを返します。
-	 * 
+	 *
 	 * @return Objectの2次元配列
 	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
@@ -936,7 +958,7 @@ public class MonitorSettingControllerBean {
 
 	/**
 	 * HTTP監視一覧リストを取得します。<BR>
-	 * 
+	 *
 	 * @return Objectの2次元配列
 	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
@@ -946,12 +968,15 @@ public class MonitorSettingControllerBean {
 		JpaTransactionManager jtm = null;
 
 		// HTTP監視一覧を取得
-		SelectMonitorHttp http = new SelectMonitorHttp();
-		ArrayList<MonitorInfo> list = null;
+		ArrayList<MonitorInfo> list = new ArrayList<MonitorInfo>();
 		try {
 			jtm = new JpaTransactionManager();
 			jtm.begin();
-			list = http.getMonitorList(HinemosModuleConstant.MONITOR_HTTP);
+			SelectMonitorHttp http = new SelectMonitorHttp();
+			list.addAll(http.getMonitorList(HinemosModuleConstant.MONITOR_HTTP_N));
+			list.addAll(http.getMonitorList(HinemosModuleConstant.MONITOR_HTTP_S));
+			SelectMonitorHttpScenario scenario = new SelectMonitorHttpScenario();
+			list.addAll(scenario.getMonitorList(HinemosModuleConstant.MONITOR_HTTP_SCENARIO));
 			jtm.commit();
 		} catch (MonitorNotFound e) {
 			jtm.rollback();
@@ -974,16 +999,54 @@ public class MonitorSettingControllerBean {
 			jtm.close();
 		}
 
-		// null check
-		if(list == null){
-			list = new ArrayList<MonitorInfo>();
+		return list;
+	}
+	/**
+	 * JMX監視一覧リストを取得します。<BR>
+	 *
+	 * @return Objectの2次元配列
+	 * @throws MonitorNotFound
+	 * @throws HinemosUnknown
+	 */
+	public ArrayList<MonitorInfo> getJmxList() throws MonitorNotFound, InvalidRole, HinemosUnknown {
+
+		JpaTransactionManager jtm = null;
+
+		// HTTP監視一覧を取得
+		SelectMonitorJmx jmx = new SelectMonitorJmx();
+		ArrayList<MonitorInfo> list = new ArrayList<MonitorInfo>();
+		try {
+			jtm = new JpaTransactionManager();
+			jtm.begin();
+			list.addAll(jmx.getMonitorList(HinemosModuleConstant.MONITOR_JMX));
+			jtm.commit();
+		} catch (MonitorNotFound e) {
+			jtm.rollback();
+			throw e;
+		} catch (HinemosUnknown e) {
+			jtm.rollback();
+			throw e;
+		} catch (InvalidRole e) {
+			jtm.rollback();
+			throw e;
+		} catch (ObjectPrivilege_InvalidRole e) {
+			jtm.rollback();
+			throw new InvalidRole(e.getMessage(), e);
+		} catch (Exception e) {
+			m_log.warn("getJmxList() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+			jtm.rollback();
+			throw new HinemosUnknown(e.getMessage(),e);
+		} finally {
+			jtm.close();
 		}
+
 		return list;
 	}
 
 	/**
 	 * ログファイル監視一覧リストを返します。
-	 * 
+	 *
 	 * @return Objectの2次元配列
 	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
@@ -1029,7 +1092,7 @@ public class MonitorSettingControllerBean {
 
 	/**
 	 * リソース監視一覧リストを返します。
-	 * 
+	 *
 	 * @return Objectの2次元配列
 	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
@@ -1076,7 +1139,7 @@ public class MonitorSettingControllerBean {
 
 	/**
 	 * ping監視一覧リストを取得します。<BR>
-	 * 
+	 *
 	 * @return Objectの2次元配列
 	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
@@ -1123,7 +1186,7 @@ public class MonitorSettingControllerBean {
 
 	/**
 	 * port監視一覧リストを返します。
-	 * 
+	 *
 	 * @return Objectの2次元配列
 	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
@@ -1170,7 +1233,7 @@ public class MonitorSettingControllerBean {
 
 	/**
 	 * プロセス監視一覧リストを取得します。<BR>
-	 * 
+	 *
 	 * @return Objectの2次元配列
 	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
@@ -1217,7 +1280,7 @@ public class MonitorSettingControllerBean {
 
 	/**
 	 * SNMPTRAP監視一覧リストを取得します。<BR>
-	 * 
+	 *
 	 * @return rrayList<MonitorInfo>
 	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
@@ -1266,7 +1329,7 @@ public class MonitorSettingControllerBean {
 
 	/**
 	 * SNMP監視一覧リストを取得します。<BR>
-	 * 
+	 *
 	 * @return Objectの2次元配列
 	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
@@ -1277,11 +1340,12 @@ public class MonitorSettingControllerBean {
 
 		// SNMP監視一覧を取得
 		SelectMonitorSnmp snmp = new SelectMonitorSnmp();
-		ArrayList<MonitorInfo> list = null;
+		ArrayList<MonitorInfo> list = new ArrayList<MonitorInfo>();
 		try {
 			jtm = new JpaTransactionManager();
 			jtm.begin();
-			list = snmp.getMonitorList(HinemosModuleConstant.MONITOR_SNMP);
+			list.addAll(snmp.getMonitorList(HinemosModuleConstant.MONITOR_SNMP_N));
+			list.addAll(snmp.getMonitorList(HinemosModuleConstant.MONITOR_SNMP_S));
 			jtm.commit();
 		} catch (MonitorNotFound e) {
 			jtm.rollback();
@@ -1304,16 +1368,12 @@ public class MonitorSettingControllerBean {
 			jtm.close();
 		}
 
-		// null check
-		if(list == null){
-			list = new ArrayList<MonitorInfo>();
-		}
 		return list;
 	}
 
 	/**
 	 * SQL監視一覧リストを取得します。
-	 * 
+	 *
 	 * @return Objectの2次元配列
 	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
@@ -1324,11 +1384,12 @@ public class MonitorSettingControllerBean {
 
 		// SQL監視一覧を取得
 		SelectMonitorSql sql = new SelectMonitorSql();
-		ArrayList<MonitorInfo> list = null;
+		ArrayList<MonitorInfo> list = new ArrayList<MonitorInfo>();
 		try {
 			jtm = new JpaTransactionManager();
 			jtm.begin();
-			list = sql.getMonitorList(HinemosModuleConstant.MONITOR_SQL);
+			list.addAll(sql.getMonitorList(HinemosModuleConstant.MONITOR_SQL_N));
+			list.addAll(sql.getMonitorList(HinemosModuleConstant.MONITOR_SQL_S));
 			jtm.commit();
 		} catch (MonitorNotFound e) {
 			jtm.rollback();
@@ -1351,16 +1412,12 @@ public class MonitorSettingControllerBean {
 			jtm.close();
 		}
 
-		// null check
-		if(list == null){
-			list = new ArrayList<MonitorInfo>();
-		}
 		return list;
 	}
 
 	/**
 	 * システムログ監視一覧リストを返します。
-	 * 
+	 *
 	 * @return Objectの2次元配列
 	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
@@ -1407,7 +1464,7 @@ public class MonitorSettingControllerBean {
 
 	/**
 	 * システムログ監視一覧リストを返します。
-	 * 
+	 *
 	 * @return Objectの2次元配列
 	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
@@ -1419,7 +1476,7 @@ public class MonitorSettingControllerBean {
 		} catch (MonitorNotFound e) {
 			throw e;
 		} catch (Exception e) {
-			m_log.error("getSystemlogList " + e.getMessage(), e);
+			m_log.warn("getSystemlogList " + e.getMessage(), e);
 			throw new HinemosUnknown(e.getMessage(), e);
 		}
 		// null check
@@ -1477,7 +1534,7 @@ public class MonitorSettingControllerBean {
 
 	/**
 	 * Windowsサービス監視一覧リストを取得します。<BR>
-	 * 
+	 *
 	 * @return MonitorInfoのリスト
 	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
@@ -1524,7 +1581,7 @@ public class MonitorSettingControllerBean {
 
 	/**
 	 * Windowsイベント監視一覧リストを取得します。<BR>
-	 * 
+	 *
 	 * @return MonitorInfoのリスト
 	 * @throws MonitorNotFound
 	 * @throws HinemosUnknown
@@ -1568,11 +1625,11 @@ public class MonitorSettingControllerBean {
 		}
 		return list;
 	}
-	
+
 	/**
-	 * 
+	 *
 	 * 監視設定の監視を有効化/無効化します。<BR>
-	 * 
+	 *
 	 * @param monitorId
 	 * @param monitorTypeId
 	 * @throws HinemosUnknown
@@ -1596,8 +1653,8 @@ public class MonitorSettingControllerBean {
 		MonitorInfo info = getMonitor(monitorId, monitorTypeId);
 		try{
 			// オブジェクト権限チェック
-			QueryUtil.getMonitorInfoPK(monitorId, ObjectPrivilegeMode.WRITE);
-			
+			QueryUtil.getMonitorInfoPK(monitorId, ObjectPrivilegeMode.MODIFY);
+
 			if (validFlag) {
 				if(info.getMonitorFlg() != ValidConstant.TYPE_VALID){
 					info.setMonitorFlg(ValidConstant.TYPE_VALID);
@@ -1623,9 +1680,9 @@ public class MonitorSettingControllerBean {
 	}
 
 	/**
-	 * 
+	 *
 	 * 監視設定の収集を有効化/無効化します。<BR>
-	 * 
+	 *
 	 * @param monitorId
 	 * @param monitorTypeId
 	 * @throws HinemosUnknown
@@ -1649,11 +1706,12 @@ public class MonitorSettingControllerBean {
 		MonitorInfo info = getMonitor(monitorId, monitorTypeId);
 		try{
 			// オブジェクト権限チェック
-			QueryUtil.getMonitorInfoPK(monitorId, ObjectPrivilegeMode.WRITE);
-			
+			QueryUtil.getMonitorInfoPK(monitorId, ObjectPrivilegeMode.MODIFY);
+
 			if (validFlag) {
-				if(info.getMonitorType() != MonitorTypeConstant.TYPE_NUMERIC){
-					m_log.debug("setStatusMonitor() : monitorId = " + monitorId + " is not numeric.");
+				if(info.getMonitorType() != MonitorTypeConstant.TYPE_NUMERIC &&
+						info.getMonitorType() != MonitorTypeConstant.TYPE_SCENARIO){
+					m_log.debug("setStatusMonitor() : monitorId = " + monitorId + " is not numeric and scenario.");
 					return;
 				}
 
@@ -1682,36 +1740,7 @@ public class MonitorSettingControllerBean {
 
 	/**
 	 * 監視設定一覧の取得
-	 * 
-	 * @return 監視設定一覧
-	 * @throws HinemosUnknown
-	 * @throws MonitorNotFound
-	 */
-	/*
-	public ArrayList<MonitorInfo> getMonitorList() throws MonitorNotFound, HinemosUnknown{
-		m_log.debug("getMonitorList() : start");
-
-		ArrayList<MonitorInfo> list = null;
-		try {
-
-			list = new SelectMonitor().getMonitorList();
-
-		} catch(MonitorNotFound e){
-			m_log.error("getMonitorList() " + e.getMessage(),e);
-			throw e;
-		} catch (Exception e) {
-			m_log.error("getMonitorList() " + e.getMessage(),e);
-			throw new HinemosUnknown(e.getMessage(),e);
-		}
-
-		m_log.debug("getMonitorList() : end");
-		return list;
-	}
-	 */
-
-	/**
-	 * 監視設定一覧の取得
-	 * 
+	 *
 	 * @param condition フィルタ条件
 	 * @return 監視設定一覧
 	 * @throws HinemosUnknown
@@ -1731,6 +1760,7 @@ public class MonitorSettingControllerBean {
 			jtm.rollback();
 			throw e;
 		} catch (MonitorNotFound e) {
+			m_log.info("getMonitorList " + e.getClass().getName() + ", " + e.getMessage());
 			jtm.rollback();
 			throw new HinemosUnknown(e.getMessage(),e);
 		} catch (InvalidRole e) {
