@@ -17,9 +17,6 @@ package com.clustercontrol.monitor.util;
 import java.sql.Date;
 import java.util.Locale;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.Property;
@@ -30,8 +27,6 @@ import com.clustercontrol.util.Messages;
 import com.clustercontrol.ws.monitor.EventDataInfo;
 
 public class EventDataPropertyUtil {
-	/** ログ出力のインスタンス */
-	private static Log m_log = LogFactory.getLog( EventDataPropertyUtil.class );
 
 	/**
 	 * イベント情報DTOをプロパティに変換するメソッドです。<BR>
@@ -112,7 +107,7 @@ public class EventDataPropertyUtil {
 				new Property(EventInfoConstant.MESSAGE_ID, Messages.getString("message.id", locale), PropertyDefineConstant.EDITOR_TEXT);
 		//メッセージ
 		Property m_message =
-				new Property(EventInfoConstant.MESSAGE, Messages.getString("message", locale), PropertyDefineConstant.EDITOR_TEXT);
+				new Property(EventInfoConstant.MESSAGE, Messages.getString("message", locale), PropertyDefineConstant.EDITOR_TEXTAREA, DataRangeConstant.TEXT);
 		//オリジナルメッセージ
 		Property m_messageOrg =
 				new Property(EventInfoConstant.MESSAGE_ORG, Messages.getString("message.org", locale), PropertyDefineConstant.EDITOR_TEXTAREA, DataRangeConstant.TEXT);
