@@ -45,25 +45,46 @@ public class StatusFilterPropertyUtil {
 		StatusFilterInfo info = new StatusFilterInfo();
 
 
-		Integer priority = null;
 		Timestamp outputFromDate = null;
 		Timestamp outputToDate = null;
 		Timestamp generationFromDate = null;
 		Timestamp generationToDate = null;
+		String monitorId = null;
+		String monitorDetailId = null;
 		String facilityType = null;
 		String application = null;
 		String message = null;;
 		String ownerRoleId = null;
 
-		ArrayList values = null;
+		ArrayList<?> values = null;
 
 		//重要度取得
-		values = PropertyUtil.getPropertyValue(property, StatusFilterConstant.PRIORITY);
-		if(!"".equals(values.get(0))){
-			int priorityType = PriorityConstant.stringToType((String)values.get(0));
-			if(priorityType != -1){
-				priority = new Integer(priorityType);
-				info.setPriority(priority);
+		values = PropertyUtil.getPropertyValue(property,
+				StatusFilterConstant.PRIORITY_CRITICAL);
+		if (!"".equals(values.get(0))) {
+			if ((Boolean)values.get(0)) {
+				info.getPriorityList().add(PriorityConstant.TYPE_CRITICAL);
+			}
+		}
+		values = PropertyUtil.getPropertyValue(property,
+				StatusFilterConstant.PRIORITY_WARNING);
+		if (!"".equals(values.get(0))) {
+			if ((Boolean)values.get(0)) {
+				info.getPriorityList().add(PriorityConstant.TYPE_WARNING);
+			}
+		}
+		values = PropertyUtil.getPropertyValue(property,
+				StatusFilterConstant.PRIORITY_INFO);
+		if (!"".equals(values.get(0))) {
+			if ((Boolean)values.get(0)) {
+				info.getPriorityList().add(PriorityConstant.TYPE_INFO);
+			}
+		}
+		values = PropertyUtil.getPropertyValue(property,
+				StatusFilterConstant.PRIORITY_UNKNOWN);
+		if (!"".equals(values.get(0))) {
+			if ((Boolean)values.get(0)) {
+				info.getPriorityList().add(PriorityConstant.TYPE_UNKNOWN);
 			}
 		}
 
@@ -99,6 +120,22 @@ public class StatusFilterPropertyUtil {
 			info.setGenerationDateTo(generationToDate.getTime());
 		}
 
+		//監視項目ID取得
+		values = PropertyUtil.getPropertyValue(property,
+				StatusFilterConstant.MONITOR_ID);
+		if (!"".equals(values.get(0))) {
+			monitorId = (String) values.get(0);
+			info.setMonitorId(monitorId);
+		}
+
+		//監視詳細取得
+		values = PropertyUtil.getPropertyValue(property,
+				StatusFilterConstant.MONITOR_DETAIL_ID);
+		if (!"".equals(values.get(0))) {
+			monitorDetailId = (String) values.get(0);
+			info.setMonitorDetailId(monitorDetailId);
+		}
+
 		//対象ファシリティ種別取得
 		values = PropertyUtil.getPropertyValue(property, StatusFilterConstant.FACILITY_TYPE);
 		if(!"".equals(values.get(0))){
@@ -119,7 +156,7 @@ public class StatusFilterPropertyUtil {
 			message = (String)values.get(0);
 			info.setMessage(message);
 		}
-		
+
 		//オーナーロールID取得
 		values = PropertyUtil.getPropertyValue(property, StatusFilterConstant.OWNER_ROLE_ID);
 		if(!"".equals(values.get(0))){
@@ -144,7 +181,13 @@ public class StatusFilterPropertyUtil {
 	 * <ul>
 	 *  <li>プロパティ（親。ダミー）</li>
 	 *  <ul>
-	 *   <li>重要度（子。コンボボックス）</li>
+	 *   <li>重要度（子。テキスト）</li>
+	 *   <ul>
+	 *    <li>危険（孫。チェックボックス）</li>
+	 *    <li>警告（孫。チェックボックス）</li>
+	 *    <li>情報（孫。チェックボックス）</li>
+	 *    <li>不明（孫。チェックボックス）</li>
+	 *   </ul>
 	 *   <li>最終変更日時（子。テキスト）</li>
 	 *   <ul>
 	 *    <li>開始（孫。日時ダイアログ）</li>
@@ -155,6 +198,8 @@ public class StatusFilterPropertyUtil {
 	 *    <li>開始（孫。日時ダイアログ）</li>
 	 *    <li>終了（孫。日時ダイアログ）</li>
 	 *   </ul>
+	 *   <li>監視項目ID（子。テキスト）</li>
+	 *   <li>監視詳細（子。テキスト）</li>
 	 *   <li>ファシリティのターゲット（子。コンボボックス）</li>
 	 *   <li>アプリケーション（子。テキスト）</li>
 	 *   <li>メッセージ（子。テキスト）</li>
@@ -172,7 +217,19 @@ public class StatusFilterPropertyUtil {
 
 		//重要度
 		Property m_priority =
-				new Property(StatusFilterConstant.PRIORITY, Messages.getString("priority", locale), PropertyDefineConstant.EDITOR_SELECT);
+				new Property(StatusFilterConstant.PRIORITY, Messages.getString("priority", locale), PropertyDefineConstant.EDITOR_TEXT);
+		//重要度（危険）
+		Property m_priorityCritical =
+				new Property(StatusFilterConstant.PRIORITY_CRITICAL, Messages.getString("critical", locale), PropertyDefineConstant.EDITOR_BOOL);
+		//重要度(警告)
+		Property m_priorityWarning =
+				new Property(StatusFilterConstant.PRIORITY_WARNING, Messages.getString("warning", locale), PropertyDefineConstant.EDITOR_BOOL);
+		//重要度(情報)
+		Property m_priorityInfo =
+				new Property(StatusFilterConstant.PRIORITY_INFO, Messages.getString("info", locale), PropertyDefineConstant.EDITOR_BOOL);
+		//重要度(不明)
+		Property m_priorityUnknown =
+				new Property(StatusFilterConstant.PRIORITY_UNKNOWN, Messages.getString("unknown", locale), PropertyDefineConstant.EDITOR_BOOL);
 		//更新日時（自）
 		Property m_outputFromDate =
 				new Property(StatusFilterConstant.OUTPUT_FROM_DATE, Messages.getString("start", locale), PropertyDefineConstant.EDITOR_DATETIME);
@@ -185,6 +242,12 @@ public class StatusFilterPropertyUtil {
 		//出力日時（至）
 		Property m_generationToDate =
 				new Property(StatusFilterConstant.GENERATION_TO_DATE, Messages.getString("end", locale), PropertyDefineConstant.EDITOR_DATETIME);
+		//監視項目ID
+		Property m_monitorId =
+				new Property(StatusFilterConstant.MONITOR_ID, Messages.getString("monitor.id", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
+		//監視項目詳細
+		Property m_monitorDetailId =
+				new Property(StatusFilterConstant.MONITOR_DETAIL_ID, Messages.getString("monitor.detail.id", locale), PropertyDefineConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_1024);
 		//対象ファシリティ種別
 		Property m_facilityType =
 				new Property(StatusFilterConstant.FACILITY_TYPE, Messages.getString("facility.target", locale), PropertyDefineConstant.EDITOR_SELECT);
@@ -206,18 +269,20 @@ public class StatusFilterPropertyUtil {
 
 		//値を初期化
 
-		Object priorityValues[][] = {
-				{ "", PriorityConstant.STRING_CRITICAL, PriorityConstant.STRING_WARNING, PriorityConstant.STRING_INFO, PriorityConstant.STRING_UNKNOWN},
-				{ "", PriorityConstant.STRING_CRITICAL, PriorityConstant.STRING_WARNING, PriorityConstant.STRING_INFO, PriorityConstant.STRING_UNKNOWN}};
-
-		m_priority.setSelectValues(priorityValues);
-		m_priority.setValue(PriorityConstant.STRING_CRITICAL);
+		m_priority.setValue("");
+		m_priorityCritical.setValue(new Boolean(true));
+		m_priorityWarning.setValue(new Boolean(true));
+		m_priorityInfo.setValue(new Boolean(true));
+		m_priorityUnknown.setValue(new Boolean(true));
 
 		m_outputFromDate.setValue("");
 		m_outputToDate.setValue("");
 		m_generationFromDate.setValue("");
 		m_generationToDate.setValue("");
 
+		m_monitorId.setValue("");
+		m_monitorDetailId.setValue("");
+
 		Object facilityTypeValues[][] = {
 				{ FacilityTargetConstant.STRING_ALL, FacilityTargetConstant.STRING_BENEATH},
 				{ FacilityTargetConstant.STRING_ALL, FacilityTargetConstant.STRING_BENEATH}};
@@ -233,11 +298,17 @@ public class StatusFilterPropertyUtil {
 		m_generationDate.setValue("");
 
 		//変更の可/不可を設定
-		m_priority.setModify(PropertyDefineConstant.MODIFY_OK);
+		m_priority.setModify(PropertyDefineConstant.MODIFY_NG);
+		m_priorityCritical.setModify(PropertyDefineConstant.MODIFY_OK);
+		m_priorityWarning.setModify(PropertyDefineConstant.MODIFY_OK);
+		m_priorityInfo.setModify(PropertyDefineConstant.MODIFY_OK);
+		m_priorityUnknown.setModify(PropertyDefineConstant.MODIFY_OK);
 		m_outputFromDate.setModify(PropertyDefineConstant.MODIFY_OK);
 		m_outputToDate.setModify(PropertyDefineConstant.MODIFY_OK);
 		m_generationFromDate.setModify(PropertyDefineConstant.MODIFY_OK);
 		m_generationToDate.setModify(PropertyDefineConstant.MODIFY_OK);
+		m_monitorId.setModify(PropertyDefineConstant.MODIFY_OK);
+		m_monitorDetailId.setModify(PropertyDefineConstant.MODIFY_OK);
 		m_facilityType.setModify(PropertyDefineConstant.MODIFY_OK);
 		m_application.setModify(PropertyDefineConstant.MODIFY_OK);
 		m_message.setModify(PropertyDefineConstant.MODIFY_OK);
@@ -253,11 +324,20 @@ public class StatusFilterPropertyUtil {
 		property.addChildren(m_priority);
 		property.addChildren(m_outputDate);
 		property.addChildren(m_generationDate);
+		property.addChildren(m_monitorId);
+		property.addChildren(m_monitorDetailId);
 		property.addChildren(m_facilityType);
 		property.addChildren(m_application);
 		property.addChildren(m_message);
 		property.addChildren(m_ownerRoleId);
 
+		// 重要度
+		m_priority.removeChildren();
+		m_priority.addChildren(m_priorityCritical);
+		m_priority.addChildren(m_priorityWarning);
+		m_priority.addChildren(m_priorityInfo);
+		m_priority.addChildren(m_priorityUnknown);
+
 		// 更新日時
 		m_outputDate.removeChildren();
 		m_outputDate.addChildren(m_outputFromDate);
