@@ -18,12 +18,7 @@ package com.clustercontrol.monitor.view;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.eclipse.jface.action.ActionContributionItem;
-import org.eclipse.jface.action.IMenuListener;
-import org.eclipse.jface.action.IMenuManager;
-import org.eclipse.jface.action.IToolBarManager;
 import org.eclipse.jface.action.MenuManager;
-import org.eclipse.jface.action.Separator;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.swt.SWT;
@@ -31,7 +26,10 @@ import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Menu;
+import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.commands.ICommandService;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.accesscontrol.util.ObjectBean;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.Property;
@@ -40,26 +38,27 @@ import com.clustercontrol.monitor.composite.action.MonitorListSelectionChangedLi
 import com.clustercontrol.monitor.run.action.GetMonitorListTableDefine;
 import com.clustercontrol.monitor.view.action.CollectorDisableAction;
 import com.clustercontrol.monitor.view.action.CollectorEnableAction;
-import com.clustercontrol.monitor.view.action.MonitorAddAction;
 import com.clustercontrol.monitor.view.action.MonitorCopyAction;
 import com.clustercontrol.monitor.view.action.MonitorDeleteAction;
 import com.clustercontrol.monitor.view.action.MonitorDisableAction;
 import com.clustercontrol.monitor.view.action.MonitorEnableAction;
+import com.clustercontrol.monitor.view.action.MonitorFilterAction;
 import com.clustercontrol.monitor.view.action.MonitorModifyAction;
+import com.clustercontrol.monitor.view.action.MonitorRefreshAction;
+import com.clustercontrol.monitor.view.action.ObjectPrivilegeMonitorListAction;
 import com.clustercontrol.view.CommonViewPart;
 import com.clustercontrol.view.ObjectPrivilegeTargetListView;
-import com.clustercontrol.view.action.ObjectPrivilegeAction;
 
 /**
  * 監視[一覧]ビュークラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 4.0.0
  */
 public class MonitorListView extends CommonViewPart implements ObjectPrivilegeTargetListView {
 
 	/** 監視[一覧]ビューID */
-	public static final String ID = "com.clustercontrol.monitor.view.MonitorListView";
+	public static final String ID = MonitorListView.class.getName();
 
 	/** 監視設定一覧コンポジット */
 	private MonitorListComposite composite = null;
@@ -67,6 +66,9 @@ public class MonitorListView extends CommonViewPart implements ObjectPrivilegeTa
 	/** 検索条件 */
 	private Property condition = null;
 
+	/** 選択レコード数 */
+	private int rowNum = 0;
+
 	/**
 	 * コンストラクタ
 	 */
@@ -76,7 +78,7 @@ public class MonitorListView extends CommonViewPart implements ObjectPrivilegeTa
 
 	/**
 	 * ViewPartへのコントロール作成処理<BR>
-	 * 
+	 *
 	 * @see org.eclipse.ui.IWorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
 	 */
 	@Override
@@ -87,6 +89,7 @@ public class MonitorListView extends CommonViewPart implements ObjectPrivilegeTa
 		layout.marginWidth = 0;
 
 		composite = new MonitorListComposite(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, null, composite);
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -106,77 +109,23 @@ public class MonitorListView extends CommonViewPart implements ObjectPrivilegeTa
 
 	/**
 	 * コンテキストメニューを作成します。
-	 * 
+	 *
 	 * @see org.eclipse.jface.action.MenuManager
 	 * @see org.eclipse.swt.widgets.Menu
 	 */
 	private void createContextMenu() {
 		MenuManager menuManager = new MenuManager();
 		menuManager.setRemoveAllWhenShown(true);
-		menuManager.addMenuListener(new IMenuListener() {
-			/* (non-Javadoc)
-			 * @see org.eclipse.jface.action.IMenuListener#menuAboutToShow(org.eclipse.jface.action.IMenuManager)
-			 */
-			@Override
-			public void menuAboutToShow(IMenuManager manager) {
-				//メニュー項目設定
-				fillContextMenu(manager);
-			}
-		});
 
 		Menu menu = menuManager.createContextMenu(composite.getTable());
+		WidgetTestUtil.setTestId(this, null, menu);
 		composite.getTable().setMenu(menu);
-	}
-
-	/**
-	 * コンテキストメニューに項目を追加します。
-	 * 
-	 * @param manager メニューマネージャ
-	 * 
-	 * @see org.eclipse.jface.action.IToolBarManager
-	 * @see org.eclipse.jface.action.IMenuManager
-	 */
-	private void fillContextMenu(IMenuManager manager) {
-		//ビューのアクションのインスタンスを取得
-		IToolBarManager toolbar =
-				this.getViewSite().getActionBars().getToolBarManager();
-		ActionContributionItem monitorAdd =
-				(ActionContributionItem) toolbar.find(MonitorAddAction.ID);
-		ActionContributionItem monitorModify =
-				(ActionContributionItem) toolbar.find(MonitorModifyAction.ID);
-		ActionContributionItem monitorDelete =
-				(ActionContributionItem) toolbar.find(MonitorDeleteAction.ID);
-		ActionContributionItem monitorCopy =
-				(ActionContributionItem) toolbar.find(MonitorCopyAction.ID);
-		ActionContributionItem monitorEnable =
-				(ActionContributionItem) toolbar.find(MonitorEnableAction.ID);
-		ActionContributionItem monitorDisable =
-				(ActionContributionItem) toolbar.find(MonitorDisableAction.ID);
-		ActionContributionItem collectorEnable =
-				(ActionContributionItem) toolbar.find(CollectorEnableAction.ID);
-		ActionContributionItem collectorDisable =
-				(ActionContributionItem) toolbar.find(CollectorDisableAction.ID);
-		ActionContributionItem objPrivilege =
-				(ActionContributionItem) toolbar.find(ObjectPrivilegeAction.ID);
-
-		//ポップアップメニューにアクションを追加
-		manager.add(monitorAdd.getAction());
-		manager.add(monitorModify.getAction());
-		manager.add(monitorDelete.getAction());
-		manager.add(new Separator());
-		manager.add(monitorCopy.getAction());
-		manager.add(new Separator());
-		manager.add(monitorEnable.getAction());
-		manager.add(monitorDisable.getAction());
-		manager.add(collectorEnable.getAction());
-		manager.add(collectorDisable.getAction());
-		manager.add(new Separator());
-		manager.add(objPrivilege.getAction());
+		getSite().registerContextMenu( menuManager, this.composite.getTableViewer() );
 	}
 
 	/**
 	 * 追加コンポジットを返します。
-	 * 
+	 *
 	 * @return 追加コンポジット
 	 */
 	public Composite getListComposite() {
@@ -186,9 +135,9 @@ public class MonitorListView extends CommonViewPart implements ObjectPrivilegeTa
 	/**
 	 * 検索条件にヒットした監視設定の一覧を表示します。
 	 * <p>
-	 * 
+	 *
 	 * conditionがnullの場合、全監視設定を表示します。
-	 * 
+	 *
 	 * @param condition
 	 *            検索条件
 	 */
@@ -201,7 +150,7 @@ public class MonitorListView extends CommonViewPart implements ObjectPrivilegeTa
 	/**
 	 * ビューを更新します。
 	 * <p>
-	 * 
+	 *
 	 * 検索条件が事前に設定されている場合、その条件にヒットする監視設定の一覧を 表示します <br>
 	 * 検索条件が設定されていない場合は、全監視設定を表示します。
 	 */
@@ -210,48 +159,42 @@ public class MonitorListView extends CommonViewPart implements ObjectPrivilegeTa
 		this.composite.update(this.condition);
 	}
 
+
+	/**
+	 * 選択レコード数を返します。
+	 * @return rowNum
+	 */
+	public int getSelectedNum(){
+		return this.rowNum;
+	}
+
 	/**
 	 * ビューのアクションの有効/無効を設定します。
-	 * 
+	 *
 	 * @param num 選択イベント数
 	 * @param selection ボタン（アクション）を有効にするための情報
 	 */
 	public void setEnabledAction(int num, ISelection selection) {
+		this.rowNum = num;
+
 		//ビューアクションの使用可/不可を設定
-		super.setEnabledAction(ObjectPrivilegeAction.ID, selection);
-		super.setEnabledAction(MonitorCopyAction.ID, selection);
-		super.setEnabledAction(MonitorDeleteAction.ID, selection);
-		super.setEnabledAction(MonitorModifyAction.ID, selection);
-		super.setEnabledAction(MonitorDisableAction.ID, selection);
-		super.setEnabledAction(MonitorEnableAction.ID, selection);
-		super.setEnabledAction(CollectorDisableAction.ID, selection);
-		super.setEnabledAction(CollectorEnableAction.ID, selection);
+		ICommandService service = (ICommandService) PlatformUI.getWorkbench().getService( ICommandService.class );
+		if( null != service ){
+			service.refreshElements(ObjectPrivilegeMonitorListAction.ID, null);
+			service.refreshElements(MonitorCopyAction.ID, null);
+			service.refreshElements(MonitorDeleteAction.ID, null);
+			service.refreshElements(MonitorModifyAction.ID, null);
+			service.refreshElements(MonitorDisableAction.ID, null);
+			service.refreshElements(MonitorEnableAction.ID, null);
+			service.refreshElements(CollectorDisableAction.ID, null);
+			service.refreshElements(CollectorEnableAction.ID, null);
+			service.refreshElements(MonitorRefreshAction.ID, null);
+			service.refreshElements(MonitorFilterAction.ID, null);
 
-		if(num > 0){
-			super.setEnabledAction(MonitorDisableAction.ID, true);
-			super.setEnabledAction(MonitorEnableAction.ID, true);
-			super.setEnabledAction(CollectorDisableAction.ID, true);
-			super.setEnabledAction(CollectorEnableAction.ID, true);
-			super.setEnabledAction(ObjectPrivilegeAction.ID, true);
-
-			if(num == 1){
-				super.setEnabledAction(MonitorCopyAction.ID, true);
-				super.setEnabledAction(MonitorDeleteAction.ID, true);
-				super.setEnabledAction(MonitorModifyAction.ID, true);
-			}else{
-				super.setEnabledAction(MonitorCopyAction.ID, false);
-				super.setEnabledAction(MonitorDeleteAction.ID, false);
-				super.setEnabledAction(MonitorModifyAction.ID, false);
-			}
-		} else {
-			super.setEnabledAction(ObjectPrivilegeAction.ID, false);
-			super.setEnabledAction(MonitorCopyAction.ID, false);
-			super.setEnabledAction(MonitorDeleteAction.ID, false);
-			super.setEnabledAction(MonitorModifyAction.ID, false);
-			super.setEnabledAction(MonitorDisableAction.ID, false);
-			super.setEnabledAction(MonitorEnableAction.ID, false);
-			super.setEnabledAction(CollectorDisableAction.ID, false);
-			super.setEnabledAction(CollectorEnableAction.ID, false);
+			// Update ToolBar after elements refreshed
+			// WARN : Both ToolBarManager must be updated after updateActionBars(), otherwise icon won't change.
+			getViewSite().getActionBars().updateActionBars();
+			getViewSite().getActionBars().getToolBarManager().update(false);
 		}
 	}
 
@@ -260,12 +203,14 @@ public class MonitorListView extends CommonViewPart implements ObjectPrivilegeTa
 		StructuredSelection selection = (StructuredSelection) this.composite.getTableViewer().getSelection();
 		Object [] objs = selection.toArray();
 
+		String managerName = null;
 		String objectType = HinemosModuleConstant.MONITOR;
 		String objectId = null;
 		List<ObjectBean> objectBeans = new ArrayList<ObjectBean>();
 		for (Object obj : objs) {
-			objectId = (String) ((List)obj).get(GetMonitorListTableDefine.MONITOR_ID);
-			ObjectBean objectBean = new ObjectBean(objectType, objectId);
+			managerName = (String) ((List<?>)obj).get(GetMonitorListTableDefine.MANAGER_NAME);
+			objectId = (String) ((List<?>)obj).get(GetMonitorListTableDefine.MONITOR_ID);
+			ObjectBean objectBean = new ObjectBean(managerName, objectType, objectId);
 			objectBeans.add(objectBean);
 		}
 		return objectBeans;
@@ -275,7 +220,7 @@ public class MonitorListView extends CommonViewPart implements ObjectPrivilegeTa
 	public String getSelectedOwnerRoleId() {
 		StructuredSelection selection = (StructuredSelection) this.composite.getTableViewer().getSelection();
 
-		List list = (List) selection.getFirstElement();
+		List<?> list = (List<?>) selection.getFirstElement();
 		String id = null;
 		if (list != null) {
 			id = (String) list.get(GetMonitorListTableDefine.OWNER_ROLE);
