@@ -17,40 +17,44 @@ package com.clustercontrol.monitor.view.action;
 
 import java.util.List;
 
-import org.eclipse.jface.action.IAction;
+import org.eclipse.core.commands.AbstractHandler;
+import org.eclipse.core.commands.ExecutionEvent;
+import org.eclipse.core.commands.ExecutionException;
 import org.eclipse.jface.dialogs.IDialogConstants;
-import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.StructuredSelection;
-import org.eclipse.ui.IViewActionDelegate;
-import org.eclipse.ui.IViewPart;
+import org.eclipse.ui.IWorkbenchPart;
+import org.eclipse.ui.IWorkbenchWindow;
+import org.eclipse.ui.handlers.HandlerUtil;
 
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.monitor.action.CommentEvent;
+import com.clustercontrol.monitor.action.GetEventListTableDefine;
 import com.clustercontrol.monitor.composite.EventListComposite;
 import com.clustercontrol.monitor.dialog.EventInfoDialog;
 import com.clustercontrol.monitor.view.EventView;
 
 /**
  * 監視[イベントの詳細]ダイアログの表示を行うクライアント側アクションクラス<BR>
- * 
- * @version 2.1.0
+ *
+ * @version 5.0.0
  * @since 2.1.0
  */
-public class EventDetailAction implements IViewActionDelegate {
+public class EventDetailAction extends AbstractHandler {
 
 	/** アクションID */
-	public static final String ID = "com.clustercontrol.monitor.view.action.EventDetailAction";
+	public static final String ID = EventDetailAction.class.getName();
 
+	private IWorkbenchWindow window;
 	/** ビュー */
-	private IViewPart viewPart;
+	private IWorkbenchPart viewPart;
 
 	/**
-	 * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
-	 * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
+	 * Dispose
 	 */
 	@Override
-	public void init(IViewPart viewPart) {
-		this.viewPart = viewPart;
+	public void dispose() {
+		this.viewPart = null;
+		this.window = null;
 	}
 
 	/**
@@ -61,13 +65,22 @@ public class EventDetailAction implements IViewActionDelegate {
 	 * <li>監視[イベント]ビューで、選択されているアイテムを取得します。</li>
 	 * <li>取得したイベント情報の監視[イベントの詳細]ダイアログを表示します。</li>
 	 * </ol>
-	 * 
-	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
+	 *
+	 * @see org.eclipse.core.commands.IHandler#execute
 	 * @see com.clustercontrol.monitor.view.EventView
 	 * @see com.clustercontrol.monitor.dialog.EventInfoDialog
 	 */
 	@Override
-	public void run(IAction action) {
+	public Object execute(ExecutionEvent event) throws ExecutionException {
+		this.window = HandlerUtil.getActiveWorkbenchWindow(event);
+		// In case this action has been disposed
+		if( null == this.window || !isEnabled() ){
+			return null;
+		}
+
+		// 選択アイテムの取得
+		this.viewPart = HandlerUtil.getActivePart(event);
+
 		// 選択アイテムを取得します。
 		EventView view = (EventView) this.viewPart.getAdapter(EventView.class);
 
@@ -77,7 +90,7 @@ public class EventDetailAction implements IViewActionDelegate {
 		StructuredSelection selection =
 				(StructuredSelection)composite.getTableViewer().getSelection();
 
-		List list = (List)selection.getFirstElement();
+		List<?> list = (List<?>)selection.getFirstElement();
 
 		if(list != null){
 			EventInfoDialog dialog =
@@ -85,26 +98,14 @@ public class EventDetailAction implements IViewActionDelegate {
 							this.viewPart.getSite().getShell(),
 							list);
 			if (dialog.open() == IDialogConstants.OK_ID){
-				Property event = dialog.getInputData();
+				String managerName = (String) list.get(GetEventListTableDefine.MANAGER_NAME);
+				Property prop = dialog.getInputData();
 				CommentEvent comment = new CommentEvent();
-				comment.updateComment(event);
+				comment.updateComment(managerName, prop);
 				view.update();
 
 			}
-
-
-
-
 		}
-	}
-
-	/**
-	 * 選択を変更した際に呼ばれます。
-	 * 
-	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction, org.eclipse.jface.viewers.ISelection)
-	 */
-	@Override
-	public void selectionChanged(IAction action, ISelection selection) {
-
+		return null;
 	}
 }
