@@ -21,10 +21,9 @@ import java.util.List;
 import org.eclipse.jface.viewers.DoubleClickEvent;
 import org.eclipse.jface.viewers.IDoubleClickListener;
 import org.eclipse.jface.viewers.StructuredSelection;
-import org.eclipse.ui.IWorkbench;
 import org.eclipse.ui.IWorkbenchPage;
+import org.eclipse.ui.PlatformUI;
 
-import com.clustercontrol.ClusterControlPlugin;
 import com.clustercontrol.composite.FacilityTreeComposite;
 import com.clustercontrol.monitor.action.GetScopeListTableDefine;
 import com.clustercontrol.monitor.view.ScopeView;
@@ -33,7 +32,7 @@ import com.clustercontrol.ws.repository.FacilityTreeItem;
 
 /**
  * 監視[スコープ]ビューでダブルクリック時にスコープ階層ペインを更新するクライアント側アクションクラス<BR>
- * 
+ *
  * @version 2.0.0
  * @since 2.0.0
  */
@@ -47,20 +46,18 @@ public class ScopeSpecifiedShowAction implements IDoubleClickListener {
 	 * <li>監視[スコープ]ビューで選択されているアイテムより、ファシリティIDを取得します。</li>
 	 * <li>取得したファシリティIDのスコープツリーアイテムを選択状態にします。 </li>
 	 * </ol>
-	 * 
+	 *
 	 * @see org.eclipse.jface.viewers.IDoubleClickListener#doubleClick(org.eclipse.jface.viewers.DoubleClickEvent)
 	 */
 	@Override
 	public void doubleClick(DoubleClickEvent event) {
 
 		// ダブルクリックしたスコープのファシリティIDを取得する
-		ArrayList list = (ArrayList) ((StructuredSelection)event.getSelection()).getFirstElement();
+		ArrayList<?> list = (ArrayList<?>) ((StructuredSelection)event.getSelection()).getFirstElement();
 		String facilityId = (String)list.get(GetScopeListTableDefine.FACILITY_ID);
 
 		if(facilityId != null && !"".equals(facilityId)){
-
-			IWorkbench workbench = ClusterControlPlugin.getDefault().getWorkbench();
-			IWorkbenchPage page = workbench.getActiveWorkbenchWindow().getActivePage();
+			IWorkbenchPage page = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();
 
 			ScopeView scopeView = (ScopeView) page.findView(ScopeView.ID);
 
