@@ -1,11 +1,18 @@
 package com.clustercontrol.nodemap.model;
 
 import java.io.Serializable;
-import javax.persistence.*;
+import java.util.List;
 
+import javax.persistence.Cacheable;
+import javax.persistence.Entity;
+import javax.persistence.FetchType;
+import javax.persistence.Id;
+import javax.persistence.OneToMany;
+import javax.persistence.Table;
+
+import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 
-import java.util.List;
 
 
 /**
@@ -13,7 +20,7 @@ import java.util.List;
  * 
  */
 @Entity
-@Table(name="cc_map_bg_image")
+@Table(name="cc_map_bg_image", schema="binarydata")
 @Cacheable(true)
 public class MapBgImageEntity implements Serializable {
 	private static final long serialVersionUID = 1L;
@@ -27,7 +34,7 @@ public class MapBgImageEntity implements Serializable {
 
 	public MapBgImageEntity(String filename) {
 		this.setFilename(filename);
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		em.persist(this);
 	}
 
