@@ -25,7 +25,7 @@ import com.clustercontrol.ws.notify.NotifyInfo;
 
 /**
  * 通知情報を作成するクライアント側アクションクラス<BR>
- * 
+ *
  * @version 2.2.0
  * @since 1.0.0
  */
@@ -34,17 +34,19 @@ public class AddNotify {
 	/**
 	 * 通知情報を作成します。<BR>
 	 * マネージャにSessionBean経由でアクセスします。
-	 * 
+	 *
+	 * @param managerName マネージャ名
 	 * @param info 作成対象の通知情報
 	 * @return 作成に成功した場合、<code> true </code>
-	 * 
+	 *
 	 */
-	public boolean add(NotifyInfo info) {
+	public boolean add(String managerName, NotifyInfo info) {
 
 		boolean result = false;
-		String[] args = { info.getNotifyId() };
+		String[] args = { info.getNotifyId(), managerName };
 		try {
-			result = NotifyEndpointWrapper.addNotify(info);
+			NotifyEndpointWrapper wrapper = NotifyEndpointWrapper.getWrapper(managerName);
+			result = wrapper.addNotify(info);
 
 			MessageDialog.openInformation(
 					null,
@@ -77,4 +79,4 @@ public class AddNotify {
 
 		return result;
 	}
-}
\ No newline at end of file
+}
