@@ -16,7 +16,6 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.notify.dialog;
 
 import java.util.ArrayList;
-import java.util.List;
 
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.swt.SWT;
@@ -30,8 +29,8 @@ import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.PriorityColorConstant;
-import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.monitor.bean.EventConfirmConstant;
@@ -39,12 +38,12 @@ import com.clustercontrol.notify.action.AddNotify;
 import com.clustercontrol.notify.action.GetNotify;
 import com.clustercontrol.notify.action.ModifyNotify;
 import com.clustercontrol.util.Messages;
-import com.clustercontrol.ws.notify.NotifyInfo;
 import com.clustercontrol.ws.notify.NotifyEventInfo;
+import com.clustercontrol.ws.notify.NotifyInfo;
 
 /**
  * 通知（イベント）作成・変更ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 3.0.0
  */
@@ -72,9 +71,6 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 	 */
 	private final int TYPE_EVENT = 1;
 
-	/** 入力値を保持するオブジェクト。 */
-	private NotifyInfo inputData = null;
-
 	/** 入力値の正当性を保持するオブジェクト。 */
 	protected ValidateResult validateResult = null;
 
@@ -100,35 +96,32 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 */
 	public NotifyEventCreateDialog(Shell parent) {
 		super(parent);
 	}
 
-	public NotifyEventCreateDialog(Shell parent, int notifyIdType) {
-		super(parent, notifyIdType);
-	}
-
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
+	 * @param managerName マネージャ名
 	 * @param notifyId 変更する通知情報の通知ID
 	 * @param updateFlg 更新フラグ（true:更新する）
 	 */
-	public NotifyEventCreateDialog(Shell parent, String notifyId, boolean updateFlg) {
-		super(parent, notifyId, updateFlg);
+	public NotifyEventCreateDialog(Shell parent, String managerName, String notifyId, boolean updateFlg) {
+		super(parent, managerName, notifyId, updateFlg);
 	}
 
 	// ----- instance メソッド ----- //
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.dialog.NotifyBasicCreateDialog#customizeDialog(Composite)
 	 * @see com.clustercontrol.notify.action.GetNotify#getNotify(String)
 	 * @see #setInputData(NotifyInfo)
@@ -141,7 +134,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 		// 通知IDが指定されている場合、その情報を初期表示する。
 		NotifyInfo info = null;
 		if(this.notifyId != null){
-			info = new GetNotify().getNotify(this.notifyId);
+			info = new GetNotify().getNotify(this.managerName, this.notifyId);
 		}else{
 			info = new NotifyInfo();
 		}
@@ -151,9 +144,9 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 親のクラスから呼ばれ、各通知用のダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.dialog.NotifyBasicCreateDialog#customizeDialog(Composite)
 	 */
 	@Override
@@ -180,6 +173,8 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 		 */
 		// イベントグループ
 		Group groupEvent = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "event", groupEvent);
+
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
@@ -197,6 +192,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 		 */
 		// ラベル（重要度）
 		label = new Label(groupEvent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "priority", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_PRIORITY;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -206,6 +202,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（通知）
 		label = new Label(groupEvent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "notifyattribute", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_NOTIFY;
 		gridData.horizontalAlignment = GridData.CENTER;
@@ -215,6 +212,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（状態）
 		label = new Label(groupEvent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "status", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_STATE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -224,6 +222,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 		// 空欄
 		label = new Label(groupEvent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space1", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_BLANK + WIDTH_INHIBITION_FLG + WIDTH_STATE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -233,10 +232,13 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 		//　イベント　重要度：通知
 		label = this.getLabelPriority(groupEvent, Messages.getString("info"),PriorityColorConstant.COLOR_INFO);
 		this.m_checkEventNormalInfo = this.getCheckEventNormal(groupEvent);
+		WidgetTestUtil.setTestId(this, "normalinfo", m_checkEventNormalInfo);
 		this.m_comboEventNormalInfo = this.getComboEventNormal(groupEvent);
+		WidgetTestUtil.setTestId(this, "normalinfo", m_comboEventNormalInfo);
 
 		// 空欄
 		label = new Label(groupEvent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space2", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_BLANK + WIDTH_INHIBITION_FLG + WIDTH_STATE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -246,10 +248,13 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 		//　イベント　重要度：警告
 		label = this.getLabelPriority(groupEvent, Messages.getString("warning"),PriorityColorConstant.COLOR_WARNING);
 		this.m_checkEventNormalWarning = this.getCheckEventNormal(groupEvent);
+		WidgetTestUtil.setTestId(this, "normalwarning", m_checkEventNormalWarning);
 		this.m_comboEventNormalWarning = this.getComboEventNormal(groupEvent);
+		WidgetTestUtil.setTestId(this, "normalwarning", m_comboEventNormalWarning);
 
 		// 空欄
 		label = new Label(groupEvent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space3", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_BLANK + WIDTH_INHIBITION_FLG + WIDTH_STATE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -259,10 +264,13 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 		//　イベント　重要度：危険
 		label = this.getLabelPriority(groupEvent, Messages.getString("critical"),PriorityColorConstant.COLOR_CRITICAL);
 		this.m_checkEventNormalCritical = this.getCheckEventNormal(groupEvent);
+		WidgetTestUtil.setTestId(this, "normalcritical", m_checkEventNormalCritical);
 		this.m_comboEventNormalCritical = this.getComboEventNormal(groupEvent);
+		WidgetTestUtil.setTestId(this, "normalcritical", m_comboEventNormalCritical);
 
 		// 空欄
 		label = new Label(groupEvent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space4", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_BLANK + WIDTH_INHIBITION_FLG + WIDTH_STATE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -272,21 +280,23 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 		//　イベント　重要度：不明
 		label = this.getLabelPriority(groupEvent, Messages.getString("unknown"),PriorityColorConstant.COLOR_UNKNOWN);
 		this.m_checkEventNormalUnknown = this.getCheckEventNormal(groupEvent);
+		WidgetTestUtil.setTestId(this, "normalunknown", m_checkEventNormalUnknown);
 		this.m_comboEventNormalUnknown = this.getComboEventNormal(groupEvent);
+		WidgetTestUtil.setTestId(this, "normalunknown", m_comboEventNormalUnknown);
 
 		// 空欄
 		label = new Label(groupEvent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space5", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_BLANK + WIDTH_INHIBITION_FLG + WIDTH_STATE;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
-
 	}
 
 	/**
 	 * 入力値を保持した通知情報を返します。
-	 * 
+	 *
 	 * @return 通知情報
 	 */
 	@Override
@@ -296,135 +306,78 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 引数で指定された通知情報の値を、各項目に設定します。
-	 * 
+	 *
 	 * @param notify 設定値として用いる通知情報
 	 */
 	@Override
 	protected void setInputData(NotifyInfo notify) {
+		super.setInputData(notify);
 
-		this.inputData = notify;
-
-		// 通知基本情報
-		super.m_notifyBasic.setInputData(notify, this.updateFlg);
-
-		// 初回通知情報
-		super.m_notifyInitial.setInputData(notify);
-
-		// 抑制情報
-		super.m_notifyInhibition.setInputData(notify);
-
-		// イベント情報
-		List<NotifyEventInfo> list = notify.getNotifyEventInfo();
-		if (list != null && list.size() > 0) {
-			for(int index=0; index<list.size(); index++){
-				NotifyEventInfo event = list.get(index);
-				if(event != null){
-					// 通知の場合
-					if(PriorityConstant.TYPE_INFO ==  event.getPriority()){
-						this.setInputDataForEvent(event, this.m_checkEventNormalInfo, 	this.m_comboEventNormalInfo);
-					}
-					// 警告の場合
-					else if(PriorityConstant.TYPE_WARNING ==  event.getPriority()){
-						this.setInputDataForEvent(event, this.m_checkEventNormalWarning, 	this.m_comboEventNormalWarning);
-					}
-					// 危険の場合
-					else if(PriorityConstant.TYPE_CRITICAL ==  event.getPriority()){
-						this.setInputDataForEvent(event, this.m_checkEventNormalCritical, this.m_comboEventNormalCritical);
-					}
-					// 不明の場合
-					else if(PriorityConstant.TYPE_UNKNOWN ==  event.getPriority()){
-						this.setInputDataForEvent(event, this.m_checkEventNormalUnknown, 	this.m_comboEventNormalUnknown);
-					}
-				}
-			}
-		}
-
-		// 有効／無効
-		if (notify.getValidFlg() != null && notify.getValidFlg() == ValidConstant.TYPE_INVALID) {
-			this.m_confirmValid.setSelection(false);
-		}
-		else {
-			this.m_confirmValid.setSelection(true);
+		// コマンド情報
+		NotifyEventInfo info = notify.getNotifyEventInfo();
+		if (info != null) {
+			this.setInputDatal(info);
 		}
 	}
 
-	/**
-	 * 引数で指定された通知イベント情報の値を、各項目に設定します。
-	 * 
-	 * @param info 設定値として用いる通知イベント情報
-	 * @param checkEventNormal 通知チェックボックス
-	 * @param comboEventNormal 通知状態コンボボックス
-	 * @param checkEventInhibition 抑制チェックボックス
-	 * @param comboEventInhibition 抑制状態コンボボックス
-	 */
-	protected void setInputDataForEvent(NotifyEventInfo info,
-			Button checkEventNormal,
-			Combo comboEventNormal
-			) {
-		// イベント通知
-		if (info.getValidFlg() != null && info.getValidFlg().intValue() == ValidConstant.TYPE_VALID) {
-			checkEventNormal.setSelection(true);
-		}
-		// イベント画面出力時の通知状態
-		if (info.getEventNormalState() != null) {
-			comboEventNormal.setText(EventConfirmConstant.typeToString(info.getEventNormalState().intValue()));
+	private void setInputDatal(NotifyEventInfo info) {
+		Button[] checkEventNormals = new Button[] {
+				this.m_checkEventNormalInfo,
+				this.m_checkEventNormalWarning,
+				this.m_checkEventNormalCritical,
+				this.m_checkEventNormalUnknown
+		};
+		Combo[] comboEventNormals = new Combo[] {
+				this.m_comboEventNormalInfo,
+				this.m_comboEventNormalWarning,
+				this.m_comboEventNormalCritical,
+				this.m_comboEventNormalUnknown
+		};
+		Integer[] eventNormalStates = new Integer[] {
+				info.getInfoEventNormalState(),
+				info.getWarnEventNormalState(),
+				info.getCriticalEventNormalState(),
+				info.getUnknownEventNormalState()
+		};
+
+		Integer[] validFlgs = this.getValidFlgs(info);
+		for (int i = 0; i < validFlgs.length; i++) {
+			// イベント通知
+			boolean valid = validFlgs[i] == ValidConstant.TYPE_VALID;
+			checkEventNormals[i].setSelection(valid);
+			WidgetTestUtil.setTestId(this, "checkEventNormals" + i, checkEventNormals[i]);
+
+
+			// イベント画面出力時の通知状態
+			if (eventNormalStates[i] != null) {
+				comboEventNormals[i].setText(EventConfirmConstant.typeToString(eventNormalStates[i]));
+				WidgetTestUtil.setTestId(this, "comboEventNormals" + i, comboEventNormals[i]);
+			}
+
 		}
 	}
 
 	/**
 	 * 入力値を設定した通知情報を返します。<BR>
 	 * 入力値チェックを行い、不正な場合は<code>null</code>を返します。
-	 * 
+	 *
 	 * @return 通知情報
-	 * 
+	 *
 	 * @see #createInputDataForEvent(ArrayList, int, Button, Combo, Button, Combo)
 	 */
 	@Override
 	protected NotifyInfo createInputData() {
-		NotifyInfo info = new NotifyInfo();
+		NotifyInfo info = super.createInputData();
+		if (info == null) {
+			return null;
+		}
 
 		// 通知タイプの設定
 		info.setNotifyType(TYPE_EVENT);
 
-		// 通知基本情報
-		validateResult = super.m_notifyBasic.createInputData(info, this.notifyId);
-		if(validateResult != null){
-			return null;
-		}
-
-		// 初回通知情報
-		validateResult = super.m_notifyInitial.createInputData(info);
-		if(validateResult != null){
-			return null;
-		}
-
-		// 抑制情報
-		validateResult = super.m_notifyInhibition.createInputData(info);
-		if(validateResult != null){
-			return null;
-		}
-
 		// イベント情報
-		ArrayList<NotifyEventInfo> list = new ArrayList<NotifyEventInfo>();
-		list = this.createInputDataForEvent(list, PriorityConstant.TYPE_INFO,		this.m_checkEventNormalInfo,	this.m_comboEventNormalInfo, null, null);
-		list = this.createInputDataForEvent(list, PriorityConstant.TYPE_WARNING,	this.m_checkEventNormalWarning,	this.m_comboEventNormalWarning, null, null);
-		list = this.createInputDataForEvent(list, PriorityConstant.TYPE_CRITICAL,	this.m_checkEventNormalCritical,this.m_comboEventNormalCritical, null, null);
-		list = this.createInputDataForEvent(list, PriorityConstant.TYPE_UNKNOWN,	this.m_checkEventNormalUnknown,	this.m_comboEventNormalUnknown, null, null);
-
-		if(list == null){
-			return null;
-		}
-
-		List<NotifyEventInfo> notifyEventInfo = info.getNotifyEventInfo();
-		notifyEventInfo.clear();
-		notifyEventInfo.addAll(list);
-
-		// 有効/無効
-		if (this.m_confirmValid.getSelection()) {
-			info.setValidFlg(ValidConstant.TYPE_VALID);
-		} else {
-			info.setValidFlg(ValidConstant.TYPE_INVALID);
-		}
+		NotifyEventInfo event = createInputData(info.getNotifyId());
+		info.setNotifyEventInfo(event);
 
 		return info;
 	}
@@ -432,47 +385,45 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 	/**
 	 * 入力値を設定した通知イベント情報を返します。<BR>
 	 * 入力値チェックを行い、不正な場合は<code>null</code>を返します。
-	 * 
+	 *
 	 * @return 通知イベント情報
-	 * 
+	 *
 	 */
-	private ArrayList<NotifyEventInfo> createInputDataForEvent(ArrayList<NotifyEventInfo> list,
-			int priority,
-			Button checkEventNormal,
-			Combo comboEventNormal,
-			Button checkEventInhibition,
-			Combo comboEventInhibition
-			) {
-
-		if(list == null)
-			return null;
-
+	private NotifyEventInfo createInputData(String notifyId) {
 		NotifyEventInfo event = new NotifyEventInfo();
-		event.setEventNormalState(EventConfirmConstant.TYPE_UNCONFIRMED);
-
-		// 重要度
-		event.setPriority(priority);
+		event.setNotifyId(notifyId);
 
 		// イベント通知
-		if (checkEventNormal.getSelection()) {
-			event.setValidFlg(new Integer(ValidConstant.TYPE_VALID));
-		} else {
-			event.setValidFlg(new Integer(ValidConstant.TYPE_INVALID));
-		}
+		event.setInfoValidFlg(ValidConstant.booleanToType(m_checkEventNormalInfo.getSelection()));
+		event.setWarnValidFlg(ValidConstant.booleanToType(m_checkEventNormalWarning.getSelection()));
+		event.setCriticalValidFlg(ValidConstant.booleanToType(m_checkEventNormalCritical.getSelection()));
+		event.setUnknownValidFlg(ValidConstant.booleanToType(m_checkEventNormalUnknown.getSelection()));
 
 		// イベント通知時の状態
-		if (comboEventNormal.getText() != null
-				&& !"".equals((comboEventNormal.getText()).trim())) {
-			event.setEventNormalState(new Integer(EventConfirmConstant.stringToType(comboEventNormal.getText())));
+		event.setInfoEventNormalState(EventConfirmConstant.TYPE_UNCONFIRMED);
+		event.setWarnEventNormalState(EventConfirmConstant.TYPE_UNCONFIRMED);
+		event.setCriticalEventNormalState(EventConfirmConstant.TYPE_UNCONFIRMED);
+		event.setUnknownEventNormalState(EventConfirmConstant.TYPE_UNCONFIRMED);
+
+		if (isNotNullAndBlank(m_comboEventNormalInfo.getText())) {
+			event.setInfoEventNormalState(EventConfirmConstant.stringToType(m_comboEventNormalInfo.getText()));
+		}
+		if (isNotNullAndBlank(m_comboEventNormalWarning.getText())) {
+			event.setWarnEventNormalState(EventConfirmConstant.stringToType(m_comboEventNormalWarning.getText()));
+		}
+		if (isNotNullAndBlank(m_comboEventNormalCritical.getText())) {
+			event.setCriticalEventNormalState(EventConfirmConstant.stringToType(m_comboEventNormalCritical.getText()));
+		}
+		if (isNotNullAndBlank(m_comboEventNormalUnknown.getText())) {
+			event.setUnknownEventNormalState(EventConfirmConstant.stringToType(m_comboEventNormalUnknown.getText()));
 		}
 
-		list.add(event);
-		return list;
+		return event;
 	}
 
 	/**
 	 * 入力値チェックをします。
-	 * 
+	 *
 	 * @return 検証結果
 	 */
 	@Override
@@ -489,9 +440,9 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -499,14 +450,15 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 		boolean result = false;
 
 		NotifyInfo info = this.getInputData();
+
 		if(info != null){
 			if (!this.updateFlg) {
 				// 作成の場合
-				result = new AddNotify().add(info);
+				result = new AddNotify().add(this.getInputManagerName(), info);
 			}
 			else{
 				// 変更の場合
-				result = new ModifyNotify().modify(info);
+				result = new ModifyNotify().modify(this.getInputManagerName(), info);
 			}
 		}
 
@@ -515,7 +467,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * ＯＫボタンのテキストを返します。
-	 * 
+	 *
 	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
@@ -525,7 +477,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * キャンセルボタンのテキストを返します。
-	 * 
+	 *
 	 * @return キャンセルボタンのテキスト
 	 */
 	@Override
@@ -535,7 +487,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 無効な入力値の情報を設定します。
-	 * 
+	 *
 	 * @param id ID
 	 * @param message メッセージ
 	 */
@@ -551,9 +503,9 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 	/**
 	 * ボタンを生成します。<BR>
 	 * 参照フラグが<code> true </code>の場合は閉じるボタンを生成し、<code> false </code>の場合は、デフォルトのボタンを生成します。
-	 * 
+	 *
 	 * @param parent ボタンバーコンポジット
-	 * 
+	 *
 	 * @see #createButtonsForButtonBar(Composite)
 	 */
 	@Override
@@ -564,12 +516,13 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 		}
 		else{
 			// 閉じるボタン
-			this.createButton(parent, IDialogConstants.CANCEL_ID, IDialogConstants.CLOSE_LABEL, false);
+			// TODO Remove the following hard-code. IDialogConstants.*_LABEL will causes IncompatibleClassChangeError on RAP
+			this.createButton(parent, IDialogConstants.CANCEL_ID, "Close", false);
 		}
 	}
 	/**
 	 * コンポジットの選択可/不可を設定します。
-	 * 
+	 *
 	 * @param enable 選択可の場合、<code> true </code>
 	 */
 	@Override
@@ -580,7 +533,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 重要度のラベルを返します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param text ラベルに表示するテキスト
 	 * @param background ラベルの背景色
@@ -593,6 +546,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（重要度）
 		Label label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "labelpriority", label);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_PRIORITY;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -606,7 +560,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * イベント通知の通知のチェックボックスを返します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
@@ -614,6 +568,8 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 		// チェックボックス（通知する）
 		Button button = new Button(parent, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, null, button);
+
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_NOTIFY;
 		gridData.horizontalAlignment = GridData.CENTER;
@@ -625,7 +581,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * イベント通知の通知状態コンボボックスを返します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @return 生成されたコンボボックス
 	 */
@@ -633,6 +589,7 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 		// コンボボックス（通知状態）
 		Combo combo = new Combo(parent, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, null, combo);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_STATE;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -644,46 +601,4 @@ public class NotifyEventCreateDialog extends NotifyBasicCreateDialog {
 
 		return combo;
 	}
-
-	/**
-	 * イベント通知の抑制のチェックボックスを返します。
-	 * 
-	 * @param parent 親のコンポジット
-	 * @return 生成されたチェックボックス
-	 */
-	private Button getCheckEventInhibition(Composite parent) {
-
-		// チェックボックス（抑制する）
-		Button button = new Button(parent, SWT.CHECK);
-		GridData gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_INHIBITION_FLG;
-		gridData.horizontalAlignment = GridData.CENTER;
-		gridData.grabExcessHorizontalSpace = true;
-		button.setLayoutData(gridData);
-
-		return button;
-	}
-
-	/**
-	 * イベント通知の抑制状態コンボボックスを返します。
-	 * 
-	 * @param parent 親のコンポジット
-	 * @return 生成されたコンボボックス
-	 */
-	private Combo getComboEventInhibition(Composite parent) {
-
-		// コンボボックス（抑制時の状態）
-		Combo combo = new Combo(parent, SWT.DROP_DOWN | SWT.READ_ONLY);
-		GridData gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_STATE;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		combo.setLayoutData(gridData);
-		combo.add(EventConfirmConstant.STRING_CONFIRMED);
-		combo.add(EventConfirmConstant.STRING_DESTRUCTION);
-		combo.setText(EventConfirmConstant.STRING_CONFIRMED);
-
-		return combo;
-	}
-
-}
\ No newline at end of file
+}
