@@ -16,7 +16,6 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.notify.dialog;
 
 import java.util.ArrayList;
-import java.util.List;
 
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.swt.SWT;
@@ -32,6 +31,7 @@ import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.PriorityColorConstant;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.ValidConstant;
@@ -47,7 +47,7 @@ import com.clustercontrol.ws.notify.NotifyStatusInfo;
 
 /**
  * 通知（ステータス）作成・変更ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 3.0.0
  */
@@ -58,7 +58,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 	/** カラム数（チェックボックス）。 */
 	private static final int WIDTH_CHECK 		= 2;
-	
+
 	/** カラム数（空欄）。 */
 	private static final int WIDTH_BLANK 		= 11;
 
@@ -70,9 +70,6 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 	 */
 	private final int TYPE_STATUS = 0;
 
-	/** 入力値を保持するオブジェクト。 */
-	private NotifyInfo inputData = null;
-
 	/** 入力値の正当性を保持するオブジェクト。 */
 	protected ValidateResult validateResult = null;
 
@@ -102,36 +99,32 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 */
 	public NotifyStatusCreateDialog(Shell parent) {
 		super(parent);
 	}
 
-
-	public NotifyStatusCreateDialog(Shell parent, int notifyIdType) {
-		super(parent, notifyIdType);
-	}
-
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 * @param notifyId 変更する通知情報の通知ID
+	 * @param managerName マネージャ名
 	 * @param updateFlg 更新フラグ（true:更新する）
 	 */
-	public NotifyStatusCreateDialog(Shell parent, String notifyId, boolean updateFlg) {
-		super(parent, notifyId, updateFlg);
+	public NotifyStatusCreateDialog(Shell parent, String managerName, String notifyId, boolean updateFlg) {
+		super(parent, managerName, notifyId, updateFlg);
 	}
 
 	// ----- instance メソッド ----- //
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.dialog.NotifyBasicCreateDialog#customizeDialog(Composite)
 	 * @see com.clustercontrol.notify.action.GetNotify#getNotify(String)
 	 * @see #setInputData(NotifyInfo)
@@ -144,7 +137,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		// 通知IDが指定されている場合、その情報を初期表示する。
 		NotifyInfo info = null;
 		if(this.notifyId != null){
-			info = new GetNotify().getNotify(this.notifyId);
+			info = new GetNotify().getNotify(this.managerName, this.notifyId);
 		}
 		else{
 			info = new NotifyInfo();
@@ -155,9 +148,9 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 親のクラスから呼ばれ、各通知用のダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.dialog.NotifyBasicCreateDialog#customizeDialog(Composite)
 	 */
 	@Override
@@ -184,6 +177,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		 */
 		// ステータス通知グループ
 		Group groupStatus1 = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "status1", groupStatus1);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
@@ -201,6 +195,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		 */
 		// ラベル（重要度）
 		label = new Label(groupStatus1, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "priority", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_PRIORITY;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -210,6 +205,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（通知する）
 		label = new Label(groupStatus1, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "attribute", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_CHECK;
 		gridData.horizontalAlignment = GridData.CENTER;
@@ -219,6 +215,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 		// 空白
 		label = new Label(groupStatus1, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space2", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_BLANK;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -229,6 +226,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		// ステータス 重要度：通知
 		label = this.getLabelPriority(groupStatus1, Messages.getString("info"),PriorityColorConstant.COLOR_INFO);
 		this.m_checkStatusNormalInfo = this.getCheckStatusNormal(groupStatus1);
+		WidgetTestUtil.setTestId(this, "normalinfo", m_checkStatusNormalInfo);
 		this.m_checkStatusNormalInfo.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
@@ -238,6 +236,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 		// 空白
 		label = new Label(groupStatus1, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space3", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_BLANK;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -248,7 +247,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		// ステータス 重要度：警告
 		label = this.getLabelPriority(groupStatus1, Messages.getString("warning"),PriorityColorConstant.COLOR_WARNING);
 		this.m_checkStatusNormalWarning = this.getCheckStatusNormal(groupStatus1);
-
+		WidgetTestUtil.setTestId(this, "normalwarning", m_checkStatusNormalWarning);
 		this.m_checkStatusNormalWarning.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
@@ -258,6 +257,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 		// 空白
 		label = new Label(groupStatus1, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space4", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_BLANK;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -268,7 +268,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		// ステータス 重要度：危険
 		label = this.getLabelPriority(groupStatus1, Messages.getString("critical"),PriorityColorConstant.COLOR_CRITICAL);
 		this.m_checkStatusNormalCritical = this.getCheckStatusNormal(groupStatus1);
-
+		WidgetTestUtil.setTestId(this, "normalcritical", m_checkStatusNormalCritical);
 		this.m_checkStatusNormalCritical.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
@@ -278,6 +278,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 		// 空白
 		label = new Label(groupStatus1, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space5", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_BLANK;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -288,7 +289,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		// ステータス 重要度：不明
 		label = this.getLabelPriority(groupStatus1, Messages.getString("unknown"),PriorityColorConstant.COLOR_UNKNOWN);
 		this.m_checkStatusNormalUnknown = this.getCheckStatusNormal(groupStatus1);
-
+		WidgetTestUtil.setTestId(this, "normalunknown", m_checkStatusNormalUnknown);
 		this.m_checkStatusNormalUnknown.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
@@ -298,6 +299,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 		// 空白
 		label = new Label(groupStatus1, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space6", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_BLANK;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -306,6 +308,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 		// 空行
 		label = new Label(groupStatus1, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space7", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -317,6 +320,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		 */
 		// ラベル
 		label = new Label(groupStatus1, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "validperiod", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 4;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -325,6 +329,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		label.setText(Messages.getString("notify.status.valid.period") + " : ");
 		// コンボボックス
 		this.m_comboStatusValidPeriod = new Combo(groupStatus1, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "validpriod", m_comboStatusValidPeriod);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -343,6 +348,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 		// 空白
 		label = new Label(groupStatus1, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space8", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 9;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -351,6 +357,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル
 		label = new Label(groupStatus1, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space9", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -363,6 +370,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		 */
 		// ステータス情報有効期間経過後の扱い通知グループ
 		Group groupStatus2 = new Group(groupStatus1, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "status2", groupStatus2);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
@@ -376,6 +384,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 		// 情報を削除する
 		this.m_radioStatusDelete = new Button(groupStatus2, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "delete", m_radioStatusDelete);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -385,6 +394,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 		// 更新されていない旨のメッセージに置換える。
 		this.m_radioStatusUpdate = new Button(groupStatus2, SWT.RADIO);
+		WidgetTestUtil.setTestId(this, "update", m_radioStatusUpdate);
 		gridData = new GridData();
 		gridData.horizontalSpan = 8;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -403,6 +413,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		 */
 		// ラベル
 		label = new Label(groupStatus2, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "priority2", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -411,6 +422,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		label.setText(Messages.getString("priority") + " : ");
 		// コンボボックス
 		this.m_comboStatusPriority = new Combo(groupStatus2, SWT.DROP_DOWN | SWT.READ_ONLY);
+		WidgetTestUtil.setTestId(this, "priority", m_comboStatusPriority);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -423,6 +435,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		this.m_comboStatusPriority.setText(PriorityConstant.STRING_WARNING);
 		// 空白
 		label = new Label(groupStatus2, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "space10", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 3;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -433,7 +446,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 入力値を保持した通知情報を返します。
-	 * 
+	 *
 	 * @return 通知情報
 	 */
 	@Override
@@ -443,76 +456,55 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 引数で指定された通知情報の値を、各項目に設定します。
-	 * 
+	 *
 	 * @param notify 設定値として用いる通知情報
 	 */
 	@Override
 	protected void setInputData(NotifyInfo notify) {
+		super.setInputData(notify);
 
-		this.inputData = notify;
-
-		// 通知基本情報
-		super.m_notifyBasic.setInputData(notify, this.updateFlg);
-
-		// 初回通知情報
-		super.m_notifyInitial.setInputData(notify);
-
-		// 抑制情報
-		super.m_notifyInhibition.setInputData(notify);
-
-		// ステータス情報
-		List<NotifyStatusInfo> list = notify.getNotifyStatusInfo();
-		if (list != null && list.size() > 0) {
-			for (int index=0; index<list.size(); index++){
-				NotifyStatusInfo status = list.get(index);
-				if(status != null){
-					// 通知の場合
-					if(PriorityConstant.TYPE_INFO ==  status.getPriority()){
-						this.setInputDataForStatus(status, this.m_checkStatusNormalInfo, null);
-						//通知のみステータス通知の共通部分の設定を行う
-						if (status.getStatusValidPeriod() != null) {
-							this.m_comboStatusValidPeriod.setText(StatusValidPeriodConstant.typeToString(status.getStatusValidPeriod().intValue()));
-						}
-						if (status.getStatusInvalidFlg() != null && status.getStatusInvalidFlg().intValue() == StatusExpirationConstant.TYPE_DELETE) {
-							this.m_radioStatusDelete.setSelection(true);
-						} else {
-							this.m_radioStatusUpdate.setSelection(true);
-						}
-						this.m_comboStatusPriority.setText(PriorityConstant.typeToString(status.getStatusUpdatePriority().intValue()));
-					}
-					// 警告の場合
-					else if(PriorityConstant.TYPE_WARNING ==  status.getPriority()){
-						this.setInputDataForStatus(status, this.m_checkStatusNormalWarning, null);
-					}
-					// 危険の場合
-					else if(PriorityConstant.TYPE_CRITICAL ==  status.getPriority()){
-						this.setInputDataForStatus(status, this.m_checkStatusNormalCritical, null);
-					}
-					// 不明の場合
-					else if(PriorityConstant.TYPE_UNKNOWN ==  status.getPriority()){
-						this.setInputDataForStatus(status, this.m_checkStatusNormalUnknown, null);
-					}
-				}
-			}
+		// コマンド情報
+		NotifyStatusInfo info = notify.getNotifyStatusInfo();
+		if (info != null) {
+			this.setInputData(info);
 		} else {
 			// 新規追加の場合
 			this.m_radioStatusDelete.setSelection(true);
 		}
+		this.m_comboStatusPriority.setEnabled(m_radioStatusUpdate.getSelection());
+	}
+
+	private void setInputData(NotifyStatusInfo status) {
+		if (status.getStatusValidPeriod() != null) {
+			this.m_comboStatusValidPeriod.setText(StatusValidPeriodConstant.typeToString(status.getStatusValidPeriod().intValue()));
+		}
+		if (status.getStatusInvalidFlg() != null && status.getStatusInvalidFlg().intValue() == StatusExpirationConstant.TYPE_DELETE) {
+			this.m_radioStatusDelete.setSelection(true);
+		} else {
+			this.m_radioStatusUpdate.setSelection(true);
+		}
+		this.m_comboStatusPriority.setText(PriorityConstant.typeToString(status.getStatusUpdatePriority().intValue()));
+
+		Button[] checkStatusNormals = new Button[] {
+				this.m_checkStatusNormalInfo,
+				this.m_checkStatusNormalWarning,
+				this.m_checkStatusNormalCritical,
+				this.m_checkStatusNormalUnknown
+		};
+		Integer[] validFlgs = getValidFlgs(status);
+		for (int i = 0; i < validFlgs.length; i++) {
+			boolean valid = validFlgs[i] == ValidConstant.TYPE_VALID;
+			checkStatusNormals[i].setSelection(valid);
+			WidgetTestUtil.setTestId(this, "checkStatusNormals" + i, checkStatusNormals[i]);
+		}
 
 		this.m_comboStatusPriority.setEnabled(m_radioStatusUpdate.getSelection());
-
-		// 有効／無効
-		if (notify.getValidFlg() != null && notify.getValidFlg() == ValidConstant.TYPE_INVALID) {
-			this.m_confirmValid.setSelection(false);
-		}
-		else {
-			this.m_confirmValid.setSelection(true);
-		}
 	}
 
+
 	/**
 	 * 引数で指定された通知ステータス情報の値を、各項目に設定します。
-	 * 
+	 *
 	 * @param info 設定値として用いる通知ステータス情報
 	 * @param checkStatusNormal 通知チェックボックス
 	 * @param checkStatusInhibition 抑制チェックボックス
@@ -521,105 +513,50 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 			Button checkStatusNormal,
 			Button checkStatusInhibition
 			) {
-		// ステータス通知
-		if (info.getValidFlg() != null && info.getValidFlg().intValue() == ValidConstant.TYPE_VALID) {
-			checkStatusNormal.setSelection(true);
-		}
 	}
 
 	/**
 	 * 入力値を設定した通知情報を返します。<BR>
 	 * 入力値チェックを行い、不正な場合は<code>null</code>を返します。
-	 * 
+	 *
 	 * @return 通知情報
-	 * 
+	 *
 	 * @see #createInputDataForStatus(ArrayList, int, Button, Button)
 	 */
 	@Override
 	protected NotifyInfo createInputData() {
-		NotifyInfo info = new NotifyInfo();
+		NotifyInfo info = super.createInputData();
+		if (info == null) {
+			return null;
+		}
 
 		// 通知タイプの設定
 		info.setNotifyType(TYPE_STATUS);
 
-		// 通知基本情報
-		validateResult = super.m_notifyBasic.createInputData(info, this.notifyId);
-		if(validateResult != null){
-			return null;
-		}
-
-		// 初回通知情報
-		validateResult = super.m_notifyInitial.createInputData(info);
-		if(validateResult != null){
-			return null;
-		}
-
-		// 抑制情報
-		validateResult = super.m_notifyInhibition.createInputData(info);
-		if(validateResult != null){
-			return null;
-		}
-
-		// ステータス情報
-		ArrayList<NotifyStatusInfo> list = new ArrayList<NotifyStatusInfo>();
-		list = this.createInputDataForStatus(list, PriorityConstant.TYPE_INFO,		this.m_checkStatusNormalInfo);
-		list = this.createInputDataForStatus(list, PriorityConstant.TYPE_WARNING,	this.m_checkStatusNormalWarning);
-		list = this.createInputDataForStatus(list, PriorityConstant.TYPE_CRITICAL,	this.m_checkStatusNormalCritical);
-		list = this.createInputDataForStatus(list, PriorityConstant.TYPE_UNKNOWN,	this.m_checkStatusNormalUnknown);
-
-		if(list == null){
-			return null;
-		}
-
-		List<NotifyStatusInfo> notifyStatusInfo = info.getNotifyStatusInfo();
-		notifyStatusInfo.clear();
-		notifyStatusInfo.addAll(list);
-
-		// 有効/無効
-		if (this.m_confirmValid.getSelection()) {
-			info.setValidFlg(ValidConstant.TYPE_VALID);
-		} else {
-			info.setValidFlg(ValidConstant.TYPE_INVALID);
-		}
+		// イベント情報
+		NotifyStatusInfo status = createInputData(info.getNotifyId());
+		info.setNotifyStatusInfo(status);
 
 		return info;
 	}
 
-	/**
-	 * 入力値を設定した通知イベント情報を返します。<BR>
-	 * 入力値チェックを行い、不正な場合は<code>null</code>を返します。
-	 * 
-	 * @return 通知ステータス情報
-	 * 
-	 */
-	private ArrayList<NotifyStatusInfo> createInputDataForStatus(
-			ArrayList<NotifyStatusInfo> list,
-			int priority,
-			Button checkStatusNormal
-			) {
-
-		if(list == null)
-			return null;
-
+	private NotifyStatusInfo createInputData(String notifyId) {
 		NotifyStatusInfo status = new NotifyStatusInfo();
+		status.setNotifyId(notifyId);
+
 		status.setStatusInvalidFlg(StatusExpirationConstant.TYPE_DELETE);
 		status.setStatusUpdatePriority(PriorityConstant.TYPE_WARNING);
 		status.setStatusValidPeriod(StatusValidPeriodConstant.TYPE_MIN_10);
 
-		// 重要度
-		status.setPriority(priority);
-
 		// ステータス通知
-		if (checkStatusNormal.getSelection()) {
-			status.setValidFlg(new Integer(ValidConstant.TYPE_VALID));
-		} else {
-			status.setValidFlg(new Integer(ValidConstant.TYPE_INVALID));
-		}
+		status.setInfoValidFlg(ValidConstant.booleanToType(m_checkStatusNormalInfo.getSelection()));
+		status.setWarnValidFlg(ValidConstant.booleanToType(m_checkStatusNormalWarning.getSelection()));
+		status.setCriticalValidFlg(ValidConstant.booleanToType(m_checkStatusNormalCritical.getSelection()));
+		status.setUnknownValidFlg(ValidConstant.booleanToType(m_checkStatusNormalUnknown.getSelection()));
 
 		// ステータス通知の共通内容（重要度に関係なく全て同じものを設定する）
 		// ステータス情報の存続期間
-		if (this.m_comboStatusValidPeriod.getText() != null
-				&& !"".equals(this.m_comboStatusValidPeriod.getText())){
+		if (isNotNullAndBlank(this.m_comboStatusValidPeriod.getText())) {
 			status.setStatusValidPeriod(StatusValidPeriodConstant.stringToType(this.m_comboStatusValidPeriod.getText()));
 		}
 
@@ -631,18 +568,16 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		}
 
 		// 更新されていない場合に通知する際の重要度
-		if (this.m_comboStatusPriority.getText() != null
-				&& !"".equals((this.m_comboStatusPriority.getText()).trim())) {
+		if (isNotNullAndBlank(this.m_comboStatusPriority.getText())) {
 			status.setStatusUpdatePriority(new Integer(PriorityConstant.stringToType(this.m_comboStatusPriority.getText())));
 		}
 
-		list.add(status);
-		return list;
+		return status;
 	}
 
 	/**
 	 * 入力値チェックをします。
-	 * 
+	 *
 	 * @return 検証結果
 	 */
 	@Override
@@ -659,9 +594,9 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -672,11 +607,11 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		if(info != null){
 			if (!this.updateFlg) {
 				// 作成の場合
-				result = new AddNotify().add(info);
+				result = new AddNotify().add(this.getInputManagerName(), info);
 			}
 			else{
 				// 変更の場合
-				result = new ModifyNotify().modify(info);
+				result = new ModifyNotify().modify(this.getInputManagerName(), info);
 			}
 		}
 
@@ -685,7 +620,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * ＯＫボタンのテキストを返します。
-	 * 
+	 *
 	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
@@ -695,7 +630,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * キャンセルボタンのテキストを返します。
-	 * 
+	 *
 	 * @return キャンセルボタンのテキスト
 	 */
 	@Override
@@ -705,7 +640,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * コンポジットの選択可/不可を設定します。
-	 * 
+	 *
 	 * @param enable 選択可の場合、<code> true </code>
 	 */
 	@Override
@@ -720,9 +655,9 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * ステータスの通知関連コンポジットの選択可/不可を設定します。
-	 * 
+	 *
 	 * @param enable 選択可の場合、<code> true </code>
-	 * 
+	 *
 	 * @see #setEnabledForStatuses(boolean, Button, Button)
 	 */
 	protected void setEnabledForStatuses(boolean enable) {
@@ -735,7 +670,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * ステータスの通知情報の選択可/不可を設定します。
-	 * 
+	 *
 	 */
 	protected void setEnabledForStatusDuration() {
 
@@ -766,7 +701,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * 無効な入力値の情報を設定します。
-	 * 
+	 *
 	 * @param id ID
 	 * @param message メッセージ
 	 */
@@ -782,9 +717,9 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 	/**
 	 * ボタンを生成します。<BR>
 	 * 参照フラグが<code> true </code>の場合は閉じるボタンを生成し、<code> false </code>の場合は、デフォルトのボタンを生成します。
-	 * 
+	 *
 	 * @param parent ボタンバーコンポジット
-	 * 
+	 *
 	 * @see #createButtonsForButtonBar(Composite)
 	 */
 	@Override
@@ -795,13 +730,14 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 		}
 		else{
 			// 閉じるボタン
-			this.createButton(parent, IDialogConstants.CANCEL_ID, IDialogConstants.CLOSE_LABEL, false);
+			// TODO Remove the following hard-code. IDialogConstants.*_LABEL will causes IncompatibleClassChangeError on RAP
+			this.createButton(parent, IDialogConstants.CANCEL_ID, "Cancel", false);
 		}
 	}
 
 	/**
 	 * 重要度のラベルを返します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @param text ラベルに表示するテキスト
 	 * @param background ラベルの背景色
@@ -814,6 +750,7 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 		// ラベル（重要度）
 		Label label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "labelpriority", label);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_PRIORITY;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -827,40 +764,19 @@ public class NotifyStatusCreateDialog extends NotifyBasicCreateDialog {
 
 	/**
 	 * ステータスの通知のチェックボックスを返します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
 	 * @return 生成されたチェックボックス
 	 */
 	private Button getCheckStatusNormal(Composite parent) {
-
 		// チェックボックス（通知する）
-		Button button = new Button(parent, SWT.CHECK);
+		Button notifyStatusCreateNormalCheckbox = new Button(parent, SWT.CHECK);
 		GridData gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_CHECK;
 		gridData.horizontalAlignment = GridData.CENTER;
 		gridData.grabExcessHorizontalSpace = true;
-		button.setLayoutData(gridData);
+		notifyStatusCreateNormalCheckbox.setLayoutData(gridData);
 
-		return button;
+		return notifyStatusCreateNormalCheckbox;
 	}
-
-	/**
-	 * ステータスの抑制のチェックボックスを返します。
-	 * 
-	 * @param parent 親のコンポジット
-	 * @return 生成されたチェックボックス
-	 */
-	private Button getCheckStatusInhibition(Composite parent) {
-
-		// チェックボックス（抑制する）
-		Button button = new Button(parent, SWT.CHECK);
-		GridData gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_CHECK;
-		gridData.horizontalAlignment = GridData.CENTER;
-		gridData.grabExcessHorizontalSpace = true;
-		button.setLayoutData(gridData);
-
-		return button;
-	}
-
-}
\ No newline at end of file
+}
