@@ -88,6 +88,10 @@ public class AddNotify {
 			// 通知情報を挿入
 			// インスタンス生成
 			NotifyInfoEntity notify = new NotifyInfoEntity(info.getNotifyId());
+			String calendarId=info.getCalendarId();
+			if("".equals(calendarId)){
+				calendarId=null;
+			}
 			// 重複チェック
 			jtm.checkEntityExists(NotifyInfoEntity.class, notify.getNotifyId());
 			notify.setDescription(info.getDescription());
@@ -98,7 +102,7 @@ public class AddNotify {
 			notify.setNotFirstNotify(info.getNotFirstNotify());
 			notify.setValidFlg(info.getValidFlg());
 			notify.setOwnerRoleId(info.getOwnerRoleId());
-			notify.setCalendarId(info.getCalendarId());
+			notify.setCalendarId(calendarId);
 			notify.setRegDate(now);
 			notify.setRegUser(user);
 			notify.setUpdateDate(now);
