@@ -102,7 +102,10 @@ public class ModifyNotify {
 
 			// 通知情報を取得
 			NotifyInfoEntity notify = QueryUtil.getNotifyInfoPK(info.getNotifyId(), ObjectPrivilegeMode.MODIFY);
-
+			String calendarId=info.getCalendarId();
+			if("".equals(calendarId)){
+				calendarId=null;
+			}
 			// 通知情報を更新
 			notify.setDescription(info.getDescription());
 			notify.setValidFlg(info.getValidFlg());
@@ -114,7 +117,7 @@ public class ModifyNotify {
 			notify.setUpdateUser(user);
 			notify.setValidFlg(info.getValidFlg());
 			notify.setOwnerRoleId(info.getOwnerRoleId());
-			notify.setCalendarId(info.getCalendarId());
+			notify.setCalendarId(calendarId);
 
 			// 通知設定を無効に設定した場合は、関連する通知履歴を削除
 			if(notify.getValidFlg().intValue() == ValidConstant.TYPE_INVALID){
