@@ -18,18 +18,13 @@ package com.clustercontrol.notify.factory;
 import java.util.Collection;
 import java.util.Iterator;
 
-import javax.ejb.CreateException;
-import javax.ejb.FinderException;
-import javax.ejb.RemoveException;
-import javax.naming.NamingException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.NotifyNotFound;
 import com.clustercontrol.notify.bean.NotifyRelationInfo;
-import com.clustercontrol.notify.ejb.entity.NotifyRelationInfoUtil;
-import com.clustercontrol.util.apllog.AplLogger;
+import com.clustercontrol.notify.model.NotifyRelationInfoEntity;
 
 /**
  * システム通知情報を変更するクラスです。
@@ -54,20 +49,16 @@ public class ModifyNotifyRelation {
 	 * 
 	 * @param info 変更対象のシステム通知情報
 	 * @return 変更に成功した場合、<code> true </code>
-	 * @throws CreateException
-	 * @throws FinderException
-	 * @throws RemoveException
-	 * @throws NamingException
-	 * @throws JMSException
+	 * @throws HinemosUnknown
+	 * @throws NotifyNotFound
 	 * 
 	 * @see com.clustercontrol.notify.ejb.entity.SystemNotifyInfoBean
 	 * @see com.clustercontrol.notify.ejb.entity.SystemNotifyEventInfoBean
 	 * @see com.clustercontrol.notify.factory.DeleteSystemNotify#deleteEvents(Collection)
 	 */
-	@SuppressWarnings("unchecked")
-	public boolean modify(Collection<NotifyRelationInfo> info, String notifyGroupId) throws CreateException, NotifyNotFound, RemoveException, NamingException {
+	public boolean modify(Collection<NotifyRelationInfo> info, String notifyGroupId) throws HinemosUnknown, NotifyNotFound {
 		NotifyRelationInfo relation = null;
-
+		m_log.debug("ModifyNotifyRelation.modify() notifyGroupId = " + notifyGroupId);
 		try
 		{
 			/**
@@ -80,7 +71,6 @@ public class ModifyNotifyRelation {
 				DeleteNotifyRelation delete = new DeleteNotifyRelation();
 				delete.delete(notifyGroupId);
 			}
-
 			if(info != null){
 				Iterator<NotifyRelationInfo> it= info.iterator();
 
@@ -89,35 +79,20 @@ public class ModifyNotifyRelation {
 					relation = it.next();
 
 					if(relation != null){
-						NotifyRelationInfoUtil.getLocalHome().create(
-								relation.getNotifyGroupId(),
-								relation.getNotifyId(),
-								relation.getNotifyType(),
-								relation.getNotifyFlg()
-						);
+						// 通知情報を検索
+						m_log.debug("NotifyRelation ADD before : notifyGroupId = " + relation.getNotifyGroupId() + ", notifyId = " + relation.getNotifyId());
+						NotifyRelationInfoEntity entity = new NotifyRelationInfoEntity(relation.getNotifyGroupId(), relation.getNotifyId());
+						entity.setNotifyType(relation.getNotifyType());
+						m_log.debug("NotifyRelation ADD : notifyGroupId = " + entity.getId().getNotifyGroupId() + ", notifyId = " + entity.getId().getNotifyId());
 					}
 				}
 			}
-
-
-		} catch (CreateException e) {
-			AplLogger apllog = new AplLogger("NOTIFY", "notify");
-			//	String[] args = { info.getNotifyId() };
-			//	apllog.put("SYS", "002", args);
-			m_log.debug("modify():" + e.getMessage());
-			throw e;
-		} catch (RemoveException e) {
-			AplLogger apllog = new AplLogger("NOTIFY", "notify");
-			//			String[] args = { info.getNotifyId() };
-			//			apllog.put("SYS", "002", args);
-			m_log.debug("modify():" + e.getMessage());
-			throw e;
-		} catch (NamingException e) {
-			AplLogger apllog = new AplLogger("NOTIFY", "notify");
-			//			String[] args = { info.getNotifyId() };
-			//			apllog.put("SYS", "002", args);
-			m_log.debug("modify():" + e.getMessage());
+		} catch (HinemosUnknown e) {
 			throw e;
+		} catch (Exception e) {
+			m_log.warn("modify() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+			throw new HinemosUnknown(e.getMessage(), e);
 		}
 
 		return true;
