@@ -22,6 +22,8 @@ import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
+import org.eclipse.swt.events.SelectionAdapter;
+import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.graphics.RGB;
@@ -34,12 +36,14 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.DataRangeConstant;
 import com.clustercontrol.bean.PropertyDefineConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
+import com.clustercontrol.composite.ManagerListComposite;
 import com.clustercontrol.composite.RoleIdListComposite;
-import com.clustercontrol.composite.TextWithParameterComposite;
 import com.clustercontrol.composite.RoleIdListComposite.Mode;
+import com.clustercontrol.composite.TextWithParameterComposite;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ValidateResult;
 import com.clustercontrol.notify.mail.util.MailTemplateEndpointWrapper;
@@ -50,7 +54,7 @@ import com.clustercontrol.ws.mailtemplate.MailTemplateInfo;
 
 /**
  * メールテンプレートID作成・変更ダイアログクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 2.4.0
  */
@@ -80,6 +84,9 @@ public class MailTemplateCreateDialog extends CommonDialog {
 	/** 変更対象のメールテンプレートID。 */
 	private String mailTemplateId = null;
 
+	/** マネージャ名 */
+	private String managerName = null;
+
 	/** メールテンプレートID テキストボックス。 */
 	private Text textMailTemplateId = null;
 
@@ -95,35 +102,29 @@ public class MailTemplateCreateDialog extends CommonDialog {
 	/** 本文 スタイルテキストコンポジット。 */
 	private TextWithParameterComposite textBody = null;
 
-	/**
-	 * 作成用ダイアログのインスタンスを返します。
-	 * 
-	 * @param parent 親のシェルオブジェクト
-	 */
-	public MailTemplateCreateDialog(Shell parent) {
-		super(parent);
-		this.mode = PropertyDefineConstant.MODE_ADD;
-	}
+	/** マネージャリスト用コンポジット */
+	private ManagerListComposite m_managerComposite = null;
 
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
 	 * @param mailTemplateId 変更するメールテンプレート情報のメールテンプレートID
 	 * @param dataOperationType データ処理タイプ
 	 */
-	public MailTemplateCreateDialog(Shell parent, String mailTemplateId, int mode) {
+	public MailTemplateCreateDialog(Shell parent, String managerName, String mailTemplateId, int mode) {
 		super(parent);
 
+		this.managerName = managerName;
 		this.mailTemplateId = mailTemplateId;
 		this.mode = mode;
 	}
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のコンポジット
-	 * 
+	 *
 	 * @see com.clustercontrol.notify.mail.action.GetMailTemplate#getMailTemplate(String)
 	 * @see #setInputData(MailTemplateInfoData)
 	 */
@@ -146,11 +147,45 @@ public class MailTemplateCreateDialog extends CommonDialog {
 		layout.numColumns = 15;
 		parent.setLayout(layout);
 
+		/*
+		 * マネージャ
+		 */
+		label = new Label(parent, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "manager", label);
+		gridData = new GridData();
+		gridData.horizontalSpan = WIDTH_LABEL;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		label.setLayoutData(gridData);
+		label.setText(Messages.getString("facility.manager") + " : ");
+		if (this.mode == PropertyDefineConstant.MODE_MODIFY || this.mode == PropertyDefineConstant.MODE_SHOW) {
+			this.m_managerComposite = new ManagerListComposite(parent, SWT.NONE, false);
+		} else {
+			this.m_managerComposite = new ManagerListComposite(parent, SWT.NONE, true);
+		}
+		WidgetTestUtil.setTestId(this, "managerComposite", m_managerComposite);
+		gridData = new GridData();
+		gridData.horizontalSpan = WIDTH_TEXT;
+		gridData.horizontalAlignment = GridData.FILL;
+		gridData.grabExcessHorizontalSpace = true;
+		this.m_managerComposite.setLayoutData(gridData);
+		this.m_managerComposite.setText(this.managerName);
+		if(this.mode != PropertyDefineConstant.MODE_MODIFY && this.mode != PropertyDefineConstant.MODE_SHOW) {
+			this.m_managerComposite.getComboManagerName().addSelectionListener(new SelectionAdapter() {
+				@Override
+				public void widgetSelected(SelectionEvent e) {
+					String managerName = m_managerComposite.getText();
+					m_ownerRoleId.createRoleIdList(managerName);
+				}
+			});
+		}
+
 		/*
 		 * メールテンプレートID
 		 */
 		// ラベル
 		label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "mailtempateid", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_LABEL;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -159,6 +194,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 		label.setText(Messages.getString("mail.template.id") + " : ");
 		// テキスト
 		this.textMailTemplateId = new Text(parent, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "id", textMailTemplateId);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -179,6 +215,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 		 */
 		// ラベル
 		label = new Label(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "description", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_LABEL;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -187,6 +224,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 		label.setText(Messages.getString("description") + " : ");
 		// テキスト
 		this.textDescription = new Text(parent, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "description", textDescription);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -197,6 +235,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 		 * オーナーロールID
 		 */
 		Label labelRoleId = new Label(parent, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "roleid", labelRoleId);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_LABEL;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -204,10 +243,11 @@ public class MailTemplateCreateDialog extends CommonDialog {
 		labelRoleId.setLayoutData(gridData);
 		labelRoleId.setText(Messages.getString("owner.role.id") + " : ");
 		if (this.mode == PropertyDefineConstant.MODE_ADD) {
-			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, true, Mode.OWNER_ROLE);
+			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, managerName, true, Mode.OWNER_ROLE);
 		} else {
-			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, false, Mode.OWNER_ROLE);
+			this.m_ownerRoleId = new RoleIdListComposite(parent, SWT.NONE, managerName, false, Mode.OWNER_ROLE);
 		}
+		WidgetTestUtil.setTestId(this, "ownerroleid", m_ownerRoleId);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH_TEXT;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -221,6 +261,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 		 * メールテンプレート設定グループ
 		 */
 		Group groupMailTemplate = new Group(parent, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "mailtemplate", groupMailTemplate);
 		layout = new GridLayout(1, true);
 		layout.marginWidth = 10;
 		layout.marginHeight = 10;
@@ -238,6 +279,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 		 */
 		// ラベル
 		label = new Label(groupMailTemplate, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "subject", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -246,6 +288,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 		label.setText(Messages.getString("subject") + " : ");
 		// テキスト
 		this.textSubject = new TextWithParameterComposite(groupMailTemplate, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "subject", textSubject);
 		gridData = new GridData();
 		gridData.horizontalSpan = 13;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -260,6 +303,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 		 */
 		// ラベル
 		label = new Label(groupMailTemplate, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "repositorybody", label);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -268,6 +312,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 		label.setText(Messages.getString("response.body") + " : ");
 		// テキスト
 		this.textBody = new TextWithParameterComposite(groupMailTemplate, SWT.MULTI | SWT.BORDER | SWT.H_SCROLL | SWT.V_SCROLL | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "body", textBody);
 		gridData = new GridData();
 		gridData.horizontalSpan = WIDTH;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -281,6 +326,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 
 		// ラインを引く
 		Label line = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
+		WidgetTestUtil.setTestId(this, "line", line);
 		gridData = new GridData();
 		gridData.horizontalSpan = 15;
 		gridData.horizontalAlignment = GridData.FILL;
@@ -301,7 +347,8 @@ public class MailTemplateCreateDialog extends CommonDialog {
 		MailTemplateInfo info = null;
 		if(this.mailTemplateId != null){
 			try {
-				info = MailTemplateEndpointWrapper.getMailTemplateInfo(this.mailTemplateId);
+				MailTemplateEndpointWrapper wrapper = MailTemplateEndpointWrapper.getWrapper(this.managerName);
+				info = wrapper.getMailTemplateInfo(this.mailTemplateId);
 			} catch (InvalidRole_Exception e) {
 				MessageDialog.openInformation(null, Messages.getString("message"),
 						Messages.getString("message.accesscontrol.16"));
@@ -321,7 +368,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	public void update(){
 		if("".equals(this.textMailTemplateId.getText())){
@@ -333,7 +380,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 
 	/**
 	 * 入力値を保持したメールテンプレート情報を返します。
-	 * 
+	 *
 	 * @return メールテンプレート情報
 	 */
 	public MailTemplateInfo getInputData() {
@@ -342,7 +389,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 
 	/**
 	 * 引数で指定されたメールテンプレート情報の値を、各項目に設定します。
-	 * 
+	 *
 	 * @param mailTemplate 設定値として用いるメールテンプレート情報
 	 */
 	protected void setInputData(MailTemplateInfo mailTemplate) {
@@ -387,7 +434,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 	/**
 	 * 入力値を設定したメールテンプレート情報を返します。<BR>
 	 * 入力値チェックを行い、不正な場合は<code>null</code>を返します。
-	 * 
+	 *
 	 * @return メールテンプレート情報
 	 */
 	private MailTemplateInfo createInputData() {
@@ -420,7 +467,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 
 	/**
 	 * 入力値チェックをします。
-	 * 
+	 *
 	 * @return 検証結果
 	 */
 	@Override
@@ -437,9 +484,9 @@ public class MailTemplateCreateDialog extends CommonDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -449,11 +496,13 @@ public class MailTemplateCreateDialog extends CommonDialog {
 		MailTemplateInfo info = this.getInputData();
 		if(info != null){
 			String errMessage = "";
-			String[] args = { info.getMailTemplateId() };
+			String managerName = m_managerComposite.getText();
+			String[] args = {info.getMailTemplateId(), managerName};
+			MailTemplateEndpointWrapper wrapper = MailTemplateEndpointWrapper.getWrapper(managerName);
 			if(this.mode == PropertyDefineConstant.MODE_ADD){
 				// 作成の場合
 				try {
-					result = MailTemplateEndpointWrapper.addMailTemplate(info);
+					result = wrapper.addMailTemplate(info);
 
 					MessageDialog.openInformation(
 							null,
@@ -484,7 +533,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 			else if (this.mode == PropertyDefineConstant.MODE_MODIFY) {
 				// 変更の場合
 				try {
-					result = MailTemplateEndpointWrapper.modifyMailTemplate(info);
+					result = wrapper.modifyMailTemplate(info);
 
 					MessageDialog.openInformation(
 							null,
@@ -514,7 +563,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 
 	/**
 	 * ＯＫボタンのテキストを返します。
-	 * 
+	 *
 	 * @return ＯＫボタンのテキスト
 	 */
 	@Override
@@ -524,7 +573,7 @@ public class MailTemplateCreateDialog extends CommonDialog {
 
 	/**
 	 * キャンセルボタンのテキストを返します。
-	 * 
+	 *
 	 * @return キャンセルボタンのテキスト
 	 */
 	@Override
@@ -535,9 +584,9 @@ public class MailTemplateCreateDialog extends CommonDialog {
 	/**
 	 * ボタンを生成します。<BR>
 	 * 参照フラグが<code> true </code>の場合は閉じるボタンを生成し、<code> false </code>の場合は、デフォルトのボタンを生成します。
-	 * 
+	 *
 	 * @param parent ボタンバーコンポジット
-	 * 
+	 *
 	 * @see #createButtonsForButtonBar(Composite)
 	 */
 	@Override
@@ -545,10 +594,10 @@ public class MailTemplateCreateDialog extends CommonDialog {
 
 		if(this.mode != PropertyDefineConstant.MODE_SHOW){
 			super.createButtonsForButtonBar(parent);
-		}
-		else{
+		}else{
 			// 閉じるボタン
-			this.createButton(parent, IDialogConstants.CANCEL_ID, IDialogConstants.CLOSE_LABEL, false);
+			// TODO Remove the following hard-code. IDialogConstants.*_LABEL will causes IncompatibleClassChangeError on RAP
+			this.createButton(parent, IDialogConstants.CANCEL_ID, "Close", false);
 		}
 	}
-}
\ No newline at end of file
+}
