@@ -18,9 +18,6 @@ package com.clustercontrol.notify.mail.factory;
 import java.sql.Timestamp;
 import java.util.Date;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.MailTemplateNotFound;
@@ -36,9 +33,6 @@ import com.clustercontrol.notify.mail.util.QueryUtil;
  */
 public class ModifyMailTemplate {
 
-	/** ログ出力のインスタンス。 */
-	private static Log m_log = LogFactory.getLog( ModifyMailTemplate.class );
-
 	/**
 	 * メールテンプレート情報を変更します。
 	 * <p>
@@ -58,7 +52,7 @@ public class ModifyMailTemplate {
 	public boolean modify(MailTemplateInfo data, String name) throws MailTemplateNotFound, InvalidRole {
 
 		//メールテンプレート情報を取得
-		MailTemplateInfoEntity mailTemplateInfo = QueryUtil.getMailTemplateInfoPK(data.getMailTemplateId(), ObjectPrivilegeMode.WRITE);
+		MailTemplateInfoEntity mailTemplateInfo = QueryUtil.getMailTemplateInfoPK(data.getMailTemplateId(), ObjectPrivilegeMode.MODIFY);
 
 		//メールテンプレート情報を更新
 		mailTemplateInfo.setDescription(data.getDescription());
