@@ -14,14 +14,12 @@ public class NotifyEventInfoEntityPK implements Serializable {
 	//default serial version id, required for serializable classes.
 	private static final long serialVersionUID = 1L;
 	private String notifyId;
-	private Integer priority;
 
 	public NotifyEventInfoEntityPK() {
 	}
 
-	public NotifyEventInfoEntityPK(String notifyId, Integer priority) {
+	public NotifyEventInfoEntityPK(String notifyId) {
 		this.setNotifyId(notifyId);
-		this.setPriority(priority);
 	}
 
 	@Column(name="notify_id")
@@ -32,13 +30,6 @@ public class NotifyEventInfoEntityPK implements Serializable {
 		this.notifyId = notifyId;
 	}
 
-	public Integer getPriority() {
-		return this.priority;
-	}
-	public void setPriority(Integer priority) {
-		this.priority = priority;
-	}
-
 	@Override
 	public boolean equals(Object other) {
 		if (this == other) {
@@ -49,8 +40,7 @@ public class NotifyEventInfoEntityPK implements Serializable {
 		}
 		NotifyEventInfoEntityPK castOther = (NotifyEventInfoEntityPK)other;
 		return
-				this.notifyId.equals(castOther.notifyId)
-				&& this.priority.equals(castOther.priority);
+				this.notifyId.equals(castOther.notifyId);
 	}
 
 	@Override
@@ -58,7 +48,6 @@ public class NotifyEventInfoEntityPK implements Serializable {
 		final int prime = 31;
 		int hash = 17;
 		hash = hash * prime + this.notifyId.hashCode();
-		hash = hash * prime + this.priority.hashCode();
 
 		return hash;
 	}
@@ -66,12 +55,10 @@ public class NotifyEventInfoEntityPK implements Serializable {
 	@Override
 	public String toString() {
 		String[] names = {
-				"notifyId",
-				"priority"
+				"notifyId"
 		};
 		String[] values = {
-				this.notifyId,
-				this.priority.toString()
+				this.notifyId
 		};
 		return Arrays.toString(names) + " = " + Arrays.toString(values);
 	}
