@@ -3,7 +3,8 @@ package com.clustercontrol.notify.model;
 import java.io.Serializable;
 import java.util.Arrays;
 
-import javax.persistence.*;
+import javax.persistence.Column;
+import javax.persistence.Embeddable;
 
 /**
  * The primary key class for the cc_notify_log_escalate_info database table.
@@ -14,14 +15,12 @@ public class NotifyLogEscalateInfoEntityPK implements Serializable {
 	//default serial version id, required for serializable classes.
 	private static final long serialVersionUID = 1L;
 	private String notifyId;
-	private Integer priority;
 
 	public NotifyLogEscalateInfoEntityPK() {
 	}
 
-	public NotifyLogEscalateInfoEntityPK(String notifyId, Integer priority) {
+	public NotifyLogEscalateInfoEntityPK(String notifyId) {
 		this.setNotifyId(notifyId);
-		this.setPriority(priority);
 	}
 
 	@Column(name="notify_id")
@@ -32,13 +31,6 @@ public class NotifyLogEscalateInfoEntityPK implements Serializable {
 		this.notifyId = notifyId;
 	}
 
-	public Integer getPriority() {
-		return this.priority;
-	}
-	public void setPriority(Integer priority) {
-		this.priority = priority;
-	}
-
 	@Override
 	public boolean equals(Object other) {
 		if (this == other) {
@@ -49,8 +41,7 @@ public class NotifyLogEscalateInfoEntityPK implements Serializable {
 		}
 		NotifyLogEscalateInfoEntityPK castOther = (NotifyLogEscalateInfoEntityPK)other;
 		return
-				this.notifyId.equals(castOther.notifyId)
-				&& this.priority.equals(castOther.priority);
+				this.notifyId.equals(castOther.notifyId);
 	}
 
 	@Override
@@ -58,7 +49,6 @@ public class NotifyLogEscalateInfoEntityPK implements Serializable {
 		final int prime = 31;
 		int hash = 17;
 		hash = hash * prime + this.notifyId.hashCode();
-		hash = hash * prime + this.priority.hashCode();
 
 		return hash;
 	}
@@ -66,12 +56,10 @@ public class NotifyLogEscalateInfoEntityPK implements Serializable {
 	@Override
 	public String toString() {
 		String[] names = {
-				"notifyId",
-				"priority"
+				"notifyId"
 		};
 		String[] values = {
-				this.notifyId,
-				this.priority.toString()
+				this.notifyId
 		};
 		return Arrays.toString(names) + " = " + Arrays.toString(values);
 	}
