@@ -18,8 +18,8 @@ package com.clustercontrol.notify.util;
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.HashSet;
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
 
 import org.apache.commons.logging.Log;
@@ -159,6 +159,31 @@ public class MonitorStatusCache {
 		return resultList;
 	}
 
+	public static List<MonitorStatusEntity> getByPluginIdAndMonitorMap(
+			String pluginId, Map<String, String> monitorMap) {
+		List<MonitorStatusEntity> resultList = new ArrayList<MonitorStatusEntity>();
+		
+		Set<MonitorStatusEntityPK> keySet = cacheKeys();
+		for (MonitorStatusEntityPK key : keySet) {
+			if (key.getPluginId().equals(pluginId) && monitorMap.containsKey(key.getMonitorId())) {
+				ILock lock = getLock(key);
+				
+				try {
+					lock.readLock();
+					
+					MonitorStatusEntity cache = getCache(key);
+					if (cache != null) {
+						resultList.add(cache);
+					}
+				} finally {
+					lock.readUnlock();
+				}
+			}
+		}
+		
+		return resultList;
+	}
+
 	public static void remove(MonitorStatusEntityPK pk) {
 		ILock lock = getLock(pk);
 		
@@ -226,10 +251,15 @@ public class MonitorStatusCache {
 
 			//削除
 			em.createQuery("delete from MonitorStatusEntity").executeUpdate();
+			
+			em.flush();
 
 			//作成
 			for (MonitorStatusEntity entity : entityList) {
-				em.persist(entity);
+				/* MonitorStatusEntityを直接persistすると、eclipselinkのクラスにおいて、MonitorStatusEntity同士の参照が生まれ、
+				 * GCされずにリークしてしまうので、deep copyをpersistする。
+				 */
+				em.persist(entity.clone());
 			}
 			jtm.commit();
 		} catch (Exception e) {
