@@ -181,14 +181,24 @@ public class QueryUtil {
 	}
 
 	public static NotifyJobInfoEntity getNotifyJobInfoPK(NotifyJobInfoEntityPK pk) throws NotifyNotFound {
-		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
-		NotifyJobInfoEntity entity = em.find(NotifyJobInfoEntity.class, pk, ObjectPrivilegeMode.READ);
-		if (entity == null) {
-			NotifyNotFound e = new NotifyNotFound("NotifyJobInfoEntity.findByPrimaryKey"
-					+ pk.toString());
-			m_log.info("getNotifyJobInfoPK() : "
-					+ e.getClass().getSimpleName() + ", " + e.getMessage());
+		JpaTransactionManager jtm = null;
+		NotifyJobInfoEntity entity = null;
+		try {
+			jtm = new JpaTransactionManager();
+			
+			HinemosEntityManager em = jtm.getEntityManager();
+			entity = em.find(NotifyJobInfoEntity.class, pk, ObjectPrivilegeMode.READ);
+			if (entity == null) {
+				NotifyNotFound e = new NotifyNotFound("NotifyJobInfoEntity.findByPrimaryKey"
+						+ pk.toString());
+				m_log.info("getNotifyJobInfoPK() : "
+						+ e.getClass().getSimpleName() + ", " + e.getMessage());
+				throw e;
+			}
+		} catch (NotifyNotFound e) {
 			throw e;
+		} finally {
+			jtm.close();
 		}
 		return entity;
 	}
