@@ -16,22 +16,27 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.notify.view.action;
 
 import java.util.List;
+import java.util.Map;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-import org.eclipse.jface.action.IAction;
+import org.eclipse.core.commands.AbstractHandler;
+import org.eclipse.core.commands.ExecutionEvent;
+import org.eclipse.core.commands.ExecutionException;
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.dialogs.MessageDialog;
-import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Table;
-import org.eclipse.ui.IViewActionDelegate;
-import org.eclipse.ui.IViewPart;
+import org.eclipse.ui.IWorkbenchPage;
+import org.eclipse.ui.IWorkbenchPart;
+import org.eclipse.ui.IWorkbenchWindow;
+import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.commands.IElementUpdater;
+import org.eclipse.ui.handlers.HandlerUtil;
+import org.eclipse.ui.menus.UIElement;
 
 import com.clustercontrol.monitor.action.NotifyTableDefineNoCheckBox;
-import com.clustercontrol.notify.composite.NotifyListComposite;
 import com.clustercontrol.notify.bean.NotifyTypeConstant;
+import com.clustercontrol.notify.composite.NotifyListComposite;
 import com.clustercontrol.notify.dialog.NotifyBasicCreateDialog;
 import com.clustercontrol.notify.dialog.NotifyCommandCreateDialog;
 import com.clustercontrol.notify.dialog.NotifyEventCreateDialog;
@@ -41,47 +46,79 @@ import com.clustercontrol.notify.dialog.NotifyMailCreateDialog;
 import com.clustercontrol.notify.dialog.NotifyStatusCreateDialog;
 import com.clustercontrol.notify.view.NotifyListView;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.WidgetTestUtil;
 
 /**
  * 通知[一覧]ビューの編集アクションクラス<BR>
- * 
- * @version 4.0.0
+ *
+ * @version 5.0.0
  * @since 4.0.0
  */
-public class NotifyModifyAction implements IViewActionDelegate {
-
-	// ログ
-	private static Log m_log = LogFactory.getLog( NotifyModifyAction.class );
+public class NotifyModifyAction extends AbstractHandler implements IElementUpdater {
 
 	/** アクションID */
-	public static final String ID = "com.clustercontrol.monitor.view.action.NotifyModifyAction";
+	public static final String ID = NotifyModifyAction.class.getName();
 
 	/** ビュー */
-	private IViewPart viewPart;
+	private IWorkbenchPart viewPart;
+
+	/**
+	 * Dispose
+	 */
+	@Override
+	public void dispose() {
+		this.viewPart = null;
+	}
+
+	public int openDialog(Shell shell, String managerName, String notifyId, int notifyType) {
+		NotifyBasicCreateDialog dialog = null;
+		boolean updateFlg = true;
+		if (notifyId == null) {
+			updateFlg = false;
+		}
+		if (NotifyTypeConstant.TYPE_STATUS == notifyType) {
+			dialog = new NotifyStatusCreateDialog(shell, managerName, notifyId, updateFlg);
+		} else if (NotifyTypeConstant.TYPE_EVENT == notifyType) {
+			dialog = new NotifyEventCreateDialog(shell, managerName, notifyId, updateFlg);
+		} else if (NotifyTypeConstant.TYPE_MAIL == notifyType) {
+			dialog = new NotifyMailCreateDialog(shell, managerName, notifyId, updateFlg);
+		} else if (NotifyTypeConstant.TYPE_JOB == notifyType) {
+			dialog = new NotifyJobCreateDialog(shell, managerName, notifyId, updateFlg);
+		} else if (NotifyTypeConstant.TYPE_LOG_ESCALATE == notifyType) {
+			dialog = new NotifyLogEscalateCreateDialog(shell, managerName, notifyId, updateFlg);
+		} else if (NotifyTypeConstant.TYPE_COMMAND == notifyType) {
+			dialog = new NotifyCommandCreateDialog(shell, managerName, notifyId, updateFlg);
+		}
+		return dialog.open();
+	}
 
 	@Override
-	public void run(IAction action) {
+	public Object execute(ExecutionEvent event) throws ExecutionException {
 		// 選択アイテムの取得
+		this.viewPart = HandlerUtil.getActivePart(event);
 		NotifyListView view = (NotifyListView) this.viewPart.getAdapter(NotifyListView.class);
 
 		NotifyListComposite composite = (NotifyListComposite) view.getListComposite();
+		WidgetTestUtil.setTestId(this, null, composite);
 		StructuredSelection selection = (StructuredSelection) composite.getTableViewer().getSelection();
 
-		List list = (List) selection.getFirstElement();
+		List<?> list = (List<?>) selection.getFirstElement();
+		String managerName = null;
 		String notifyId = null;
 		Integer notifyType = null;
 		if(list != null && list.size() > 0){
+			managerName = (String) list.get(NotifyTableDefineNoCheckBox.MANAGER_NAME);
 			notifyId = (String) list.get(NotifyTableDefineNoCheckBox.NOTIFY_ID);
 			notifyType = (Integer) list.get(NotifyTableDefineNoCheckBox.NOTIFY_TYPE);
 		}
 
 		Table table = composite.getTableViewer().getTable();
+		WidgetTestUtil.setTestId(this, null, table);
 
 		// 選択アイテムがある場合に、編集ダイアログを表示する
 		if(notifyId != null && notifyType != null){
-
 			Shell shell = view.getListComposite().getShell();
-			if (openDialog(shell, notifyId, notifyType) == IDialogConstants.OK_ID) {
+			if (openDialog(shell, managerName, notifyId, notifyType) == IDialogConstants.OK_ID) {
 				int selectIndex = table.getSelectionIndex();
 				composite.update();
 				table.setSelection(selectIndex);
@@ -92,39 +129,31 @@ public class NotifyModifyAction implements IViewActionDelegate {
 					Messages.getString("warning"),
 					Messages.getString("message.notify.8"));
 		}
-	}
-
-	public int openDialog(Shell shell, String notifyId, int notifyType) {
-		NotifyBasicCreateDialog dialog = null;
-		boolean updateFlg = true;
-		if (notifyId == null) {
-			updateFlg = false;
-		}
-		if (NotifyTypeConstant.TYPE_STATUS == notifyType) {
-			dialog = new NotifyStatusCreateDialog(shell, notifyId, updateFlg);
-		} else if (NotifyTypeConstant.TYPE_EVENT == notifyType) {
-			dialog = new NotifyEventCreateDialog(shell, notifyId, updateFlg);
-		} else if (NotifyTypeConstant.TYPE_MAIL == notifyType) {
-			dialog = new NotifyMailCreateDialog(shell, notifyId, updateFlg);
-		} else if (NotifyTypeConstant.TYPE_JOB == notifyType) {
-			dialog = new NotifyJobCreateDialog(shell, notifyId, updateFlg);
-		} else if (NotifyTypeConstant.TYPE_LOG_ESCALATE == notifyType) {
-			dialog = new NotifyLogEscalateCreateDialog(shell, notifyId, updateFlg);
-		} else if (NotifyTypeConstant.TYPE_COMMAND == notifyType) {
-			dialog = new NotifyCommandCreateDialog(shell, notifyId, updateFlg);
-		}
-		return dialog.open();
+		return null;
 	}
 
 	@Override
-	public void selectionChanged(IAction action, ISelection selection) {
-		// TODO Auto-generated method stub
+	public void updateElement(UIElement element, @SuppressWarnings("rawtypes") Map parameters) {
+		IWorkbenchWindow window = PlatformUI.getWorkbench().getActiveWorkbenchWindow();
+		if( null != window ){
+			IWorkbenchPage page = window.getActivePage();
+			if( null != page ){
+				IWorkbenchPart part = page.getActivePart();
 
-	}
+				boolean editEnable = false;
+				if(part instanceof NotifyListView){
+					// Enable button when 1 item is selected
+					NotifyListView view = (NotifyListView)part;
 
-	@Override
-	public void init(IViewPart viewPart) {
-		this.viewPart = viewPart;
+					if(view.getSelectedNum() == 1) {
+						editEnable = true;
+					}
+				}
+				this.setBaseEnabled(editEnable);
+			} else {
+				this.setBaseEnabled(false);
+			}
+		}
 	}
 
 }
