@@ -1374,11 +1374,7 @@ public class PerformanceGraphComposite extends Composite {
 			break;
 
 		case GraphConstant.DISPLAY_ITEMCODE:
-			if(targetItemCodeInfo.getDisplayName() != null && !"".equals(targetItemCodeInfo.getDisplayName())){
-				title = PerformanceDataSettingsUtil.getItemName(performanceDataSettings, targetItemCodeInfo.getItemCode()) + "[" + targetItemCodeInfo.getDisplayName() + "]";
-			}else{
-				title = PerformanceDataSettingsUtil.getItemName(performanceDataSettings, targetItemCodeInfo.getItemCode());
-			}
+			title = PerformanceDataSettingsUtil.getItemName(performanceDataSettings, targetItemCodeInfo.getItemCode());
 			title = title + " " + STRING_DISPLAY_ITEMCODE;
 			break;
 
@@ -1416,6 +1412,17 @@ public class PerformanceGraphComposite extends Composite {
 		if(dataSet1 == null && dataSet2 == null){
 			return new ArrayList<CollectedDataInfo>();
 		}
+		
+		// 空 check
+		if(dataSet1.size() == 0 && dataSet2.size() > 0){
+			return dataSet2;
+		}
+		if(dataSet2.size() == 0 && dataSet1.size() > 0){
+			return dataSet1;
+		}
+		if(dataSet1.size() == 0 && dataSet2.size() == 0){
+			return new ArrayList<CollectedDataInfo>();
+		}
 
 
 		ArrayList<CollectedDataInfo> dataList = new ArrayList<CollectedDataInfo>();
