@@ -15,34 +15,34 @@
 
 package com.clustercontrol.performance.etc.action;
 
-import org.eclipse.jface.action.IAction;
-import org.eclipse.jface.viewers.ISelection;
+import org.eclipse.core.commands.AbstractHandler;
+import org.eclipse.core.commands.ExecutionEvent;
+import org.eclipse.core.commands.ExecutionException;
 import org.eclipse.ui.IWorkbenchPage;
-import org.eclipse.ui.IWorkbenchWindow;
-import org.eclipse.ui.IWorkbenchWindowActionDelegate;
 import org.eclipse.ui.PartInitException;
-import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.handlers.HandlerUtil;
 
 import com.clustercontrol.performance.view.PerformanceListView;
 
 /**
  * 性能[一覧]グラフビューを表示するアクションクラス
  * 
- * @version 1.0
+ * @version 5.0.0
  * @since 1.0
  */
-public class OpenPerformanceListViewAction implements IWorkbenchWindowActionDelegate {
+public class OpenPerformanceListViewAction extends AbstractHandler {
 
 	/**
-	 * 性能[一覧]グラフビューを表示します。
-	 * 
-	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
+	 * @see org.eclipse.ui.IWorkbenchWindowActionDelegate#dispose()
 	 */
 	@Override
-	public void run(IAction action) {
+	public void dispose() {
+	}
+
+	@Override
+	public Object execute(ExecutionEvent event) throws ExecutionException {
 		// アクティブページ取得
-		IWorkbenchPage page = PlatformUI.getWorkbench()
-				.getActiveWorkbenchWindow().getActivePage();
+		IWorkbenchPage page = HandlerUtil.getActiveWorkbenchWindow( event ).getActivePage();
 
 		// ビューを表示する
 		try {
@@ -52,27 +52,6 @@ public class OpenPerformanceListViewAction implements IWorkbenchWindowActionDele
 			view.setFocus();
 		} catch (PartInitException e) {
 		}
+		return null;
 	}
-
-	/**
-	 * @see org.eclipse.ui.IWorkbenchWindowActionDelegate#dispose()
-	 */
-	@Override
-	public void dispose() {
-	}
-
-	/**
-	 * @see org.eclipse.ui.IWorkbenchWindowActionDelegate#init(org.eclipse.ui.IWorkbenchWindow)
-	 */
-	@Override
-	public void init(IWorkbenchWindow window) {
-	}
-
-	/**
-	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
-	 *      org.eclipse.jface.viewers.ISelection)
-	 */
-	@Override
-	public void selectionChanged(IAction action, ISelection selection) {
-	}
-}
\ No newline at end of file
+}
