@@ -15,13 +15,15 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.ping.action;
 
+import java.util.List;
+
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.monitor.action.DeleteInterface;
 import com.clustercontrol.monitor.util.MonitorSettingEndpointWrapper;
 
 /**
  * ping監視情報を削除するクライアント側アクションクラス<BR>
- * 
+ *
  * @version 4.0.0
  * @since 2.0.0
  */
@@ -29,12 +31,13 @@ public class DeletePing implements DeleteInterface{
 
 	/**
 	 * ping監視情報を削除します。<BR>
-	 * 
-	 * @param monitorId 監視項目ID
+	 *
+	 * @param monitorIdList 監視項目IDリスト
 	 * @return 削除に成功した場合、true
 	 */
 	@Override
-	public boolean delete(String monitorId) throws Exception{
-		return MonitorSettingEndpointWrapper.deleteMonitor(monitorId, HinemosModuleConstant.MONITOR_PING);
+	public boolean delete(String managerName, List<String> monitorIdList) throws Exception{
+		MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
+		return wrapper.deleteMonitor(monitorIdList, HinemosModuleConstant.MONITOR_PING);
 	}
-}
\ No newline at end of file
+}
