@@ -15,13 +15,11 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.ping.factory;
 
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.factory.SelectMonitor;
 import com.clustercontrol.ping.bean.PingCheckInfo;
-import com.clustercontrol.ping.ejb.entity.MonitorPingInfoLocal;
-import com.clustercontrol.ping.ejb.entity.MonitorPingInfoUtil;
+import com.clustercontrol.ping.model.MonitorPingInfoEntity;
+import com.clustercontrol.ping.util.QueryUtil;
 
 /**
  * ping監視判定情報を検索するクラス<BR>
@@ -35,17 +33,17 @@ public class SelectMonitorPing extends SelectMonitor{
 	 * @see com.clustercontrol.monitor.run.factory.SelectMonitor#getCheckInfo()
 	 */
 	@Override
-	protected PingCheckInfo getPingCheckInfo() throws FinderException, NamingException{
+	protected PingCheckInfo getPingCheckInfo() throws MonitorNotFound {
 
 		// ping監視情報を取得
-		MonitorPingInfoLocal pingLocal = MonitorPingInfoUtil.getLocalHome().findByPrimaryKey(m_monitorId);
+		MonitorPingInfoEntity entity = QueryUtil.getMonitorPingInfoPK(m_monitorId);
 
 		PingCheckInfo ping = new PingCheckInfo();
 		ping.setMonitorTypeId(m_monitorTypeId);
 		ping.setMonitorId(m_monitorId);
-		ping.setRunCount(pingLocal.getRunCount());
-		ping.setRunInterval(pingLocal.getRunInterval());
-		ping.setTimeout(pingLocal.getTimeout());
+		ping.setRunCount(entity.getRunCount());
+		ping.setRunInterval(entity.getRunInterval());
+		ping.setTimeout(entity.getTimeout());
 
 		return ping;
 	}
