@@ -15,14 +15,16 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.port.factory;
 
-import javax.ejb.CreateException;
-import javax.naming.NamingException;
-
-import com.clustercontrol.commons.scheduler.TriggerScheduler;
+import com.clustercontrol.fault.InvalidRole;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.factory.AddMonitor;
 import com.clustercontrol.monitor.run.factory.AddMonitorNumericValueType;
+import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
+import com.clustercontrol.plugin.impl.SchedulerPlugin.TriggerType;
 import com.clustercontrol.port.bean.PortCheckInfo;
-import com.clustercontrol.port.ejb.entity.MonitorPortInfoUtil;
+import com.clustercontrol.port.model.MonitorPortInfoEntity;
+import com.clustercontrol.port.model.MonitorProtocolMstEntity;
+import com.clustercontrol.port.util.QueryUtil;
 
 /**
  * port監視情報登録クラス
@@ -36,18 +38,24 @@ public class AddMonitorPort extends AddMonitorNumericValueType{
 	 * @see com.clustercontrol.monitor.run.factory.AddMonitor#addCheckInfo()
 	 */
 	@Override
-	protected boolean addCheckInfo() throws CreateException, NamingException{
+	protected boolean addCheckInfo() throws MonitorNotFound, InvalidRole {
+
+		MonitorInfoEntity monitorEntity
+		= com.clustercontrol.monitor.run.util.QueryUtil.getMonitorInfoPK(m_monitorInfo.getMonitorId());
+
+		PortCheckInfo port = m_monitorInfo.getPortCheckInfo();
+		MonitorProtocolMstEntity monitorProtocolMstEntity = null;
+		try {
+			monitorProtocolMstEntity = QueryUtil.getMonitorProtocolMstPK(port.getServiceId());
+		} catch (MonitorNotFound e) {
+		}
 
 		// port監視情報を設定
-		PortCheckInfo port = m_monitorInfo.getPortCheckInfo();
-
-		MonitorPortInfoUtil.getLocalHome().create(
-				m_monitorInfo.getMonitorId(),
-				port.getPortNo(),
-				port.getRunCount(),
-				port.getRunInterval(),
-				port.getTimeout(),
-				port.getServiceId());
+		MonitorPortInfoEntity entity = new MonitorPortInfoEntity(monitorEntity, monitorProtocolMstEntity);
+		entity.setPortNumber(port.getPortNo());
+		entity.setRunCount(port.getRunCount());
+		entity.setRunInterval(port.getRunInterval());
+		entity.setTimeout(port.getTimeout());
 		return true;
 	}
 
@@ -63,7 +71,7 @@ public class AddMonitorPort extends AddMonitorNumericValueType{
 	 * スケジュール実行種別を返します。
 	 */
 	@Override
-	protected String getTriggerType() {
-		return TriggerScheduler.TRIGGER_TYPE_SIMPLE;
+	protected TriggerType getTriggerType() {
+		return TriggerType.SIMPLE;
 	}
 }
