@@ -15,16 +15,16 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.port.factory;
 
-import javax.ejb.CreateException;
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
-import com.clustercontrol.commons.scheduler.TriggerScheduler;
+import com.clustercontrol.fault.InvalidRole;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.factory.AddMonitor;
 import com.clustercontrol.monitor.run.factory.ModifyMonitorNumericValueType;
+import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
+import com.clustercontrol.plugin.impl.SchedulerPlugin.TriggerType;
 import com.clustercontrol.port.bean.PortCheckInfo;
-import com.clustercontrol.port.ejb.entity.MonitorPortInfoLocal;
-import com.clustercontrol.port.ejb.entity.MonitorPortInfoUtil;
+import com.clustercontrol.port.model.MonitorPortInfoEntity;
+import com.clustercontrol.port.model.MonitorProtocolMstEntity;
+import com.clustercontrol.port.util.QueryUtil;
 
 /**
  * port監視情報更新クラス
@@ -38,18 +38,27 @@ public class ModifyMonitorPort extends ModifyMonitorNumericValueType{
 	 * @see com.clustercontrol.monitor.run.factory.ModifyMonitor#modifyCheckInfo()
 	 */
 	@Override
-	protected boolean modifyCheckInfo() throws CreateException, FinderException, NamingException {
+	protected boolean modifyCheckInfo() throws MonitorNotFound, InvalidRole {
+
+		MonitorInfoEntity monitorEntity
+		= com.clustercontrol.monitor.run.util.QueryUtil.getMonitorInfoPK(m_monitorInfo.getMonitorId());
 
 		// port監視情報を取得
-		MonitorPortInfoLocal portLocal = MonitorPortInfoUtil.getLocalHome().findByPrimaryKey(m_monitorInfo.getMonitorId());
+		MonitorPortInfoEntity entity = QueryUtil.getMonitorPortInfoPK(m_monitorInfo.getMonitorId());
 
 		// port監視情報を設定
 		PortCheckInfo port = m_monitorInfo.getPortCheckInfo();
-		portLocal.setPortNo(port.getPortNo());  //ポート番号
-		portLocal.setRunCount(port.getRunCount());
-		portLocal.setRunInterval(port.getRunInterval());
-		portLocal.setTimeout(port.getTimeout());
-		portLocal.setServiceId(port.getServiceId());
+		entity.setPortNumber(port.getPortNo());  //ポート番号
+		entity.setRunCount(port.getRunCount());
+		entity.setRunInterval(port.getRunInterval());
+		entity.setTimeout(port.getTimeout());
+		MonitorProtocolMstEntity monitorProtocolMstEntity = null;
+		try {
+			monitorProtocolMstEntity = QueryUtil.getMonitorProtocolMstPK(port.getServiceId());
+		} catch (MonitorNotFound e) {
+		}
+		entity.relateToMonitorProtocolMstEntity(monitorProtocolMstEntity);
+		monitorEntity.setMonitorPortInfoEntity(entity);
 
 		return true;
 	}
@@ -66,7 +75,7 @@ public class ModifyMonitorPort extends ModifyMonitorNumericValueType{
 	 * スケジュール実行種別を返します。
 	 */
 	@Override
-	protected String getTriggerType() {
-		return TriggerScheduler.TRIGGER_TYPE_SIMPLE;
+	protected TriggerType getTriggerType() {
+		return TriggerType.SIMPLE;
 	}
 }
