@@ -39,6 +39,7 @@ import com.clustercontrol.monitor.run.factory.RunMonitor;
 import com.clustercontrol.monitor.run.factory.RunMonitorNumericValueType;
 import com.clustercontrol.plugin.impl.SharedTablePlugin;
 import com.clustercontrol.poller.NotInitializedException;
+import com.clustercontrol.poller.PollingController;
 import com.clustercontrol.poller.bean.PollerProtocolConstant;
 import com.clustercontrol.process.entity.MonitorProcessPollingMstData;
 import com.clustercontrol.process.entity.MonitorProcessPollingMstPK;
@@ -779,4 +780,22 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 
 		return ret;
 	}
+
+	@Override
+	public int getCheckResult(boolean arg) {
+		// FIXME 5.1では下記の機構は不要になるよう設計変更をすること
+		// （センシティブな修正なので、細かくコメントを記載します）
+		//
+		// 基本的には規程クラスの RunMonitorNumericValueType.getCheckResult() の値を返すが、
+		// 不明の場合に限っては、ノードの管理対象フラグの直近の状態を見て、監視結果をキャンセルする（通知しない）。
+		// （ポーリング時点(00秒)では管理対象フラグがOFFで、集計時点(30秒)で管理対象フラグがONになった場合の対策）
+		int retVal = super.getCheckResult(arg);
+		if (retVal == PriorityConstant.TYPE_UNKNOWN) {
+			if (PollingController.skipProcessMonitorNotifyByNodeFlagHistory(m_nodeId, m_runInterval) == true) {
+				// ログ監視などで、フィルタにひっかからなかった場合には本関数が-2を返すことを利用し、強制的に-2を返却する
+				retVal = -2;
+			}
+		}
+		return retVal;
+	}
 }
