@@ -25,7 +25,7 @@ import com.clustercontrol.util.Messages;
 
 /**
  * 割り当てスコープビューのテーブル定義を取得するクライアント側アクションクラス<BR>
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -34,6 +34,9 @@ public class GetNodeScopeTableDefine {
 	/** スコープ */
 	public static final int SCOPE = 0;
 
+	/** ダミー**/
+	public static final int DUMMY = 1;
+
 	/** 初期表示時ソートカラム */
 	public static final int SORT_COLUMN_INDEX = SCOPE;
 
@@ -45,7 +48,7 @@ public class GetNodeScopeTableDefine {
 
 	/**
 	 * 全てのノード一覧を取得します。<BR>
-	 * 
+	 *
 	 * @return ノード一覧
 	 */
 	public static ArrayList<TableColumnInfo> get() {
@@ -56,7 +59,9 @@ public class GetNodeScopeTableDefine {
 		/** メイン処理 */
 		tableDefine.add(SCOPE,
 				new TableColumnInfo(Messages.getString("scope", locale), TableColumnInfo.NONE, 300, SWT.LEFT));
+		tableDefine.add(DUMMY,
+				new TableColumnInfo("", TableColumnInfo.DUMMY, 200, SWT.LEFT));
 
 		return tableDefine;
 	}
-}
\ No newline at end of file
+}
