@@ -17,6 +17,8 @@ package com.clustercontrol.repository.composite;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
 
 import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.SelectionChangedEvent;
@@ -30,7 +32,9 @@ import org.eclipse.ui.IWorkbench;
 import org.eclipse.ui.IWorkbenchPage;
 
 import com.clustercontrol.ClusterControlPlugin;
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.Property;
+import com.clustercontrol.jobmanagement.util.JobPropertyUtil;
 import com.clustercontrol.repository.action.GetNodeList;
 import com.clustercontrol.repository.action.GetNodeListTableDefine;
 import com.clustercontrol.repository.composite.action.NodeDoubleClickListener;
@@ -42,7 +46,7 @@ import com.clustercontrol.ws.repository.NodeInfo;
 
 /**
  * ノード一覧コンポジットクラス<BR>
- * 
+ *
  * @version 1.0.0
  * @since 1.0.0
  */
@@ -66,7 +70,7 @@ public class NodeListComposite extends Composite {
 
 	/**
 	 * インスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のコンポジット
 	 * @param style
@@ -90,14 +94,16 @@ public class NodeListComposite extends Composite {
 		layout.marginWidth = 0;
 
 		this.statuslabel = new Label(this, SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "statuslabel", statuslabel);
 		this.statuslabel.setText("");
 		GridData gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
 		this.statuslabel.setLayoutData(gridData);
 
-		Table table = new Table(this, SWT.SINGLE | SWT.H_SCROLL | SWT.V_SCROLL
+		Table table = new Table(this, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL
 				| SWT.FULL_SELECTION);
+		WidgetTestUtil.setTestId( this, null, table );
 		table.setHeaderVisible(true);
 		table.setLinesVisible(true);
 
@@ -111,9 +117,13 @@ public class NodeListComposite extends Composite {
 		// テーブルビューアの作成
 		this.tableViewer = new CommonTableViewer(table);
 		this.tableViewer.createTableColumn(GetNodeListTableDefine.get(),
-				GetNodeListTableDefine.SORT_COLUMN_INDEX,
+				GetNodeListTableDefine.SORT_COLUMN_INDEX1,
+				GetNodeListTableDefine.SORT_COLUMN_INDEX2,
 				GetNodeListTableDefine.SORT_ORDER);
 
+		for (int i = 0; i < table.getColumnCount(); i++){
+			table.getColumn(i).setMoveable(true);
+		}
 		this.tableViewer
 		.addSelectionChangedListener(new ISelectionChangedListener() {
 			@Override
@@ -142,6 +152,7 @@ public class NodeListComposite extends Composite {
 		this.tableViewer.addDoubleClickListener(new NodeDoubleClickListener(this));
 
 		this.totalLabel = new Label(this, SWT.RIGHT);
+		WidgetTestUtil.setTestId(this, "totallabel", totalLabel);
 		gridData = new GridData();
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.verticalAlignment = GridData.FILL;
@@ -151,7 +162,7 @@ public class NodeListComposite extends Composite {
 
 	/**
 	 * tableViewerを返します。
-	 * 
+	 *
 	 * @return tableViewer
 	 */
 	public CommonTableViewer getTableViewer() {
@@ -160,7 +171,7 @@ public class NodeListComposite extends Composite {
 
 	/**
 	 * このコンポジットが利用するテーブルを返します。
-	 * 
+	 *
 	 * @return テーブル
 	 */
 	public Table getTable() {
@@ -170,47 +181,67 @@ public class NodeListComposite extends Composite {
 	/**
 	 * コンポジットを更新します。
 	 * <p>
-	 * 
+	 *
 	 * 検索条件が事前に設定されている場合、その条件にヒットするノードの一覧を 表示します <br>
 	 * 検索条件が設定されていない場合は、全ノードを表示します。
 	 */
 	@Override
 	public void update() {
 		// データ取得
-		List<NodeInfo> list = null;
+		Map<String, List<NodeInfo>> dispDataMap = null;
+		ArrayList<Object> listInput = new ArrayList<Object>();
+
 		if (this.condition == null) {
 			this.statuslabel.setText("");
-			list = new GetNodeList().getAll();
+			dispDataMap = new GetNodeList().getAll();
 		} else {
 			this.statuslabel.setText(Messages.getString("filtered.list"));
-			list = new GetNodeList().get(this.condition);
-		}
 
-		if(list == null){
-			list = new ArrayList<NodeInfo>();
-		}
+			String conditionManager = null;
+			if(this.condition != null) {
+				conditionManager = JobPropertyUtil.getManagerName(this.condition);
+			}
 
-		ArrayList<Object> listInput = new ArrayList<Object>();
-		for (NodeInfo node : list) {
-			ArrayList<Object> a = new ArrayList<Object>();
-			a.add(node.getFacilityId());
-			a.add(node.getFacilityName());
-			a.add(node.getPlatformFamily());
-			if (node.getIpAddressVersion() == 6) {
-				a.add(node.getIpAddressV6());
+			if(conditionManager == null || conditionManager.equals("")) {
+				dispDataMap = new GetNodeList().get(this.condition);
 			} else {
-				a.add(node.getIpAddressV4());
+				List<NodeInfo> list = new GetNodeList().get(conditionManager, this.condition);
+				dispDataMap = new ConcurrentHashMap<String, List<NodeInfo>>();
+				dispDataMap.put(conditionManager, list);
 			}
-			a.add(node.getDescription());
-			a.add(node.getOwnerRoleId());
-			listInput.add(a);
 		}
 
+		int cnt = 0;
+		for(Map.Entry<String, List<NodeInfo>> entrySet : dispDataMap.entrySet()) {
+			List<NodeInfo> list = entrySet.getValue();
+
+			if(list == null){
+				list = new ArrayList<NodeInfo>();
+			}
+
+			for (NodeInfo node : list) {
+				ArrayList<Object> a = new ArrayList<Object>();
+				a.add(entrySet.getKey());
+				a.add(node.getFacilityId());
+				a.add(node.getFacilityName());
+				a.add(node.getPlatformFamily());
+				if (node.getIpAddressVersion() == 6) {
+					a.add(new Ip(node.getIpAddressV6(), 6));
+				} else {
+					a.add(new Ip(node.getIpAddressV4(), 4));
+				}
+				a.add(node.getDescription());
+				a.add(node.getOwnerRoleId());
+				a.add(null);
+				listInput.add(a);
+				cnt++;
+			}
+		}
 		// テーブル更新
 		this.tableViewer.setInput(listInput);
 
 		// 合計欄更新
-		String[] args = { String.valueOf(list.size()) };
+		String[] args = { new Integer(cnt).toString() };
 		String message = null;
 		if (this.condition == null) {
 			message = Messages.getString("records", args);
@@ -220,12 +251,65 @@ public class NodeListComposite extends Composite {
 		this.totalLabel.setText(message);
 	}
 
+	private class Ip implements Comparable<Ip>{
+		int version = 6;
+		String ip = "";
+		private Ip (String ip, int version) {
+			if (version == 4) {
+				this.version = 4;
+			}
+			this.ip = ip;
+		}
+		
+		@Override
+		public int compareTo(Ip o) {
+			
+			if (this.version != o.version) {
+				return this.version - o.version;
+			}
+			if (this.version == 4 && o.version == 4) {
+				long v1 = 0;
+				for (String octet : this.ip.split("\\.")){
+					v1 *= 256;
+					try {
+						int i = Integer.parseInt(octet);
+						v1 += i;
+					} catch (Exception e) {
+					}
+				}
+				long v2 = 0;
+				for (String octet : o.ip.split("\\.")){
+					v2 *= 256;
+					try {
+						v2 += Integer.parseInt(octet);
+					} catch (Exception e) {
+					}
+				}
+				long diff = v1 - v2;
+				if (diff > 0) {
+					return 1;
+				} else if (diff < 0) {
+					return -1;
+				} else {
+					return 0;
+				}
+			}
+			
+			return this.ip.compareTo(o.ip);
+		}
+		
+		@Override
+		public String toString() {
+			return ip;
+		}
+	}
+	
 	/**
 	 * 検索条件にヒットしたノードの一覧を表示します。
 	 * <p>
-	 * 
+	 *
 	 * conditionがnullの場合、全ノードを表示します。
-	 * 
+	 *
 	 * @param condition
 	 *            検索条件
 	 */
@@ -234,4 +318,4 @@ public class NodeListComposite extends Composite {
 
 		this.update();
 	}
-}
\ No newline at end of file
+}
