@@ -15,24 +15,23 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.repository.etc.action;
 
-import org.eclipse.jface.action.IAction;
-import org.eclipse.jface.viewers.ISelection;
+import org.eclipse.core.commands.AbstractHandler;
+import org.eclipse.core.commands.ExecutionEvent;
+import org.eclipse.core.commands.ExecutionException;
 import org.eclipse.ui.IViewPart;
 import org.eclipse.ui.IWorkbenchPage;
-import org.eclipse.ui.IWorkbenchWindow;
-import org.eclipse.ui.IWorkbenchWindowActionDelegate;
 import org.eclipse.ui.PartInitException;
-import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.handlers.HandlerUtil;
 
 import com.clustercontrol.repository.view.AgentListView;
 
 /**
  * リポジトリ[エージェント]ビューを表示するクライアント側アクションクラス<BR>
  * 
- * @version 4.0.0
+ * @version 5.0.0
  * @since 4.0.0
  */
-public class AgentListAction implements IWorkbenchWindowActionDelegate {
+public class AgentListAction extends AbstractHandler {
 
 	/**
 	 * @see org.eclipse.ui.IWorkbenchWindowActionDelegate#dispose()
@@ -42,22 +41,10 @@ public class AgentListAction implements IWorkbenchWindowActionDelegate {
 
 	}
 
-	/**
-	 * @see org.eclipse.ui.IWorkbenchWindowActionDelegate#init(org.eclipse.ui.IWorkbenchWindow)
-	 */
 	@Override
-	public void init(IWorkbenchWindow window) {
-
-	}
-
-	/**
-	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
-	 */
-	@Override
-	public void run(IAction action) {
+	public Object execute(ExecutionEvent event) throws ExecutionException {
 		//アクティブページを手に入れる
-		IWorkbenchPage page = PlatformUI.getWorkbench()
-				.getActiveWorkbenchWindow().getActivePage();
+		IWorkbenchPage page = HandlerUtil.getActiveWorkbenchWindow( event ).getActivePage();
 
 		//ビューを表示する
 		try {
@@ -66,13 +53,6 @@ public class AgentListAction implements IWorkbenchWindowActionDelegate {
 			view.setFocus();
 		} catch (PartInitException e) {
 		}
+		return null;
 	}
-
-	/**
-	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
-	 *      org.eclipse.jface.viewers.ISelection)
-	 */
-	@Override
-	public void selectionChanged(IAction action, ISelection selection) {
-	}
-}
\ No newline at end of file
+}
