@@ -229,6 +229,42 @@ public class FacilityModifier {
 		m_log.info("addScope() successful in adding a scope . (parentFacilityId = " + parentFacilityId + ", facilityId = " + facilityId + ")");
 	}
 
+	/**
+	 * オーナーロールスコープを変更する。<BR>
+	 * 
+	 * @param property 変更後のスコープ情報
+	 * @param modifyUserId 作業ユーザID
+	 * @param topicSendFlg 更新を周知する場合はtrue, 周知しない場合はfalse
+	 * @throws FacilityNotFound
+	 * @throws InvalidRole
+	 */
+	public static void modifyOwnerRoleScope(ScopeInfo property, String modifyUserId, boolean topicSendFlg)
+			throws FacilityNotFound, InvalidRole {
+
+		/** ローカル変数 */
+		FacilityEntity facility = null;
+		String facilityId = null;
+
+		/** メイン処理 */
+		m_log.debug("modifing an owner role scope...");
+
+		// 入力値（ファシリティID）の格納
+		facilityId = property.getFacilityId();
+
+		// ファシリティインスタンスを取得（オブジェクト権限のチェックなし）
+		facility = QueryUtil.getFacilityPK_NONE(facilityId);
+
+		// ファシリティがスコープかどうかを確認する
+		if (!FacilityUtil.isScope(facility)) {
+			FacilityNotFound e = new FacilityNotFound("this facility is not a scope. (facilityId = " + facilityId + ")");
+			m_log.info("modifyOwnerRoleScope() : " + e.getClass().getSimpleName() + ", " + e.getMessage());
+			throw e;
+		}
+		// 変更後の値を格納する
+		setFacilityEntityProperties(facility, property, modifyUserId, false);
+		m_log.info("modifyOwnerRoleScope() successful in modifing a scope. (facilityId = " + facilityId + ")");
+	}
+
 	/**
 	 * スコープを変更する。<BR>
 	 *
