@@ -1,8 +1,13 @@
 package com.clustercontrol.repository.model;
 
 import java.io.Serializable;
-import javax.persistence.*;
 
+import javax.persistence.Cacheable;
+import javax.persistence.EmbeddedId;
+import javax.persistence.Entity;
+import javax.persistence.Table;
+
+import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 
 
@@ -11,7 +16,7 @@ import com.clustercontrol.commons.util.JpaTransactionManager;
  * 
  */
 @Entity
-@Table(name="cc_cfg_facility_relation")
+@Table(name="cc_cfg_facility_relation", schema="setting")
 @Cacheable(true)
 public class FacilityRelationEntity implements Serializable {
 	private static final long serialVersionUID = 1L;
@@ -23,7 +28,7 @@ public class FacilityRelationEntity implements Serializable {
 
 	public FacilityRelationEntity(FacilityRelationEntityPK pk) {
 		this.setId(pk);
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		em.persist(this);
 	}
 
