@@ -1,33 +1,49 @@
 package com.clustercontrol.repository.model;
 
 import java.io.Serializable;
-import javax.persistence.*;
-
-import com.clustercontrol.commons.util.JpaTransactionManager;
-
 import java.util.Iterator;
 import java.util.List;
 
+import javax.persistence.Cacheable;
+import javax.persistence.CascadeType;
+import javax.persistence.Column;
+import javax.persistence.Entity;
+import javax.persistence.FetchType;
+import javax.persistence.Id;
+import javax.persistence.OneToMany;
+import javax.persistence.OneToOne;
+import javax.persistence.PrimaryKeyJoinColumn;
+import javax.persistence.Table;
+import javax.persistence.Transient;
+
+import com.clustercontrol.bean.SnmpProtocolConstant;
+import com.clustercontrol.bean.SnmpSecurityLevelConstant;
+import com.clustercontrol.bean.ValidConstant;
+import com.clustercontrol.commons.util.CryptUtil;
+import com.clustercontrol.commons.util.HinemosEntityManager;
+import com.clustercontrol.commons.util.JpaTransactionManager;
+
+
 
 /**
  * The persistent class for the cc_cfg_node database table.
- * 
+ *
  */
 @Entity
-@Table(name="cc_cfg_node")
+@Table(name="cc_cfg_node", schema="setting")
 @Cacheable(true)
 public class NodeEntity implements Serializable {
 	private static final long serialVersionUID = 1L;
 	private String facilityId;
+	private Integer autoDeviceSearch		= ValidConstant.TYPE_VALID;
 	private String administrator			= "";
 	private String characterSet				= "";
-	private String cloudNodeType			= "";
 	private String cloudService				= "";
-	private String cloudAccountResouce		= "";
+	private String cloudScope				= "";
 	private String cloudResourceType		= "";
 	private String cloudResourceId			= "";
-	private String cloudRegion				= "";
-	private String cloudZone				= "";
+	private String cloudResourceName		= "";
+	private String cloudLocation			= "";
 	private String contact					= "";
 	private String hardwareType				= "";
 	private String ipAddressV4				= "";
@@ -44,8 +60,6 @@ public class NodeEntity implements Serializable {
 	private Integer jobPriority				= 16;
 	private Integer jobMultiplicity			= 0;
 	private String nodeName					= "";
-	private String openflowCtrlIpAddress	= "";
-	private String openflowDataPathId		= "";
 	private String osName					= "";
 	private String osRelease				= "";
 	private String osVersion				= "";
@@ -55,16 +69,19 @@ public class NodeEntity implements Serializable {
 	private Integer snmpRetryCount			= 3;
 	private Integer snmpTimeout				= 5000;
 	private String snmpVersion				= "2c";
+	private String snmpSecurityLevel			= SnmpSecurityLevelConstant.NOAUTH_NOPRIV;
+	private String snmpUser					= "";
+	private String snmpAuthPassword			= "";
+	private String snmpPrivPassword			= "";
+	private String snmpAuthProtocol			= SnmpProtocolConstant.MD5;
+	private String snmpPrivProtocol			= SnmpProtocolConstant.DES;
+	private String sshUser 					= "root";
+	private String sshUserPassword				= "";
+	private String sshPrivateKeyFilepath		= "";
+	private String sshPrivateKeyPassphrase		= "";
+	private Integer sshPort					= 22;
+	private Integer sshTimeout					= 50000;
 	private String subPlatformFamily		= "";
-	private String vmId						= "";
-	private String vmManagementNode			= "";
-	private String vmName					= "";
-	private String vmNodeType				= "";
-	private String vmProtocol				= "";
-	private String vmUser					= "";
-	private String vmUserPassword			= "";
-	private String vnetHostNode				= "";
-	private String vnetSwitchType			= "";
 	private Integer wbemPort				= 5988;
 	private String wbemProtocol				= "http";
 	private Integer wbemRetryCount			= 3;
@@ -96,7 +113,7 @@ public class NodeEntity implements Serializable {
 
 	public NodeEntity(FacilityEntity facilityEntity) {
 		this.setFacilityId(facilityEntity.getFacilityId());
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		em.persist(this);
 		this.relateToFacilityEntity(facilityEntity);
 	}
@@ -122,6 +139,15 @@ public class NodeEntity implements Serializable {
 	}
 
 
+	@Column(name="auto_device_search")
+	public Integer getAutoDeviceSearch() {
+		return this.autoDeviceSearch;
+	}
+
+	public void setAutoDeviceSearch(Integer autoDeviceSearch) {
+		this.autoDeviceSearch = autoDeviceSearch;
+	}
+
 	@Column(name="character_set")
 	public String getCharacterSet() {
 		return this.characterSet;
@@ -132,16 +158,6 @@ public class NodeEntity implements Serializable {
 	}
 
 
-	@Column(name="cloud_node_type")
-	public String getCloudNodeType() {
-		return this.cloudNodeType;
-	}
-
-	public void setCloudNodeType(String cloudNodeType) {
-		this.cloudNodeType = cloudNodeType;
-	}
-
-
 	@Column(name="cloud_service")
 	public String getCloudService() {
 		return this.cloudService;
@@ -152,13 +168,13 @@ public class NodeEntity implements Serializable {
 	}
 
 
-	@Column(name="cloud_account_resource")
-	public String getCloudAccountResouce() {
-		return this.cloudAccountResouce;
+	@Column(name="cloud_scope")
+	public String getCloudScope() {
+		return this.cloudScope;
 	}
 
-	public void setCloudAccountResouce(String cloudAccountResouce) {
-		this.cloudAccountResouce = cloudAccountResouce;
+	public void setCloudScope(String cloudScope) {
+		this.cloudScope = cloudScope;
 	}
 
 
@@ -180,25 +196,24 @@ public class NodeEntity implements Serializable {
 	public void setCloudResourceId(String cloudResourceId) {
 		this.cloudResourceId = cloudResourceId;
 	}
-
-
-	@Column(name="cloud_region")
-	public String getCloudRegion() {
-		return this.cloudRegion;
+	
+	@Column(name="cloud_resource_name")
+	public String getCloudResourceName() {
+		return this.cloudResourceName;
 	}
-
-	public void setCloudRegion(String cloudRegion) {
-		this.cloudRegion = cloudRegion;
+	
+	public void setCloudResourceName(String cloudResourceName) {
+		this.cloudResourceName = cloudResourceName;
 	}
 
 
-	@Column(name="cloud_zone")
-	public String getCloudZone() {
-		return this.cloudZone;
+	@Column(name="cloud_location")
+	public String getCloudLocation() {
+		return this.cloudLocation;
 	}
 
-	public void setCloudZone(String cloudZone) {
-		this.cloudZone = cloudZone;
+	public void setCloudLocation(String cloudLocation) {
+		this.cloudLocation = cloudLocation;
 	}
 
 
@@ -339,13 +354,22 @@ public class NodeEntity implements Serializable {
 		this.ipmiUser = ipmiUser;
 	}
 
-
-	@Column(name="ipmi_user_password")
+	@Transient
 	public String getIpmiUserPassword() {
-		return this.ipmiUserPassword;
+		return CryptUtil.decrypt(getIpmiUserPasswordCrypt());
 	}
 
 	public void setIpmiUserPassword(String ipmiUserPassword) {
+		setIpmiUserPasswordCrypt(CryptUtil.encrypt(ipmiUserPassword));
+	}
+
+	
+	@Column(name="ipmi_user_password")
+	public String getIpmiUserPasswordCrypt() {
+		return this.ipmiUserPassword;
+	}
+
+	public void setIpmiUserPasswordCrypt(String ipmiUserPassword) {
 		this.ipmiUserPassword = ipmiUserPassword;
 	}
 
@@ -359,27 +383,6 @@ public class NodeEntity implements Serializable {
 		this.nodeName = nodeName;
 	}
 
-
-	@Column(name="openflow_ctrl_ip_address")
-	public String getOpenflowCtrlIpAddress() {
-		return this.openflowCtrlIpAddress;
-	}
-
-	public void setOpenflowCtrlIpAddress(String openflowCtrlIpAddress) {
-		this.openflowCtrlIpAddress = openflowCtrlIpAddress;
-	}
-
-
-	@Column(name="openflow_data_path_id")
-	public String getOpenflowDataPathId() {
-		return this.openflowDataPathId;
-	}
-
-	public void setOpenflowDataPathId(String openflowDataPathId) {
-		this.openflowDataPathId = openflowDataPathId;
-	}
-
-
 	@Column(name="os_name")
 	public String getOsName() {
 		return this.osName;
@@ -470,6 +473,155 @@ public class NodeEntity implements Serializable {
 	}
 
 
+	@Column(name="snmp_security_level")
+	public String getSnmpSecurityLevel() {
+		return this.snmpSecurityLevel;
+	}
+
+	public void setSnmpSecurityLevel(String snmpSecurityLevel) {
+		this.snmpSecurityLevel = snmpSecurityLevel;
+	}
+
+
+	@Column(name="snmp_user")
+	public String getSnmpUser() {
+		return this.snmpUser;
+	}
+
+	public void setSnmpUser(String snmpUser) {
+		this.snmpUser = snmpUser;
+	}
+
+	@Transient
+	public String getSnmpAuthPassword() {
+		return CryptUtil.decrypt(getSnmpAuthPasswordCrypt());
+	}
+
+	public void setSnmpAuthPassword(String snmpAuthPassword) {
+		setSnmpAuthPasswordCrypt(CryptUtil.encrypt(snmpAuthPassword));
+	}
+
+	@Column(name="snmp_auth_password")
+	public String getSnmpAuthPasswordCrypt() {
+		return this.snmpAuthPassword;
+	}
+
+	public void setSnmpAuthPasswordCrypt(String snmpAuthPassword) {
+		this.snmpAuthPassword = snmpAuthPassword;
+	}
+
+
+	@Transient
+	public String getSnmpPrivPassword() {
+		return CryptUtil.decrypt(getSnmpPrivPasswordCrypt());
+	}
+
+	public void setSnmpPrivPassword(String snmpPrivPassword) {
+		setSnmpPrivPasswordCrypt(CryptUtil.encrypt(snmpPrivPassword));
+	}
+
+
+	@Column(name="snmp_priv_password")
+	public String getSnmpPrivPasswordCrypt() {
+		return this.snmpPrivPassword;
+	}
+
+	public void setSnmpPrivPasswordCrypt(String snmpPrivPassword) {
+		this.snmpPrivPassword = snmpPrivPassword;
+	}
+
+
+	@Column(name="snmp_auth_protocol")
+	public String getSnmpAuthProtocol() {
+		return this.snmpAuthProtocol;
+	}
+
+	public void setSnmpAuthProtocol(String snmpAuthProtocol) {
+		this.snmpAuthProtocol = snmpAuthProtocol;
+	}
+
+
+	@Column(name="snmp_priv_protocol")
+	public String getSnmpPrivProtocol() {
+		return this.snmpPrivProtocol;
+	}
+
+	public void setSnmpPrivProtocol(String snmpPrivProtocol) {
+		this.snmpPrivProtocol = snmpPrivProtocol;
+	}
+
+	@Column(name="ssh_user")
+	public String getSshUser() {
+		return this.sshUser;
+	}
+	
+	public void setSshUser(String sshUser) {
+		this.sshUser = sshUser;
+	}
+	
+	@Transient
+	public String getSshUserPassword() {
+		return CryptUtil.decrypt(getSshUserPasswordCrypt());
+	}
+	
+	public void setSshUserPassword(String sshUserPassword) {
+		setSshUserPasswordCrypt(CryptUtil.encrypt(sshUserPassword));
+	}
+
+	@Column(name="ssh_user_password")
+	public String getSshUserPasswordCrypt() {
+		return this.sshUserPassword;
+	}
+	
+	public void setSshUserPasswordCrypt(String sshUserPassword) {
+		this.sshUserPassword = sshUserPassword;
+	}
+	
+	@Column(name="ssh_private_key_filepath")
+	public String getSshPrivateKeyFilepath() {
+		return this.sshPrivateKeyFilepath;
+	}
+	
+	public void setSshPrivateKeyFilepath(String sshPrivateKeyFilepath) {
+		this.sshPrivateKeyFilepath = sshPrivateKeyFilepath;
+	}
+
+	@Transient
+	public String getSshPrivateKeyPassphrase() {
+		return CryptUtil.decrypt(getSshPrivateKeyPassphraseCrypt());
+	}
+	
+	public void setSshPrivateKeyPassphrase(String sshPrivateKeyPassphrase) {
+		setSshPrivateKeyPassphraseCrypt(CryptUtil.encrypt(sshPrivateKeyPassphrase));
+	}
+	
+	@Column(name="ssh_private_key_passphrase")
+	public String getSshPrivateKeyPassphraseCrypt() {
+		return this.sshPrivateKeyPassphrase;
+	}
+	
+	public void setSshPrivateKeyPassphraseCrypt(String sshPrivateKeyPassphrase) {
+		this.sshPrivateKeyPassphrase = sshPrivateKeyPassphrase;
+	}
+	
+	@Column(name="ssh_port")
+	public Integer getSshPort() {
+		return this.sshPort;
+	}
+	
+	public void setSshPort(Integer sshPort) {
+		this.sshPort = sshPort;
+	}
+	
+	@Column(name="ssh_timeout")
+	public Integer getSshTimeout() {
+		return this.sshTimeout;
+	}
+	
+	public void setSshTimeout(Integer sshTimeout) {
+		this.sshTimeout = sshTimeout;
+	}
+
 	@Column(name="sub_platform_family")
 	public String getSubPlatformFamily() {
 		return this.subPlatformFamily;
@@ -479,97 +631,6 @@ public class NodeEntity implements Serializable {
 		this.subPlatformFamily = subPlatformFamily;
 	}
 
-
-	@Column(name="vm_id")
-	public String getVmId() {
-		return this.vmId;
-	}
-
-	public void setVmId(String vmId) {
-		this.vmId = vmId;
-	}
-
-
-	@Column(name="vm_management_node")
-	public String getVmManagementNode() {
-		return this.vmManagementNode;
-	}
-
-	public void setVmManagementNode(String vmManagementNode) {
-		this.vmManagementNode = vmManagementNode;
-	}
-
-
-	@Column(name="vm_name")
-	public String getVmName() {
-		return this.vmName;
-	}
-
-	public void setVmName(String vmName) {
-		this.vmName = vmName;
-	}
-
-
-	@Column(name="vm_node_type")
-	public String getVmNodeType() {
-		return this.vmNodeType;
-	}
-
-	public void setVmNodeType(String vmNodeType) {
-		this.vmNodeType = vmNodeType;
-	}
-
-
-	@Column(name="vm_protocol")
-	public String getVmProtocol() {
-		return this.vmProtocol;
-	}
-
-	public void setVmProtocol(String vmProtocol) {
-		this.vmProtocol = vmProtocol;
-	}
-
-
-	@Column(name="vm_user")
-	public String getVmUser() {
-		return this.vmUser;
-	}
-
-	public void setVmUser(String vmUser) {
-		this.vmUser = vmUser;
-	}
-
-
-	@Column(name="vm_user_password")
-	public String getVmUserPassword() {
-		return this.vmUserPassword;
-	}
-
-	public void setVmUserPassword(String vmUserPassword) {
-		this.vmUserPassword = vmUserPassword;
-	}
-
-
-	@Column(name="vnet_host_node")
-	public String getVnetHostNode() {
-		return this.vnetHostNode;
-	}
-
-	public void setVnetHostNode(String vnetHostNode) {
-		this.vnetHostNode = vnetHostNode;
-	}
-
-
-	@Column(name="vnet_switch_type")
-	public String getVnetSwitchType() {
-		return this.vnetSwitchType;
-	}
-
-	public void setVnetSwitchType(String vnetSwitchType) {
-		this.vnetSwitchType = vnetSwitchType;
-	}
-
-
 	@Column(name="wbem_port")
 	public Integer getWbemPort() {
 		return this.wbemPort;
@@ -619,13 +680,21 @@ public class NodeEntity implements Serializable {
 		this.wbemUser = wbemUser;
 	}
 
-
-	@Column(name="wbem_user_password")
+	@Transient
 	public String getWbemUserPassword() {
-		return this.wbemUserPassword;
+		return CryptUtil.decrypt(getWbemUserPasswordCrypt());
 	}
 
 	public void setWbemUserPassword(String wbemUserPassword) {
+		setWbemUserPasswordCrypt(CryptUtil.encrypt(wbemUserPassword));
+	}
+
+	@Column(name="wbem_user_password")
+	public String getWbemUserPasswordCrypt() {
+		return this.wbemUserPassword;
+	}
+
+	public void setWbemUserPasswordCrypt(String wbemUserPassword) {
 		this.wbemUserPassword = wbemUserPassword;
 	}
 
@@ -679,13 +748,21 @@ public class NodeEntity implements Serializable {
 		this.winrmUser = winrmUser;
 	}
 
-
-	@Column(name="winrm_user_password")
+	@Transient
 	public String getWinrmUserPassword() {
-		return this.winrmUserPassword;
+		return CryptUtil.decrypt(getWinrmUserPasswordCrypt());
 	}
 
 	public void setWinrmUserPassword(String winrmUserPassword) {
+		setWinrmUserPasswordCrypt(CryptUtil.encrypt(winrmUserPassword));
+	}
+
+	@Column(name="winrm_user_password")
+	public String getWinrmUserPasswordCrypt() {
+		return this.winrmUserPassword;
+	}
+
+	public void setWinrmUserPasswordCrypt(String winrmUserPassword) {
 		this.winrmUserPassword = winrmUserPassword;
 	}
 
@@ -755,14 +832,14 @@ public class NodeEntity implements Serializable {
 
 	/**
 	 * NodeEntityオブジェクト参照設定<BR>
-	 * 
+	 *
 	 * NodeEntity設定時はSetterに代わりこちらを使用すること。
-	 * 
+	 *
 	 * JPAの仕様(JSR 220)では、データ更新に伴うrelationshipの管理はユーザに委ねられており、
 	 * INSERTやDELETE時に、そのオブジェクトに対する参照をメンテナンスする処理を実装する。
-	 * 
+	 *
 	 * JSR 220 3.2.3 Synchronization to the Database
-	 * 
+	 *
 	 * Bidirectional relationships between managed entities will be persisted
 	 * based on references held by the owning side of the relationship.
 	 * It is the developer’s responsibility to keep the in-memory references
@@ -844,12 +921,12 @@ public class NodeEntity implements Serializable {
 
 	/**
 	 * 削除前処理<BR>
-	 * 
+	 *
 	 * JPAの仕様(JSR 220)では、データ更新に伴うrelationshipの管理はユーザに委ねられており、
 	 * INSERTやDELETE時に、そのオブジェクトに対する参照をメンテナンスする処理を実装する。
-	 * 
+	 *
 	 * JSR 220 3.2.3 Synchronization to the Database
-	 * 
+	 *
 	 * Bidirectional relationships between managed entities will be persisted
 	 * based on references held by the owning side of the relationship.
 	 * It is the developer’s responsibility to keep the in-memory references
@@ -865,12 +942,12 @@ public class NodeEntity implements Serializable {
 	}
 	/**
 	 * NodeCpuEntity削除<BR>
-	 * 
+	 *
 	 * 指定されたPK以外の子Entityを削除する。
-	 * 
+	 *
 	 */
 	public void deleteNodeCpuEntities(List<NodeCpuEntityPK> notDelPkList) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<NodeCpuEntity> list = this.getNodeCpuEntities();
 		Iterator<NodeCpuEntity> iter = list.iterator();
 		while(iter.hasNext()) {
@@ -884,12 +961,12 @@ public class NodeEntity implements Serializable {
 
 	/**
 	 * NodeDeviceEntity削除<BR>
-	 * 
+	 *
 	 * 指定されたPK以外の子Entityを削除する。
-	 * 
+	 *
 	 */
 	public void deleteNodeDeviceEntities(List<NodeDeviceEntityPK> notDelPkList) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<NodeDeviceEntity> list = this.getNodeDeviceEntities();
 		Iterator<NodeDeviceEntity> iter = list.iterator();
 		while(iter.hasNext()) {
@@ -903,12 +980,12 @@ public class NodeEntity implements Serializable {
 
 	/**
 	 * NodeDiskEntity削除<BR>
-	 * 
+	 *
 	 * 指定されたPK以外の子Entityを削除する。
-	 * 
+	 *
 	 */
 	public void deleteNodeDiskEntities(List<NodeDiskEntityPK> notDelPkList) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<NodeDiskEntity> list = this.getNodeDiskEntities();
 		Iterator<NodeDiskEntity> iter = list.iterator();
 		while(iter.hasNext()) {
@@ -922,12 +999,12 @@ public class NodeEntity implements Serializable {
 
 	/**
 	 * NodeFilesystemEntity削除<BR>
-	 * 
+	 *
 	 * 指定されたPK以外の子Entityを削除する。
-	 * 
+	 *
 	 */
 	public void deleteNodeFilesystemEntities(List<NodeFilesystemEntityPK> notDelPkList) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<NodeFilesystemEntity> list = this.getNodeFilesystemEntities();
 		Iterator<NodeFilesystemEntity> iter = list.iterator();
 		while(iter.hasNext()) {
@@ -941,12 +1018,12 @@ public class NodeEntity implements Serializable {
 
 	/**
 	 * NodeHostnameEntity削除<BR>
-	 * 
+	 *
 	 * 指定されたPK以外の子Entityを削除する。
-	 * 
+	 *
 	 */
 	public void deleteNodeHostnameEntities(List<NodeHostnameEntityPK> notDelPkList) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<NodeHostnameEntity> list = this.getNodeHostnameEntities();
 		Iterator<NodeHostnameEntity> iter = list.iterator();
 		while(iter.hasNext()) {
@@ -960,12 +1037,12 @@ public class NodeEntity implements Serializable {
 
 	/**
 	 * NodeMemoryEntity削除<BR>
-	 * 
+	 *
 	 * 指定されたPK以外の子Entityを削除する。
-	 * 
+	 *
 	 */
 	public void deleteNodeMemoryEntities(List<NodeMemoryEntityPK> notDelPkList) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<NodeMemoryEntity> list = this.getNodeMemoryEntities();
 		Iterator<NodeMemoryEntity> iter = list.iterator();
 		while(iter.hasNext()) {
@@ -979,12 +1056,12 @@ public class NodeEntity implements Serializable {
 
 	/**
 	 * NodeNetworkInterfaceEntity削除<BR>
-	 * 
+	 *
 	 * 指定されたPK以外の子Entityを削除する。
-	 * 
+	 *
 	 */
 	public void deleteNodeNetworkInterfaceEntities(List<NodeNetworkInterfaceEntityPK> notDelPkList) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<NodeNetworkInterfaceEntity> list = this.getNodeNetworkInterfaceEntities();
 		Iterator<NodeNetworkInterfaceEntity> iter = list.iterator();
 		while(iter.hasNext()) {
@@ -998,12 +1075,12 @@ public class NodeEntity implements Serializable {
 
 	/**
 	 * NodeNoteEntity削除<BR>
-	 * 
+	 *
 	 * 指定されたPK以外の子Entityを削除する。
-	 * 
+	 *
 	 */
 	public void deleteNodeNoteEntities(List<NodeNoteEntityPK> notDelPkList) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<NodeNoteEntity> list = this.getNodeNoteEntities();
 		Iterator<NodeNoteEntity> iter = list.iterator();
 		while(iter.hasNext()) {
@@ -1017,12 +1094,12 @@ public class NodeEntity implements Serializable {
 
 	/**
 	 * NodeVariableEntity削除<BR>
-	 * 
+	 *
 	 * 指定されたPK以外の子Entityを削除する。
-	 * 
+	 *
 	 */
 	public void deleteNodeVariableEntities(List<NodeVariableEntityPK> notDelPkList) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<NodeVariableEntity> list = this.getNodeVariableEntities();
 		Iterator<NodeVariableEntity> iter = list.iterator();
 		while(iter.hasNext()) {
