@@ -81,6 +81,8 @@ import com.clustercontrol.repository.util.FacilityTreeCache;
 import com.clustercontrol.repository.util.FacilityTreeCacheRefreshCallback;
 import com.clustercontrol.repository.util.JobMultiplicityCacheKickCallback;
 import com.clustercontrol.repository.util.NodeCacheRemoveCallback;
+import com.clustercontrol.repository.util.NotifySkipControlCallback;
+import com.clustercontrol.repository.util.NotifySkipControlCallback.Mode;
 import com.clustercontrol.repository.util.QueryUtil;
 import com.clustercontrol.repository.util.RepositoryChangedNotificationCallback;
 import com.clustercontrol.repository.util.RepositoryListenerCallback;
@@ -1057,6 +1059,28 @@ public class RepositoryControllerBean {
 			jtm.addCallback(new FacilityIdCacheInitCallback());
 			jtm.addCallback(new FacilityTreeCacheRefreshCallback());
 			jtm.addCallback(new RepositoryChangedNotificationCallback());
+			
+			// FIXME 5.1では下記の機構は不要になるよう設計変更をすること（センシティブな修正なので、細かくコメントを記載します）
+			// 
+			// 管理対象フラグを毎分00秒～30秒の間にONにした場合に、意図せず不明が出てしまう修正の補足修正。
+			// メインの修正は、
+			// PollingController.run の PollingController.setLastPollingDisableTime 呼び出しや
+			// RunMonitorPerformance.collectList 内での PollingController.skipResourceMonitorByNodeFlagHistory 呼び出し、
+			// RunMonitorProcess.getCheckResult 内での PollingController.skipProcessMonitorByNodeFlagHistory 呼び出し
+			// によって実施されている。
+			// 
+			// しかし上記修正のみでは、マネージャ再起動時に管理対象フラグがOFFだったノードについて、再起動後に管理対象フラグを初めて
+			// ONにするタイミングが00～30秒だった場合に、リソース監視・プロセス監視で不明がでることを防げない。
+			// マネージャ再起動時に管理対象フラグがOFFだった場合、ポーラーそのものが動いていないため、
+			// PollingController.run の処理が動作しておらず、PollingController.setLastPollingDisableTime が呼ばれない。
+			// PollingController.setLastPollingDisableTimeが一度も呼ばれていない状態では、
+			// 最後にポーリングを行わなかった時刻が遥か過去（つまりポーリングがすでに行われている）という風に認識されてしまうため、
+			// 00～30秒の間に管理対象フラグをONにすると、直後の集計はデータがないため不明となり、かつ上記理由によりスキップされず通知されてしまう。
+			// そこで、管理対象フラグがOFFからONになったこの時点までポーリングがスキップされていたという情報をセットすることで、
+			// 上記のレアケースにおいても不明が出ないように修正を行っている。
+			if (info.isValid() == true && this.getNode(info.getFacilityId()).isValid() == false) {
+				jtm.addCallback(new NotifySkipControlCallback(info.getFacilityId(), Mode.CHANGE));
+			}
 
 			try {
 				ListenerReadWriteLock.readLock();
@@ -1116,10 +1140,15 @@ public class RepositoryControllerBean {
 
 			for (String facilityId : facilityIds) {
 				jtm.addCallback(new NodeCacheRemoveCallback(facilityId));
+				
+				// FIXME 5.1では下記の機構は不要になるよう設計変更をすること
+				// 詳細は modifyNode 参照。
+				jtm.addCallback(new NotifySkipControlCallback(facilityId, Mode.REMOVE));
 			}
 			jtm.addCallback(new FacilityIdCacheInitCallback());
 			jtm.addCallback(new FacilityTreeCacheRefreshCallback());
 			jtm.addCallback(new RepositoryChangedNotificationCallback());
+			
 
 			try {
 				ListenerReadWriteLock.readLock();
@@ -2594,20 +2623,19 @@ public class RepositoryControllerBean {
 			String errMsg = " ipAddress=" + nodeInfo.getIpAddressV4() + " "
 					+ nodeInfo.getIpAddressV6() + " facilityID="
 					+ nodeInfo.getFacilityId() + ",";
-			m_log.warn("addNodeWithoutRefresh() : " + errMsg + e.getClass().getSimpleName() + ", " + e.getMessage(), e);
+			m_log.warn("addNodeWithoutRefresh() : " + errMsg + e.getClass().getSimpleName() + ", " + e.getMessage());
 
 			jtm.rollback();
-			throw e;
+			throw new FacilityDuplicate(e.getMessage(), e);
 		} catch (InvalidSetting e) {
-			m_log.warn("addNodeWithoutRefresh() : "
-					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			jtm.rollback();
 			throw e;
 		} catch (FacilityNotFound e) {
-			m_log.warn("addNodeWithoutRefresh() : "
-					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			jtm.rollback();
 			throw new HinemosUnknown(e.getMessage(), e);
+		} catch (HinemosUnknown e) {
+			jtm.rollback();
+			throw e;
 		} catch (Exception e) {
 			m_log.warn("addNodeWithoutRefresh() : "
 					+ e.getClass().getSimpleName() + ", " + e.getMessage(), e);
