@@ -16,11 +16,7 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.clustercontrol.repository.util;
 
 import java.util.ArrayList;
-import java.util.HashMap;
 import java.util.List;
-import java.util.Map;
-
-import javax.persistence.EntityManager;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -33,7 +29,6 @@ import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.fault.ObjectPrivilege_InvalidRole;
 import com.clustercontrol.repository.bean.FacilityConstant;
-import com.clustercontrol.repository.bean.FacilityInfo;
 import com.clustercontrol.repository.model.CollectorPlatformMstEntity;
 import com.clustercontrol.repository.model.CollectorSubPlatformMstEntity;
 import com.clustercontrol.repository.model.FacilityEntity;
@@ -64,8 +59,8 @@ public class QueryUtil {
 	private static Log m_log = LogFactory.getLog( QueryUtil.class );
 
 	public static NodeEntity getNodePK(String facilityId) throws FacilityNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		NodeEntity entity = em.find(NodeEntity.class, facilityId);
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
+		NodeEntity entity = em.find(NodeEntity.class, facilityId, ObjectPrivilegeMode.READ);
 		if (entity == null) {
 			FacilityNotFound e = new FacilityNotFound("NodeEntity.findByPrimaryKey"
 					+ ", facilityId = " + facilityId);
@@ -79,12 +74,12 @@ public class QueryUtil {
 	public static FacilityEntity getFacilityPK(String facilityId) throws FacilityNotFound, InvalidRole {
 		return getFacilityPK(facilityId, ObjectPrivilegeMode.READ);
 	}
-	
+
 	public static FacilityEntity getFacilityPK(String facilityId, ObjectPrivilegeMode mode) throws FacilityNotFound, InvalidRole {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		FacilityEntity entity = null;
 		try {
-			entity = ((HinemosEntityManager)em).find(FacilityEntity.class, facilityId, mode);
+			entity = em.find(FacilityEntity.class, facilityId, mode);
 			if (entity == null) {
 				FacilityNotFound e = new FacilityNotFound("FacilityEntity.findByPrimaryKey"
 						+ ", facilityId = " + facilityId);
@@ -101,10 +96,10 @@ public class QueryUtil {
 	}
 
 	public static FacilityEntity getFacilityPK_OR(String facilityId, String ownerRoleId) throws FacilityNotFound, InvalidRole {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		FacilityEntity entity = null;
 		try {
-			entity = ((HinemosEntityManager)em).find_OR(FacilityEntity.class, facilityId, ownerRoleId);
+			entity = em.find_OR(FacilityEntity.class, facilityId, ownerRoleId);
 			if (entity == null) {
 				FacilityNotFound e = new FacilityNotFound("FacilityEntity.findByPrimaryKey"
 						+ ", facilityId = " + facilityId);
@@ -121,10 +116,10 @@ public class QueryUtil {
 	}
 
 	public static FacilityEntity getFacilityPK_NONE(String facilityId) throws FacilityNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		FacilityEntity entity = null;
 		try {
-			entity = ((HinemosEntityManager)em).find(FacilityEntity.class, facilityId, ObjectPrivilegeMode.NONE);
+			entity = em.find(FacilityEntity.class, facilityId, ObjectPrivilegeMode.NONE);
 			if (entity == null) {
 				FacilityNotFound e = new FacilityNotFound("FacilityEntity.findByPrimaryKey"
 						+ ", facilityId = " + facilityId);
@@ -141,20 +136,20 @@ public class QueryUtil {
 
 	@Deprecated
 	public static FacilityEntity getFacilityPK_WRITE(String facilityId) throws FacilityNotFound, InvalidRole {
-		return getFacilityPK(facilityId, ObjectPrivilegeMode.WRITE);
+		return getFacilityPK(facilityId, ObjectPrivilegeMode.MODIFY);
 	}
-	
+
 	public static List<FacilityEntity> getFacilityByOwnerRoleId_NONE(String roleId) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<FacilityEntity> list
-		= ((HinemosEntityManager)em).createNamedQuery("FacilityEntity.findByOwnerRoleId", FacilityEntity.class, ObjectPrivilegeMode.NONE)
+		= em.createNamedQuery("FacilityEntity.findByOwnerRoleId", FacilityEntity.class, ObjectPrivilegeMode.NONE)
 		.setParameter("ownerRoleId", roleId)
 		.getResultList();
 		return list;
 	}
 
 	public static List<FacilityEntity> getAllFacility() {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<FacilityEntity> list
 		= em.createNamedQuery("FacilityEntity.findAll", FacilityEntity.class)
 		.getResultList();
@@ -162,26 +157,26 @@ public class QueryUtil {
 	}
 
 	public static List<FacilityEntity> getAllFacility_NONE() {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<FacilityEntity> list
-		= ((HinemosEntityManager)em).createNamedQuery("FacilityEntity.findAll", FacilityEntity.class, ObjectPrivilegeMode.NONE)
+		= em.createNamedQuery("FacilityEntity.findAll", FacilityEntity.class, ObjectPrivilegeMode.NONE)
 		.getResultList();
 		return list;
 	}
 
 	public static List<FacilityEntity> getRootScopeFacility_NONE() {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<FacilityEntity> list
-		= ((HinemosEntityManager)em).createNamedQuery("FacilityEntity.findRootByFacilityType", FacilityEntity.class, ObjectPrivilegeMode.NONE)
+		= em.createNamedQuery("FacilityEntity.findRootByFacilityType", FacilityEntity.class, ObjectPrivilegeMode.NONE)
 		.setParameter("facilityType", FacilityConstant.TYPE_SCOPE)
 		.getResultList();
 		return list;
 	}
 
 	public static FacilityRelationEntity getFacilityRelationPk(String parentFacilityId, String childFacilityId) throws FacilityNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		FacilityRelationEntityPK pk = new FacilityRelationEntityPK(parentFacilityId, childFacilityId);
-		FacilityRelationEntity entity = em.find(FacilityRelationEntity.class, pk);
+		FacilityRelationEntity entity = em.find(FacilityRelationEntity.class, pk, ObjectPrivilegeMode.READ);
 		if (entity == null) {
 			FacilityNotFound e = new FacilityNotFound("FacilityRelationEntity.findByPrimaryKey"
 					+ pk.toString());
@@ -193,7 +188,7 @@ public class QueryUtil {
 	}
 
 	public static List<FacilityEntity> getParentFacilityEntity(String childFacilityId) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<FacilityEntity> list = new ArrayList<FacilityEntity>();
 		List<FacilityRelationEntity> FacilityRelationEntities
 		= em.createNamedQuery("FacilityRelationEntity.findParent", FacilityRelationEntity.class)
@@ -201,7 +196,7 @@ public class QueryUtil {
 		.getResultList();
 		for (FacilityRelationEntity facilityRelationEntity : FacilityRelationEntities) {
 			try {
-				FacilityEntity parentFacilityEntity 
+				FacilityEntity parentFacilityEntity
 					= QueryUtil.getFacilityPK_NONE(facilityRelationEntity.getId().getParentFacilityId());
 				list.add(parentFacilityEntity);
 			} catch (FacilityNotFound e) {
@@ -212,7 +207,7 @@ public class QueryUtil {
 	}
 
 	public static List<FacilityEntity> getChildFacilityEntity(String parentFacilityId) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<FacilityEntity> list = new ArrayList<FacilityEntity>();
 		List<FacilityRelationEntity> FacilityRelationEntities
 		= em.createNamedQuery("FacilityRelationEntity.findChild", FacilityRelationEntity.class)
@@ -220,7 +215,7 @@ public class QueryUtil {
 		.getResultList();
 		for (FacilityRelationEntity facilityRelationEntity : FacilityRelationEntities) {
 			try {
-				FacilityEntity childFacilityEntity 
+				FacilityEntity childFacilityEntity
 					= QueryUtil.getFacilityPK_NONE(facilityRelationEntity.getId().getChildFacilityId());
 				list.add(childFacilityEntity);
 			} catch (FacilityNotFound e) {
@@ -230,8 +225,17 @@ public class QueryUtil {
 		return list;
 	}
 
+	public static List<FacilityRelationEntity> getAllFacilityRelations_NONE() {
+		HinemosEntityManager em = new JpaTransactionManager()
+				.getEntityManager();
+		List<FacilityRelationEntity> list = em.createNamedQuery(
+				"FacilityRelationEntity.findAll", FacilityRelationEntity.class,
+				ObjectPrivilegeMode.NONE).getResultList();
+		return list;
+	}
+
 	public static List<FacilityEntity> getAllNode() {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<FacilityEntity> list
 		= em.createNamedQuery("FacilityEntity.findByFacilityType", FacilityEntity.class)
 		.setParameter("facilityType", FacilityConstant.TYPE_NODE)
@@ -240,16 +244,16 @@ public class QueryUtil {
 	}
 
 	public static List<FacilityEntity> getAllNode_NONE() {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<FacilityEntity> list
-		= ((HinemosEntityManager)em).createNamedQuery("FacilityEntity.findByFacilityType", FacilityEntity.class, ObjectPrivilegeMode.NONE)
+		= em.createNamedQuery("FacilityEntity.findByFacilityType", FacilityEntity.class, ObjectPrivilegeMode.NONE)
 		.setParameter("facilityType", FacilityConstant.TYPE_NODE)
 		.getResultList();
 		return list;
 	}
 
 	public static List<NodeHostnameEntity> getAllNodeHostname() {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<NodeHostnameEntity> list
 		= em.createNamedQuery("NodeHostnameEntity.findAll", NodeHostnameEntity.class)
 		.getResultList();
@@ -257,7 +261,7 @@ public class QueryUtil {
 	}
 
 	public static List<FacilityEntity> getNodeByIpv4(String ipAddressV4) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<FacilityEntity> list
 		= em.createNamedQuery("FacilityEntity.findByIpAddressV4", FacilityEntity.class)
 		.setParameter("ipAddressV4", ipAddressV4)
@@ -266,7 +270,7 @@ public class QueryUtil {
 	}
 
 	public static List<FacilityEntity> getNodeByIpv6(String ipAddressV6) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<FacilityEntity> list
 		= em.createNamedQuery("FacilityEntity.findByIpAddressV6", FacilityEntity.class)
 		.setParameter("ipAddressV6", Ipv6Util.expand(ipAddressV6))
@@ -275,7 +279,7 @@ public class QueryUtil {
 	}
 
 	public static List<FacilityEntity> getNodeByNodename(String nodeName) {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<FacilityEntity> list
 		= em.createNamedQuery("FacilityEntity.findByNodename", FacilityEntity.class)
 		.setParameter("nodeName", nodeName.toLowerCase())
@@ -284,8 +288,8 @@ public class QueryUtil {
 	}
 
 	public static NodeHostnameEntity getNodeHostnamePK(NodeHostnameEntityPK pk) throws FacilityNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		NodeHostnameEntity entity = em.find(NodeHostnameEntity.class, pk);
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
+		NodeHostnameEntity entity = em.find(NodeHostnameEntity.class, pk, ObjectPrivilegeMode.READ);
 		if (entity == null) {
 			FacilityNotFound e = new FacilityNotFound("NodeHostnameEntity.findByPrimaryKey"
 					+ pk.toString());
@@ -297,8 +301,8 @@ public class QueryUtil {
 	}
 
 	public static NodeDeviceEntity getNodeDeviceEntityPK(NodeDeviceEntityPK pk) throws FacilityNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		NodeDeviceEntity entity = em.find(NodeDeviceEntity.class, pk);
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
+		NodeDeviceEntity entity = em.find(NodeDeviceEntity.class, pk, ObjectPrivilegeMode.READ);
 		if (entity == null) {
 			FacilityNotFound e = new FacilityNotFound("NodeDeviceEntity.findByPrimaryKey"
 					+ pk.toString());
@@ -310,8 +314,8 @@ public class QueryUtil {
 	}
 
 	public static NodeCpuEntity getNodeCpuEntityPK(NodeCpuEntityPK pk) throws FacilityNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		NodeCpuEntity entity = em.find(NodeCpuEntity.class, pk);
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
+		NodeCpuEntity entity = em.find(NodeCpuEntity.class, pk, ObjectPrivilegeMode.READ);
 		if (entity == null) {
 			FacilityNotFound e = new FacilityNotFound("NodeCpuEntity.findByPrimaryKey"
 					+ pk.toString());
@@ -323,8 +327,8 @@ public class QueryUtil {
 	}
 
 	public static NodeMemoryEntity getNodeMemoryEntityPK(NodeMemoryEntityPK pk) throws FacilityNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		NodeMemoryEntity entity = em.find(NodeMemoryEntity.class, pk);
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
+		NodeMemoryEntity entity = em.find(NodeMemoryEntity.class, pk, ObjectPrivilegeMode.READ);
 		if (entity == null) {
 			FacilityNotFound e = new FacilityNotFound("NodeMemoryEntity.findByPrimaryKey"
 					+ pk.toString());
@@ -336,8 +340,8 @@ public class QueryUtil {
 	}
 
 	public static NodeNetworkInterfaceEntity getNodeNetworkInterfaceEntityPK(NodeNetworkInterfaceEntityPK pk) throws FacilityNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		NodeNetworkInterfaceEntity entity = em.find(NodeNetworkInterfaceEntity.class, pk);
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
+		NodeNetworkInterfaceEntity entity = em.find(NodeNetworkInterfaceEntity.class, pk, ObjectPrivilegeMode.READ);
 		if (entity == null) {
 			FacilityNotFound e = new FacilityNotFound("NodeNetworkInterfaceEntity.findByPrimaryKey"
 					+ pk.toString());
@@ -349,8 +353,8 @@ public class QueryUtil {
 	}
 
 	public static NodeDiskEntity getNodeDiskEntityPK(NodeDiskEntityPK pk) throws FacilityNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		NodeDiskEntity entity = em.find(NodeDiskEntity.class, pk);
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
+		NodeDiskEntity entity = em.find(NodeDiskEntity.class, pk, ObjectPrivilegeMode.READ);
 		if (entity == null) {
 			FacilityNotFound e = new FacilityNotFound("NodeDiskEntity.findByPrimaryKey"
 					+ pk.toString());
@@ -362,8 +366,8 @@ public class QueryUtil {
 	}
 
 	public static NodeFilesystemEntity getFilesystemDiskEntityPK(NodeFilesystemEntityPK pk) throws FacilityNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		NodeFilesystemEntity entity = em.find(NodeFilesystemEntity.class, pk);
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
+		NodeFilesystemEntity entity = em.find(NodeFilesystemEntity.class, pk, ObjectPrivilegeMode.READ);
 		if (entity == null) {
 			FacilityNotFound e = new FacilityNotFound("NodeFilesystemEntity.findByPrimaryKey"
 					+ pk.toString());
@@ -375,8 +379,8 @@ public class QueryUtil {
 	}
 
 	public static NodeVariableEntity getNodeVariableEntityPK(NodeVariableEntityPK pk) throws FacilityNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		NodeVariableEntity entity = em.find(NodeVariableEntity.class, pk);
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
+		NodeVariableEntity entity = em.find(NodeVariableEntity.class, pk, ObjectPrivilegeMode.READ);
 		if (entity == null) {
 			FacilityNotFound e = new FacilityNotFound("NodeVariableEntity.findByPrimaryKey"
 					+ pk.toString());
@@ -388,8 +392,8 @@ public class QueryUtil {
 	}
 
 	public static NodeNoteEntity getNodeNoteEntityPK(NodeNoteEntityPK pk) throws FacilityNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		NodeNoteEntity entity = em.find(NodeNoteEntity.class, pk);
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
+		NodeNoteEntity entity = em.find(NodeNoteEntity.class, pk, ObjectPrivilegeMode.READ);
 		if (entity == null) {
 			FacilityNotFound e = new FacilityNotFound("NodeNoteEntity.findByPrimaryKey"
 					+ pk.toString());
@@ -401,8 +405,8 @@ public class QueryUtil {
 	}
 
 	public static CollectorPlatformMstEntity getCollectorPlatformMstPK(String platformId) throws FacilityNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		CollectorPlatformMstEntity entity = em.find(CollectorPlatformMstEntity.class, platformId);
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
+		CollectorPlatformMstEntity entity = em.find(CollectorPlatformMstEntity.class, platformId, ObjectPrivilegeMode.READ);
 		if (entity == null) {
 			FacilityNotFound e = new FacilityNotFound("CollectorPlatformMstEntity.findByPrimaryKey"
 					+ ", platformId = " + platformId);
@@ -414,8 +418,8 @@ public class QueryUtil {
 	}
 
 	public static CollectorSubPlatformMstEntity getCollectorSubPlatformMstPK(String subPlatformId) throws FacilityNotFound {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
-		CollectorSubPlatformMstEntity entity = em.find(CollectorSubPlatformMstEntity.class, subPlatformId);
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
+		CollectorSubPlatformMstEntity entity = em.find(CollectorSubPlatformMstEntity.class, subPlatformId, ObjectPrivilegeMode.READ);
 		if (entity == null) {
 			FacilityNotFound e = new FacilityNotFound("CollectorSubPlatformMstEntity.findByPrimaryKey"
 					+ ", subPlatformId = " + subPlatformId);
@@ -425,17 +429,17 @@ public class QueryUtil {
 		}
 		return entity;
 	}
-	
+
 	public static List<CollectorPlatformMstEntity> getAllCollectorPlatformMst() {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<CollectorPlatformMstEntity> list
 		= em.createNamedQuery("CollectorPlatformMstEntity.findAll", CollectorPlatformMstEntity.class)
 		.getResultList();
 		return list;
 	}
-	
+
 	public static List<CollectorSubPlatformMstEntity> getAllCollectorSubPlatformMstEntity() {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<CollectorSubPlatformMstEntity> list
 		= em.createNamedQuery("CollectorSubPlatformMstEntity.findAll", CollectorSubPlatformMstEntity.class)
 		.getResultList();
