@@ -15,12 +15,12 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.selfcheck.monitor;
 
-import javax.persistence.EntityManager;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
+import com.clustercontrol.maintenance.util.HinemosPropertyUtil;
 import com.clustercontrol.util.apllog.AplLogger;
 
 /**
@@ -30,14 +30,13 @@ public class JobRunSessionMonitor extends SelfCheckMonitorBase {
 
 	private static Log m_log = LogFactory.getLog( JobRunSessionMonitor.class );
 
-	public final long threshold;
+	public long threshold;
 
 	public final String monitorId = "SYS_JOB_SESSION";
 	public final String subKey = "";
 	public final String application = "SELFCHECK (Running Job Session)";
 
-	public JobRunSessionMonitor(long threshold) {
-		this.threshold = threshold;
+	public JobRunSessionMonitor() {
 	}
 
 	/**
@@ -56,25 +55,23 @@ public class JobRunSessionMonitor extends SelfCheckMonitorBase {
 		return monitorId;
 	}
 
-	/**
-	 * 監視項目subKey
-	 */
-	@Override
-	public String getSubKey() {
-		return subKey;
-	}
-
 	/**
 	 * ジョブセッション数の確認
 	 * @return 通知情報（アプリケーション名は未格納）
 	 */
 	@Override
 	public void execute() {
+		if (!HinemosPropertyUtil.getHinemosPropertyBool("selfcheck.monitoring.job.runningsession", true)) {
+			m_log.debug("skip");
+			return;
+		}
 		/** ローカル変数 */
 		JpaTransactionManager tm = null;
 		long count = -1;
 		boolean warn = true;
 
+		threshold = HinemosPropertyUtil.getHinemosPropertyNum("selfcheck.monitoring.job.runningsession.threshold", 1000);
+
 		/** メイン処理 */
 		if (m_log.isDebugEnabled())
 			m_log.debug("monitoring job session running. (threshold = " + threshold + ")");
@@ -105,7 +102,7 @@ public class JobRunSessionMonitor extends SelfCheckMonitorBase {
 		if (warn) {
 			m_log.info("job session running size is too high. (count= "  + count + ", threshold = " + threshold + ")");
 		}
-		if (!isNotify(warn)) {
+		if (!isNotify(subKey, warn)) {
 			return;
 		}
 		String[] msgAttr1 = { new Long(count).toString(), new Long(threshold).toString() };
@@ -126,13 +123,13 @@ public class JobRunSessionMonitor extends SelfCheckMonitorBase {
 	 * @param conn 問い合わせに利用するコネクション
 	 * @return レコード数
 	 */
-	private static long getJobRunSessionCount() {
+	public static long getJobRunSessionCount() {
 		// ローカル変数
 		JpaTransactionManager tm = null;
-		EntityManager em =null;
+		HinemosEntityManager em =null;
 
 		String query = "SELECT count(*) " +
-				"FROM cc_job_session s, cc_job_session_job j " +
+				"FROM log.cc_job_session s, log.cc_job_session_job j " +
 				"WHERE s.session_id = j.session_id AND s.jobunit_id = j.jobunit_id " +
 				"AND s.job_id = j.job_id AND status NOT IN (300,301)";
 
