@@ -92,7 +92,7 @@ public class ThreadActivityMonitor extends SelfCheckMonitorBase {
 		if (!isNotify(subKey, warn)) {
 			return;
 		}
-		String[] msgAttr1 = { new Long(threadInfo.thread.getId()).toString(), threadInfo.thread.getName(), threadInfo.taskClassName, startTimeStr };
+		String[] msgAttr1 = { new Long(threadInfo.thread.getId()).toString(), threadInfo.thread.getName(), threadInfo.taskClassName, startTimeStr, Integer.toString(thresholdSec) };
 		AplLogger aplLogger = new AplLogger(PLUGIN_ID, APL_ID);
 		aplLogger.put(MESSAGE_ID, "012", msgAttr1,
 				"internal logic (tid " +
