@@ -38,6 +38,6 @@ public class DeleteSnmpString implements DeleteInterface{
 	@Override
 	public boolean delete(String managerName, List<String> monitorIdList) throws Exception {
 		MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
-		return wrapper.deleteMonitor(monitorIdList, HinemosModuleConstant.MONITOR_SNMP_N);
+		return wrapper.deleteMonitor(monitorIdList, HinemosModuleConstant.MONITOR_SNMP_S);
 	}
 }
