@@ -10,10 +10,8 @@ import javax.persistence.Column;
 import javax.persistence.Entity;
 import javax.persistence.FetchType;
 import javax.persistence.Id;
-import javax.persistence.JoinColumn;
 import javax.persistence.OneToMany;
 import javax.persistence.OneToOne;
-import javax.persistence.OrderBy;
 import javax.persistence.PrimaryKeyJoinColumn;
 import javax.persistence.Table;
 
@@ -125,9 +123,7 @@ public class MonitorTrapInfoEntity implements Serializable {
 		this.priorityUnspecified = priorityUnspecified;
 	}
 
-	@OneToMany(fetch=FetchType.LAZY, cascade=CascadeType.ALL)
-	@JoinColumn(name="monitor_id", referencedColumnName="monitor_id", insertable=false, updatable=false)
-	@OrderBy
+	@OneToMany(mappedBy="monitorTrapInfoEntity", cascade=CascadeType.ALL, fetch=FetchType.LAZY)
 	public List<MonitorTrapValueInfoEntity> getMonitorTrapValueInfoEntities() {
 		return this.monitorTrapValueInfoEntities;
 	}
