@@ -68,32 +68,54 @@ import com.clustercontrol.util.apllog.AplLogger;
  */
 public class ReceivedTrapFilterTask implements Runnable {
 
-	private static class QueryResutIterator<E> implements Iterator<E> {
+	/*
+	 * 受信したSNMPTRAPにマッチするSNMPTRAP監視設定を順番に処理するためのクラス
+	 * 
+	 * クエリの結果、受信したSNMPTRAPにマッチする(MonitorInfoEntity, MonitorTrapValueInfoEntity)の配列のリストが得られるので、
+	 * MonitorInfoEntityごとに順番に処理する
+	 * 
+	 * 例：SNMPTRAP監視設定A,Bがあり、受信したSNMPTRAPが、監視設定Aのトラップ定義A-1とトラップ定義A-2、監視設定Bのトラップ定義B-1にマッチする場合
+	 * resultsには、以下のように2要素の配列から成るリストが設定される
+	 * [[監視設定A, トラップ定義A-1],
+	 *  [監視設定A, トラップ定義A-2],
+	 *  [監視設定B, トラップ定義B-1]]
+	 *  
+	 *  この場合next()を実行すると、監視設定A, 監視設定Bと順に得られる。
+	 *  next()で監視設定Aが得られた後、次にnext()を実行するまでgetValueInfoList()を実行すると、リスト[トラップ定義A-1, トラップ定義A-2]が得られ、
+	 *  next()で監視設定Bが得られた後、次にnext()を実行するまでgetValueInfoList()を実行すると、リスト[トラップ定義B-1]が得られる。
+	 */
+	private static class QueryResultIterator<E> implements Iterator<E> {
+		
+		/* 受信したSNMPTRAPにマッチする(MonitorInfoEntity, MonitorTrapValueInfoEntity)の配列のリスト
+		 * 配列の0番目にはMonitorInfoEntityが、1番目にはMonitorTrapValueInfoEntityが入る
+		 */
 		private List<Object[]> results;
-		private int position;
+		private static int MONITOR_INFO = 0;
+		private static int MONITOR_TRAP_VALUE_INFO = 1;
+		
+		// 処理しているMonitorInfoEntityを示すための、リストresultsのインデックス
 		private int current;
-
+		// currentに対応するMonitorInfoEntity
+		private MonitorInfoEntity currentMonitorInfo;
+		// リストresultsのインデックス(next()で次に得られるものを示す）
 		private Integer nextIndex = null;
-
-		private Object currentObject;
-
-		public QueryResutIterator(List<Object[]> results) {
+		
+		public QueryResultIterator(List<Object[]> results) {
 			this.results = results;
-			this.position = 0;
 			this.current = 0;
-			this.currentObject = results.isEmpty() ? null: results.get(current)[position];
-			this.nextIndex = currentObject == null ? -1: current;
+			this.currentMonitorInfo = results.isEmpty() ? null: (MonitorInfoEntity)results.get(current)[MONITOR_INFO];
+			this.nextIndex = currentMonitorInfo == null ? -1: current;
 		}
 
 		@Override
 		public boolean hasNext() {
 			if (nextIndex == null) {
 				for (int i = current; i < results.size(); ++i) {
-					Object o = results.get(i)[position];
-					if (o != null && o != currentObject) {
+					MonitorInfoEntity o = (MonitorInfoEntity)results.get(i)[MONITOR_INFO];
+					if (o != null && o != currentMonitorInfo) {
 						nextIndex = i;
 						current = i;
-						currentObject = o;
+						currentMonitorInfo = o;
 						break;
 					}
 				}
@@ -103,12 +125,32 @@ public class ReceivedTrapFilterTask implements Runnable {
 			}
 			return nextIndex != -1;
 		}
+		
+		// MonitorInfoEntityに対応するMonitorTrapValueInfoEntity(受信したトラップにマッチするもの)のリストを返す
+		private List<MonitorTrapValueInfoEntity> getValueInfoList() {
+			List<MonitorTrapValueInfoEntity> list = new ArrayList<MonitorTrapValueInfoEntity>();
+			for (int i = current; i < results.size(); ++i) {
+				MonitorInfoEntity o = (MonitorInfoEntity)results.get(i)[MONITOR_INFO];
+				if (o != null && o == currentMonitorInfo) {
+					// MonitorInfoEntityに対応するMonitorTrapValueInfoEntityが複数ある場合はすべてリストにつめる
+					MonitorTrapValueInfoEntity entity = (MonitorTrapValueInfoEntity)results.get(i)[MONITOR_TRAP_VALUE_INFO];
+					if (entity != null) {
+						list.add(entity);
+					}
+				} else {
+					break;
+				}
+			}
+			
+			return list;
+		}
 
+		// MonitorInfoEntityを順番に返す
 		@SuppressWarnings("unchecked")
 		@Override
 		public E next() {
 			if (hasNext()) {
-				Object result = results.get(nextIndex)[position];
+				Object result = results.get(nextIndex)[MONITOR_INFO];
 				nextIndex = null;
 				return (E)result;
 			}
@@ -117,7 +159,7 @@ public class ReceivedTrapFilterTask implements Runnable {
 
 		@Override
 		public void remove() {
-			if (results.get(current)[position] == currentObject) {
+			if ((MonitorInfoEntity)results.get(current)[MONITOR_INFO] == currentMonitorInfo) {
 				results.remove(current);
 				nextIndex = null;
 			}
@@ -193,7 +235,7 @@ public class ReceivedTrapFilterTask implements Runnable {
 				List<Object[]> results = getTargetMonitorTrapList(
 						receivedTrap, em, unspecifiedFlgMonitorInfoEntityList);
 
-				QueryResutIterator<MonitorInfoEntity> monitorIter = new QueryResutIterator<MonitorInfoEntity>(results);
+				QueryResultIterator<MonitorInfoEntity> monitorIter = new QueryResultIterator<MonitorInfoEntity>(results);
 				while (monitorIter.hasNext()) {
 					MonitorInfoEntity currentMonitor = monitorIter.next();
 	
@@ -253,8 +295,8 @@ public class ReceivedTrapFilterTask implements Runnable {
 					MonitorTrapVarbindPatternInfoEntity matchedPattern = null;
 					String matchedString = null;
 					
-					List<MonitorTrapValueInfoEntity> velueList = currentMonitor.getMonitorTrapInfoEntity().getMonitorTrapValueInfoEntities();
-					Iterator<MonitorTrapValueInfoEntity> valueIterator = velueList.iterator();
+					List<MonitorTrapValueInfoEntity> valueList = monitorIter.getValueInfoList();
+					Iterator<MonitorTrapValueInfoEntity> valueIterator = valueList.iterator();
 					
 					if (!valueIterator.hasNext() && ValidConstant.typeToBoolean(trapInfo.getNotifyofReceivingUnspecifiedFlg())) {
 						// マッチするTRAPの設定が存在せず、存在しない場合に通知する場合
