@@ -17,9 +17,6 @@ package com.clustercontrol.sql.session;
 
 import java.util.ArrayList;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 import com.clustercontrol.sql.bean.JdbcDriverInfo;
 import com.clustercontrol.sql.util.JdbcDriverUtil;
 
@@ -29,8 +26,6 @@ import com.clustercontrol.sql.util.JdbcDriverUtil;
  */
 public class MonitorSqlControllerBean {
 
-	private static Log m_log = LogFactory.getLog( MonitorSqlControllerBean.class );
-
 	/**
 	 * JDBC定義一覧をリストで返却します。<BR>
 	 * 
