@@ -17,14 +17,13 @@ package com.clustercontrol.vm.util;
 
 import java.util.List;
 
-import javax.persistence.EntityManager;
-
+import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 
 public class QueryUtil {
 
 	public static List<String> getVmProtocolMstDistinctProtocol() {
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		List<String> list
 		= em.createNamedQuery("VmProtocolMstEntity.findDistinctProtocol", String.class)
 		.getResultList();
