@@ -32,12 +32,12 @@ import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
+import com.clustercontrol.util.WidgetTestUtil;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.RequiredFieldColorConstant;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.monitor.run.dialog.CommonMonitorStringDialog;
 import com.clustercontrol.monitor.util.MonitorSettingEndpointWrapper;
-import com.clustercontrol.notify.util.NotifyGroupIdGenerator;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.winevent.bean.WinEventUtil;
 import com.clustercontrol.ws.monitor.InvalidRole_Exception;
@@ -67,44 +67,50 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 	private Text eventId = null;
 	private Text category = null;
 	private Text keywords = null;
+	/** マネージャ名 */
+	private String managerName = null;
 
 	// ----- コンストラクタ ----- //
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent
 	 *            親のシェルオブジェクト
 	 */
 	public WinEventDialog(Shell parent) {
-		super(parent);
+		super(parent, null);
 		logLineFlag = true;
 	}
 
 	/**
 	 * 作成用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
+	 * @param managerName マネージャ名
 	 * @param monitorType 監視判定タイプ
 	 */
-	public WinEventDialog(Shell parent, int monitorType) {
-		super(parent);
+	public WinEventDialog(Shell parent, String managerName, int monitorType) {
+		super(parent, managerName);
 
 		logLineFlag = true;
+		this.managerName = managerName;
 		this.m_monitorType = monitorType;
 	}
 
 	/**
 	 * 変更用ダイアログのインスタンスを返します。
-	 * 
+	 *
 	 * @param parent 親のシェルオブジェクト
+	 * @param managerName マネージャ名
 	 * @param monitorId 変更する監視項目ID
 	 * @param updateFlg 更新するか否か（true:変更、false:新規登録）
 	 */
-	public WinEventDialog(Shell parent, String monitorId, boolean updateFlg) {
-		super(parent);
+	public WinEventDialog(Shell parent, String managerName, String monitorId, boolean updateFlg) {
+		super(parent, managerName);
 
 		logLineFlag = true;
+		this.managerName = managerName;
 		this.monitorId = monitorId;
 		this.updateFlg = updateFlg;
 	}
@@ -113,7 +119,7 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * ダイアログエリアを生成します。
-	 * 
+	 *
 	 * @param parent 親のインスタンス
 	 */
 	@Override
@@ -133,13 +139,14 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 		 * チェック設定グループ（条件グループの子グループ）
 		 */
 		Group groupCheckRule = new Group(groupRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "checkrule", groupCheckRule);
 		GridLayout layout = new GridLayout(1, true);
 		layout.marginWidth = 5;
 		layout.marginHeight = 5;
-		layout.numColumns = 15;
+		layout.numColumns = BASIC_UNIT;
 		groupCheckRule.setLayout(layout);
 		gridData = new GridData();
-		gridData.horizontalSpan = 15;
+		gridData.horizontalSpan = BASIC_UNIT;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		groupCheckRule.setLayoutData(gridData);
@@ -150,8 +157,9 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "wineventlevel", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
@@ -159,8 +167,9 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 
 		// ボタン(重大)
 		this.levelCritical = new Button(groupCheckRule, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "criticalcheck", levelCritical);
 		gridData = new GridData();
-		gridData.horizontalSpan = 2;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.levelCritical.setLayoutData(gridData);
@@ -168,8 +177,9 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 
 		// ボタン(警告)
 		this.levelWarning = new Button(groupCheckRule, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "warningcheck", levelWarning);
 		gridData = new GridData();
-		gridData.horizontalSpan = 2;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.levelWarning.setLayoutData(gridData);
@@ -177,8 +187,9 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 
 		// ボタン(詳細)
 		this.levelVerbose = new Button(groupCheckRule, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "verbosecheck", levelVerbose);
 		gridData = new GridData();
-		gridData.horizontalSpan = 2;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.levelVerbose.setLayoutData(gridData);
@@ -186,8 +197,9 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 
 		// ボタン(エラー)
 		this.levelError = new Button(groupCheckRule, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "errorcheck", levelError);
 		gridData = new GridData();
-		gridData.horizontalSpan = 2;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.levelError.setLayoutData(gridData);
@@ -195,8 +207,9 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 
 		// ボタン(情報)
 		this.levelInformational = new Button(groupCheckRule, SWT.CHECK);
+		WidgetTestUtil.setTestId(this, "infomationalcheck", levelInformational);
 		gridData = new GridData();
-		gridData.horizontalSpan = 2;
+		gridData.horizontalSpan = WIDTH_VALUE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.levelInformational.setLayoutData(gridData);
@@ -207,16 +220,18 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "wineveltlog", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("winevent.log") + " : ");
 		// テキスト
 		this.logName = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "logname", logName);
 		gridData = new GridData();
-		gridData.horizontalSpan = 8;
+		gridData.horizontalSpan = WIDTH_TEXT_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.logName.setLayoutData(gridData);
@@ -232,16 +247,18 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "wineventsource", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("winevent.source") + " : ");
 		// テキスト
 		this.source = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "source", source);
 		gridData = new GridData();
-		gridData.horizontalSpan = 8;
+		gridData.horizontalSpan = WIDTH_TEXT_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.source.setLayoutData(gridData);
@@ -252,16 +269,18 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "wineventid", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("winevent.id") + " : ");
 		// テキスト
 		this.eventId = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "eventid", eventId);
 		gridData = new GridData();
-		gridData.horizontalSpan = 8;
+		gridData.horizontalSpan = WIDTH_TEXT_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.eventId.setLayoutData(gridData);
@@ -272,16 +291,18 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "wineventcategory", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("winevent.category") + " : ");
 		// テキスト
 		this.category = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "category", category);
 		gridData = new GridData();
-		gridData.horizontalSpan = 8;
+		gridData.horizontalSpan = WIDTH_TEXT_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.category.setLayoutData(gridData);
@@ -292,16 +313,18 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 		 */
 		// ラベル
 		label = new Label(groupCheckRule, SWT.NONE);
+		WidgetTestUtil.setTestId(this, "keywords", label);
 		gridData = new GridData();
-		gridData.horizontalSpan = WIDTH_TITLE;
+		gridData.horizontalSpan = WIDTH_TITLE_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		label.setLayoutData(gridData);
 		label.setText(Messages.getString("winevent.keywords") + " : ");
 		// テキスト
 		this.keywords = new Text(groupCheckRule, SWT.BORDER | SWT.LEFT);
+		WidgetTestUtil.setTestId(this, "keywords", keywords);
 		gridData = new GridData();
-		gridData.horizontalSpan = 8;
+		gridData.horizontalSpan = WIDTH_TEXT_LONG;
 		gridData.horizontalAlignment = GridData.FILL;
 		gridData.grabExcessHorizontalSpace = true;
 		this.keywords.setLayoutData(gridData);
@@ -322,7 +345,8 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 		} else {
 			// 変更の場合、情報取得
 			try {
-				info = MonitorSettingEndpointWrapper.getMonitor(this.monitorId, HinemosModuleConstant.MONITOR_WINEVENT);
+				MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
+				info = wrapper.getMonitor(this.monitorId, HinemosModuleConstant.MONITOR_WINEVENT);
 			} catch (InvalidRole_Exception e) {
 				// アクセス権なしの場合、エラーダイアログを表示する
 				MessageDialog.openInformation(
@@ -344,7 +368,7 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 更新処理
-	 * 
+	 *
 	 */
 	@Override
 	public void update(){
@@ -359,7 +383,7 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 	}
 	/**
 	 * 各項目に入力値を設定します。
-	 * 
+	 *
 	 * @param monitor 設定値として用いる監視情報
 	 */
 	@Override
@@ -401,7 +425,7 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 入力値を用いて通知情報を生成します。
-	 * 
+	 *
 	 * @return 入力値を保持した通知情報
 	 */
 	@Override
@@ -439,7 +463,7 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 		} catch (HinemosUnknown e) {
 			setValidateResult(Messages.getString("message.hinemos.1"), e.getMessage() + "\n"+Messages.getString("winevent.id"));
 		}
-		
+
 		try {
 			for(Integer category : commaSeparatedStringToIntegerList(this.category.getText())){
 				winEventInfo.getCategory().add(category);
@@ -467,8 +491,6 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 		}
 
 		// 通知関連情報とアプリケーションの設定
-		// 通知グループIDの設定
-		monitorInfo.setNotifyGroupId(NotifyGroupIdGenerator.createNotifyGroupId(HinemosModuleConstant.MONITOR_WINEVENT, monitorInfo.getMonitorId()));
 		validateResult = m_notifyInfo.createInputData(monitorInfo);
 		if (validateResult != null) {
 			if(validateResult.getID() == null){	// 通知ID警告用出力
@@ -487,9 +509,9 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 
 	/**
 	 * 入力値をマネージャに登録します。
-	 * 
+	 *
 	 * @return true：正常、false：異常
-	 * 
+	 *
 	 * @see com.clustercontrol.dialog.CommonDialog#action()
 	 */
 	@Override
@@ -497,13 +519,15 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 		boolean result = false;
 
 		MonitorInfo info = this.inputData;
+		String managerName = this.getManagerName();
 
 		if(info != null){
-			String[] args = { info.getMonitorId() };
+			String[] args = { info.getMonitorId(), managerName };
+			MonitorSettingEndpointWrapper wrapper = MonitorSettingEndpointWrapper.getWrapper(managerName);
 			if(!this.updateFlg){
 				// 作成の場合
 				try {
-					result = MonitorSettingEndpointWrapper.addMonitor(info);
+					result = wrapper.addMonitor(info);
 
 					if(result){
 						MessageDialog.openInformation(
@@ -542,7 +566,7 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 				// 変更の場合
 				String errMessage = "";
 				try {
-					result = MonitorSettingEndpointWrapper.modifyMonitor(info);
+					result = wrapper.modifyMonitor(info);
 				} catch (InvalidRole_Exception e) {
 					// アクセス権なしの場合、エラーダイアログを表示する
 					MessageDialog.openInformation(
@@ -582,7 +606,7 @@ public class WinEventDialog extends CommonMonitorStringDialog {
 		}
 	}
 
-	private static List<Integer> commaSeparatedStringToIntegerList(String string) throws HinemosUnknown {
+	private static List<Integer> commaSeparatedStringToIntegerList(String string) throws HinemosUnknown{
 		String[] numbers = string.split("\\s*,\\s*");
 		ArrayList<Integer> list = new ArrayList<Integer>();
 		try{
