@@ -21,7 +21,6 @@ import javax.persistence.Cacheable;
 import javax.persistence.CascadeType;
 import javax.persistence.Column;
 import javax.persistence.Entity;
-import javax.persistence.EntityManager;
 import javax.persistence.FetchType;
 import javax.persistence.Id;
 import javax.persistence.OneToMany;
@@ -29,6 +28,7 @@ import javax.persistence.OneToOne;
 import javax.persistence.PrimaryKeyJoinColumn;
 import javax.persistence.Table;
 
+import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
 
@@ -38,7 +38,7 @@ import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
  * 
  */
 @Entity
-@Table(name="cc_monitor_winevent_info")
+@Table(name="cc_monitor_winevent_info", schema="setting")
 @Cacheable(true)
 public class MonitorWinEventInfoEntity implements Serializable {
 	private static final long serialVersionUID = 1L;
@@ -61,7 +61,7 @@ public class MonitorWinEventInfoEntity implements Serializable {
 
 	public MonitorWinEventInfoEntity(MonitorInfoEntity monitorInfoEntity) {
 		this.setMonitorId(monitorInfoEntity.getMonitorId());
-		EntityManager em = new JpaTransactionManager().getEntityManager();
+		HinemosEntityManager em = new JpaTransactionManager().getEntityManager();
 		em.persist(this);
 		this.relateToMonitorInfoEntity(monitorInfoEntity);
 	}
