@@ -15,9 +15,6 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.winservice.factory;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.monitor.run.factory.SelectMonitor;
 import com.clustercontrol.winservice.bean.WinServiceCheckInfo;
@@ -32,8 +29,6 @@ import com.clustercontrol.winservice.util.QueryUtil;
  */
 public class SelectMonitorWinService extends SelectMonitor{
 
-	private static Log m_log = LogFactory.getLog(SelectMonitorWinService.class);
-
 	/* (非 Javadoc)
 	 * @see com.clustercontrol.monitor.run.factory.SelectMonitor#getCheckInfo()
 	 */
