@@ -14,8 +14,10 @@ package com.clustercontrol.ws.agent;
 
 import java.io.File;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Iterator;
+import java.util.List;
 import java.util.StringTokenizer;
 
 import javax.activation.DataHandler;
@@ -23,27 +25,28 @@ import javax.activation.FileDataSource;
 import javax.annotation.Resource;
 import javax.xml.bind.annotation.XmlMimeType;
 import javax.xml.ws.WebServiceContext;
+import javax.xml.ws.soap.MTOM;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-import com.clustercontrol.fault.FacilityNotFound;
-import com.clustercontrol.fault.HinemosUnknown;
-import com.clustercontrol.fault.InvalidRole;
-import com.clustercontrol.fault.InvalidUserPass;
-import com.clustercontrol.fault.JobInfoNotFound;
-import com.clustercontrol.fault.CustomInvalid;
-import com.clustercontrol.fault.JobMasterNotFound;
-import com.clustercontrol.fault.JobSessionDuplicate;
-import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.accesscontrol.bean.FunctionConstant;
-import com.clustercontrol.accesscontrol.bean.SystemPrivilegeInfo;
 import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.SystemPrivilegeMode;
+import com.clustercontrol.accesscontrol.bean.SystemPrivilegeInfo;
 import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.commons.bean.SettingUpdateInfo;
 import com.clustercontrol.custom.bean.CommandExecuteDTO;
 import com.clustercontrol.custom.bean.CommandResultDTO;
 import com.clustercontrol.custom.session.MonitorCustomControllerBean;
+import com.clustercontrol.fault.CustomInvalid;
+import com.clustercontrol.fault.FacilityNotFound;
+import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.InvalidRole;
+import com.clustercontrol.fault.InvalidUserPass;
+import com.clustercontrol.fault.JobInfoNotFound;
+import com.clustercontrol.fault.JobMasterNotFound;
+import com.clustercontrol.fault.JobSessionDuplicate;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.hinemosagent.bean.AgentInfo;
 import com.clustercontrol.hinemosagent.bean.AgentOutputBasicInfo;
 import com.clustercontrol.hinemosagent.bean.HinemosTopicInfo;
@@ -55,23 +58,24 @@ import com.clustercontrol.jobmanagement.bean.JobTriggerTypeConstant;
 import com.clustercontrol.jobmanagement.bean.RunResultInfo;
 import com.clustercontrol.jobmanagement.session.JobControllerBean;
 import com.clustercontrol.jobmanagement.session.JobRunManagementBean;
+import com.clustercontrol.logfile.bean.LogfileResultDTO;
 import com.clustercontrol.logfile.session.MonitorLogfileControllerBean;
 import com.clustercontrol.monitor.run.bean.MonitorInfo;
 import com.clustercontrol.monitor.run.bean.MonitorStringValueInfo;
 import com.clustercontrol.notify.bean.OutputBasicInfo;
 import com.clustercontrol.repository.factory.FacilitySelector;
+import com.clustercontrol.repository.factory.NodeProperty;
 import com.clustercontrol.repository.session.RepositoryControllerBean;
-import com.clustercontrol.systemlog.bean.SyslogMessage;
 import com.clustercontrol.systemlog.service.MessageInfo;
-import com.clustercontrol.systemlog.service.SystemLogMonitor;
-import com.clustercontrol.systemlog.service.SystemLogNotifier;
 import com.clustercontrol.util.apllog.AplLogger;
+import com.clustercontrol.winevent.bean.WinEventResultDTO;
 import com.clustercontrol.winevent.session.MonitorWinEventControllerBean;
 import com.clustercontrol.ws.util.HttpAuthenticator;
 
 /**
  * ジョブ操作用のWebAPIエンドポイント
  */
+@MTOM
 @javax.jws.WebService(targetNamespace = "http://agent.ws.clustercontrol.com")
 public class AgentEndpoint {
 	@Resource
@@ -81,9 +85,9 @@ public class AgentEndpoint {
 
 	/**
 	 * echo(WebサービスAPI疎通用)
-	 * 
+	 *
 	 * 権限必要なし（ユーザ名チェックのみ実施）
-	 * 
+	 *
 	 * @param str
 	 * @return
 	 * @throws InvalidUserPass
@@ -100,9 +104,9 @@ public class AgentEndpoint {
 	/**
 	 * [Agent Base] エージェントからwebサービスで利用。
 	 * エージェントから取得要請のあるものをまとめて返す。
-	 * 
+	 *
 	 * HinemosAgentAccess権限が必要
-	 * 
+	 *
 	 * @param agentInfo
 	 * @return
 	 * @throws InvalidRole
@@ -112,7 +116,7 @@ public class AgentEndpoint {
 	public HinemosTopicInfo getHinemosTopic (AgentInfo agentInfo) throws HinemosUnknown, InvalidUserPass, InvalidRole
 	{
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		HinemosTopicInfo hinemosTopicInfo = new HinemosTopicInfo();
@@ -137,6 +141,19 @@ public class AgentEndpoint {
 			}
 		}
 
+		int awakePort = 0;
+		for (String facilityId : facilityIdList) {
+			try {
+				int tmp = NodeProperty.getProperty(facilityId).getAgentAwakePort();
+				if (awakePort != 0 && tmp != awakePort) {
+					m_log.warn("getHinemosTopic() different awake port " + tmp); 
+				}
+				awakePort = tmp;
+				hinemosTopicInfo.setAwakePort(awakePort);
+			} catch (FacilityNotFound e) {
+				m_log.info("getHinemosTopic() : FacilityNotFound " + facilityId); 
+			}
+		}
 		hinemosTopicInfo.setTopicInfoList(topicInfoList);
 
 		// SettingUpdateInfo を設定
@@ -149,9 +166,9 @@ public class AgentEndpoint {
 	/**
 	 * [Agent Base] エージェントからwebサービスで利用。
 	 * エージェントがシャットダウンする際に利用。(shutdownhook に登録)
-	 * 
+	 *
 	 * HinemosAgentAccess権限が必要
-	 * 
+	 *
 	 * @param agentInfo
 	 * @return
 	 * @throws InvalidRole
@@ -160,21 +177,21 @@ public class AgentEndpoint {
 	 */
 	public void deleteAgent (AgentInfo agentInfo) throws HinemosUnknown, InvalidUserPass, InvalidRole {
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		ArrayList<String> facilityIdList = getFacilityId(agentInfo);
 		for (String facilityId : facilityIdList) {
 			m_log.info("deleteAgent " + facilityId + " is shutdown");
-			AgentConnectUtil.deleteAgent(facilityId);
+			AgentConnectUtil.deleteAgent(facilityId, agentInfo);
 		}
 	}
 
 	/**
 	 * [Agent Base] Internalイベントに出力する際に利用する。
-	 * 
+	 *
 	 * HinemosAgentAccess権限が必要
-	 * 
+	 *
 	 * @param message
 	 * @throws HinemosUnknown
 	 * @throws FacilityNotFound
@@ -185,7 +202,7 @@ public class AgentEndpoint {
 			throws HinemosUnknown, FacilityNotFound,
 			InvalidUserPass, InvalidRole {
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		ArrayList<String> facilityIdList = getFacilityId(message.getAgentInfo());
@@ -203,7 +220,7 @@ public class AgentEndpoint {
 
 	/**
 	 * [Agent Base] AgentInfoからFacilityIdのリストを取得する。
-	 * 
+	 *
 	 * @param agentInfo
 	 * @return
 	 * @throws HinemosUnknown
@@ -250,9 +267,9 @@ public class AgentEndpoint {
 
 	/**
 	 * [Job] ジョブの結果を送信する。
-	 * 
+	 *
 	 * HinemosAgentAccess権限が必要
-	 * 
+	 *
 	 * @param info
 	 * @throws HinemosUnknown
 	 * @throws InvalidRole
@@ -271,7 +288,7 @@ public class AgentEndpoint {
 				info.getFacilityId() + ", "
 				);
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		return new JobRunManagementBean().endNode(info);
@@ -279,9 +296,9 @@ public class AgentEndpoint {
 
 	/**
 	 * [Logfile] ログファイル監視の監視設定を取得
-	 * 
+	 *
 	 * HinemosAgentAccess権限が必要
-	 * 
+	 *
 	 * @param agentInfo
 	 * @return
 	 * @throws HinemosUnknown
@@ -293,7 +310,7 @@ public class AgentEndpoint {
 	{
 		m_log.debug("getMonitorLogFile : " + agentInfo);
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 		ArrayList<String> facilityIdList = new ArrayList<String>();
 
@@ -327,9 +344,9 @@ public class AgentEndpoint {
 
 	/**
 	 * [JobFileCheck] ファイルチェック(ジョブ)の設定を取得
-	 * 
+	 *
 	 * HinemosAgentAccess権限が必要
-	 * 
+	 *
 	 * @param agentInfo
 	 * @return
 	 * @throws HinemosUnknown
@@ -341,7 +358,7 @@ public class AgentEndpoint {
 	{
 		m_log.debug("getFileCheckForAgent : " + agentInfo);
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 		ArrayList<String> facilityIdList = new ArrayList<String>();
 
@@ -371,9 +388,9 @@ public class AgentEndpoint {
 
 	/**
 	 * [JobFileCheck] ファイルチェック(ジョブ)の結果
-	 * 
+	 *
 	 * HinemosAgentAccess権限が必要
-	 * 
+	 *
 	 * @param jobFileCheck
 	 * @return
 	 * @throws HinemosUnknown
@@ -389,18 +406,20 @@ public class AgentEndpoint {
 		String jobunitId = jobFileCheck.getJobunitId();
 		String jobId = jobFileCheck.getJobId();
 		String filename = jobFileCheck.getFileName();
+		String directory = jobFileCheck.getDirectory();
 		Integer eventType = jobFileCheck.getEventType();
 		Integer modifyType = jobFileCheck.getModifyType();
 		m_log.info("jobFileCheckResult : id=" + id + ", jobunitId=" + jobunitId + ", jobId=" + jobId
-				+ ", filename=" + filename + ", eventType=" + eventType + ", modifyType=" + modifyType);
+				+ ", filename=" + filename + ", directory=" + directory + ", eventType=" + eventType + ", modifyType=" + modifyType);
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		JobTriggerInfo trigger = new JobTriggerInfo();
 		trigger.setTrigger_type(JobTriggerTypeConstant.TYPE_FILECHECK);
 		trigger.setTrigger_info(jobFileCheck.getName() + "(" + id + ") file=" + filename);
 		trigger.setFilename(filename);
+		trigger.setDirectory(directory);
 		OutputBasicInfo output = null;
 		String sessionId = null;
 		for (String facilityId : getFacilityId(agentInfo)) {
@@ -416,6 +435,7 @@ public class AgentEndpoint {
 					AplLogger apllog = new AplLogger(HinemosModuleConstant.JOB, "job");
 					String[] args = { jobId, trigger.getTrigger_info() };
 					apllog.put("SYS", "017", args);
+					throw new HinemosUnknown(e.getMessage(), e);
 				}
 			}
 		}
@@ -424,9 +444,9 @@ public class AgentEndpoint {
 
 	/**
 	 * [WinEvent] Windowsイベント監視の監視設定を取得
-	 * 
+	 *
 	 * HinemosAgentAccess権限が必要
-	 * 
+	 *
 	 * @param agentInfo
 	 * @return
 	 * @throws HinemosUnknown
@@ -438,7 +458,7 @@ public class AgentEndpoint {
 	{
 		m_log.debug("getMonitorWinEvent : " + agentInfo);
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 		ArrayList<String> facilityIdList = new ArrayList<String>();
 
@@ -472,19 +492,20 @@ public class AgentEndpoint {
 
 	/**
 	 * [Logfile] ログファイル監視でマッチしたものに対して通知をマネージャに依頼する。
-	 * 
+	 *
 	 * HinemosAgentAccess権限が必要
-	 * 
+	 *
 	 * @throws HinemosUnknown
 	 * @throws InvalidRole
 	 * @throws InvalidUserPass
 	 */
+	@Deprecated
 	public void sendNotify(String message, MessageInfo logmsg,
 			MonitorInfo monitorInfo, MonitorStringValueInfo rule, AgentInfo agentInfo) throws HinemosUnknown, InvalidRole, InvalidUserPass {
 
 		m_log.debug("sendNotify : " + message);
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		for (String logFacilityId : getFacilityId(agentInfo)) {
@@ -498,23 +519,19 @@ public class AgentEndpoint {
 				m_log.debug("facilityId=" + logFacilityId + ", (" + str + ")");
 			}
 			if (facilityList.contains(logFacilityId)) {
-				SyslogMessage syslog = new SyslogMessage();
-				syslog.date = logmsg.getGenerationDate();
-				syslog.hostname = logmsg.getHostName();
-				syslog.message = logmsg.getMessage();
-				syslog.rawSyslog = message;
-				new SystemLogNotifier().put(SystemLogMonitor._receiverId, syslog, monitorInfo, rule, logFacilityId);
+				new MonitorLogfileControllerBean().run(logFacilityId, Arrays.asList(new LogfileResultDTO(message, logmsg, monitorInfo, rule)));
 			} else {
 				m_log.debug("sendNotify facilityId=" + logFacilityId + ", " + str);
 			}
 		}
 	}
+	
 
 	/**
 	 * [Command Monitor] コマンド実行情報を問い合わせられた場合にコールされるメソッドであり、問い合わせたエージェントが実行すべきコマンド実行情報を返す。
-	 * 
+	 *
 	 * HinemosAgentAccess権限が必要
-	 * 
+	 *
 	 * @param agentInfo メソッドをコールしたエージェント情報
 	 * @return コマンド実行情報の一覧
 	 * @throws CustomInvalid コマンド監視設定に不整合が見つかった場合にスローされる例外
@@ -527,7 +544,7 @@ public class AgentEndpoint {
 			InvalidUserPass, InvalidRole
 			{
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		// Local Variables
@@ -546,38 +563,97 @@ public class AgentEndpoint {
 			}
 
 	/**
-	 * [Command Monitor] コマンド監視において、コマンドの実行結果をマネージャに通知する。
-	 * 
+	 * [Custom Monitor] コマンド監視において、コマンドの実行結果をマネージャに通知する。
+	 *
 	 * HinemosAgentAccess権限が必要
-	 * 
+	 *
 	 * @param result コマンドの実行結果
 	 * @throws InvalidRole
 	 * @throws InvalidUserPass
 	 * @throws HinemosUnknown
 	 */
+	@Deprecated
 	public void putCommandResultDTO(CommandResultDTO result) throws InvalidUserPass, InvalidRole, HinemosUnknown
+	{
+		forwardCustomResult(Arrays.asList(result));
+	}
+	
+	/**
+	 * [Custom Monitor] コマンド監視において、コマンドの実行結果をまとめてマネージャに通知する。
+	 * 1 HTTP Requestで多数のコマンド実行結果を送信できるため、リソース観点から効率的に処理できる。
+	 *
+	 * HinemosAgentAccess権限が必要
+	 *
+	 * @param resultList コマンドの実行結果のリスト
+	 * @throws InvalidRole
+	 * @throws InvalidUserPass
+	 * @throws HinemosUnknown
+	 */
+	public void forwardCustomResult(List<CommandResultDTO> resultList)  throws InvalidUserPass, InvalidRole, HinemosUnknown
 	{
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		// MAIN
 		try {
-			new MonitorCustomControllerBean().CustomResultDTO(result);
+			new MonitorCustomControllerBean().evalCommandResult(resultList);
 		} catch (MonitorNotFound e) {
 			m_log.warn("monitor not found...", e);
 		} catch (HinemosUnknown e) {
 			m_log.warn("unexpected internal failure occurred...", e);
+			throw e;
 		} catch (CustomInvalid e) {
 			m_log.warn("configuration of command monitor is not valid...", e);
 		}
 	}
+	
+
+	/**
+	 * [Logfile] ログファイル監視でマッチしたものに対して通知をマネージャに依頼する。
+	 * 1 HTTP Requestで多数の監視実行結果を送信できるため、リソース観点から効率的に処理できる。
+	 *
+	 * HinemosAgentAccess権限が必要
+	 *
+	 * @throws HinemosUnknown
+	 * @throws InvalidRole
+	 * @throws InvalidUserPass
+	 */
+	public void forwardLogfileResult(List<LogfileResultDTO> resultList, AgentInfo agentInfo) throws InvalidUserPass, InvalidRole, HinemosUnknown {
+		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.MODIFY));
+		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
+		
+		for (String facilityId : getFacilityId(agentInfo)) {
+			new MonitorLogfileControllerBean().run(facilityId, resultList);
+		}
+	}
+	
+	/**
+	 * [WinEvent] Windowsイベント監視でマッチしたものに対して通知をマネージャに依頼する。
+	 * 1 HTTP Requestで多数の監視実行結果を送信できるため、リソース観点から効率的に処理できる。
+	 *
+	 * HinemosAgentAccess権限が必要
+	 *
+	 * @throws HinemosUnknown
+	 * @throws InvalidRole
+	 * @throws InvalidUserPass
+	 */
+	public void forwardWinEventResult(List<WinEventResultDTO> resultList, AgentInfo agentInfo) throws InvalidUserPass, InvalidRole, HinemosUnknown {
+		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.MODIFY));
+		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
+		
+		for (String facilityId : getFacilityId(agentInfo)) {
+			new MonitorWinEventControllerBean().run(facilityId, resultList);
+		}
+	}
 
 	/**
 	 * [Update] 新モジュールを取得
-	 * 
+	 *
 	 * HinemosAgentAccess権限が必要
-	 * 
+	 *
 	 * @throws HinemosUnknown
 	 * @throws InvalidRole
 	 * @throws InvalidUserPass
@@ -586,7 +662,7 @@ public class AgentEndpoint {
 	public DataHandler downloadModule(String filename) throws InvalidUserPass, InvalidRole, HinemosUnknown
 	{
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		String filepath= "/opt/hinemos/lib/agent/" + filename;
@@ -602,9 +678,9 @@ public class AgentEndpoint {
 
 	/**
 	 * [Update] モジュール一覧を取得
-	 * 
+	 *
 	 * HinemosAgentAccess権限が必要
-	 * 
+	 *
 	 * @return
 	 * @throws HinemosUnknown
 	 * @throws InvalidRole
@@ -612,7 +688,7 @@ public class AgentEndpoint {
 	 */
 	public ArrayList<String> getAgentLibMap() throws HinemosUnknown, InvalidRole, InvalidUserPass {
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		// TODO HashMapが利用できないのでArrayList<String>で実装。
@@ -628,13 +704,13 @@ public class AgentEndpoint {
 
 	/**
 	 * [Update] ファイル名とMD5の組をマネージャに登録しておく。
-	 * 
+	 *
 	 * HinemosAgentAccess権限が必要
-	 * 
+	 *
 	 * TODO
 	 * ArrayList<String>ではなく、HashMap<String, String>にしたい。
 	 * 要調査。
-	 * 
+	 *
 	 * @param filenameMd5
 	 * @param agentInto
 	 * @throws HinemosUnknown
@@ -643,7 +719,7 @@ public class AgentEndpoint {
 	 */
 	public void setAgentLibMd5(ArrayList<String> filenameMd5, AgentInfo agentInfo) throws InvalidUserPass, InvalidRole, HinemosUnknown {
 		ArrayList<SystemPrivilegeInfo> systemPrivilegeList = new ArrayList<SystemPrivilegeInfo>();
-		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.WRITE));
+		systemPrivilegeList.add(new SystemPrivilegeInfo(FunctionConstant.HINEMOS_AGENT, SystemPrivilegeMode.MODIFY));
 		HttpAuthenticator.authCheck(wsctx, systemPrivilegeList);
 
 		HashMap<String, String> map = new HashMap<String, String>();
